# This file is auto-generated by pyrandyos/gui/icons/update_from_spec.py  # noqa: E501
# Do not edit.
add = 60000
plus = 60000
gist_new = 60000
repo_create = 60000
lightbulb = 60001
light_bulb = 60001
repo = 60002
repo_delete = 60002
gist_fork = 60003
repo_forked = 60003
git_pull_request = 60004
git_pull_request_abandoned = 60004
record_keys = 60005
keyboard = 60005
tag = 60006
git_pull_request_label = 60006
tag_add = 60006
tag_remove = 60006
person = 60007
person_follow = 60007
person_outline = 60007
person_filled = 60007
git_branch = 60008
git_branch_create = 60008
git_branch_delete = 60008
source_control = 60008
mirror = 60009
mirror_public = 60009
star = 60010
star_add = 60010
star_delete = 60010
star_empty = 60010
comment = 60011
comment_add = 60011
alert = 60012
warning = 60012
search = 60013
search_save = 60013
log_out = 60014
sign_out = 60014
log_in = 60015
sign_in = 60015
eye = 60016
eye_unwatch = 60016
eye_watch = 60016
circle_filled = 60017
primitive_dot = 60017
close_dirty = 60017
debug_breakpoint = 60017
debug_breakpoint_disabled = 60017
debug_hint = 60017
terminal_decoration_success = 60017
primitive_square = 60018
edit = 60019
pencil = 60019
info = 60020
issue_opened = 60020
gist_private = 60021
git_fork_private = 60021
lock = 60021
mirror_private = 60021
close = 60022
remove_close = 60022
x = 60022
repo_sync = 60023
sync = 60023
clone = 60024
desktop_download = 60024
beaker = 60025
microscope = 60025
vm = 60026
device_desktop = 60026
file = 60027
file_text = 60027
more = 60028
ellipsis = 60028
kebab_horizontal = 60028
mail_reply = 60029
reply = 60029
organization = 60030
organization_filled = 60030
organization_outline = 60030
new_file = 60031
file_add = 60031
new_folder = 60032
file_directory_create = 60032
trash = 60033
trashcan = 60033
history = 60034
clock = 60034
folder = 60035
file_directory = 60035
symbol_folder = 60035
logo_github = 60036
mark_github = 60036
github = 60036
terminal = 60037
console = 60037
repl = 60037
zap = 60038
symbol_event = 60038
error = 60039
stop = 60039
variable = 60040
symbol_variable = 60040
array = 60042
symbol_array = 60042
symbol_module = 60043
symbol_package = 60043
symbol_namespace = 60043
symbol_object = 60043
symbol_method = 60044
symbol_function = 60044
symbol_constructor = 60044
symbol_boolean = 60047
symbol_null = 60047
symbol_numeric = 60048
symbol_number = 60048
symbol_structure = 60049
symbol_struct = 60049
symbol_parameter = 60050
symbol_type_parameter = 60050
symbol_key = 60051
symbol_text = 60051
symbol_reference = 60052
go_to_file = 60052
symbol_enum = 60053
symbol_value = 60053
symbol_ruler = 60054
symbol_unit = 60054
activate_breakpoints = 60055
archive = 60056
arrow_both = 60057
arrow_down = 60058
arrow_left = 60059
arrow_right = 60060
arrow_small_down = 60061
arrow_small_left = 60062
arrow_small_right = 60063
arrow_small_up = 60064
arrow_up = 60065
bell = 60066
bold = 60067
book = 60068
bookmark = 60069
debug_breakpoint_conditional_unverified = 60070
debug_breakpoint_conditional = 60071
debug_breakpoint_conditional_disabled = 60071
debug_breakpoint_data_unverified = 60072
debug_breakpoint_data = 60073
debug_breakpoint_data_disabled = 60073
debug_breakpoint_log_unverified = 60074
debug_breakpoint_log = 60075
debug_breakpoint_log_disabled = 60075
briefcase = 60076
broadcast = 60077
browser = 60078
bug = 60079
calendar = 60080
case_sensitive = 60081
check = 60082
checklist = 60083
chevron_down = 60084
chevron_left = 60085
chevron_right = 60086
chevron_up = 60087
chrome_close = 60088
chrome_maximize = 60089
chrome_minimize = 60090
chrome_restore = 60091
circle_outline = 60092
circle = 60092
debug_breakpoint_unverified = 60092
terminal_decoration_incomplete = 60092
circle_slash = 60093
circuit_board = 60094
clear_all = 60095
clippy = 60096
close_all = 60097
cloud_download = 60098
cloud_upload = 60099
code = 60100
collapse_all = 60101
color_mode = 60102
comment_discussion = 60103
credit_card = 60105
dash = 60108
dashboard = 60109
database = 60110
debug_continue = 60111
debug_disconnect = 60112
debug_pause = 60113
debug_restart = 60114
debug_start = 60115
debug_step_into = 60116
debug_step_out = 60117
debug_step_over = 60118
debug_stop = 60119
debug = 60120
device_camera_video = 60121
device_camera = 60122
device_mobile = 60123
diff_added = 60124
diff_ignored = 60125
diff_modified = 60126
diff_removed = 60127
diff_renamed = 60128
diff = 60129
diff_sidebyside = 60129
discard = 60130
editor_layout = 60131
empty_window = 60132
exclude = 60133
extensions = 60134
eye_closed = 60135
file_binary = 60136
file_code = 60137
file_media = 60138
file_pdf = 60139
file_submodule = 60140
file_symlink_directory = 60141
file_symlink_file = 60142
file_zip = 60143
files = 60144
filter = 60145
flame = 60146
fold_down = 60147
fold_up = 60148
fold = 60149
folder_active = 60150
folder_opened = 60151
gear = 60152
gift = 60153
gist_secret = 60154
gist = 60155
git_commit = 60156
git_compare = 60157
compare_changes = 60157
git_merge = 60158
github_action = 60159
github_alt = 60160
globe = 60161
grabber = 60162
graph = 60163
gripper = 60164
heart = 60165
home = 60166
horizontal_rule = 60167
hubot = 60168
inbox = 60169
issue_reopened = 60171
issues = 60172
italic = 60173
jersey = 60174
json = 60175
kebab_vertical = 60176
key = 60177
law = 60178
lightbulb_autofix = 60179
link_external = 60180
link = 60181
list_ordered = 60182
list_unordered = 60183
live_share = 60184
loading = 60185
location = 60186
mail_read = 60187
mail = 60188
markdown = 60189
megaphone = 60190
mention = 60191
milestone = 60192
git_pull_request_milestone = 60192
mortar_board = 60193
move = 60194
multiple_windows = 60195
mute = 60196
no_newline = 60197
note = 60198
octoface = 60199
open_preview = 60200
package = 60201
paintcan = 60202
pin = 60203
play = 60204
run = 60204
plug = 60205
preserve_case = 60206
preview = 60207
project = 60208
pulse = 60209
question = 60210
quote = 60211
radio_tower = 60212
reactions = 60213
references = 60214
refresh = 60215
regex = 60216
remote_explorer = 60217
remote = 60218
remove = 60219
replace_all = 60220
replace = 60221
repo_clone = 60222
repo_force_push = 60223
repo_pull = 60224
repo_push = 60225
report = 60226
request_changes = 60227
rocket = 60228
root_folder_opened = 60229
root_folder = 60230
rss = 60231
ruby = 60232
save_all = 60233
save_as = 60234
save = 60235
screen_full = 60236
screen_normal = 60237
search_stop = 60238
server = 60240
settings_gear = 60241
settings = 60242
shield = 60243
smiley = 60244
sort_precedence = 60245
split_horizontal = 60246
split_vertical = 60247
squirrel = 60248
star_full = 60249
star_half = 60250
symbol_class = 60251
symbol_color = 60252
symbol_constant = 60253
symbol_enum_member = 60254
symbol_field = 60255
symbol_file = 60256
symbol_interface = 60257
symbol_keyword = 60258
symbol_misc = 60259
symbol_operator = 60260
symbol_property = 60261
wrench = 60261
wrench_subaction = 60261
symbol_snippet = 60262
tasklist = 60263
telescope = 60264
text_size = 60265
three_bars = 60266
thumbsdown = 60267
thumbsup = 60268
tools = 60269
triangle_down = 60270
triangle_left = 60271
triangle_right = 60272
triangle_up = 60273
twitter = 60274
unfold = 60275
unlock = 60276
unmute = 60277
unverified = 60278
verified = 60279
versions = 60280
vm_active = 60281
vm_outline = 60282
vm_running = 60283
watch = 60284
whitespace = 60285
whole_word = 60286
window = 60287
word_wrap = 60288
zoom_in = 60289
zoom_out = 60290
list_filter = 60291
list_flat = 60292
list_selection = 60293
selection = 60293
list_tree = 60294
debug_breakpoint_function_unverified = 60295
debug_breakpoint_function = 60296
debug_breakpoint_function_disabled = 60296
debug_stackframe_active = 60297
circle_small_filled = 60298
debug_stackframe_dot = 60298
terminal_decoration_mark = 60298
debug_stackframe = 60299
debug_stackframe_focused = 60299
debug_breakpoint_unsupported = 60300
symbol_string = 60301
debug_reverse_continue = 60302
debug_step_back = 60303
debug_restart_frame = 60304
debug_alt = 60305
call_incoming = 60306
call_outgoing = 60307
menu = 60308
expand_all = 60309
feedback = 60310
git_pull_request_reviewer = 60310
group_by_ref_type = 60311
ungroup_by_ref_type = 60312
account = 60313
git_pull_request_assignee = 60313
bell_dot = 60314
debug_console = 60315
library = 60316
output = 60317
run_all = 60318
sync_ignored = 60319
pinned = 60320
github_inverted = 60321
server_process = 60322
server_environment = 60323
pass_ = 60324
issue_closed = 60324
stop_circle = 60325
play_circle = 60326
record = 60327
debug_alt_small = 60328
vm_connect = 60329
cloud = 60330
merge = 60331
export = 60332
graph_left = 60333
magnet = 60334
notebook = 60335
redo = 60336
check_all = 60337
pinned_dirty = 60338
pass_filled = 60339
circle_large_filled = 60340
circle_large = 60341
circle_large_outline = 60341
combine = 60342
gather = 60342
table = 60343
variable_group = 60344
type_hierarchy = 60345
type_hierarchy_sub = 60346
type_hierarchy_super = 60347
git_pull_request_create = 60348
run_above = 60349
run_below = 60350
notebook_template = 60351
debug_rerun = 60352
workspace_trusted = 60353
workspace_untrusted = 60354
workspace_unknown = 60355
terminal_cmd = 60356
terminal_debian = 60357
terminal_linux = 60358
terminal_powershell = 60359
terminal_tmux = 60360
terminal_ubuntu = 60361
terminal_bash = 60362
arrow_swap = 60363
copy = 60364
person_add = 60365
filter_filled = 60366
wand = 60367
debug_line_by_line = 60368
inspect = 60369
layers = 60370
layers_dot = 60371
layers_active = 60372
compass = 60373
compass_dot = 60374
compass_active = 60375
azure = 60376
issue_draft = 60377
git_pull_request_closed = 60378
git_pull_request_draft = 60379
debug_all = 60380
debug_coverage = 60381
run_errors = 60382
folder_library = 60383
debug_continue_small = 60384
beaker_stop = 60385
graph_line = 60386
graph_scatter = 60387
pie_chart = 60388
bracket = 60175
bracket_dot = 60389
bracket_error = 60390
lock_small = 60391
azure_devops = 60392
verified_filled = 60393
newline = 60394
layout = 60395
layout_activitybar_left = 60396
layout_activitybar_right = 60397
layout_panel_left = 60398
layout_panel_center = 60399
layout_panel_justify = 60400
layout_panel_right = 60401
layout_panel = 60402
layout_sidebar_left = 60403
layout_sidebar_right = 60404
layout_statusbar = 60405
layout_menubar = 60406
layout_centered = 60407
target = 60408
indent = 60409
record_small = 60410
error_small = 60411
terminal_decoration_error = 60411
arrow_circle_down = 60412
arrow_circle_left = 60413
arrow_circle_right = 60414
arrow_circle_up = 60415
layout_sidebar_right_off = 60416
layout_panel_off = 60417
layout_sidebar_left_off = 60418
blank = 60419
heart_filled = 60420
map = 60421
map_horizontal = 60421
fold_horizontal = 60421
map_filled = 60422
map_horizontal_filled = 60422
fold_horizontal_filled = 60422
circle_small = 60423
bell_slash = 60424
bell_slash_dot = 60425
comment_unresolved = 60426
git_pull_request_go_to_changes = 60427
git_pull_request_new_changes = 60428
search_fuzzy = 60429
comment_draft = 60430
send = 60431
sparkle = 60432
insert = 60433
mic = 60434
thumbsdown_filled = 60435
thumbsup_filled = 60436
coffee = 60437
snake = 60438
game = 60439
vr = 60440
chip = 60441
piano = 60442
music = 60443
mic_filled = 60444
repo_fetch = 60445
copilot = 60446
lightbulb_sparkle = 60447
robot = 60448
sparkle_filled = 60449
diff_single = 60450
diff_multiple = 60451
surround_with = 60452
share = 60453
git_stash = 60454
git_stash_apply = 60455
git_stash_pop = 60456
vscode = 60457
vscode_insiders = 60458
code_oss = 60459
run_coverage = 60460
run_all_coverage = 60461
coverage = 60462
github_project = 60463
map_vertical = 60464
fold_vertical = 60464
map_vertical_filled = 60465
fold_vertical_filled = 60465
go_to_search = 60466
percentage = 60467
sort_percentage = 60467
attach = 60468
go_to_editing_session = 60469
edit_session = 60470
code_review = 60471
copilot_warning = 60472
python = 60473
copilot_large = 60474
copilot_warning_large = 60475
keyboard_tab = 60476
copilot_blocked = 60477
copilot_not_connected = 60478
flag = 60479
lightbulb_empty = 60480
symbol_method_arrow = 60481
copilot_unavailable = 60482
repo_pinned = 60483
keyboard_tab_above = 60484
keyboard_tab_below = 60485
git_pull_request_done = 60486
mcp = 60487
extensions_large = 60488
layout_panel_dock = 60489
layout_sidebar_left_dock = 60490
layout_sidebar_right_dock = 60491
copilot_in_progress = 60492
copilot_error = 60493
copilot_success = 60494
chat_sparkle = 60495
search_sparkle = 60496
edit_sparkle = 60497
copilot_snooze = 60498
