# This file is auto-generated by pyrandyos/gui/icons/update_from_spec.py  # noqa: E501
# Do not edit.
address_book = 62137
address_card = 62139
angry = 62806
arrow_alt_circle_down = 62296
arrow_alt_circle_left = 62297
arrow_alt_circle_right = 62298
arrow_alt_circle_up = 62299
bell = 61683
bell_slash = 61942
bookmark = 61486
building = 61869
calendar = 61747
calendar_alt = 61555
calendar_check = 62068
calendar_minus = 62066
calendar_plus = 62065
calendar_times = 62067
caret_square_down = 61776
caret_square_left = 61841
caret_square_right = 61778
caret_square_up = 61777
chart_bar = 61568
check_circle = 61528
check_square = 61770
circle = 61713
clipboard = 62248
clock = 61463
clone = 62029
closed_captioning = 61962
comment = 61557
comment_alt = 62074
comment_dots = 62637
comments = 61574
compass = 61774
copy = 61637
copyright = 61945
credit_card = 61597
dizzy = 62823
dot_circle = 61842
edit = 61508
envelope = 61664
envelope_open = 62134
eye = 61550
eye_slash = 61552
file = 61787
file_alt = 61788
file_archive = 61894
file_audio = 61895
file_code = 61897
file_excel = 61891
file_image = 61893
file_pdf = 61889
file_powerpoint = 61892
file_video = 61896
file_word = 61890
flag = 61476
flushed = 62841
folder = 61563
folder_open = 61564
font_awesome_logo_full = 62694
frown = 61721
frown_open = 62842
futbol = 61923
gem = 62373
grimace = 62847
grin = 62848
grin_alt = 62849
grin_beam = 62850
grin_beam_sweat = 62851
grin_hearts = 62852
grin_squint = 62853
grin_squint_tears = 62854
grin_stars = 62855
grin_tears = 62856
grin_tongue = 62857
grin_tongue_squint = 62858
grin_tongue_wink = 62859
grin_wink = 62860
hand_lizard = 62040
hand_paper = 62038
hand_peace = 62043
hand_point_down = 61607
hand_point_left = 61605
hand_point_right = 61604
hand_point_up = 61606
hand_pointer = 62042
hand_rock = 62037
hand_scissors = 62039
hand_spock = 62041
handshake = 62133
hdd = 61600
heart = 61444
hospital = 61688
hourglass = 62036
id_badge = 62145
id_card = 62146
image = 61502
images = 62210
keyboard = 61724
kiss = 62870
kiss_beam = 62871
kiss_wink_heart = 62872
laugh = 62873
laugh_beam = 62874
laugh_squint = 62875
laugh_wink = 62876
lemon = 61588
life_ring = 61901
lightbulb = 61675
list_alt = 61474
map = 62073
meh = 61722
meh_blank = 62884
meh_rolling_eyes = 62885
minus_square = 61766
money_bill_alt = 62417
moon = 61830
newspaper = 61930
object_group = 62023
object_ungroup = 62024
paper_plane = 61912
pause_circle = 62091
play_circle = 61764
plus_square = 61694
question_circle = 61529
registered = 62045
sad_cry = 62899
sad_tear = 62900
save = 61639
share_square = 61773
smile = 61720
smile_beam = 62904
smile_wink = 62682
snowflake = 62172
square = 61640
star = 61445
star_half = 61577
sticky_note = 62025
stop_circle = 62093
sun = 61829
surprise = 62914
thumbs_down = 61797
thumbs_up = 61796
times_circle = 61527
tired = 62920
trash_alt = 62189
user = 61447
user_circle = 62141
window_close = 62480
window_maximize = 62160
window_minimize = 62161
window_restore = 62162
