# This file is auto-generated by pyrandyos/gui/icons/update_from_spec.py  # noqa: E501
# Do not edit.
address_book = 61698
address_book_alt = 61697
adjust = 61700
adjust_alt = 61699
adult = 61701
align_center = 61702
align_justify = 61703
align_left = 61704
align_right = 61705
arrow_down = 61706
arrow_left = 61707
arrow_right = 61708
arrow_up = 61709
asl = 61710
asterisk = 61711
backward = 61712
ban_circle = 61713
barcode = 61714
behance = 61715
bell = 61716
blind = 61717
blogger = 61718
bold = 61719
book = 61720
bookmark = 61722
bookmark_empty = 61721
braille = 61723
briefcase = 61724
broom = 61725
brush = 61726
bulb = 61727
bullhorn = 61728
calendar = 61730
calendar_sign = 61729
camera = 61731
car = 61732
caret_down = 61733
caret_left = 61734
caret_right = 61735
caret_up = 61736
cc = 61737
certificate = 61738
check = 61740
check_empty = 61739
chevron_down = 61741
chevron_left = 61742
chevron_right = 61743
chevron_up = 61744
child = 61745
circle_arrow_down = 61746
circle_arrow_left = 61747
circle_arrow_right = 61748
circle_arrow_up = 61749
cloud = 61751
cloud_alt = 61750
cog = 61753
cog_alt = 61752
cogs = 61754
comment = 61756
comment_alt = 61755
compass = 61758
compass_alt = 61757
credit_card = 61759
css = 61760
dashboard = 61761
delicious = 61762
deviantart = 61763
digg = 61764
download = 61766
download_alt = 61765
dribbble = 61767
edit = 61768
eject = 61769
envelope = 61771
envelope_alt = 61770
error = 61773
error_alt = 61772
eur = 61774
exclamation_sign = 61775
eye_close = 61776
eye_open = 61777
facebook = 61778
facetime_video = 61779
fast_backward = 61780
fast_forward = 61781
female = 61782
file = 61788
file_alt = 61783
file_edit = 61785
file_edit_alt = 61784
file_new = 61787
file_new_alt = 61786
film = 61789
filter = 61790
fire = 61791
flag = 61793
flag_alt = 61792
flickr = 61794
folder = 61798
folder_close = 61795
folder_open = 61796
folder_sign = 61797
font = 61799
fontsize = 61800
fork = 61801
forward = 61803
forward_alt = 61802
foursquare = 61804
friendfeed = 61806
friendfeed_rect = 61805
fullscreen = 61807
gbp = 61808
gift = 61809
github = 61811
github_text = 61810
glass = 61812
glasses = 61813
globe = 61815
globe_alt = 61814
googleplus = 61816
graph = 61818
graph_alt = 61817
group = 61820
group_alt = 61819
guidedog = 61821
hand_down = 61822
hand_left = 61823
hand_right = 61824
hand_up = 61825
hdd = 61826
headphones = 61827
hearing_impaired = 61828
heart = 61831
heart_alt = 61829
heart_empty = 61830
home = 61833
home_alt = 61832
hourglass = 61834
idea = 61836
idea_alt = 61835
inbox = 61839
inbox_alt = 61837
inbox_box = 61838
indent_left = 61840
indent_right = 61841
info_circle = 61842
instagram = 61843
iphone_home = 61844
italic = 61845
key = 61846
laptop = 61848
laptop_alt = 61847
lastfm = 61849
leaf = 61850
lines = 61851
link = 61852
linkedin = 61853
list = 61855
list_alt = 61854
livejournal = 61856
lock = 61858
lock_alt = 61857
magic = 61859
magnet = 61860
male = 61861
map_marker = 61863
map_marker_alt = 61862
mic = 61865
mic_alt = 61864
minus = 61867
minus_sign = 61866
move = 61868
music = 61869
myspace = 61870
network = 61871
off = 61872
ok = 61875
ok_circle = 61873
ok_sign = 61874
opensource = 61876
paper_clip = 61878
paper_clip_alt = 61877
path = 61879
pause = 61881
pause_alt = 61880
pencil = 61883
pencil_alt = 61882
person = 61884
phone = 61886
phone_alt = 61885
photo = 61888
photo_alt = 61887
picasa = 61889
picture = 61890
pinterest = 61891
plane = 61892
play = 61895
play_alt = 61893
play_circle = 61894
plurk = 61897
plurk_alt = 61896
plus = 61899
plus_sign = 61898
podcast = 61900
print = 61901
puzzle = 61902
qrcode = 61903
question = 61905
question_sign = 61904
quote_alt = 61906
quote_right = 61908
quote_right_alt = 61907
quotes = 61909
random = 61910
record = 61911
reddit = 61912
redux = 61913
refresh = 61914
remove = 61917
remove_circle = 61915
remove_sign = 61916
repeat = 61919
repeat_alt = 61918
resize_full = 61920
resize_horizontal = 61921
resize_small = 61922
resize_vertical = 61923
return_key = 61924
retweet = 61925
reverse_alt = 61926
road = 61927
rss = 61928
scissors = 61929
screen = 61931
screen_alt = 61930
screenshot = 61932
search = 61934
search_alt = 61933
share = 61936
share_alt = 61935
shopping_cart = 61938
shopping_cart_sign = 61937
signal = 61939
skype = 61940
slideshare = 61941
smiley = 61943
smiley_alt = 61942
soundcloud = 61944
speaker = 61945
spotify = 61946
stackoverflow = 61947
star = 61950
star_alt = 61948
star_empty = 61949
step_backward = 61951
step_forward = 61952
stop = 61954
stop_alt = 61953
stumbleupon = 61955
tag = 61956
tags = 61957
tasks = 61958
text_height = 61959
text_width = 61960
th = 61963
th_large = 61961
th_list = 61962
thumbs_down = 61964
thumbs_up = 61965
time = 61967
time_alt = 61966
tint = 61968
torso = 61969
trash = 61971
trash_alt = 61970
tumblr = 61972
twitter = 61973
universal_access = 61974
unlock = 61976
unlock_alt = 61975
upload = 61977
usd = 61978
user = 61979
viadeo = 61980
video = 61983
video_alt = 61981
video_chat = 61982
view_mode = 61984
vimeo = 61985
vkontakte = 61986
volume_down = 61987
volume_off = 61988
volume_up = 61989
w3c = 61990
warning_sign = 61991
website = 61993
website_alt = 61992
wheelchair = 61994
wordpress = 61995
wrench = 61997
wrench_alt = 61996
youtube = 61998
zoom_in = 61999
zoom_out = 62000
