# This file is auto-generated by pyrandyos/gui/icons/update_from_spec.py  # noqa: E501
# Do not edit.
_500px = 62062
accessible_icon = 62312
accusoft = 62313
acquisitions_incorporated = 63151
adn = 61808
adversal = 62314
affiliatetheme = 62315
airbnb = 63540
algolia = 62316
alipay = 63042
amazon = 62064
amazon_pay = 62508
amilia = 62317
android = 61819
angellist = 61961
angrycreative = 62318
angular = 62496
app_store = 62319
app_store_ios = 62320
apper = 62321
apple = 61817
apple_pay = 62485
artstation = 63354
asymmetrik = 62322
atlassian = 63355
audible = 62323
autoprefixer = 62492
avianex = 62324
aviato = 62497
aws = 62325
bandcamp = 62165
battle_net = 63541
behance = 61876
behance_square = 61877
bimobject = 62328
bitbucket = 61809
bitcoin = 62329
bity = 62330
black_tie = 62078
blackberry = 62331
blogger = 62332
blogger_b = 62333
bluetooth = 62099
bluetooth_b = 62100
bootstrap = 63542
btc = 61786
buffer = 63543
buromobelexperte = 62335
buy_n_large = 63654
buysellads = 61965
canadian_maple_leaf = 63365
cc_amazon_pay = 62509
cc_amex = 61939
cc_apple_pay = 62486
cc_diners_club = 62028
cc_discover = 61938
cc_jcb = 62027
cc_mastercard = 61937
cc_paypal = 61940
cc_stripe = 61941
cc_visa = 61936
centercode = 62336
centos = 63369
chrome = 62056
chromecast = 63544
cloudflare = 57469
cloudscale = 62339
cloudsmith = 62340
cloudversify = 62341
codepen = 61899
codiepie = 62084
confluence = 63373
connectdevelop = 61966
contao = 62061
cotton_bureau = 63646
cpanel = 62344
creative_commons = 62046
creative_commons_by = 62695
creative_commons_nc = 62696
creative_commons_nc_eu = 62697
creative_commons_nc_jp = 62698
creative_commons_nd = 62699
creative_commons_pd = 62700
creative_commons_pd_alt = 62701
creative_commons_remix = 62702
creative_commons_sa = 62703
creative_commons_sampling = 62704
creative_commons_sampling_plus = 62705
creative_commons_share = 62706
creative_commons_zero = 62707
critical_role = 63177
css3 = 61756
css3_alt = 62347
cuttlefish = 62348
d_and_d = 62349
d_and_d_beyond = 63178
dailymotion = 57426
dashcube = 61968
deezer = 57463
delicious = 61861
deploydog = 62350
deskpro = 62351
dev = 63180
deviantart = 61885
dhl = 63376
diaspora = 63377
digg = 61862
digital_ocean = 62353
discord = 62354
discourse = 62355
dochub = 62356
docker = 62357
draft2digital = 62358
dribbble = 61821
dribbble_square = 62359
dropbox = 61803
drupal = 61865
dyalog = 62361
earlybirds = 62362
ebay = 62708
edge = 62082
edge_legacy = 57464
elementor = 62512
ello = 62961
ember = 62499
empire = 61905
envira = 62105
erlang = 62365
ethereum = 62510
etsy = 62167
evernote = 63545
expeditedssl = 62014
facebook = 61594
facebook_f = 62366
facebook_messenger = 62367
facebook_square = 61570
fantasy_flight_games = 63196
fedex = 63383
fedora = 63384
figma = 63385
firefox = 62057
firefox_browser = 57351
first_order = 62128
first_order_alt = 62730
firstdraft = 62369
flickr = 61806
flipboard = 62541
fly = 62487
font_awesome = 62132
font_awesome_alt = 62300
font_awesome_flag = 62501
font_awesome_logo_full = 62694
fonticons = 62080
fonticons_fi = 62370
fort_awesome = 62086
fort_awesome_alt = 62371
forumbee = 61969
foursquare = 61824
free_code_camp = 62149
freebsd = 62372
fulcrum = 62731
galactic_republic = 62732
galactic_senate = 62733
get_pocket = 62053
gg = 62048
gg_circle = 62049
git = 61907
git_alt = 63553
git_square = 61906
github = 61595
github_alt = 61715
github_square = 61586
gitkraken = 62374
gitlab = 62102
gitter = 62502
glide = 62117
glide_g = 62118
gofore = 62375
goodreads = 62376
goodreads_g = 62377
google = 61856
google_drive = 62378
google_pay = 57465
google_play = 62379
google_plus = 62131
google_plus_g = 61653
google_plus_square = 61652
google_wallet = 61934
gratipay = 61828
grav = 62166
gripfire = 62380
grunt = 62381
guilded = 57470
gulp = 62382
hacker_news = 61908
hacker_news_square = 62383
hackerrank = 62967
hips = 62546
hire_a_helper = 62384
hive = 57471
hooli = 62503
hornbill = 62866
hotjar = 62385
houzz = 62076
html5 = 61755
hubspot = 62386
ideal = 57363
imdb = 62168
innosoft = 57472
instagram = 61805
instagram_square = 57429
instalod = 57473
intercom = 63407
internet_explorer = 62059
invision = 63408
ioxhost = 61960
itch_io = 63546
itunes = 62388
itunes_note = 62389
java = 62692
jedi_order = 62734
jenkins = 62390
jira = 63409
joget = 62391
joomla = 61866
js = 62392
js_square = 62393
jsfiddle = 61900
kaggle = 62970
keybase = 62709
keycdn = 62394
kickstarter = 62395
kickstarter_k = 62396
korvue = 62511
laravel = 62397
lastfm = 61954
lastfm_square = 61955
leanpub = 61970
less = 62493
line = 62400
linkedin = 61580
linkedin_in = 61665
linode = 62136
linux = 61820
lyft = 62403
magento = 62404
mailchimp = 62878
mandalorian = 62735
markdown = 62991
mastodon = 62710
maxcdn = 61750
mdb = 63690
medapps = 62406
medium = 62010
medium_m = 62407
medrt = 62408
meetup = 62176
megaport = 62883
mendeley = 63411
microblog = 57370
microsoft = 62410
mix = 62411
mixcloud = 62089
mixer = 57430
mizuni = 62412
modx = 62085
monero = 62416
napster = 62418
neos = 62994
nimblr = 62888
node = 62489
node_js = 62419
npm = 62420
ns8 = 62421
nutritionix = 62422
octopus_deploy = 57474
odnoklassniki = 62051
odnoklassniki_square = 62052
old_republic = 62736
opencart = 62013
openid = 61851
opera = 62058
optin_monster = 62012
orcid = 63698
osi = 62490
page4 = 62423
pagelines = 61836
palfed = 62424
patreon = 62425
paypal = 61933
penny_arcade = 63236
perbyte = 57475
periscope = 62426
phabricator = 62427
phoenix_framework = 62428
phoenix_squadron = 62737
php = 62551
pied_piper = 62126
pied_piper_alt = 61864
pied_piper_hat = 62693
pied_piper_pp = 61863
pied_piper_square = 57374
pinterest = 61650
pinterest_p = 62001
pinterest_square = 61651
playstation = 62431
product_hunt = 62088
pushed = 62433
python = 62434
qq = 61910
quinscape = 62553
quora = 62148
r_project = 62711
raspberry_pi = 63419
ravelry = 62169
react = 62491
reacteurope = 63325
readme = 62677
rebel = 61904
red_river = 62435
reddit = 61857
reddit_alien = 62081
reddit_square = 61858
redhat = 63420
renren = 61835
replyd = 62438
researchgate = 62712
resolving = 62439
rev = 62898
rocketchat = 62440
rockrms = 62441
rust = 57466
safari = 62055
salesforce = 63547
sass = 62494
schlix = 62442
scribd = 62090
searchengin = 62443
sellcast = 62170
sellsy = 61971
servicestack = 62444
shirtsinbulk = 61972
shopify = 57431
shopware = 62901
simplybuilt = 61973
sistrix = 62446
sith = 62738
sketch = 63430
skyatlas = 61974
skype = 61822
slack = 61848
slack_hash = 62447
slideshare = 61927
snapchat = 62123
snapchat_ghost = 62124
snapchat_square = 62125
soundcloud = 61886
sourcetree = 63443
speakap = 62451
speaker_deck = 63548
spotify = 61884
squarespace = 62910
stack_exchange = 61837
stack_overflow = 61804
stackpath = 63554
staylinked = 62453
steam = 61878
steam_square = 61879
steam_symbol = 62454
sticker_mule = 62455
strava = 62504
stripe = 62505
stripe_s = 62506
studiovinari = 62456
stumbleupon = 61860
stumbleupon_circle = 61859
superpowers = 62173
supple = 62457
suse = 63446
swift = 63713
symfony = 63549
teamspeak = 62713
telegram = 62150
telegram_plane = 62462
tencent_weibo = 61909
the_red_yeti = 63133
themeco = 62918
themeisle = 62130
think_peaks = 63281
tiktok = 57467
trade_federation = 62739
trello = 61825
tumblr = 61811
tumblr_square = 61812
twitch = 61928
twitter = 61593
twitter_square = 61569
typo3 = 62507
uber = 62466
ubuntu = 63455
uikit = 62467
umbraco = 63720
uncharted = 57476
uniregistry = 62468
unity = 57417
unsplash = 57468
untappd = 62469
ups = 63456
usb = 62087
usps = 63457
ussunnah = 62471
vaadin = 62472
viacoin = 62007
viadeo = 62121
viadeo_square = 62122
viber = 62473
vimeo = 62474
vimeo_square = 61844
vimeo_v = 62077
vine = 61898
vk = 61833
vnv = 62475
vuejs = 62495
watchman_monitoring = 57479
waze = 63551
weebly = 62924
weibo = 61834
weixin = 61911
whatsapp = 62002
whatsapp_square = 62476
whmcs = 62477
wikipedia_w = 62054
windows = 61818
wix = 62927
wizards_of_the_coast = 63280
wodu = 57480
wolf_pack_battalion = 62740
wordpress = 61850
wordpress_simple = 62481
wpbeginner = 62103
wpexplorer = 62174
wpforms = 62104
wpressr = 62436
xbox = 62482
xing = 61800
xing_square = 61801
y_combinator = 62011
yahoo = 61854
yammer = 63552
yandex = 62483
yandex_international = 62484
yarn = 63459
yelp = 61929
yoast = 62129
youtube = 61799
youtube_square = 62513
zhihu = 63039
