# This file is auto-generated by pyrandyos/gui/icons/update_from_spec.py  # noqa: E501
# Do not edit.
from ....iconfont import IconFont


class FluentUI_Filled(IconFont):
    _SPECNAME = 'FluentUI.Filled'
