# This file is auto-generated by pyrandyos/gui/icons/update_from_spec.py  # noqa: E501
# Do not edit.
_0 = 48
_1 = 49
_2 = 50
_3 = 51
_4 = 52
_5 = 53
_6 = 54
_7 = 55
_8 = 56
_9 = 57
a = 65
address_book = 62137
address_card = 62139
align_center = 61495
align_justify = 61497
align_left = 61494
align_right = 61496
anchor = 61757
anchor_circle_check = 58538
anchor_circle_exclamation = 58539
anchor_circle_xmark = 58540
anchor_lock = 58541
angle_down = 61703
angle_left = 61700
angle_right = 61701
angle_up = 61702
angles_down = 61699
angles_left = 61696
angles_right = 61697
angles_up = 61698
ankh = 63044
apple_whole = 62929
archway = 62807
arrow_down = 61539
arrow_down_1_9 = 61794
arrow_down_9_1 = 63622
arrow_down_a_z = 61789
arrow_down_long = 61813
arrow_down_short_wide = 63620
arrow_down_up_across_line = 58543
arrow_down_up_lock = 58544
arrow_down_wide_short = 61792
arrow_down_z_a = 63617
arrow_left = 61536
arrow_left_long = 61815
arrow_pointer = 62021
arrow_right = 61537
arrow_right_arrow_left = 61676
arrow_right_from_bracket = 61579
arrow_right_long = 61816
arrow_right_to_bracket = 61584
arrow_right_to_city = 58547
arrow_rotate_left = 61666
arrow_rotate_right = 61470
arrow_trend_down = 57495
arrow_trend_up = 57496
arrow_turn_down = 61769
arrow_turn_up = 61768
arrow_up = 61538
arrow_up_1_9 = 61795
arrow_up_9_1 = 63623
arrow_up_a_z = 61790
arrow_up_from_bracket = 57498
arrow_up_from_ground_water = 58549
arrow_up_from_water_pump = 58550
arrow_up_long = 61814
arrow_up_right_dots = 58551
arrow_up_right_from_square = 61582
arrow_up_short_wide = 63621
arrow_up_wide_short = 61793
arrow_up_z_a = 63618
arrows_down_to_line = 58552
arrows_down_to_people = 58553
arrows_left_right = 61566
arrows_left_right_to_line = 58554
arrows_rotate = 61473
arrows_spin = 58555
arrows_split_up_and_left = 58556
arrows_to_circle = 58557
arrows_to_dot = 58558
arrows_to_eye = 58559
arrows_turn_right = 58560
arrows_turn_to_dots = 58561
arrows_up_down = 61565
arrows_up_down_left_right = 61511
arrows_up_to_line = 58562
asterisk = 42
at = 64
atom = 62930
audio_description = 62110
austral_sign = 57513
award = 62809
b = 66
baby = 63356
baby_carriage = 63357
backward = 61514
backward_fast = 61513
backward_step = 61512
bacon = 63461
bacteria = 57433
bacterium = 57434
bag_shopping = 62096
bahai = 63078
baht_sign = 57516
ban = 61534
ban_smoking = 62797
bandage = 62562
bangladeshi_taka_sign = 58086
barcode = 61482
bars = 61641
bars_progress = 63528
bars_staggered = 62800
baseball = 62515
baseball_bat_ball = 62514
basket_shopping = 62097
basketball = 62516
bath = 62157
battery_empty = 62020
battery_full = 62016
battery_half = 62018
battery_quarter = 62019
battery_three_quarters = 62017
bed = 62006
bed_pulse = 62599
beer_mug_empty = 61692
bell = 61683
bell_concierge = 62818
bell_slash = 61942
bezier_curve = 62811
bicycle = 61958
binoculars = 61925
biohazard = 63360
bitcoin_sign = 57524
blender = 62743
blender_phone = 63158
blog = 63361
bold = 61490
bolt = 61671
bolt_lightning = 57527
bomb = 61922
bone = 62935
bong = 62812
book = 61485
book_atlas = 62808
book_bible = 63047
book_bookmark = 57531
book_journal_whills = 63082
book_medical = 63462
book_open = 62744
book_open_reader = 62938
book_quran = 63111
book_skull = 63159
book_tanakh = 63527
bookmark = 61486
border_all = 63564
border_none = 63568
border_top_left = 63571
bore_hole = 58563
bottle_droplet = 58564
bottle_water = 58565
bowl_food = 58566
bowl_rice = 58091
bowling_ball = 62518
box = 62566
box_archive = 61831
box_open = 62622
box_tissue = 57435
boxes_packing = 58567
boxes_stacked = 62568
braille = 62113
brain = 62940
brazilian_real_sign = 58476
bread_slice = 63468
bridge = 58568
bridge_circle_check = 58569
bridge_circle_exclamation = 58570
bridge_circle_xmark = 58571
bridge_lock = 58572
bridge_water = 58574
briefcase = 61617
briefcase_medical = 62569
broom = 62746
broom_ball = 62552
brush = 62813
bucket = 58575
bug = 61832
bug_slash = 58512
bugs = 58576
building = 61869
building_circle_arrow_right = 58577
building_circle_check = 58578
building_circle_exclamation = 58579
building_circle_xmark = 58580
building_columns = 61852
building_flag = 58581
building_lock = 58582
building_ngo = 58583
building_shield = 58584
building_un = 58585
building_user = 58586
building_wheat = 58587
bullhorn = 61601
bullseye = 61760
burger = 63493
burst = 58588
bus = 61959
bus_simple = 62814
business_time = 63050
c = 67
cable_car = 63450
cake_candles = 61949
calculator = 61932
calendar = 61747
calendar_check = 62068
calendar_day = 63363
calendar_days = 61555
calendar_minus = 62066
calendar_plus = 62065
calendar_week = 63364
calendar_xmark = 62067
camera = 61488
camera_retro = 61571
camera_rotate = 57560
campground = 63163
candy_cane = 63366
cannabis = 62815
capsules = 62571
car = 61881
car_battery = 62943
car_burst = 62945
car_on = 58589
car_rear = 62942
car_side = 62948
car_tunnel = 58590
caravan = 63743
caret_down = 61655
caret_left = 61657
caret_right = 61658
caret_up = 61656
carrot = 63367
cart_arrow_down = 61976
cart_flatbed = 62580
cart_flatbed_suitcase = 62877
cart_plus = 61975
cart_shopping = 61562
cash_register = 63368
cat = 63166
cedi_sign = 57567
cent_sign = 58357
certificate = 61603
chair = 63168
chalkboard = 62747
chalkboard_user = 62748
champagne_glasses = 63391
charging_station = 62951
chart_area = 61950
chart_bar = 61568
chart_column = 57571
chart_diagram = 59029
chart_gantt = 57572
chart_line = 61953
chart_pie = 61952
chart_simple = 58483
check = 61452
check_double = 62816
check_to_slot = 63346
cheese = 63471
chess = 62521
chess_bishop = 62522
chess_board = 62524
chess_king = 62527
chess_knight = 62529
chess_pawn = 62531
chess_queen = 62533
chess_rook = 62535
chevron_down = 61560
chevron_left = 61523
chevron_right = 61524
chevron_up = 61559
child = 61870
child_combatant = 58592
child_dress = 58780
child_reaching = 58781
children = 58593
church = 62749
circle = 61713
circle_arrow_down = 61611
circle_arrow_left = 61608
circle_arrow_right = 61609
circle_arrow_up = 61610
circle_check = 61528
circle_chevron_down = 61754
circle_chevron_left = 61751
circle_chevron_right = 61752
circle_chevron_up = 61753
circle_dollar_to_slot = 62649
circle_dot = 61842
circle_down = 62296
circle_exclamation = 61546
circle_h = 62590
circle_half_stroke = 61506
circle_info = 61530
circle_left = 62297
circle_minus = 61526
circle_nodes = 58594
circle_notch = 61902
circle_pause = 62091
circle_play = 61764
circle_plus = 61525
circle_question = 61529
circle_radiation = 63418
circle_right = 62298
circle_stop = 62093
circle_up = 62299
circle_user = 62141
circle_xmark = 61527
city = 63055
clapperboard = 57649
clipboard = 62248
clipboard_check = 62572
clipboard_list = 62573
clipboard_question = 58595
clipboard_user = 63475
clock = 61463
clock_rotate_left = 61914
clone = 62029
closed_captioning = 61962
cloud = 61634
cloud_arrow_down = 61677
cloud_arrow_up = 61678
cloud_bolt = 63340
cloud_meatball = 63291
cloud_moon = 63171
cloud_moon_rain = 63292
cloud_rain = 63293
cloud_showers_heavy = 63296
cloud_showers_water = 58596
cloud_sun = 63172
cloud_sun_rain = 63299
clover = 57657
code = 61729
code_branch = 61734
code_commit = 62342
code_compare = 57658
code_fork = 57659
code_merge = 62343
code_pull_request = 57660
coins = 62750
colon_sign = 57664
comment = 61557
comment_dollar = 63057
comment_dots = 62637
comment_medical = 63477
comment_nodes = 59030
comment_slash = 62643
comment_sms = 63437
comments = 61574
comments_dollar = 63059
compact_disc = 62751
compass = 61774
compass_drafting = 62824
compress = 61542
computer = 58597
computer_mouse = 63692
cookie = 62819
cookie_bite = 62820
copy = 61637
copyright = 61945
couch = 62648
cow = 63176
credit_card = 61597
crop = 61733
crop_simple = 62821
cross = 63060
crosshairs = 61531
crow = 62752
crown = 62753
crutch = 63479
cruzeiro_sign = 57682
cube = 61874
cubes = 61875
cubes_stacked = 58598
d = 68
database = 61888
delete_left = 62810
democrat = 63303
desktop = 62352
dharmachakra = 63061
diagram_next = 58486
diagram_predecessor = 58487
diagram_project = 62786
diagram_successor = 58490
diamond = 61977
diamond_turn_right = 62955
dice = 62754
dice_d20 = 63183
dice_d6 = 63185
dice_five = 62755
dice_four = 62756
dice_one = 62757
dice_six = 62758
dice_three = 62759
dice_two = 62760
disease = 63482
display = 57699
divide = 62761
dna = 62577
dog = 63187
dollar_sign = 36
dolly = 62578
dong_sign = 57705
door_closed = 62762
door_open = 62763
dove = 62650
down_left_and_up_right_to_center = 62498
down_long = 62217
download = 61465
dragon = 63189
draw_polygon = 62958
droplet = 61507
droplet_slash = 62919
drum = 62825
drum_steelpan = 62826
drumstick_bite = 63191
dumbbell = 62539
dumpster = 63379
dumpster_fire = 63380
dungeon = 63193
e = 69
ear_deaf = 62116
ear_listen = 62114
earth_africa = 62844
earth_americas = 62845
earth_asia = 62846
earth_europe = 63394
earth_oceania = 58491
egg = 63483
eject = 61522
elevator = 57709
ellipsis = 61761
ellipsis_vertical = 61762
envelope = 61664
envelope_circle_check = 58600
envelope_open = 62134
envelope_open_text = 63064
envelopes_bulk = 63092
equals = 61
eraser = 61741
ethernet = 63382
euro_sign = 61779
exclamation = 33
expand = 61541
explosion = 58601
eye = 61550
eye_dropper = 61947
eye_low_vision = 62120
eye_slash = 61552
f = 70
face_angry = 62806
face_dizzy = 62823
face_flushed = 62841
face_frown = 61721
face_frown_open = 62842
face_grimace = 62847
face_grin = 62848
face_grin_beam = 62850
face_grin_beam_sweat = 62851
face_grin_hearts = 62852
face_grin_squint = 62853
face_grin_squint_tears = 62854
face_grin_stars = 62855
face_grin_tears = 62856
face_grin_tongue = 62857
face_grin_tongue_squint = 62858
face_grin_tongue_wink = 62859
face_grin_wide = 62849
face_grin_wink = 62860
face_kiss = 62870
face_kiss_beam = 62871
face_kiss_wink_heart = 62872
face_laugh = 62873
face_laugh_beam = 62874
face_laugh_squint = 62875
face_laugh_wink = 62876
face_meh = 61722
face_meh_blank = 62884
face_rolling_eyes = 62885
face_sad_cry = 62899
face_sad_tear = 62900
face_smile = 61720
face_smile_beam = 62904
face_smile_wink = 62682
face_surprise = 62914
face_tired = 62920
fan = 63587
faucet = 57349
faucet_drip = 57350
fax = 61868
feather = 62765
feather_pointed = 62827
ferry = 58602
file = 61787
file_arrow_down = 62829
file_arrow_up = 62836
file_audio = 61895
file_circle_check = 58784
file_circle_exclamation = 58603
file_circle_minus = 58605
file_circle_plus = 58516
file_circle_question = 58607
file_circle_xmark = 58785
file_code = 61897
file_contract = 62828
file_csv = 63197
file_excel = 61891
file_export = 62830
file_fragment = 59031
file_half_dashed = 59032
file_image = 61893
file_import = 62831
file_invoice = 62832
file_invoice_dollar = 62833
file_lines = 61788
file_medical = 62583
file_pdf = 61889
file_pen = 62236
file_powerpoint = 61892
file_prescription = 62834
file_shield = 58608
file_signature = 62835
file_video = 61896
file_waveform = 62584
file_word = 61890
file_zipper = 61894
fill = 62837
fill_drip = 62838
film = 61448
filter = 61616
filter_circle_dollar = 63074
filter_circle_xmark = 57723
fingerprint = 62839
fire = 61549
fire_burner = 58609
fire_extinguisher = 61748
fire_flame_curved = 63460
fire_flame_simple = 62570
fish = 62840
fish_fins = 58610
flag = 61476
flag_checkered = 61726
flag_usa = 63309
flask = 61635
flask_vial = 58611
floppy_disk = 61639
florin_sign = 57732
folder = 61563
folder_closed = 57733
folder_minus = 63069
folder_open = 61564
folder_plus = 63070
folder_tree = 63490
font = 61489
font_awesome = 62132
football = 62542
forward = 61518
forward_fast = 61520
forward_step = 61521
franc_sign = 57743
frog = 62766
futbol = 61923
g = 71
gamepad = 61723
gas_pump = 62767
gauge = 63012
gauge_high = 63013
gauge_simple = 63017
gauge_simple_high = 63018
gavel = 61667
gear = 61459
gears = 61573
gem = 62373
genderless = 61997
ghost = 63202
gift = 61547
gifts = 63388
glass_water = 58612
glass_water_droplet = 58613
glasses = 62768
globe = 61612
golf_ball_tee = 62544
gopuram = 63076
graduation_cap = 61853
greater_than = 62
greater_than_equal = 62770
grip = 62861
grip_lines = 63396
grip_lines_vertical = 63397
grip_vertical = 62862
group_arrows_rotate = 58614
guarani_sign = 57754
guitar = 63398
gun = 57755
h = 72
hammer = 63203
hamsa = 63077
hand = 62038
hand_back_fist = 62037
hand_dots = 62561
hand_fist = 63198
hand_holding = 62653
hand_holding_dollar = 62656
hand_holding_droplet = 62657
hand_holding_hand = 58615
hand_holding_heart = 62654
hand_holding_medical = 57436
hand_lizard = 62040
hand_middle_finger = 63494
hand_peace = 62043
hand_point_down = 61607
hand_point_left = 61605
hand_point_right = 61604
hand_point_up = 61606
hand_pointer = 62042
hand_scissors = 62039
hand_sparkles = 57437
hand_spock = 62041
handcuffs = 58616
hands = 62119
hands_asl_interpreting = 62115
hands_bound = 58617
hands_bubbles = 57438
hands_clapping = 57768
hands_holding = 62658
hands_holding_child = 58618
hands_holding_circle = 58619
hands_praying = 63108
handshake = 62133
handshake_angle = 62660
handshake_simple = 62662
handshake_simple_slash = 57439
handshake_slash = 57440
hanukiah = 63206
hard_drive = 61600
hashtag = 35
hat_cowboy = 63680
hat_cowboy_side = 63681
hat_wizard = 63208
head_side_cough = 57441
head_side_cough_slash = 57442
head_side_mask = 57443
head_side_virus = 57444
heading = 61916
headphones = 61477
headphones_simple = 62863
headset = 62864
heart = 61444
heart_circle_bolt = 58620
heart_circle_check = 58621
heart_circle_exclamation = 58622
heart_circle_minus = 58623
heart_circle_plus = 58624
heart_circle_xmark = 58625
heart_crack = 63401
heart_pulse = 61982
helicopter = 62771
helicopter_symbol = 58626
helmet_safety = 63495
helmet_un = 58627
hexagon_nodes = 59033
hexagon_nodes_bolt = 59034
highlighter = 62865
hill_avalanche = 58631
hill_rockslide = 58632
hippo = 63213
hockey_puck = 62547
holly_berry = 63402
horse = 63216
horse_head = 63403
hospital = 61688
hospital_user = 63501
hot_tub_person = 62867
hotdog = 63503
hotel = 62868
hourglass = 62036
hourglass_end = 62035
hourglass_half = 62034
hourglass_start = 62033
house = 61461
house_chimney = 58287
house_chimney_crack = 63217
house_chimney_medical = 63474
house_chimney_user = 57445
house_chimney_window = 57357
house_circle_check = 58633
house_circle_exclamation = 58634
house_circle_xmark = 58635
house_crack = 58289
house_fire = 58636
house_flag = 58637
house_flood_water = 58638
house_flood_water_circle_arrow_right = 58639
house_laptop = 57446
house_lock = 58640
house_medical = 58290
house_medical_circle_check = 58641
house_medical_circle_exclamation = 58642
house_medical_circle_xmark = 58643
house_medical_flag = 58644
house_signal = 57362
house_tsunami = 58645
house_user = 57776
hryvnia_sign = 63218
hurricane = 63313
i = 73
i_cursor = 62022
ice_cream = 63504
icicles = 63405
icons = 63597
id_badge = 62145
id_card = 62146
id_card_clip = 62591
igloo = 63406
image = 61502
image_portrait = 62432
images = 62210
inbox = 61468
indent = 61500
indian_rupee_sign = 57788
industry = 62069
infinity = 62772
info = 61737
italic = 61491
j = 74
jar = 58646
jar_wheat = 58647
jedi = 63081
jet_fighter = 61691
jet_fighter_up = 58648
joint = 62869
jug_detergent = 58649
k = 75
kaaba = 63083
key = 61572
keyboard = 61724
khanda = 63085
kip_sign = 57796
kit_medical = 62585
kitchen_set = 58650
kiwi_bird = 62773
L = 76
land_mine_on = 58651
landmark = 63087
landmark_dome = 63314
landmark_flag = 58652
language = 61867
laptop = 61705
laptop_code = 62972
laptop_file = 58653
laptop_medical = 63506
lari_sign = 57800
layer_group = 62973
leaf = 61548
left_long = 62218
left_right = 62263
lemon = 61588
less_than = 60
less_than_equal = 62775
life_ring = 61901
lightbulb = 61675
lines_leaning = 58654
link = 61633
link_slash = 61735
lira_sign = 61845
list = 61498
list_check = 61614
list_ol = 61643
list_ul = 61642
litecoin_sign = 57811
location_arrow = 61732
location_crosshairs = 62977
location_dot = 62405
location_pin = 61505
location_pin_lock = 58655
lock = 61475
lock_open = 62401
locust = 58656
lungs = 62980
lungs_virus = 57447
m = 77
magnet = 61558
magnifying_glass = 61442
magnifying_glass_arrow_right = 58657
magnifying_glass_chart = 58658
magnifying_glass_dollar = 63112
magnifying_glass_location = 63113
magnifying_glass_minus = 61456
magnifying_glass_plus = 61454
manat_sign = 57813
map = 62073
map_location = 62879
map_location_dot = 62880
map_pin = 62070
marker = 62881
mars = 61986
mars_and_venus = 61988
mars_and_venus_burst = 58659
mars_double = 61991
mars_stroke = 61993
mars_stroke_right = 61995
mars_stroke_up = 61994
martini_glass = 62843
martini_glass_citrus = 62817
martini_glass_empty = 61440
mask = 63226
mask_face = 57815
mask_ventilator = 58660
masks_theater = 63024
mattress_pillow = 58661
maximize = 62238
medal = 62882
memory = 62776
menorah = 63094
mercury = 61987
message = 62074
meteor = 63315
microchip = 62171
microphone = 61744
microphone_lines = 62409
microphone_lines_slash = 62777
microphone_slash = 61745
microscope = 62992
mill_sign = 57837
minimize = 63372
minus = 61544
mitten = 63413
mobile = 62414
mobile_button = 61707
mobile_retro = 58663
mobile_screen = 62415
mobile_screen_button = 62413
money_bill = 61654
money_bill_1 = 62417
money_bill_1_wave = 62779
money_bill_transfer = 58664
money_bill_trend_up = 58665
money_bill_wave = 62778
money_bill_wheat = 58666
money_bills = 57843
money_check = 62780
money_check_dollar = 62781
monument = 62886
moon = 61830
mortar_pestle = 62887
mosque = 63096
mosquito = 58667
mosquito_net = 58668
motorcycle = 61980
mound = 58669
mountain = 63228
mountain_city = 58670
mountain_sun = 58671
mug_hot = 63414
mug_saucer = 61684
music = 61441
n = 78
naira_sign = 57846
network_wired = 63231
neuter = 61996
newspaper = 61930
not_equal = 62782
notdef = 57854
note_sticky = 62025
notes_medical = 62593
o = 79
object_group = 62023
object_ungroup = 62024
oil_can = 62995
oil_well = 58674
om = 63097
otter = 63232
outdent = 61499
p = 80
pager = 63509
paint_roller = 62890
paintbrush = 61948
palette = 62783
pallet = 62594
panorama = 57865
paper_plane = 61912
paperclip = 61638
parachute_box = 62669
paragraph = 61917
passport = 62891
paste = 61674
pause = 61516
paw = 61872
peace = 63100
pen = 62212
pen_clip = 62213
pen_fancy = 62892
pen_nib = 62893
pen_ruler = 62894
pen_to_square = 61508
pencil = 62211
people_arrows = 57448
people_carry_box = 62670
people_group = 58675
people_line = 58676
people_pulling = 58677
people_robbery = 58678
people_roof = 58679
pepper_hot = 63510
percent = 37
person = 61827
person_arrow_down_to_line = 58680
person_arrow_up_from_line = 58681
person_biking = 63562
person_booth = 63318
person_breastfeeding = 58682
person_burst = 58683
person_cane = 58684
person_chalkboard = 58685
person_circle_check = 58686
person_circle_exclamation = 58687
person_circle_minus = 58688
person_circle_plus = 58689
person_circle_question = 58690
person_circle_xmark = 58691
person_digging = 63582
person_dots_from_line = 62576
person_dress = 61826
person_dress_burst = 58692
person_drowning = 58693
person_falling = 58694
person_falling_burst = 58695
person_half_dress = 58696
person_harassing = 58697
person_hiking = 63212
person_military_pointing = 58698
person_military_rifle = 58699
person_military_to_person = 58700
person_praying = 63107
person_pregnant = 58142
person_rays = 58701
person_rifle = 58702
person_running = 63244
person_shelter = 58703
person_skating = 63429
person_skiing = 63433
person_skiing_nordic = 63434
person_snowboarding = 63438
person_swimming = 62916
person_through_window = 58793
person_walking = 62804
person_walking_arrow_loop_left = 58705
person_walking_arrow_right = 58706
person_walking_dashed_line_arrow_right = 58707
person_walking_luggage = 58708
person_walking_with_cane = 62109
peseta_sign = 57889
peso_sign = 57890
phone = 61589
phone_flip = 63609
phone_slash = 62429
phone_volume = 62112
photo_film = 63612
piggy_bank = 62675
pills = 62596
pizza_slice = 63512
place_of_worship = 63103
plane = 61554
plane_arrival = 62895
plane_circle_check = 58709
plane_circle_exclamation = 58710
plane_circle_xmark = 58711
plane_departure = 62896
plane_lock = 58712
plane_slash = 57449
plane_up = 57901
plant_wilt = 58794
plate_wheat = 58714
play = 61515
plug = 61926
plug_circle_bolt = 58715
plug_circle_check = 58716
plug_circle_exclamation = 58717
plug_circle_minus = 58718
plug_circle_plus = 58719
plug_circle_xmark = 58720
plus = 43
plus_minus = 58428
podcast = 62158
poo = 62206
poo_storm = 63322
poop = 63001
power_off = 61457
prescription = 62897
prescription_bottle = 62597
prescription_bottle_medical = 62598
print = 61487
pump_medical = 57450
pump_soap = 57451
puzzle_piece = 61742
q = 81
qrcode = 61481
question = 63
quote_left = 61709
quote_right = 61710
r = 82
radiation = 63417
radio = 63703
rainbow = 63323
ranking_star = 58721
receipt = 62787
record_vinyl = 63705
rectangle_ad = 63041
rectangle_list = 61474
rectangle_xmark = 62480
recycle = 61880
registered = 62045
repeat = 62307
reply = 62437
reply_all = 61730
republican = 63326
restroom = 63421
retweet = 61561
ribbon = 62678
right_from_bracket = 62197
right_left = 62306
right_long = 62219
right_to_bracket = 62198
ring = 63243
road = 61464
road_barrier = 58722
road_bridge = 58723
road_circle_check = 58724
road_circle_exclamation = 58725
road_circle_xmark = 58726
road_lock = 58727
road_spikes = 58728
robot = 62788
rocket = 61749
rotate = 62193
rotate_left = 62186
rotate_right = 62201
route = 62679
rss = 61598
ruble_sign = 61784
rug = 58729
ruler = 62789
ruler_combined = 62790
ruler_horizontal = 62791
ruler_vertical = 62792
rupee_sign = 61782
rupiah_sign = 57917
s = 83
sack_dollar = 63517
sack_xmark = 58730
sailboat = 58437
satellite = 63423
satellite_dish = 63424
scale_balanced = 62030
scale_unbalanced = 62741
scale_unbalanced_flip = 62742
school = 62793
school_circle_check = 58731
school_circle_exclamation = 58732
school_circle_xmark = 58733
school_flag = 58734
school_lock = 58735
scissors = 61636
screwdriver = 62794
screwdriver_wrench = 63449
scroll = 63246
scroll_torah = 63136
sd_card = 63426
section = 58439
seedling = 62680
server = 62003
shapes = 63007
share = 61540
share_from_square = 61773
share_nodes = 61920
sheet_plastic = 58737
shekel_sign = 61963
shield = 61746
shield_cat = 58738
shield_dog = 58739
shield_halved = 62445
shield_heart = 58740
shield_virus = 57452
ship = 61978
shirt = 62803
shoe_prints = 62795
shop = 62799
shop_lock = 58533
shop_slash = 57456
shower = 62156
shrimp = 58440
shuffle = 61556
shuttle_space = 61847
sign_hanging = 62681
signal = 61458
signature = 62903
signs_post = 62071
sim_card = 63428
sink = 57453
sitemap = 61672
skull = 62796
skull_crossbones = 63252
slash = 63253
sleigh = 63436
sliders = 61918
smog = 63327
smoking = 62605
snowflake = 62172
snowman = 63440
snowplow = 63442
soap = 57454
socks = 63126
solar_panel = 62906
sort = 61660
sort_down = 61661
sort_up = 61662
spa = 62907
spaghetti_monster_flying = 63099
spell_check = 63633
spider = 63255
spinner = 61712
splotch = 62908
spoon = 62181
spray_can = 62909
spray_can_sparkles = 62928
square = 61640
square_arrow_up_right = 61772
square_binary = 59035
square_caret_down = 61776
square_caret_left = 61841
square_caret_right = 61778
square_caret_up = 61777
square_check = 61770
square_envelope = 61849
square_full = 62556
square_h = 61693
square_minus = 61766
square_nfi = 58742
square_parking = 62784
square_pen = 61771
square_person_confined = 58743
square_phone = 61592
square_phone_flip = 63611
square_plus = 61694
square_poll_horizontal = 63106
square_poll_vertical = 63105
square_root_variable = 63128
square_rss = 61763
square_share_nodes = 61921
square_up_right = 62304
square_virus = 58744
square_xmark = 62163
staff_snake = 58745
stairs = 57993
stamp = 62911
stapler = 58799
star = 61445
star_and_crescent = 63129
star_half = 61577
star_half_stroke = 62912
star_of_david = 63130
star_of_life = 63009
sterling_sign = 61780
stethoscope = 61681
stop = 61517
stopwatch = 62194
stopwatch_20 = 57455
store = 62798
store_slash = 57457
street_view = 61981
strikethrough = 61644
stroopwafel = 62801
subscript = 61740
suitcase = 61682
suitcase_medical = 61690
suitcase_rolling = 62913
sun = 61829
sun_plant_wilt = 58746
superscript = 61739
swatchbook = 62915
synagogue = 63131
syringe = 62606
t = 84
table = 61646
table_cells = 61450
table_cells_column_lock = 59000
table_cells_large = 61449
table_cells_row_lock = 59002
table_cells_row_unlock = 59025
table_columns = 61659
table_list = 61451
table_tennis_paddle_ball = 62557
tablet = 62459
tablet_button = 61706
tablet_screen_button = 62458
tablets = 62608
tachograph_digital = 62822
tag = 61483
tags = 61484
tape = 62683
tarp = 58747
tarp_droplet = 58748
taxi = 61882
teeth = 63022
teeth_open = 63023
temperature_arrow_down = 57407
temperature_arrow_up = 57408
temperature_empty = 62155
temperature_full = 62151
temperature_half = 62153
temperature_high = 63337
temperature_low = 63339
temperature_quarter = 62154
temperature_three_quarters = 62152
tenge_sign = 63447
tent = 58749
tent_arrow_down_to_line = 58750
tent_arrow_left_right = 58751
tent_arrow_turn_left = 58752
tent_arrows_down = 58753
tents = 58754
terminal = 61728
text_height = 61492
text_slash = 63613
text_width = 61493
thermometer = 62609
thumbs_down = 61797
thumbs_up = 61796
thumbtack = 61581
thumbtack_slash = 59023
ticket = 61765
ticket_simple = 62463
timeline = 58012
toggle_off = 61956
toggle_on = 61957
toilet = 63448
toilet_paper = 63262
toilet_paper_slash = 57458
toilet_portable = 58755
toilets_portable = 58756
toolbox = 62802
tooth = 62921
torii_gate = 63137
tornado = 63343
tower_broadcast = 62745
tower_cell = 58757
tower_observation = 58758
tractor = 63266
trademark = 62044
traffic_light = 63031
trailer = 57409
train = 62008
train_subway = 62009
train_tram = 58804
transgender = 61989
trash = 61944
trash_arrow_up = 63529
trash_can = 62189
trash_can_arrow_up = 63530
tree = 61883
tree_city = 58759
triangle_exclamation = 61553
trophy = 61585
trowel = 58761
trowel_bricks = 58762
truck = 61649
truck_arrow_right = 58763
truck_droplet = 58764
truck_fast = 62603
truck_field = 58765
truck_field_un = 58766
truck_front = 58039
truck_medical = 61689
truck_monster = 63035
truck_moving = 62687
truck_pickup = 63036
truck_plane = 58767
truck_ramp_box = 62686
tty = 61924
turkish_lira_sign = 58043
turn_down = 62398
turn_up = 62399
tv = 62060
u = 85
umbrella = 61673
umbrella_beach = 62922
underline = 61645
universal_access = 62106
unlock = 61596
unlock_keyhole = 61758
up_down = 62264
up_down_left_right = 61618
up_long = 62220
up_right_and_down_left_from_center = 62500
up_right_from_square = 62301
upload = 61587
user = 61447
user_astronaut = 62715
user_check = 62716
user_clock = 62717
user_doctor = 61680
user_gear = 62718
user_graduate = 62721
user_group = 62720
user_injured = 63272
user_large = 62470
user_large_slash = 62714
user_lock = 62722
user_minus = 62723
user_ninja = 62724
user_nurse = 63535
user_pen = 62719
user_plus = 62004
user_secret = 61979
user_shield = 62725
user_slash = 62726
user_tag = 62727
user_tie = 62728
user_xmark = 62005
users = 61632
users_between_lines = 58769
users_gear = 62729
users_line = 58770
users_rays = 58771
users_rectangle = 58772
users_slash = 57459
users_viewfinder = 58773
utensils = 62183
v = 86
van_shuttle = 62902
vault = 58053
vector_square = 62923
venus = 61985
venus_double = 61990
venus_mars = 61992
vest = 57477
vest_patches = 57478
vial = 62610
vial_circle_check = 58774
vial_virus = 58775
vials = 62611
video = 61501
video_slash = 62690
vihara = 63143
virus = 57460
virus_covid = 58536
virus_covid_slash = 58537
virus_slash = 57461
viruses = 57462
voicemail = 63639
volcano = 63344
volleyball = 62559
volume_high = 61480
volume_low = 61479
volume_off = 61478
volume_xmark = 63145
vr_cardboard = 63273
w = 87
walkie_talkie = 63727
wallet = 62805
wand_magic = 61648
wand_magic_sparkles = 58058
wand_sparkles = 63275
warehouse = 62612
water = 63347
water_ladder = 62917
wave_square = 63550
web_awesome = 59010
weight_hanging = 62925
weight_scale = 62614
wheat_awn = 58061
wheat_awn_circle_exclamation = 58776
wheelchair = 61843
wheelchair_move = 58062
whiskey_glass = 63392
wifi = 61931
wind = 63278
window_maximize = 62160
window_minimize = 62161
window_restore = 62162
wine_bottle = 63279
wine_glass = 62691
wine_glass_empty = 62926
won_sign = 61785
worm = 58777
wrench = 61613
x = 88
x_ray = 62615
xmark = 61453
xmarks_lines = 58778
y = 89
yen_sign = 61783
yin_yang = 63149
z = 90
