'''
# PyRandyOS

Library of common functions for Python applications

[![GitHub Badge](https://img.shields.io/badge/GitHub-181717?logo=github&logoColor=fff&style=plastic)](https://github.com/emanspeaks/pyrandyos)
[![CI Status](https://github.com/emanspeaks/pyrandyos/actions/workflows/ci.yml/badge.svg)](https://github.com/emanspeaks/pyrandyos/actions)
[![last-commit](https://img.shields.io/github/last-commit/emanspeaks/pyrandyos)](https://github.com/emanspeaks/pyrandyos/commits/main)
[![PyPI Downloads](https://img.shields.io/pypi/dm/pyrandyos?label=PyPI%20downloads)](https://pypi.org/project/pyrandyos/)
<!-- [![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/pyrandyos?label=Conda%20downloads)](https://anaconda.org/conda-forge/pyrandyos) -->

This library was created to assist with rapid prototyping of Qt GUIs and other
common functionality Randy needs on a day-to-day basis.
'''  # noqa: E501

from .version import __version__  # noqa: F401
from .app import PyRandyOSApp  # noqa: F401
