# This file is auto-generated by pyrandyos/gui/icons/update_from_spec.py  # noqa: E501
# Do not edit.
address_book = 62137
address_card = 62139
bell = 61683
bell_slash = 61942
bookmark = 61486
building = 61869
calendar = 61747
calendar_check = 62068
calendar_days = 61555
calendar_minus = 62066
calendar_plus = 62065
calendar_xmark = 62067
chart_bar = 61568
chess_bishop = 62522
chess_king = 62527
chess_knight = 62529
chess_pawn = 62531
chess_queen = 62533
chess_rook = 62535
circle = 61713
circle_check = 61528
circle_dot = 61842
circle_down = 62296
circle_left = 62297
circle_pause = 62091
circle_play = 61764
circle_question = 61529
circle_right = 62298
circle_stop = 62093
circle_up = 62299
circle_user = 62141
circle_xmark = 61527
clipboard = 62248
clock = 61463
clone = 62029
closed_captioning = 61962
comment = 61557
comment_dots = 62637
comments = 61574
compass = 61774
copy = 61637
copyright = 61945
credit_card = 61597
envelope = 61664
envelope_open = 62134
eye = 61550
eye_slash = 61552
face_angry = 62806
face_dizzy = 62823
face_flushed = 62841
face_frown = 61721
face_frown_open = 62842
face_grimace = 62847
face_grin = 62848
face_grin_beam = 62850
face_grin_beam_sweat = 62851
face_grin_hearts = 62852
face_grin_squint = 62853
face_grin_squint_tears = 62854
face_grin_stars = 62855
face_grin_tears = 62856
face_grin_tongue = 62857
face_grin_tongue_squint = 62858
face_grin_tongue_wink = 62859
face_grin_wide = 62849
face_grin_wink = 62860
face_kiss = 62870
face_kiss_beam = 62871
face_kiss_wink_heart = 62872
face_laugh = 62873
face_laugh_beam = 62874
face_laugh_squint = 62875
face_laugh_wink = 62876
face_meh = 61722
face_meh_blank = 62884
face_rolling_eyes = 62885
face_sad_cry = 62899
face_sad_tear = 62900
face_smile = 61720
face_smile_beam = 62904
face_smile_wink = 62682
face_surprise = 62914
face_tired = 62920
file = 61787
file_audio = 61895
file_code = 61897
file_excel = 61891
file_image = 61893
file_lines = 61788
file_pdf = 61889
file_powerpoint = 61892
file_video = 61896
file_word = 61890
file_zipper = 61894
flag = 61476
floppy_disk = 61639
folder = 61563
folder_closed = 57733
folder_open = 61564
font_awesome = 62132
futbol = 61923
gem = 62373
hand = 62038
hand_back_fist = 62037
hand_lizard = 62040
hand_peace = 62043
hand_point_down = 61607
hand_point_left = 61605
hand_point_right = 61604
hand_point_up = 61606
hand_pointer = 62042
hand_scissors = 62039
hand_spock = 62041
handshake = 62133
hard_drive = 61600
heart = 61444
hospital = 61688
hourglass = 62036
hourglass_half = 62034
id_badge = 62145
id_card = 62146
image = 61502
images = 62210
keyboard = 61724
lemon = 61588
life_ring = 61901
lightbulb = 61675
map = 62073
message = 62074
money_bill_1 = 62417
moon = 61830
newspaper = 61930
note_sticky = 62025
object_group = 62023
object_ungroup = 62024
paper_plane = 61912
paste = 61674
pen_to_square = 61508
rectangle_list = 61474
rectangle_xmark = 62480
registered = 62045
share_from_square = 61773
snowflake = 62172
square = 61640
square_caret_down = 61776
square_caret_left = 61841
square_caret_right = 61778
square_caret_up = 61777
square_check = 61770
square_full = 62556
square_minus = 61766
square_plus = 61694
star = 61445
star_half = 61577
star_half_stroke = 62912
sun = 61829
thumbs_down = 61797
thumbs_up = 61796
trash_can = 62189
user = 61447
window_maximize = 62160
window_minimize = 62161
window_restore = 62162
