# This file is auto-generated by pyrandyos/gui/icons/update_from_spec.py  # noqa: E501
# Do not edit.
ic_fluent_accessibility_checkmark_32_light = 57344
ic_fluent_add_32_light = 57345
ic_fluent_alert_32_light = 57346
ic_fluent_app_folder_32_light = 57347
ic_fluent_app_generic_32_light = 57348
ic_fluent_archive_32_light = 57349
ic_fluent_archive_settings_32_light = 57350
ic_fluent_arrow_clockwise_32_light = 57351
ic_fluent_arrow_down_32_light = 57352
ic_fluent_arrow_download_32_light = 57353
ic_fluent_arrow_forward_32_light = 57354
ic_fluent_arrow_hook_down_left_32_light = 57355
ic_fluent_arrow_hook_down_right_32_light = 57356
ic_fluent_arrow_hook_up_left_32_light = 57357
ic_fluent_arrow_hook_up_right_32_light = 57358
ic_fluent_arrow_redo_32_light = 57359
ic_fluent_arrow_reply_32_light = 57360
ic_fluent_arrow_reply_all_32_light = 57361
ic_fluent_arrow_undo_32_light = 57362
ic_fluent_attach_32_light = 57363
ic_fluent_auto_fit_32_light = 57364
ic_fluent_auto_fit_width_32_light = 57365
ic_fluent_autocorrect_32_light = 57366
ic_fluent_breakout_room_32_light = 57367
ic_fluent_broom_32_light = 57368
ic_fluent_calendar_3_day_32_light = 57369
ic_fluent_calendar_clock_32_light = 57370
ic_fluent_calendar_data_bar_32_light = 57371
ic_fluent_calendar_day_32_light = 57372
ic_fluent_calendar_edit_32_light = 57373
ic_fluent_calendar_empty_32_light = 57374
ic_fluent_calendar_ltr_32_light = 57375
ic_fluent_calendar_month_32_light = 57376
ic_fluent_calendar_multiple_32_light = 57377
ic_fluent_calendar_pattern_32_light = 57378
ic_fluent_calendar_reply_32_light = 57379
ic_fluent_calendar_sparkle_32_light = 57380
ic_fluent_calendar_todo_32_light = 57381
ic_fluent_calendar_work_week_32_light = 57382
ic_fluent_chat_32_light = 57383
ic_fluent_checkmark_32_light = 57384
ic_fluent_checkmark_circle_32_light = 57385
ic_fluent_classification_32_light = 57386
ic_fluent_clipboard_paste_32_light = 57387
ic_fluent_clock_32_light = 57388
ic_fluent_clock_alarm_32_light = 57389
ic_fluent_color_32_light = 57390
ic_fluent_color_fill_32_light = 57391
ic_fluent_color_fill_accent_32_light = 57392
ic_fluent_comment_32_light = 57393
ic_fluent_comment_add_32_light = 57394
ic_fluent_compose_32_light = 57395
ic_fluent_copy_32_light = 57396
ic_fluent_crop_32_light = 57397
ic_fluent_cursor_32_light = 57398
ic_fluent_cut_32_light = 57399
ic_fluent_delete_32_light = 57400
ic_fluent_dismiss_32_light = 57401
ic_fluent_dismiss_circle_32_light = 57402
ic_fluent_document_24_light = 57403
ic_fluent_document_28_light = 57404
ic_fluent_document_32_light = 57405
ic_fluent_document_48_light = 57406
ic_fluent_document_lightning_32_light = 57407
ic_fluent_document_signature_32_light = 57408
ic_fluent_document_sparkle_24_light = 57409
ic_fluent_document_sparkle_28_light = 57410
ic_fluent_document_sparkle_32_light = 57411
ic_fluent_document_sparkle_48_light = 57412
ic_fluent_door_arrow_right_32_light = 57413
ic_fluent_edit_32_light = 57414
ic_fluent_emoji_32_light = 57415
ic_fluent_eye_32_light = 57416
ic_fluent_eye_off_32_light = 57417
ic_fluent_filter_32_light = 57418
ic_fluent_flag_32_light = 57419
ic_fluent_flag_off_32_light = 57420
ic_fluent_flash_32_light = 57421
ic_fluent_folder_arrow_right_32_light = 57422
ic_fluent_folder_mail_32_light = 57423
ic_fluent_hand_draw_32_light = 57424
ic_fluent_history_32_light = 57425
ic_fluent_image_add_32_light = 57426
ic_fluent_image_alt_text_32_light = 57427
ic_fluent_image_copy_32_light = 57428
ic_fluent_image_reflection_32_light = 57429
ic_fluent_image_shadow_32_light = 57430
ic_fluent_immersive_reader_32_light = 57431
ic_fluent_important_32_light = 57432
ic_fluent_lasso_32_light = 57433
ic_fluent_layout_column_two_32_light = 57434
ic_fluent_layout_column_two_focus_left_32_light = 57435
ic_fluent_layout_column_two_focus_right_32_light = 57436
ic_fluent_layout_row_two_32_light = 57437
ic_fluent_layout_row_two_focus_top_32_light = 57438
ic_fluent_layout_row_two_focus_top_settings_32_light = 57439
ic_fluent_layout_row_two_settings_32_light = 57440
ic_fluent_lightbulb_32_light = 57441
ic_fluent_link_32_light = 57442
ic_fluent_lock_closed_32_light = 57443
ic_fluent_lock_open_32_light = 57444
ic_fluent_mail_32_light = 57445
ic_fluent_mail_alert_32_light = 57446
ic_fluent_mail_arrow_clockwise_32_light = 57447
ic_fluent_mail_arrow_double_back_32_light = 57448
ic_fluent_mail_copy_32_light = 57449
ic_fluent_mail_edit_32_light = 57450
ic_fluent_mail_list_32_light = 57451
ic_fluent_mail_multiple_32_light = 57452
ic_fluent_mail_read_32_light = 57453
ic_fluent_mail_read_multiple_32_light = 57454
ic_fluent_mail_rewind_32_light = 57455
ic_fluent_mail_settings_32_light = 57456
ic_fluent_mail_template_32_light = 57457
ic_fluent_mail_unread_32_light = 57458
ic_fluent_mic_32_light = 57459
ic_fluent_molecule_32_light = 57460
ic_fluent_note_32_light = 57461
ic_fluent_options_32_light = 57462
ic_fluent_paint_brush_32_light = 57463
ic_fluent_panel_left_default_32_light = 57464
ic_fluent_panel_left_focus_right_32_light = 57465
ic_fluent_pen_sparkle_32_light = 57466
ic_fluent_people_32_light = 57467
ic_fluent_people_add_32_light = 57468
ic_fluent_people_community_32_light = 57469
ic_fluent_people_edit_32_light = 57470
ic_fluent_people_list_32_light = 57471
ic_fluent_people_settings_32_light = 57472
ic_fluent_people_sync_32_light = 57473
ic_fluent_person_32_light = 57474
ic_fluent_person_add_32_light = 57475
ic_fluent_person_available_32_light = 57476
ic_fluent_person_feedback_32_light = 57477
ic_fluent_person_mail_32_light = 57478
ic_fluent_person_prohibited_32_light = 57479
ic_fluent_person_suport_32_light = 57480
ic_fluent_phone_32_light = 57481
ic_fluent_picture_in_picture_32_light = 57482
ic_fluent_pin_32_light = 57483
ic_fluent_pin_off_32_light = 57484
ic_fluent_poll_32_light = 57485
ic_fluent_print_32_light = 57486
ic_fluent_question_32_light = 57487
ic_fluent_read_aloud_32_light = 57488
ic_fluent_rectangle_landscape_32_light = 57489
ic_fluent_rotate_left_32_light = 57490
ic_fluent_save_32_light = 57491
ic_fluent_send_clock_32_light = 57492
ic_fluent_settings_32_light = 57493
ic_fluent_share_32_light = 57494
ic_fluent_shield_error_32_light = 57495
ic_fluent_signature_32_light = 57496
ic_fluent_speaker_mute_32_light = 57497
ic_fluent_square_arrow_forward_32_light = 57498
ic_fluent_stamp_32_light = 57499
ic_fluent_star_add_32_light = 57500
ic_fluent_star_arrow_right_32_light = 57501
ic_fluent_sticker_32_light = 57502
ic_fluent_tab_add_32_light = 57503
ic_fluent_table_32_light = 57504
ic_fluent_table_alt_text_32_light = 57505
ic_fluent_table_cells_merge_32_light = 57506
ic_fluent_table_cells_split_32_light = 57507
ic_fluent_table_dismiss_32_light = 57508
ic_fluent_table_move_above_32_light = 57509
ic_fluent_table_move_below_32_light = 57510
ic_fluent_table_move_left_32_light = 57511
ic_fluent_table_move_right_32_light = 57512
ic_fluent_table_settings_32_light = 57513
ic_fluent_table_simple_32_light = 57514
ic_fluent_tag_32_light = 57515
ic_fluent_text_32_light = 57516
ic_fluent_text_clear_formatting_32_light = 57517
ic_fluent_text_collapse_32_light = 57518
ic_fluent_text_density_32_light = 57519
ic_fluent_text_edit_style_32_light = 57520
ic_fluent_text_expand_32_light = 57521
ic_fluent_textbox_align_top_left_32_light = 57522
ic_fluent_toolbox_32_light = 57523
ic_fluent_translate_32_light = 57524
ic_fluent_video_32_light = 57525
ic_fluent_video_clip_32_light = 57526
ic_fluent_weather_moon_32_light = 57527
ic_fluent_weather_sunny_32_light = 57528
ic_fluent_window_32_light = 57529
ic_fluent_wrench_screwdriver_32_light = 57530
ic_fluent_zoom_in_32_light = 57531
ic_fluent_zoom_out_32_light = 57532
