# This file is auto-generated by pyrandyos/gui/icons/update_from_spec.py  # noqa: E501
# Do not edit.
ic_fluent_access_time_24_filled = 61697
ic_fluent_accessibility_16_filled = 61698
ic_fluent_accessibility_20_filled = 61699
ic_fluent_accessibility_24_filled = 61700
ic_fluent_accessibility_28_filled = 61701
ic_fluent_add_12_filled = 61703
ic_fluent_add_16_filled = 61704
ic_fluent_add_20_filled = 61705
ic_fluent_add_24_filled = 61706
ic_fluent_add_28_filled = 61707
ic_fluent_add_circle_20_filled = 61708
ic_fluent_add_circle_24_filled = 61709
ic_fluent_add_circle_28_filled = 61710
ic_fluent_airplane_20_filled = 61711
ic_fluent_airplane_24_filled = 61712
ic_fluent_airplane_take_off_16_filled = 61713
ic_fluent_airplane_take_off_20_filled = 61714
ic_fluent_airplane_take_off_24_filled = 61715
ic_fluent_alert_20_filled = 61716
ic_fluent_alert_24_filled = 61717
ic_fluent_alert_28_filled = 61718
ic_fluent_alert_off_16_filled = 61719
ic_fluent_alert_off_20_filled = 61720
ic_fluent_alert_off_24_filled = 61721
ic_fluent_alert_off_28_filled = 61722
ic_fluent_alert_on_24_filled = 61723
ic_fluent_alert_snooze_20_filled = 61724
ic_fluent_alert_snooze_24_filled = 61725
ic_fluent_alert_urgent_20_filled = 61726
ic_fluent_alert_urgent_24_filled = 61727
ic_fluent_animal_dog_20_filled = 61728
ic_fluent_animal_dog_24_filled = 61729
ic_fluent_app_folder_20_filled = 61730
ic_fluent_app_folder_24_filled = 61731
ic_fluent_app_generic_24_filled = 61732
ic_fluent_app_recent_24_filled = 61733
ic_fluent_app_store_24_filled = 61738
ic_fluent_app_title_24_filled = 61739
ic_fluent_approvals_app_24_filled = 61744
ic_fluent_approvals_app_28_filled = 61745
ic_fluent_apps_16_filled = 61746
ic_fluent_apps_20_filled = 61747
ic_fluent_apps_24_filled = 61748
ic_fluent_apps_28_filled = 61749
ic_fluent_apps_add_in_20_filled = 61750
ic_fluent_apps_add_in_24_filled = 61751
ic_fluent_apps_list_24_filled = 61752
ic_fluent_archive_20_filled = 61753
ic_fluent_archive_24_filled = 61754
ic_fluent_archive_28_filled = 61755
ic_fluent_archive_48_filled = 61756
ic_fluent_arrow_clockwise_20_filled = 61757
ic_fluent_arrow_clockwise_24_filled = 61758
ic_fluent_arrow_counterclockwise_20_filled = 61759
ic_fluent_arrow_counterclockwise_24_filled = 61760
ic_fluent_arrow_curve_down_left_20_filled = 61761
ic_fluent_arrow_curve_down_right_20_filled = 61762
ic_fluent_arrow_curve_up_left_20_filled = 61765
ic_fluent_arrow_curve_up_right_20_filled = 61766
ic_fluent_arrow_down_16_filled = 61767
ic_fluent_arrow_down_20_filled = 61768
ic_fluent_arrow_down_24_filled = 61769
ic_fluent_arrow_down_28_filled = 61770
ic_fluent_arrow_down_left_24_filled = 61771
ic_fluent_arrow_download_16_filled = 61775
ic_fluent_arrow_download_20_filled = 61776
ic_fluent_arrow_download_24_filled = 61777
ic_fluent_arrow_download_48_filled = 61778
ic_fluent_arrow_expand_24_filled = 61780
ic_fluent_arrow_forward_16_filled = 61782
ic_fluent_arrow_forward_20_filled = 61783
ic_fluent_arrow_forward_24_filled = 61784
ic_fluent_arrow_import_20_filled = 61785
ic_fluent_arrow_import_24_filled = 61786
ic_fluent_arrow_left_20_filled = 61787
ic_fluent_arrow_left_24_filled = 61788
ic_fluent_arrow_left_28_filled = 61789
ic_fluent_arrow_maximize_16_filled = 61790
ic_fluent_arrow_maximize_20_filled = 61791
ic_fluent_arrow_maximize_24_filled = 61792
ic_fluent_arrow_maximize_28_filled = 61793
ic_fluent_arrow_maximize_vertical_20_filled = 61794
ic_fluent_arrow_maximize_vertical_24_filled = 61795
ic_fluent_arrow_minimize_16_filled = 61796
ic_fluent_arrow_minimize_20_filled = 61797
ic_fluent_arrow_minimize_24_filled = 61798
ic_fluent_arrow_minimize_28_filled = 61799
ic_fluent_arrow_minimize_vertical_24_filled = 61800
ic_fluent_arrow_move_24_filled = 61801
ic_fluent_arrow_next_20_filled = 61802
ic_fluent_arrow_next_24_filled = 61803
ic_fluent_arrow_previous_20_filled = 61804
ic_fluent_arrow_previous_24_filled = 61805
ic_fluent_arrow_redo_20_filled = 61806
ic_fluent_arrow_redo_24_filled = 61807
ic_fluent_arrow_repeat_all_16_filled = 61808
ic_fluent_arrow_repeat_all_20_filled = 61809
ic_fluent_arrow_repeat_all_24_filled = 61810
ic_fluent_arrow_repeat_all_off_16_filled = 61811
ic_fluent_arrow_repeat_all_off_20_filled = 61812
ic_fluent_arrow_repeat_all_off_24_filled = 61813
ic_fluent_arrow_reply_16_filled = 61814
ic_fluent_arrow_reply_20_filled = 61815
ic_fluent_arrow_reply_24_filled = 61816
ic_fluent_arrow_reply_48_filled = 61817
ic_fluent_arrow_reply_all_16_filled = 61818
ic_fluent_arrow_reply_all_20_filled = 61819
ic_fluent_arrow_reply_all_24_filled = 61820
ic_fluent_arrow_reply_all_48_filled = 61821
ic_fluent_arrow_reply_down_16_filled = 61822
ic_fluent_arrow_reply_down_20_filled = 61823
ic_fluent_arrow_reply_down_24_filled = 61824
ic_fluent_arrow_right_20_filled = 61825
ic_fluent_arrow_right_24_filled = 61826
ic_fluent_arrow_right_28_filled = 61827
ic_fluent_arrow_rotate_clockwise_20_filled = 61829
ic_fluent_arrow_rotate_clockwise_24_filled = 61830
ic_fluent_arrow_rotate_counterclockwise_20_filled = 61831
ic_fluent_arrow_rotate_counterclockwise_24_filled = 61832
ic_fluent_arrow_sort_20_filled = 61834
ic_fluent_arrow_sort_24_filled = 61835
ic_fluent_arrow_sort_28_filled = 61836
ic_fluent_arrow_swap_20_filled = 61837
ic_fluent_arrow_swap_24_filled = 61838
ic_fluent_arrow_sync_12_filled = 61839
ic_fluent_arrow_sync_20_filled = 61840
ic_fluent_arrow_sync_24_filled = 61841
ic_fluent_arrow_sync_circle_16_filled = 61842
ic_fluent_arrow_sync_circle_20_filled = 61843
ic_fluent_arrow_sync_circle_24_filled = 61844
ic_fluent_arrow_sync_off_12_filled = 61845
ic_fluent_arrow_trending_16_filled = 61846
ic_fluent_arrow_trending_20_filled = 61847
ic_fluent_arrow_trending_24_filled = 61848
ic_fluent_arrow_undo_20_filled = 61849
ic_fluent_arrow_undo_24_filled = 61850
ic_fluent_arrow_up_20_filled = 61851
ic_fluent_arrow_up_24_filled = 61852
ic_fluent_arrow_up_28_filled = 61853
ic_fluent_arrow_up_left_24_filled = 61857
ic_fluent_arrow_up_right_24_filled = 61859
ic_fluent_arrow_upload_20_filled = 61860
ic_fluent_arrow_upload_24_filled = 61861
ic_fluent_arrows_bidirectional_24_filled = 61862
ic_fluent_attach_16_filled = 61864
ic_fluent_attach_20_filled = 61865
ic_fluent_attach_24_filled = 61866
ic_fluent_autocorrect_24_filled = 61870
ic_fluent_autosum_20_filled = 61871
ic_fluent_autosum_24_filled = 61872
ic_fluent_backspace_20_filled = 61873
ic_fluent_backspace_24_filled = 61874
ic_fluent_badge_24_filled = 61877
ic_fluent_balloon_20_filled = 61878
ic_fluent_balloon_24_filled = 61879
ic_fluent_battery_0_20_filled = 61883
ic_fluent_battery_0_24_filled = 61884
ic_fluent_battery_1_20_filled = 61885
ic_fluent_battery_1_24_filled = 61886
ic_fluent_battery_2_20_filled = 61887
ic_fluent_battery_2_24_filled = 61888
ic_fluent_battery_3_20_filled = 61889
ic_fluent_battery_3_24_filled = 61890
ic_fluent_battery_4_20_filled = 61891
ic_fluent_battery_4_24_filled = 61892
ic_fluent_battery_5_20_filled = 61893
ic_fluent_battery_5_24_filled = 61894
ic_fluent_battery_6_20_filled = 61895
ic_fluent_battery_6_24_filled = 61896
ic_fluent_battery_7_20_filled = 61897
ic_fluent_battery_7_24_filled = 61898
ic_fluent_battery_8_20_filled = 61899
ic_fluent_battery_8_24_filled = 61900
ic_fluent_battery_9_20_filled = 61901
ic_fluent_battery_9_24_filled = 61902
ic_fluent_battery_charge_20_filled = 61903
ic_fluent_battery_charge_24_filled = 61904
ic_fluent_battery_saver_20_filled = 61907
ic_fluent_battery_saver_24_filled = 61908
ic_fluent_battery_warning_24_filled = 61909
ic_fluent_beaker_16_filled = 61910
ic_fluent_beaker_20_filled = 61911
ic_fluent_beaker_24_filled = 61912
ic_fluent_bed_20_filled = 61913
ic_fluent_bed_24_filled = 61914
ic_fluent_bluetooth_20_filled = 61918
ic_fluent_bluetooth_24_filled = 61919
ic_fluent_bluetooth_connected_24_filled = 61920
ic_fluent_bluetooth_disabled_24_filled = 61921
ic_fluent_bluetooth_searching_24_filled = 61922
ic_fluent_board_24_filled = 61923
ic_fluent_book_globe_24_filled = 61936
ic_fluent_book_number_16_filled = 61937
ic_fluent_book_number_20_filled = 61938
ic_fluent_book_number_24_filled = 61939
ic_fluent_bookmark_16_filled = 61940
ic_fluent_bookmark_20_filled = 61941
ic_fluent_bookmark_24_filled = 61942
ic_fluent_bookmark_28_filled = 61943
ic_fluent_bookmark_off_24_filled = 61944
ic_fluent_bot_24_filled = 61945
ic_fluent_bot_add_24_filled = 61946
ic_fluent_branch_24_filled = 61947
ic_fluent_briefcase_20_filled = 61948
ic_fluent_briefcase_24_filled = 61949
ic_fluent_broad_activity_feed_24_filled = 61952
ic_fluent_broom_20_filled = 61953
ic_fluent_broom_24_filled = 61954
ic_fluent_building_24_filled = 61957
ic_fluent_building_retail_24_filled = 61961
ic_fluent_calculator_20_filled = 61962
ic_fluent_calendar_3_day_20_filled = 61966
ic_fluent_calendar_3_day_24_filled = 61967
ic_fluent_calendar_3_day_28_filled = 61968
ic_fluent_calendar_add_20_filled = 61969
ic_fluent_calendar_add_24_filled = 61970
ic_fluent_calendar_agenda_20_filled = 61971
ic_fluent_calendar_agenda_24_filled = 61972
ic_fluent_calendar_agenda_28_filled = 61973
ic_fluent_calendar_arrow_right_20_filled = 61974
ic_fluent_calendar_assistant_20_filled = 61975
ic_fluent_calendar_assistant_24_filled = 61976
ic_fluent_calendar_cancel_20_filled = 61977
ic_fluent_calendar_cancel_24_filled = 61978
ic_fluent_calendar_checkmark_16_filled = 61979
ic_fluent_calendar_checkmark_20_filled = 61980
ic_fluent_calendar_clock_20_filled = 61981
ic_fluent_calendar_clock_24_filled = 61982
ic_fluent_calendar_day_20_filled = 61986
ic_fluent_calendar_day_24_filled = 61987
ic_fluent_calendar_day_28_filled = 61988
ic_fluent_calendar_empty_16_filled = 61989
ic_fluent_calendar_empty_20_filled = 61990
ic_fluent_calendar_empty_24_filled = 61991
ic_fluent_calendar_empty_28_filled = 61992
ic_fluent_calendar_month_20_filled = 61994
ic_fluent_calendar_month_24_filled = 61995
ic_fluent_calendar_month_28_filled = 61996
ic_fluent_calendar_multiple_20_filled = 61997
ic_fluent_calendar_multiple_24_filled = 61998
ic_fluent_calendar_person_20_filled = 62000
ic_fluent_calendar_reply_16_filled = 62001
ic_fluent_calendar_reply_20_filled = 62002
ic_fluent_calendar_reply_24_filled = 62003
ic_fluent_calendar_reply_28_filled = 62004
ic_fluent_calendar_settings_20_filled = 62005
ic_fluent_calendar_star_20_filled = 62006
ic_fluent_calendar_star_24_filled = 62007
ic_fluent_calendar_sync_16_filled = 62008
ic_fluent_calendar_sync_20_filled = 62009
ic_fluent_calendar_sync_24_filled = 62010
ic_fluent_calendar_today_16_filled = 62011
ic_fluent_calendar_today_20_filled = 62012
ic_fluent_calendar_today_24_filled = 62013
ic_fluent_calendar_today_28_filled = 62014
ic_fluent_calendar_week_numbers_24_filled = 62015
ic_fluent_calendar_week_start_20_filled = 62016
ic_fluent_calendar_week_start_24_filled = 62017
ic_fluent_calendar_week_start_28_filled = 62018
ic_fluent_calendar_work_week_16_filled = 62019
ic_fluent_calendar_work_week_20_filled = 62020
ic_fluent_calendar_work_week_24_filled = 62021
ic_fluent_call_add_24_filled = 62022
ic_fluent_call_end_20_filled = 62023
ic_fluent_call_end_24_filled = 62024
ic_fluent_call_end_28_filled = 62025
ic_fluent_call_forward_24_filled = 62026
ic_fluent_call_inbound_16_filled = 62027
ic_fluent_call_inbound_24_filled = 62028
ic_fluent_call_missed_16_filled = 62029
ic_fluent_call_missed_24_filled = 62030
ic_fluent_call_outbound_16_filled = 62031
ic_fluent_call_outbound_24_filled = 62032
ic_fluent_call_park_24_filled = 62033
ic_fluent_calligraphy_pen_20_filled = 62034
ic_fluent_calligraphy_pen_24_filled = 62035
ic_fluent_camera_20_filled = 62036
ic_fluent_camera_24_filled = 62037
ic_fluent_camera_28_filled = 62038
ic_fluent_camera_add_20_filled = 62039
ic_fluent_camera_add_24_filled = 62040
ic_fluent_camera_add_48_filled = 62041
ic_fluent_camera_switch_24_filled = 62042
ic_fluent_caret_down_12_filled = 62047
ic_fluent_caret_down_16_filled = 62048
ic_fluent_caret_down_20_filled = 62049
ic_fluent_caret_down_24_filled = 62050
ic_fluent_caret_left_12_filled = 62051
ic_fluent_caret_left_16_filled = 62052
ic_fluent_caret_left_20_filled = 62053
ic_fluent_caret_left_24_filled = 62054
ic_fluent_caret_right_12_filled = 62055
ic_fluent_caret_right_16_filled = 62056
ic_fluent_caret_right_20_filled = 62057
ic_fluent_caret_right_24_filled = 62058
ic_fluent_cart_24_filled = 62059
ic_fluent_cast_20_filled = 62060
ic_fluent_cast_24_filled = 62061
ic_fluent_cast_28_filled = 62062
ic_fluent_cellular_3g_24_filled = 62063
ic_fluent_cellular_4g_24_filled = 62064
ic_fluent_cellular_data_1_20_filled = 62065
ic_fluent_cellular_data_1_24_filled = 62066
ic_fluent_cellular_data_2_20_filled = 62067
ic_fluent_cellular_data_2_24_filled = 62068
ic_fluent_cellular_data_3_20_filled = 62069
ic_fluent_cellular_data_3_24_filled = 62070
ic_fluent_cellular_data_4_20_filled = 62071
ic_fluent_cellular_data_4_24_filled = 62072
ic_fluent_cellular_data_5_20_filled = 62073
ic_fluent_cellular_data_5_24_filled = 62074
ic_fluent_certificate_20_filled = 62078
ic_fluent_certificate_24_filled = 62079
ic_fluent_channel_16_filled = 62080
ic_fluent_channel_20_filled = 62081
ic_fluent_channel_24_filled = 62082
ic_fluent_chat_20_filled = 62086
ic_fluent_chat_24_filled = 62087
ic_fluent_chat_28_filled = 62088
ic_fluent_chat_bubbles_question_24_filled = 62089
ic_fluent_chat_help_24_filled = 62090
ic_fluent_chat_off_24_filled = 62091
ic_fluent_chat_warning_24_filled = 62092
ic_fluent_checkbox_checked_20_filled = 62093
ic_fluent_checkbox_checked_24_filled = 62094
ic_fluent_checkbox_unchecked_12_filled = 62095
ic_fluent_checkbox_unchecked_16_filled = 62096
ic_fluent_checkbox_unchecked_20_filled = 62097
ic_fluent_checkbox_unchecked_24_filled = 62098
ic_fluent_checkmark_12_filled = 62099
ic_fluent_checkmark_20_filled = 62100
ic_fluent_checkmark_24_filled = 62101
ic_fluent_checkmark_28_filled = 62102
ic_fluent_checkmark_circle_16_filled = 62103
ic_fluent_checkmark_circle_20_filled = 62104
ic_fluent_checkmark_circle_24_filled = 62105
ic_fluent_checkmark_circle_48_filled = 62106
ic_fluent_checkmark_lock_16_filled = 62107
ic_fluent_checkmark_lock_20_filled = 62108
ic_fluent_checkmark_lock_24_filled = 62109
ic_fluent_checkmark_square_24_filled = 62110
ic_fluent_checkmark_underline_circle_16_filled = 62111
ic_fluent_checkmark_underline_circle_20_filled = 62112
ic_fluent_chevron_down_12_filled = 62113
ic_fluent_chevron_down_16_filled = 62114
ic_fluent_chevron_down_20_filled = 62115
ic_fluent_chevron_down_24_filled = 62116
ic_fluent_chevron_down_28_filled = 62117
ic_fluent_chevron_down_48_filled = 62118
ic_fluent_chevron_left_12_filled = 62120
ic_fluent_chevron_left_16_filled = 62121
ic_fluent_chevron_left_20_filled = 62122
ic_fluent_chevron_left_24_filled = 62123
ic_fluent_chevron_left_28_filled = 62124
ic_fluent_chevron_left_48_filled = 62125
ic_fluent_chevron_right_12_filled = 62126
ic_fluent_chevron_right_16_filled = 62127
ic_fluent_chevron_right_20_filled = 62128
ic_fluent_chevron_right_24_filled = 62129
ic_fluent_chevron_right_28_filled = 62130
ic_fluent_chevron_right_48_filled = 62131
ic_fluent_chevron_up_12_filled = 62132
ic_fluent_chevron_up_16_filled = 62133
ic_fluent_chevron_up_20_filled = 62134
ic_fluent_chevron_up_24_filled = 62135
ic_fluent_chevron_up_28_filled = 62136
ic_fluent_chevron_up_48_filled = 62137
ic_fluent_circle_16_filled = 62138
ic_fluent_circle_20_filled = 62139
ic_fluent_circle_24_filled = 62140
ic_fluent_circle_half_fill_20_filled = 62141
ic_fluent_circle_half_fill_24_filled = 62142
ic_fluent_circle_line_24_filled = 62143
ic_fluent_circle_small_24_filled = 62144
ic_fluent_city_16_filled = 62145
ic_fluent_city_20_filled = 62146
ic_fluent_city_24_filled = 62147
ic_fluent_class_24_filled = 62148
ic_fluent_classification_16_filled = 62149
ic_fluent_classification_20_filled = 62150
ic_fluent_classification_24_filled = 62151
ic_fluent_clear_formatting_24_filled = 62152
ic_fluent_clipboard_20_filled = 62153
ic_fluent_clipboard_24_filled = 62154
ic_fluent_clipboard_code_16_filled = 62155
ic_fluent_clipboard_code_20_filled = 62156
ic_fluent_clipboard_code_24_filled = 62157
ic_fluent_clipboard_letter_16_filled = 62158
ic_fluent_clipboard_letter_20_filled = 62159
ic_fluent_clipboard_letter_24_filled = 62160
ic_fluent_clipboard_link_16_filled = 62161
ic_fluent_clipboard_link_20_filled = 62162
ic_fluent_clipboard_link_24_filled = 62163
ic_fluent_clipboard_more_24_filled = 62164
ic_fluent_clipboard_paste_20_filled = 62165
ic_fluent_clipboard_paste_24_filled = 62166
ic_fluent_clipboard_search_20_filled = 62167
ic_fluent_clipboard_search_24_filled = 62168
ic_fluent_clock_12_filled = 62171
ic_fluent_clock_16_filled = 62172
ic_fluent_clock_20_filled = 62173
ic_fluent_clock_24_filled = 62174
ic_fluent_clock_28_filled = 62175
ic_fluent_clock_48_filled = 62176
ic_fluent_clock_alarm_20_filled = 62177
ic_fluent_clock_alarm_24_filled = 62178
ic_fluent_closed_caption_24_filled = 62179
ic_fluent_cloud_20_filled = 62180
ic_fluent_cloud_24_filled = 62181
ic_fluent_cloud_48_filled = 62182
ic_fluent_cloud_off_24_filled = 62186
ic_fluent_cloud_off_48_filled = 62187
ic_fluent_code_20_filled = 62191
ic_fluent_code_24_filled = 62192
ic_fluent_collections_20_filled = 62193
ic_fluent_collections_24_filled = 62194
ic_fluent_collections_add_20_filled = 62195
ic_fluent_collections_add_24_filled = 62196
ic_fluent_color_20_filled = 62197
ic_fluent_color_24_filled = 62198
ic_fluent_color_background_20_filled = 62199
ic_fluent_color_background_24_filled = 62200
ic_fluent_color_fill_20_filled = 62201
ic_fluent_color_fill_24_filled = 62202
ic_fluent_color_line_20_filled = 62203
ic_fluent_color_line_24_filled = 62204
ic_fluent_column_triple_24_filled = 62205
ic_fluent_comment_16_filled = 62206
ic_fluent_comment_20_filled = 62207
ic_fluent_comment_24_filled = 62208
ic_fluent_comment_add_24_filled = 62209
ic_fluent_comment_mention_16_filled = 62211
ic_fluent_comment_mention_20_filled = 62212
ic_fluent_comment_mention_24_filled = 62213
ic_fluent_comment_multiple_16_filled = 62214
ic_fluent_comment_multiple_20_filled = 62215
ic_fluent_comment_multiple_24_filled = 62216
ic_fluent_communication_16_filled = 62220
ic_fluent_communication_20_filled = 62221
ic_fluent_communication_24_filled = 62222
ic_fluent_compass_northwest_16_filled = 62223
ic_fluent_compass_northwest_20_filled = 62224
ic_fluent_compass_northwest_24_filled = 62225
ic_fluent_compass_northwest_28_filled = 62226
ic_fluent_compose_16_filled = 62227
ic_fluent_compose_20_filled = 62228
ic_fluent_compose_24_filled = 62229
ic_fluent_compose_28_filled = 62230
ic_fluent_conference_room_16_filled = 62231
ic_fluent_conference_room_20_filled = 62232
ic_fluent_conference_room_24_filled = 62233
ic_fluent_conference_room_28_filled = 62234
ic_fluent_conference_room_48_filled = 62235
ic_fluent_connector_16_filled = 62236
ic_fluent_connector_20_filled = 62237
ic_fluent_connector_24_filled = 62238
ic_fluent_contact_card_20_filled = 62239
ic_fluent_contact_card_24_filled = 62240
ic_fluent_contact_card_group_24_filled = 62241
ic_fluent_content_settings_16_filled = 62243
ic_fluent_content_settings_20_filled = 62244
ic_fluent_content_settings_24_filled = 62245
ic_fluent_cookies_20_filled = 62248
ic_fluent_cookies_24_filled = 62249
ic_fluent_copy_16_filled = 62250
ic_fluent_copy_20_filled = 62251
ic_fluent_copy_24_filled = 62252
ic_fluent_crop_24_filled = 62257
ic_fluent_crop_interim_24_filled = 62258
ic_fluent_crop_interim_off_24_filled = 62259
ic_fluent_cube_16_filled = 62260
ic_fluent_cube_20_filled = 62261
ic_fluent_cube_24_filled = 62262
ic_fluent_cut_20_filled = 62266
ic_fluent_cut_24_filled = 62267
ic_fluent_dark_theme_24_filled = 62268
ic_fluent_data_area_24_filled = 62269
ic_fluent_data_bar_horizontal_24_filled = 62270
ic_fluent_data_bar_vertical_20_filled = 62271
ic_fluent_data_bar_vertical_24_filled = 62272
ic_fluent_data_funnel_24_filled = 62273
ic_fluent_data_histogram_24_filled = 62274
ic_fluent_data_line_24_filled = 62275
ic_fluent_data_pie_20_filled = 62276
ic_fluent_data_pie_24_filled = 62277
ic_fluent_data_scatter_24_filled = 62278
ic_fluent_data_sunburst_24_filled = 62279
ic_fluent_data_treemap_24_filled = 62280
ic_fluent_data_usage_24_filled = 62281
ic_fluent_data_waterfall_24_filled = 62282
ic_fluent_data_whisker_24_filled = 62283
ic_fluent_delete_20_filled = 62284
ic_fluent_delete_24_filled = 62285
ic_fluent_delete_28_filled = 62286
ic_fluent_delete_48_filled = 62287
ic_fluent_delete_off_20_filled = 62290
ic_fluent_delete_off_24_filled = 62291
ic_fluent_dentist_24_filled = 62292
ic_fluent_design_ideas_16_filled = 62293
ic_fluent_design_ideas_20_filled = 62294
ic_fluent_design_ideas_24_filled = 62295
ic_fluent_desktop_16_filled = 62296
ic_fluent_desktop_20_filled = 62297
ic_fluent_desktop_24_filled = 62298
ic_fluent_desktop_28_filled = 62299
ic_fluent_developer_board_24_filled = 62300
ic_fluent_device_eq_24_filled = 62301
ic_fluent_dialpad_20_filled = 62302
ic_fluent_dialpad_24_filled = 62303
ic_fluent_dialpad_off_24_filled = 62304
ic_fluent_directions_20_filled = 62309
ic_fluent_directions_24_filled = 62310
ic_fluent_dismiss_12_filled = 62311
ic_fluent_dismiss_16_filled = 62312
ic_fluent_dismiss_20_filled = 62313
ic_fluent_dismiss_24_filled = 62314
ic_fluent_dismiss_28_filled = 62315
ic_fluent_dismiss_circle_16_filled = 62316
ic_fluent_dismiss_circle_20_filled = 62317
ic_fluent_dismiss_circle_24_filled = 62318
ic_fluent_dismiss_circle_48_filled = 62319
ic_fluent_divider_short_24_filled = 62320
ic_fluent_divider_tall_24_filled = 62321
ic_fluent_dock_24_filled = 62322
ic_fluent_dock_row_24_filled = 62326
ic_fluent_doctor_24_filled = 62327
ic_fluent_document_20_filled = 62328
ic_fluent_document_24_filled = 62329
ic_fluent_document_28_filled = 62330
ic_fluent_document_briefcase_20_filled = 62332
ic_fluent_document_briefcase_24_filled = 62333
ic_fluent_document_catch_up_24_filled = 62334
ic_fluent_document_copy_16_filled = 62335
ic_fluent_document_copy_20_filled = 62336
ic_fluent_document_copy_24_filled = 62337
ic_fluent_document_copy_48_filled = 62338
ic_fluent_document_dismiss_20_filled = 62339
ic_fluent_document_dismiss_24_filled = 62340
ic_fluent_document_edit_16_filled = 62341
ic_fluent_document_edit_20_filled = 62342
ic_fluent_document_edit_24_filled = 62343
ic_fluent_document_endnote_20_filled = 62344
ic_fluent_document_endnote_24_filled = 62345
ic_fluent_document_error_16_filled = 62346
ic_fluent_document_error_20_filled = 62347
ic_fluent_document_error_24_filled = 62348
ic_fluent_document_footer_24_filled = 62349
ic_fluent_document_header_24_filled = 62351
ic_fluent_document_header_footer_20_filled = 62352
ic_fluent_document_header_footer_24_filled = 62353
ic_fluent_document_landscape_20_filled = 62355
ic_fluent_document_landscape_24_filled = 62356
ic_fluent_document_margins_20_filled = 62357
ic_fluent_document_margins_24_filled = 62358
ic_fluent_document_one_page_20_filled = 62361
ic_fluent_document_one_page_24_filled = 62362
ic_fluent_document_page_bottom_center_20_filled = 62364
ic_fluent_document_page_bottom_center_24_filled = 62365
ic_fluent_document_page_bottom_left_20_filled = 62366
ic_fluent_document_page_bottom_left_24_filled = 62367
ic_fluent_document_page_bottom_right_20_filled = 62368
ic_fluent_document_page_bottom_right_24_filled = 62369
ic_fluent_document_page_break_24_filled = 62370
ic_fluent_document_page_number_20_filled = 62371
ic_fluent_document_page_number_24_filled = 62372
ic_fluent_document_page_top_center_20_filled = 62373
ic_fluent_document_page_top_center_24_filled = 62374
ic_fluent_document_page_top_left_20_filled = 62375
ic_fluent_document_page_top_left_24_filled = 62376
ic_fluent_document_page_top_right_20_filled = 62377
ic_fluent_document_page_top_right_24_filled = 62378
ic_fluent_document_pdf_16_filled = 62379
ic_fluent_document_pdf_20_filled = 62380
ic_fluent_document_pdf_24_filled = 62381
ic_fluent_document_search_20_filled = 62382
ic_fluent_document_search_24_filled = 62383
ic_fluent_document_toolbox_20_filled = 62384
ic_fluent_document_toolbox_24_filled = 62385
ic_fluent_document_width_20_filled = 62392
ic_fluent_document_width_24_filled = 62393
ic_fluent_double_swipe_down_24_filled = 62394
ic_fluent_double_swipe_up_24_filled = 62395
ic_fluent_drafts_16_filled = 62398
ic_fluent_drafts_20_filled = 62399
ic_fluent_drafts_24_filled = 62400
ic_fluent_drag_24_filled = 62401
ic_fluent_drink_beer_24_filled = 62403
ic_fluent_drink_coffee_20_filled = 62404
ic_fluent_drink_coffee_24_filled = 62405
ic_fluent_drink_margarita_24_filled = 62406
ic_fluent_drink_wine_24_filled = 62407
ic_fluent_dual_screen_24_filled = 62408
ic_fluent_dual_screen_add_24_filled = 62409
ic_fluent_dual_screen_arrow_right_24_filled = 62410
ic_fluent_dual_screen_clock_24_filled = 62411
ic_fluent_dual_screen_desktop_24_filled = 62412
ic_fluent_dual_screen_group_24_filled = 62414
ic_fluent_dual_screen_lock_24_filled = 62415
ic_fluent_dual_screen_mirror_24_filled = 62416
ic_fluent_dual_screen_pagination_24_filled = 62417
ic_fluent_dual_screen_settings_24_filled = 62418
ic_fluent_dual_screen_status_bar_24_filled = 62419
ic_fluent_dual_screen_tablet_24_filled = 62420
ic_fluent_dual_screen_update_24_filled = 62421
ic_fluent_dual_screen_vertical_scroll_24_filled = 62422
ic_fluent_dual_screen_vibrate_24_filled = 62423
ic_fluent_earth_16_filled = 62424
ic_fluent_earth_20_filled = 62425
ic_fluent_earth_24_filled = 62426
ic_fluent_edit_16_filled = 62427
ic_fluent_edit_20_filled = 62428
ic_fluent_edit_24_filled = 62429
ic_fluent_emoji_16_filled = 62430
ic_fluent_emoji_20_filled = 62431
ic_fluent_emoji_24_filled = 62432
ic_fluent_emoji_add_24_filled = 62433
ic_fluent_emoji_angry_20_filled = 62434
ic_fluent_emoji_angry_24_filled = 62435
ic_fluent_emoji_laugh_20_filled = 62436
ic_fluent_emoji_laugh_24_filled = 62437
ic_fluent_emoji_meh_20_filled = 62438
ic_fluent_emoji_meh_24_filled = 62439
ic_fluent_emoji_sad_20_filled = 62440
ic_fluent_emoji_sad_24_filled = 62441
ic_fluent_emoji_surprise_20_filled = 62442
ic_fluent_emoji_surprise_24_filled = 62443
ic_fluent_eraser_tool_24_filled = 62446
ic_fluent_error_circle_16_filled = 62447
ic_fluent_error_circle_20_filled = 62448
ic_fluent_error_circle_24_filled = 62449
ic_fluent_extended_dock_24_filled = 62451
ic_fluent_fast_acceleration_24_filled = 62460
ic_fluent_fast_forward_20_filled = 62461
ic_fluent_fast_forward_24_filled = 62462
ic_fluent_filter_20_filled = 62469
ic_fluent_filter_24_filled = 62470
ic_fluent_filter_28_filled = 62471
ic_fluent_fingerprint_24_filled = 62472
ic_fluent_flag_16_filled = 62473
ic_fluent_flag_20_filled = 62474
ic_fluent_flag_24_filled = 62475
ic_fluent_flag_28_filled = 62476
ic_fluent_flag_48_filled = 62477
ic_fluent_flag_off_24_filled = 62478
ic_fluent_flag_off_28_filled = 62479
ic_fluent_flag_off_48_filled = 62480
ic_fluent_flag_pride_16_filled = 62481
ic_fluent_flag_pride_20_filled = 62482
ic_fluent_flag_pride_24_filled = 62483
ic_fluent_flag_pride_28_filled = 62484
ic_fluent_flag_pride_48_filled = 62485
ic_fluent_flash_auto_24_filled = 62486
ic_fluent_flash_off_24_filled = 62487
ic_fluent_flashlight_24_filled = 62490
ic_fluent_flashlight_off_24_filled = 62491
ic_fluent_folder_20_filled = 62492
ic_fluent_folder_24_filled = 62493
ic_fluent_folder_28_filled = 62494
ic_fluent_folder_48_filled = 62495
ic_fluent_folder_add_20_filled = 62496
ic_fluent_folder_add_24_filled = 62497
ic_fluent_folder_add_28_filled = 62498
ic_fluent_folder_add_48_filled = 62499
ic_fluent_folder_briefcase_20_filled = 62500
ic_fluent_folder_link_20_filled = 62505
ic_fluent_folder_link_24_filled = 62506
ic_fluent_folder_link_28_filled = 62507
ic_fluent_folder_link_48_filled = 62508
ic_fluent_folder_open_16_filled = 62513
ic_fluent_folder_open_20_filled = 62514
ic_fluent_folder_open_24_filled = 62515
ic_fluent_folder_open_vertical_20_filled = 62516
ic_fluent_folder_zip_16_filled = 62520
ic_fluent_folder_zip_20_filled = 62521
ic_fluent_folder_zip_24_filled = 62522
ic_fluent_font_decrease_20_filled = 62523
ic_fluent_font_decrease_24_filled = 62524
ic_fluent_font_increase_20_filled = 62525
ic_fluent_font_increase_24_filled = 62526
ic_fluent_font_space_tracking_in_16_filled = 62527
ic_fluent_font_space_tracking_in_20_filled = 62528
ic_fluent_font_space_tracking_in_24_filled = 62529
ic_fluent_font_space_tracking_in_28_filled = 62530
ic_fluent_font_space_tracking_out_16_filled = 62531
ic_fluent_font_space_tracking_out_20_filled = 62532
ic_fluent_font_space_tracking_out_24_filled = 62533
ic_fluent_font_space_tracking_out_28_filled = 62534
ic_fluent_food_20_filled = 62535
ic_fluent_food_24_filled = 62536
ic_fluent_food_cake_24_filled = 62537
ic_fluent_food_egg_24_filled = 62538
ic_fluent_food_toast_24_filled = 62539
ic_fluent_form_new_24_filled = 62540
ic_fluent_form_new_28_filled = 62541
ic_fluent_form_new_48_filled = 62542
ic_fluent_fps_240_24_filled = 62545
ic_fluent_fps_960_24_filled = 62546
ic_fluent_games_24_filled = 62549
ic_fluent_gesture_24_filled = 62550
ic_fluent_gif_20_filled = 62551
ic_fluent_gif_24_filled = 62552
ic_fluent_gift_20_filled = 62553
ic_fluent_gift_24_filled = 62554
ic_fluent_glance_24_filled = 62555
ic_fluent_glasses_24_filled = 62556
ic_fluent_glasses_off_24_filled = 62557
ic_fluent_globe_20_filled = 62558
ic_fluent_globe_24_filled = 62559
ic_fluent_globe_add_24_filled = 62560
ic_fluent_globe_clock_24_filled = 62561
ic_fluent_globe_desktop_24_filled = 62562
ic_fluent_globe_location_24_filled = 62563
ic_fluent_globe_search_24_filled = 62564
ic_fluent_globe_video_24_filled = 62565
ic_fluent_grid_20_filled = 62566
ic_fluent_grid_24_filled = 62567
ic_fluent_grid_28_filled = 62568
ic_fluent_group_20_filled = 62569
ic_fluent_group_24_filled = 62570
ic_fluent_group_list_24_filled = 62571
ic_fluent_guest_16_filled = 62572
ic_fluent_guest_20_filled = 62573
ic_fluent_guest_24_filled = 62574
ic_fluent_guest_28_filled = 62575
ic_fluent_guest_add_24_filled = 62576
ic_fluent_handshake_16_filled = 62578
ic_fluent_handshake_20_filled = 62579
ic_fluent_handshake_24_filled = 62580
ic_fluent_hdr_24_filled = 62581
ic_fluent_headphones_24_filled = 62582
ic_fluent_headphones_28_filled = 62583
ic_fluent_headset_24_filled = 62584
ic_fluent_headset_28_filled = 62585
ic_fluent_headset_vr_20_filled = 62586
ic_fluent_headset_vr_24_filled = 62587
ic_fluent_heart_16_filled = 62588
ic_fluent_heart_20_filled = 62589
ic_fluent_heart_24_filled = 62590
ic_fluent_highlight_16_filled = 62591
ic_fluent_highlight_20_filled = 62592
ic_fluent_highlight_24_filled = 62593
ic_fluent_highlight_accent_16_filled = 62594
ic_fluent_highlight_accent_20_filled = 62595
ic_fluent_highlight_accent_24_filled = 62596
ic_fluent_history_20_filled = 62597
ic_fluent_history_24_filled = 62598
ic_fluent_home_20_filled = 62599
ic_fluent_home_24_filled = 62600
ic_fluent_home_28_filled = 62601
ic_fluent_home_add_24_filled = 62602
ic_fluent_home_checkmark_24_filled = 62603
ic_fluent_icons_20_filled = 62604
ic_fluent_icons_24_filled = 62605
ic_fluent_image_16_filled = 62606
ic_fluent_image_20_filled = 62607
ic_fluent_image_24_filled = 62608
ic_fluent_image_28_filled = 62609
ic_fluent_image_48_filled = 62610
ic_fluent_image_add_24_filled = 62611
ic_fluent_image_alt_text_20_filled = 62612
ic_fluent_image_alt_text_24_filled = 62613
ic_fluent_image_copy_20_filled = 62614
ic_fluent_image_copy_24_filled = 62615
ic_fluent_image_copy_28_filled = 62616
ic_fluent_image_edit_16_filled = 62617
ic_fluent_image_edit_20_filled = 62618
ic_fluent_image_edit_24_filled = 62619
ic_fluent_image_off_24_filled = 62623
ic_fluent_image_search_20_filled = 62624
ic_fluent_image_search_24_filled = 62625
ic_fluent_immersive_reader_20_filled = 62626
ic_fluent_immersive_reader_24_filled = 62627
ic_fluent_important_12_filled = 62628
ic_fluent_important_16_filled = 62629
ic_fluent_important_20_filled = 62630
ic_fluent_important_24_filled = 62631
ic_fluent_incognito_24_filled = 62632
ic_fluent_info_16_filled = 62633
ic_fluent_info_20_filled = 62634
ic_fluent_info_24_filled = 62635
ic_fluent_info_28_filled = 62636
ic_fluent_inking_tool_16_filled = 62637
ic_fluent_inking_tool_20_filled = 62638
ic_fluent_inking_tool_24_filled = 62639
ic_fluent_inking_tool_accent_16_filled = 62640
ic_fluent_inking_tool_accent_20_filled = 62641
ic_fluent_inking_tool_accent_24_filled = 62642
ic_fluent_inprivate_account_16_filled = 62643
ic_fluent_inprivate_account_20_filled = 62644
ic_fluent_inprivate_account_24_filled = 62645
ic_fluent_inprivate_account_28_filled = 62646
ic_fluent_insert_20_filled = 62647
ic_fluent_ios_chevron_right_20_filled = 62652
ic_fluent_javascript_16_filled = 62653
ic_fluent_javascript_20_filled = 62654
ic_fluent_javascript_24_filled = 62655
ic_fluent_key_20_filled = 62656
ic_fluent_key_24_filled = 62657
ic_fluent_keyboard_20_filled = 62658
ic_fluent_keyboard_24_filled = 62659
ic_fluent_keyboard_dock_24_filled = 62660
ic_fluent_keyboard_layout_float_24_filled = 62661
ic_fluent_keyboard_layout_one_handed_left_24_filled = 62662
ic_fluent_keyboard_layout_resize_24_filled = 62663
ic_fluent_keyboard_layout_split_24_filled = 62664
ic_fluent_keyboard_shift_24_filled = 62665
ic_fluent_keyboard_shift_uppercase_24_filled = 62666
ic_fluent_keyboard_tab_24_filled = 62667
ic_fluent_laptop_16_filled = 62668
ic_fluent_laptop_20_filled = 62669
ic_fluent_laptop_24_filled = 62670
ic_fluent_laptop_28_filled = 62671
ic_fluent_lasso_24_filled = 62675
ic_fluent_launcher_settings_24_filled = 62676
ic_fluent_layer_20_filled = 62677
ic_fluent_layer_24_filled = 62678
ic_fluent_leaf_two_16_filled = 62682
ic_fluent_leaf_two_20_filled = 62683
ic_fluent_leaf_two_24_filled = 62684
ic_fluent_library_24_filled = 62685
ic_fluent_library_28_filled = 62686
ic_fluent_lightbulb_16_filled = 62687
ic_fluent_lightbulb_20_filled = 62688
ic_fluent_lightbulb_24_filled = 62689
ic_fluent_lightbulb_circle_24_filled = 62690
ic_fluent_lightbulb_filament_16_filled = 62691
ic_fluent_lightbulb_filament_20_filled = 62692
ic_fluent_lightbulb_filament_24_filled = 62693
ic_fluent_likert_16_filled = 62695
ic_fluent_likert_20_filled = 62696
ic_fluent_likert_24_filled = 62697
ic_fluent_line_horizontal_1_20_filled = 62698
ic_fluent_line_horizontal_3_20_filled = 62699
ic_fluent_line_horizontal_5_20_filled = 62700
ic_fluent_link_16_filled = 62701
ic_fluent_link_20_filled = 62702
ic_fluent_link_24_filled = 62703
ic_fluent_link_28_filled = 62704
ic_fluent_link_48_filled = 62705
ic_fluent_link_edit_16_filled = 62706
ic_fluent_link_edit_20_filled = 62707
ic_fluent_link_edit_24_filled = 62708
ic_fluent_link_square_24_filled = 62710
ic_fluent_list_20_filled = 62711
ic_fluent_list_24_filled = 62712
ic_fluent_list_28_filled = 62713
ic_fluent_live_20_filled = 62714
ic_fluent_live_24_filled = 62715
ic_fluent_local_language_16_filled = 62716
ic_fluent_local_language_20_filled = 62717
ic_fluent_local_language_24_filled = 62718
ic_fluent_local_language_28_filled = 62719
ic_fluent_location_12_filled = 62720
ic_fluent_location_16_filled = 62721
ic_fluent_location_20_filled = 62722
ic_fluent_location_24_filled = 62723
ic_fluent_location_28_filled = 62724
ic_fluent_location_live_20_filled = 62725
ic_fluent_location_live_24_filled = 62726
ic_fluent_lock_shield_20_filled = 62732
ic_fluent_lock_shield_24_filled = 62733
ic_fluent_lock_shield_48_filled = 62734
ic_fluent_mail_20_filled = 62736
ic_fluent_mail_24_filled = 62737
ic_fluent_mail_28_filled = 62738
ic_fluent_mail_48_filled = 62739
ic_fluent_mail_add_24_filled = 62740
ic_fluent_mail_all_read_20_filled = 62744
ic_fluent_mail_all_unread_20_filled = 62745
ic_fluent_mail_clock_20_filled = 62746
ic_fluent_mail_copy_20_filled = 62747
ic_fluent_mail_copy_24_filled = 62748
ic_fluent_mail_inbox_16_filled = 62749
ic_fluent_mail_inbox_20_filled = 62750
ic_fluent_mail_inbox_24_filled = 62751
ic_fluent_mail_inbox_28_filled = 62752
ic_fluent_mail_inbox_add_16_filled = 62753
ic_fluent_mail_inbox_add_20_filled = 62754
ic_fluent_mail_inbox_add_24_filled = 62755
ic_fluent_mail_inbox_add_28_filled = 62756
ic_fluent_mail_inbox_dismiss_16_filled = 62757
ic_fluent_mail_inbox_dismiss_20_filled = 62758
ic_fluent_mail_inbox_dismiss_24_filled = 62759
ic_fluent_mail_inbox_dismiss_28_filled = 62760
ic_fluent_mail_read_20_filled = 62763
ic_fluent_mail_read_24_filled = 62764
ic_fluent_mail_read_28_filled = 62765
ic_fluent_mail_read_48_filled = 62766
ic_fluent_mail_unread_16_filled = 62767
ic_fluent_mail_unread_20_filled = 62768
ic_fluent_mail_unread_24_filled = 62769
ic_fluent_mail_unread_28_filled = 62770
ic_fluent_mail_unread_48_filled = 62771
ic_fluent_map_24_filled = 62776
ic_fluent_map_drive_16_filled = 62777
ic_fluent_map_drive_20_filled = 62778
ic_fluent_map_drive_24_filled = 62779
ic_fluent_match_app_layout_24_filled = 62780
ic_fluent_maximize_16_filled = 62781
ic_fluent_meet_now_20_filled = 62782
ic_fluent_meet_now_24_filled = 62783
ic_fluent_megaphone_16_filled = 62784
ic_fluent_megaphone_20_filled = 62785
ic_fluent_megaphone_24_filled = 62786
ic_fluent_megaphone_28_filled = 62787
ic_fluent_megaphone_off_24_filled = 62788
ic_fluent_mention_16_filled = 62789
ic_fluent_mention_20_filled = 62790
ic_fluent_mention_24_filled = 62791
ic_fluent_merge_24_filled = 62792
ic_fluent_mic_off_12_filled = 62793
ic_fluent_mic_off_16_filled = 62794
ic_fluent_mic_off_24_filled = 62795
ic_fluent_mic_off_28_filled = 62796
ic_fluent_mic_settings_24_filled = 62802
ic_fluent_midi_20_filled = 62803
ic_fluent_midi_24_filled = 62804
ic_fluent_mobile_optimized_24_filled = 62807
ic_fluent_money_16_filled = 62808
ic_fluent_money_20_filled = 62809
ic_fluent_money_24_filled = 62810
ic_fluent_more_vertical_20_filled = 62816
ic_fluent_more_vertical_24_filled = 62817
ic_fluent_more_vertical_28_filled = 62818
ic_fluent_more_vertical_48_filled = 62819
ic_fluent_movies_and_tv_24_filled = 62820
ic_fluent_my_location_24_filled = 62825
ic_fluent_navigation_20_filled = 62826
ic_fluent_navigation_24_filled = 62827
ic_fluent_network_check_24_filled = 62828
ic_fluent_new_16_filled = 62829
ic_fluent_new_24_filled = 62830
ic_fluent_news_20_filled = 62831
ic_fluent_news_24_filled = 62832
ic_fluent_news_28_filled = 62833
ic_fluent_next_16_filled = 62834
ic_fluent_next_20_filled = 62835
ic_fluent_next_24_filled = 62836
ic_fluent_note_20_filled = 62837
ic_fluent_note_24_filled = 62838
ic_fluent_note_add_16_filled = 62839
ic_fluent_note_add_20_filled = 62840
ic_fluent_note_add_24_filled = 62841
ic_fluent_notebook_24_filled = 62842
ic_fluent_notebook_error_24_filled = 62843
ic_fluent_notebook_lightning_24_filled = 62844
ic_fluent_notebook_question_mark_24_filled = 62845
ic_fluent_notebook_section_24_filled = 62846
ic_fluent_notebook_sync_24_filled = 62847
ic_fluent_notepad_20_filled = 62848
ic_fluent_notepad_24_filled = 62849
ic_fluent_notepad_28_filled = 62850
ic_fluent_number_row_16_filled = 62851
ic_fluent_number_row_20_filled = 62852
ic_fluent_number_row_24_filled = 62853
ic_fluent_number_symbol_16_filled = 62854
ic_fluent_number_symbol_20_filled = 62855
ic_fluent_number_symbol_24_filled = 62856
ic_fluent_open_16_filled = 62859
ic_fluent_open_20_filled = 62860
ic_fluent_open_24_filled = 62861
ic_fluent_open_folder_24_filled = 62862
ic_fluent_options_16_filled = 62864
ic_fluent_options_20_filled = 62865
ic_fluent_options_24_filled = 62866
ic_fluent_organization_20_filled = 62867
ic_fluent_organization_24_filled = 62868
ic_fluent_organization_28_filled = 62869
ic_fluent_page_fit_16_filled = 62872
ic_fluent_page_fit_20_filled = 62873
ic_fluent_page_fit_24_filled = 62874
ic_fluent_paint_brush_16_filled = 62875
ic_fluent_paint_brush_20_filled = 62876
ic_fluent_paint_brush_24_filled = 62877
ic_fluent_paint_bucket_16_filled = 62878
ic_fluent_paint_bucket_20_filled = 62879
ic_fluent_paint_bucket_24_filled = 62880
ic_fluent_pair_24_filled = 62881
ic_fluent_password_24_filled = 62888
ic_fluent_patient_24_filled = 62889
ic_fluent_pause_16_filled = 62890
ic_fluent_pause_20_filled = 62891
ic_fluent_pause_24_filled = 62892
ic_fluent_pause_48_filled = 62893
ic_fluent_payment_20_filled = 62894
ic_fluent_payment_24_filled = 62895
ic_fluent_people_16_filled = 62897
ic_fluent_people_20_filled = 62898
ic_fluent_people_24_filled = 62899
ic_fluent_people_28_filled = 62900
ic_fluent_people_add_16_filled = 62901
ic_fluent_people_add_20_filled = 62902
ic_fluent_people_add_24_filled = 62903
ic_fluent_people_audience_24_filled = 62904
ic_fluent_people_community_16_filled = 62905
ic_fluent_people_community_20_filled = 62906
ic_fluent_people_community_24_filled = 62907
ic_fluent_people_community_28_filled = 62908
ic_fluent_people_community_add_24_filled = 62909
ic_fluent_people_prohibited_20_filled = 62910
ic_fluent_people_search_24_filled = 62911
ic_fluent_people_settings_20_filled = 62912
ic_fluent_people_team_16_filled = 62913
ic_fluent_people_team_20_filled = 62914
ic_fluent_people_team_24_filled = 62915
ic_fluent_people_team_28_filled = 62916
ic_fluent_person_12_filled = 62917
ic_fluent_person_16_filled = 62918
ic_fluent_person_20_filled = 62919
ic_fluent_person_24_filled = 62920
ic_fluent_person_28_filled = 62921
ic_fluent_person_48_filled = 62922
ic_fluent_person_accounts_24_filled = 62923
ic_fluent_person_add_20_filled = 62924
ic_fluent_person_add_24_filled = 62925
ic_fluent_person_arrow_left_20_filled = 62926
ic_fluent_person_arrow_left_24_filled = 62927
ic_fluent_person_arrow_right_16_filled = 62928
ic_fluent_person_arrow_right_20_filled = 62929
ic_fluent_person_arrow_right_24_filled = 62930
ic_fluent_person_available_16_filled = 62931
ic_fluent_person_available_24_filled = 62932
ic_fluent_person_board_16_filled = 62934
ic_fluent_person_board_20_filled = 62935
ic_fluent_person_board_24_filled = 62936
ic_fluent_person_call_24_filled = 62937
ic_fluent_person_delete_16_filled = 62938
ic_fluent_person_delete_24_filled = 62939
ic_fluent_person_feedback_20_filled = 62940
ic_fluent_person_feedback_24_filled = 62941
ic_fluent_person_prohibited_20_filled = 62942
ic_fluent_person_question_mark_16_filled = 62943
ic_fluent_person_question_mark_20_filled = 62944
ic_fluent_person_question_mark_24_filled = 62945
ic_fluent_person_support_16_filled = 62946
ic_fluent_person_support_20_filled = 62947
ic_fluent_person_support_24_filled = 62948
ic_fluent_person_swap_16_filled = 62949
ic_fluent_person_swap_20_filled = 62950
ic_fluent_person_swap_24_filled = 62951
ic_fluent_person_voice_20_filled = 62952
ic_fluent_person_voice_24_filled = 62953
ic_fluent_phone_20_filled = 62954
ic_fluent_phone_24_filled = 62955
ic_fluent_phone_desktop_16_filled = 62958
ic_fluent_phone_desktop_20_filled = 62959
ic_fluent_phone_desktop_24_filled = 62960
ic_fluent_phone_desktop_28_filled = 62961
ic_fluent_phone_laptop_20_filled = 62964
ic_fluent_phone_laptop_24_filled = 62965
ic_fluent_phone_link_setup_24_filled = 62966
ic_fluent_phone_page_header_24_filled = 62969
ic_fluent_phone_pagination_24_filled = 62970
ic_fluent_phone_screen_time_24_filled = 62971
ic_fluent_phone_shake_24_filled = 62972
ic_fluent_phone_status_bar_24_filled = 62973
ic_fluent_phone_tablet_20_filled = 62974
ic_fluent_phone_tablet_24_filled = 62975
ic_fluent_phone_update_24_filled = 62978
ic_fluent_phone_vertical_scroll_24_filled = 62979
ic_fluent_phone_vibrate_24_filled = 62980
ic_fluent_photo_filter_24_filled = 62981
ic_fluent_picture_in_picture_16_filled = 62982
ic_fluent_picture_in_picture_20_filled = 62983
ic_fluent_picture_in_picture_24_filled = 62984
ic_fluent_pin_12_filled = 62985
ic_fluent_pin_16_filled = 62986
ic_fluent_pin_20_filled = 62987
ic_fluent_pin_24_filled = 62988
ic_fluent_pin_off_20_filled = 62989
ic_fluent_pin_off_24_filled = 62990
ic_fluent_play_20_filled = 62991
ic_fluent_play_24_filled = 62992
ic_fluent_play_48_filled = 62993
ic_fluent_play_circle_24_filled = 62994
ic_fluent_plug_disconnected_20_filled = 62995
ic_fluent_plug_disconnected_24_filled = 62996
ic_fluent_plug_disconnected_28_filled = 62997
ic_fluent_point_scan_24_filled = 62998
ic_fluent_poll_24_filled = 62999
ic_fluent_power_20_filled = 63000
ic_fluent_power_24_filled = 63001
ic_fluent_power_28_filled = 63002
ic_fluent_predictions_24_filled = 63003
ic_fluent_premium_16_filled = 63004
ic_fluent_premium_20_filled = 63005
ic_fluent_premium_24_filled = 63006
ic_fluent_premium_28_filled = 63007
ic_fluent_presence_available_10_filled = 63008
ic_fluent_presence_available_12_filled = 63009
ic_fluent_presence_available_16_filled = 63010
ic_fluent_presence_away_10_filled = 63011
ic_fluent_presence_away_12_filled = 63012
ic_fluent_presence_away_16_filled = 63013
ic_fluent_presence_busy_10_filled = 63014
ic_fluent_presence_busy_12_filled = 63015
ic_fluent_presence_busy_16_filled = 63016
ic_fluent_presence_dnd_10_filled = 63017
ic_fluent_presence_dnd_12_filled = 63018
ic_fluent_presence_dnd_16_filled = 63019
ic_fluent_presenter_24_filled = 63020
ic_fluent_presenter_off_24_filled = 63021
ic_fluent_preview_link_16_filled = 63022
ic_fluent_preview_link_20_filled = 63023
ic_fluent_preview_link_24_filled = 63024
ic_fluent_previous_16_filled = 63025
ic_fluent_previous_20_filled = 63026
ic_fluent_previous_24_filled = 63027
ic_fluent_print_20_filled = 63028
ic_fluent_print_24_filled = 63029
ic_fluent_print_48_filled = 63030
ic_fluent_prohibited_20_filled = 63031
ic_fluent_prohibited_24_filled = 63032
ic_fluent_prohibited_28_filled = 63033
ic_fluent_prohibited_48_filled = 63034
ic_fluent_protocol_handler_16_filled = 63036
ic_fluent_protocol_handler_20_filled = 63037
ic_fluent_protocol_handler_24_filled = 63038
ic_fluent_qr_code_24_filled = 63039
ic_fluent_qr_code_28_filled = 63040
ic_fluent_question_16_filled = 63041
ic_fluent_question_20_filled = 63042
ic_fluent_question_24_filled = 63043
ic_fluent_question_28_filled = 63044
ic_fluent_question_48_filled = 63045
ic_fluent_question_circle_16_filled = 63046
ic_fluent_question_circle_20_filled = 63047
ic_fluent_question_circle_24_filled = 63048
ic_fluent_question_circle_28_filled = 63049
ic_fluent_question_circle_48_filled = 63050
ic_fluent_quiz_new_24_filled = 63051
ic_fluent_quiz_new_28_filled = 63052
ic_fluent_quiz_new_48_filled = 63053
ic_fluent_radio_button_20_filled = 63054
ic_fluent_radio_button_24_filled = 63055
ic_fluent_rating_mature_16_filled = 63056
ic_fluent_rating_mature_20_filled = 63057
ic_fluent_rating_mature_24_filled = 63058
ic_fluent_re_order_16_filled = 63059
ic_fluent_re_order_24_filled = 63060
ic_fluent_read_aloud_20_filled = 63063
ic_fluent_read_aloud_24_filled = 63064
ic_fluent_reading_list_16_filled = 63067
ic_fluent_reading_list_20_filled = 63068
ic_fluent_reading_list_24_filled = 63069
ic_fluent_reading_list_28_filled = 63070
ic_fluent_reading_list_add_16_filled = 63071
ic_fluent_reading_list_add_20_filled = 63072
ic_fluent_reading_list_add_24_filled = 63073
ic_fluent_reading_list_add_28_filled = 63074
ic_fluent_reading_mode_mobile_20_filled = 63077
ic_fluent_reading_mode_mobile_24_filled = 63078
ic_fluent_record_16_filled = 63082
ic_fluent_record_20_filled = 63083
ic_fluent_record_24_filled = 63084
ic_fluent_rename_16_filled = 63090
ic_fluent_rename_20_filled = 63091
ic_fluent_rename_24_filled = 63092
ic_fluent_rename_28_filled = 63093
ic_fluent_resize_20_filled = 63094
ic_fluent_resize_image_24_filled = 63095
ic_fluent_resize_table_24_filled = 63096
ic_fluent_resize_video_24_filled = 63097
ic_fluent_reward_16_filled = 63099
ic_fluent_reward_20_filled = 63100
ic_fluent_reward_24_filled = 63101
ic_fluent_rewind_20_filled = 63102
ic_fluent_rewind_24_filled = 63103
ic_fluent_rocket_16_filled = 63104
ic_fluent_rocket_20_filled = 63105
ic_fluent_rocket_24_filled = 63106
ic_fluent_router_24_filled = 63107
ic_fluent_row_triple_24_filled = 63108
ic_fluent_ruler_16_filled = 63109
ic_fluent_ruler_20_filled = 63110
ic_fluent_ruler_24_filled = 63111
ic_fluent_run_24_filled = 63112
ic_fluent_save_20_filled = 63113
ic_fluent_save_24_filled = 63114
ic_fluent_save_copy_24_filled = 63117
ic_fluent_savings_16_filled = 63118
ic_fluent_savings_20_filled = 63119
ic_fluent_savings_24_filled = 63120
ic_fluent_scale_fill_24_filled = 63121
ic_fluent_scale_fit_16_filled = 63122
ic_fluent_scale_fit_20_filled = 63123
ic_fluent_scale_fit_24_filled = 63124
ic_fluent_scan_24_filled = 63125
ic_fluent_scratchpad_24_filled = 63126
ic_fluent_screenshot_20_filled = 63127
ic_fluent_screenshot_24_filled = 63128
ic_fluent_search_20_filled = 63129
ic_fluent_search_24_filled = 63130
ic_fluent_search_28_filled = 63131
ic_fluent_search_info_24_filled = 63132
ic_fluent_search_square_24_filled = 63133
ic_fluent_select_all_off_24_filled = 63135
ic_fluent_select_object_20_filled = 63136
ic_fluent_select_object_24_filled = 63137
ic_fluent_send_20_filled = 63138
ic_fluent_send_24_filled = 63139
ic_fluent_send_28_filled = 63140
ic_fluent_send_clock_20_filled = 63141
ic_fluent_send_copy_24_filled = 63142
ic_fluent_serial_port_16_filled = 63146
ic_fluent_serial_port_20_filled = 63147
ic_fluent_serial_port_24_filled = 63148
ic_fluent_service_bell_24_filled = 63149
ic_fluent_settings_16_filled = 63153
ic_fluent_settings_20_filled = 63154
ic_fluent_settings_24_filled = 63155
ic_fluent_settings_28_filled = 63156
ic_fluent_shapes_16_filled = 63157
ic_fluent_shapes_20_filled = 63158
ic_fluent_shapes_24_filled = 63159
ic_fluent_share_20_filled = 63160
ic_fluent_share_24_filled = 63161
ic_fluent_share_android_20_filled = 63162
ic_fluent_share_android_24_filled = 63163
ic_fluent_share_close_tray_24_filled = 63164
ic_fluent_share_ios_20_filled = 63166
ic_fluent_share_ios_24_filled = 63167
ic_fluent_share_ios_28_filled = 63168
ic_fluent_share_ios_48_filled = 63169
ic_fluent_shield_20_filled = 63175
ic_fluent_shield_24_filled = 63176
ic_fluent_shield_dismiss_20_filled = 63177
ic_fluent_shield_dismiss_24_filled = 63178
ic_fluent_shield_error_20_filled = 63179
ic_fluent_shield_error_24_filled = 63180
ic_fluent_shield_keyhole_16_filled = 63181
ic_fluent_shield_keyhole_20_filled = 63182
ic_fluent_shield_keyhole_24_filled = 63183
ic_fluent_shield_prohibited_20_filled = 63184
ic_fluent_shield_prohibited_24_filled = 63185
ic_fluent_shifts_24_filled = 63186
ic_fluent_shifts_28_filled = 63189
ic_fluent_shifts_30_minutes_24_filled = 63190
ic_fluent_shifts_activity_20_filled = 63191
ic_fluent_shifts_activity_24_filled = 63192
ic_fluent_shifts_add_24_filled = 63193
ic_fluent_shifts_availability_24_filled = 63195
ic_fluent_shifts_open_20_filled = 63197
ic_fluent_shifts_open_24_filled = 63198
ic_fluent_shifts_team_24_filled = 63200
ic_fluent_sign_out_24_filled = 63203
ic_fluent_signature_16_filled = 63204
ic_fluent_signature_20_filled = 63205
ic_fluent_signature_24_filled = 63206
ic_fluent_signature_28_filled = 63207
ic_fluent_sim_16_filled = 63211
ic_fluent_sim_20_filled = 63212
ic_fluent_sim_24_filled = 63213
ic_fluent_sleep_24_filled = 63214
ic_fluent_slide_add_24_filled = 63215
ic_fluent_slide_hide_24_filled = 63217
ic_fluent_slide_layout_20_filled = 63218
ic_fluent_slide_layout_24_filled = 63219
ic_fluent_slide_microphone_24_filled = 63220
ic_fluent_slide_text_24_filled = 63221
ic_fluent_snooze_16_filled = 63229
ic_fluent_snooze_24_filled = 63230
ic_fluent_sound_source_24_filled = 63231
ic_fluent_sound_source_28_filled = 63232
ic_fluent_spacebar_24_filled = 63233
ic_fluent_speaker_0_24_filled = 63234
ic_fluent_speaker_1_24_filled = 63236
ic_fluent_speaker_bluetooth_24_filled = 63240
ic_fluent_speaker_edit_16_filled = 63241
ic_fluent_speaker_edit_20_filled = 63242
ic_fluent_speaker_edit_24_filled = 63243
ic_fluent_speaker_off_24_filled = 63247
ic_fluent_speaker_off_28_filled = 63248
ic_fluent_speaker_settings_24_filled = 63249
ic_fluent_spinner_ios_20_filled = 63250
ic_fluent_star_12_filled = 63254
ic_fluent_star_16_filled = 63255
ic_fluent_star_20_filled = 63256
ic_fluent_star_24_filled = 63257
ic_fluent_star_28_filled = 63258
ic_fluent_star_add_16_filled = 63259
ic_fluent_star_add_20_filled = 63260
ic_fluent_star_add_24_filled = 63261
ic_fluent_star_arrow_right_start_24_filled = 63263
ic_fluent_star_emphasis_24_filled = 63264
ic_fluent_star_half_12_filled = 63265
ic_fluent_star_half_16_filled = 63266
ic_fluent_star_half_20_filled = 63267
ic_fluent_star_half_24_filled = 63268
ic_fluent_star_half_28_filled = 63269
ic_fluent_star_off_12_filled = 63270
ic_fluent_star_off_16_filled = 63271
ic_fluent_star_off_20_filled = 63272
ic_fluent_star_off_24_filled = 63273
ic_fluent_star_off_28_filled = 63274
ic_fluent_star_one_quarter_12_filled = 63275
ic_fluent_star_one_quarter_16_filled = 63276
ic_fluent_star_one_quarter_20_filled = 63277
ic_fluent_star_one_quarter_24_filled = 63278
ic_fluent_star_one_quarter_28_filled = 63279
ic_fluent_star_prohibited_16_filled = 63280
ic_fluent_star_prohibited_20_filled = 63281
ic_fluent_star_prohibited_24_filled = 63282
ic_fluent_star_settings_24_filled = 63283
ic_fluent_star_three_quarter_12_filled = 63284
ic_fluent_star_three_quarter_16_filled = 63285
ic_fluent_star_three_quarter_20_filled = 63286
ic_fluent_star_three_quarter_24_filled = 63287
ic_fluent_star_three_quarter_28_filled = 63288
ic_fluent_status_16_filled = 63289
ic_fluent_status_20_filled = 63290
ic_fluent_status_24_filled = 63291
ic_fluent_stethoscope_20_filled = 63292
ic_fluent_stethoscope_24_filled = 63293
ic_fluent_sticker_20_filled = 63294
ic_fluent_sticker_24_filled = 63295
ic_fluent_sticker_add_24_filled = 63296
ic_fluent_stop_16_filled = 63297
ic_fluent_stop_20_filled = 63298
ic_fluent_stop_24_filled = 63299
ic_fluent_storage_24_filled = 63300
ic_fluent_store_microsoft_16_filled = 63304
ic_fluent_store_microsoft_20_filled = 63305
ic_fluent_store_microsoft_24_filled = 63306
ic_fluent_style_guide_24_filled = 63307
ic_fluent_sub_grid_24_filled = 63308
ic_fluent_surface_earbuds_20_filled = 63312
ic_fluent_surface_earbuds_24_filled = 63313
ic_fluent_surface_hub_20_filled = 63314
ic_fluent_surface_hub_24_filled = 63315
ic_fluent_swipe_down_24_filled = 63316
ic_fluent_swipe_right_24_filled = 63317
ic_fluent_swipe_up_24_filled = 63318
ic_fluent_symbols_24_filled = 63319
ic_fluent_sync_off_16_filled = 63320
ic_fluent_sync_off_20_filled = 63321
ic_fluent_system_24_filled = 63322
ic_fluent_tab_16_filled = 63323
ic_fluent_tab_20_filled = 63324
ic_fluent_tab_24_filled = 63325
ic_fluent_tab_28_filled = 63326
ic_fluent_tab_desktop_20_filled = 63327
ic_fluent_tab_desktop_arrow_clockwise_16_filled = 63328
ic_fluent_tab_desktop_arrow_clockwise_20_filled = 63329
ic_fluent_tab_desktop_arrow_clockwise_24_filled = 63330
ic_fluent_tab_desktop_clock_20_filled = 63331
ic_fluent_tab_desktop_copy_20_filled = 63332
ic_fluent_tab_desktop_image_16_filled = 63333
ic_fluent_tab_desktop_image_20_filled = 63334
ic_fluent_tab_desktop_image_24_filled = 63335
ic_fluent_tab_desktop_multiple_20_filled = 63336
ic_fluent_tab_desktop_new_page_20_filled = 63337
ic_fluent_tab_in_private_16_filled = 63338
ic_fluent_tab_in_private_20_filled = 63339
ic_fluent_tab_in_private_24_filled = 63340
ic_fluent_tab_in_private_28_filled = 63341
ic_fluent_tab_inprivate_account_20_filled = 63342
ic_fluent_tab_inprivate_account_24_filled = 63343
ic_fluent_table_20_filled = 63349
ic_fluent_table_24_filled = 63350
ic_fluent_table_add_24_filled = 63351
ic_fluent_table_cells_merge_20_filled = 63352
ic_fluent_table_cells_merge_24_filled = 63353
ic_fluent_table_cells_split_20_filled = 63354
ic_fluent_table_cells_split_24_filled = 63355
ic_fluent_table_edit_24_filled = 63360
ic_fluent_table_freeze_column_24_filled = 63362
ic_fluent_table_freeze_row_24_filled = 63363
ic_fluent_table_move_left_24_filled = 63369
ic_fluent_table_move_right_24_filled = 63370
ic_fluent_table_settings_24_filled = 63375
ic_fluent_table_switch_24_filled = 63376
ic_fluent_tablet_20_filled = 63377
ic_fluent_tablet_24_filled = 63378
ic_fluent_tabs_24_filled = 63379
ic_fluent_tag_20_filled = 63380
ic_fluent_tag_24_filled = 63381
ic_fluent_tap_double_24_filled = 63382
ic_fluent_tap_single_24_filled = 63383
ic_fluent_target_16_filled = 63384
ic_fluent_target_20_filled = 63385
ic_fluent_target_24_filled = 63386
ic_fluent_target_edit_16_filled = 63387
ic_fluent_target_edit_20_filled = 63388
ic_fluent_target_edit_24_filled = 63389
ic_fluent_task_list_add_20_filled = 63392
ic_fluent_task_list_add_24_filled = 63393
ic_fluent_tasks_app_24_filled = 63394
ic_fluent_tasks_app_28_filled = 63395
ic_fluent_teddy_24_filled = 63398
ic_fluent_temperature_20_filled = 63399
ic_fluent_temperature_24_filled = 63400
ic_fluent_tent_24_filled = 63401
ic_fluent_text_add_space_after_20_filled = 63405
ic_fluent_text_add_space_after_24_filled = 63406
ic_fluent_text_add_space_before_20_filled = 63407
ic_fluent_text_add_space_before_24_filled = 63408
ic_fluent_text_align_center_20_filled = 63409
ic_fluent_text_align_center_24_filled = 63410
ic_fluent_text_align_distributed_20_filled = 63411
ic_fluent_text_align_distributed_24_filled = 63412
ic_fluent_text_align_justify_20_filled = 63413
ic_fluent_text_align_justify_24_filled = 63414
ic_fluent_text_align_left_20_filled = 63415
ic_fluent_text_align_left_24_filled = 63416
ic_fluent_text_align_right_20_filled = 63417
ic_fluent_text_align_right_24_filled = 63418
ic_fluent_text_asterisk_20_filled = 63419
ic_fluent_text_bold_20_filled = 63420
ic_fluent_text_bold_24_filled = 63421
ic_fluent_text_bullet_list_add_24_filled = 63424
ic_fluent_text_bullet_list_square_24_filled = 63425
ic_fluent_text_bullet_list_square_warning_16_filled = 63426
ic_fluent_text_bullet_list_square_warning_20_filled = 63427
ic_fluent_text_bullet_list_square_warning_24_filled = 63428
ic_fluent_text_bullet_list_tree_16_filled = 63429
ic_fluent_text_bullet_list_tree_20_filled = 63430
ic_fluent_text_bullet_list_tree_24_filled = 63431
ic_fluent_text_change_case_20_filled = 63434
ic_fluent_text_change_case_24_filled = 63435
ic_fluent_text_clear_formatting_20_filled = 63444
ic_fluent_text_clear_formatting_24_filled = 63445
ic_fluent_text_collapse_24_filled = 63446
ic_fluent_text_color_20_filled = 63447
ic_fluent_text_color_24_filled = 63448
ic_fluent_text_column_one_20_filled = 63449
ic_fluent_text_column_one_24_filled = 63450
ic_fluent_text_column_three_20_filled = 63451
ic_fluent_text_column_three_24_filled = 63452
ic_fluent_text_column_two_20_filled = 63453
ic_fluent_text_column_two_24_filled = 63454
ic_fluent_text_column_two_left_20_filled = 63455
ic_fluent_text_column_two_left_24_filled = 63456
ic_fluent_text_column_two_right_20_filled = 63457
ic_fluent_text_column_two_right_24_filled = 63458
ic_fluent_text_description_20_filled = 63459
ic_fluent_text_description_24_filled = 63460
ic_fluent_text_direction_vertical_20_filled = 63471
ic_fluent_text_direction_vertical_24_filled = 63472
ic_fluent_text_edit_style_20_filled = 63473
ic_fluent_text_edit_style_24_filled = 63474
ic_fluent_text_effects_20_filled = 63475
ic_fluent_text_effects_24_filled = 63476
ic_fluent_text_expand_24_filled = 63477
ic_fluent_text_field_16_filled = 63478
ic_fluent_text_field_20_filled = 63479
ic_fluent_text_field_24_filled = 63480
ic_fluent_text_first_line_20_filled = 63481
ic_fluent_text_first_line_24_filled = 63482
ic_fluent_text_font_16_filled = 63483
ic_fluent_text_font_20_filled = 63484
ic_fluent_text_font_24_filled = 63485
ic_fluent_text_font_size_20_filled = 63486
ic_fluent_text_font_size_24_filled = 63487
ic_fluent_text_footnote_20_filled = 63488
ic_fluent_text_footnote_24_filled = 63489
ic_fluent_text_hanging_20_filled = 63493
ic_fluent_text_hanging_24_filled = 63494
ic_fluent_text_header_1_20_filled = 63495
ic_fluent_text_header_2_20_filled = 63496
ic_fluent_text_header_3_20_filled = 63497
ic_fluent_text_italic_20_filled = 63500
ic_fluent_text_italic_24_filled = 63501
ic_fluent_text_line_spacing_20_filled = 63502
ic_fluent_text_line_spacing_24_filled = 63503
ic_fluent_text_number_format_20_filled = 63504
ic_fluent_text_number_format_24_filled = 63505
ic_fluent_text_number_list_ltr_20_filled = 63506
ic_fluent_text_number_list_ltr_24_filled = 63507
ic_fluent_text_number_list_rtl_24_filled = 63508
ic_fluent_text_proofing_tools_20_filled = 63511
ic_fluent_text_proofing_tools_24_filled = 63512
ic_fluent_text_quote_20_filled = 63513
ic_fluent_text_quote_24_filled = 63514
ic_fluent_text_sort_ascending_20_filled = 63515
ic_fluent_text_sort_descending_20_filled = 63516
ic_fluent_text_subscript_20_filled = 63519
ic_fluent_text_subscript_24_filled = 63520
ic_fluent_text_superscript_20_filled = 63521
ic_fluent_text_superscript_24_filled = 63522
ic_fluent_text_underline_20_filled = 63523
ic_fluent_text_underline_24_filled = 63524
ic_fluent_text_word_count_20_filled = 63525
ic_fluent_text_word_count_24_filled = 63526
ic_fluent_text_wrap_24_filled = 63527
ic_fluent_textbox_20_filled = 63528
ic_fluent_textbox_24_filled = 63529
ic_fluent_textbox_align_bottom_20_filled = 63532
ic_fluent_textbox_align_bottom_24_filled = 63533
ic_fluent_textbox_align_middle_20_filled = 63534
ic_fluent_textbox_align_middle_24_filled = 63535
ic_fluent_textbox_align_top_20_filled = 63536
ic_fluent_textbox_align_top_24_filled = 63537
ic_fluent_thinking_20_filled = 63540
ic_fluent_thinking_24_filled = 63541
ic_fluent_thumb_dislike_20_filled = 63542
ic_fluent_thumb_dislike_24_filled = 63543
ic_fluent_thumb_like_20_filled = 63544
ic_fluent_thumb_like_24_filled = 63545
ic_fluent_time_and_weather_24_filled = 63548
ic_fluent_time_picker_24_filled = 63549
ic_fluent_timeline_24_filled = 63550
ic_fluent_timer_10_24_filled = 63551
ic_fluent_timer_24_filled = 63552
ic_fluent_timer_2_24_filled = 63553
ic_fluent_timer_off_24_filled = 63554
ic_fluent_toggle_right_16_filled = 63555
ic_fluent_toggle_right_20_filled = 63556
ic_fluent_toggle_right_24_filled = 63557
ic_fluent_toolbox_16_filled = 63558
ic_fluent_toolbox_20_filled = 63559
ic_fluent_toolbox_24_filled = 63560
ic_fluent_toolbox_28_filled = 63561
ic_fluent_top_speed_24_filled = 63562
ic_fluent_translate_20_filled = 63563
ic_fluent_translate_24_filled = 63564
ic_fluent_trophy_16_filled = 63565
ic_fluent_trophy_20_filled = 63566
ic_fluent_trophy_24_filled = 63567
ic_fluent_uninstall_app_24_filled = 63568
ic_fluent_usb_stick_20_filled = 63575
ic_fluent_usb_stick_24_filled = 63576
ic_fluent_vault_16_filled = 63577
ic_fluent_vault_20_filled = 63578
ic_fluent_vault_24_filled = 63579
ic_fluent_vehicle_bicycle_24_filled = 63580
ic_fluent_vehicle_bus_24_filled = 63581
ic_fluent_vehicle_cab_24_filled = 63582
ic_fluent_vehicle_car_16_filled = 63583
ic_fluent_vehicle_car_20_filled = 63584
ic_fluent_vehicle_car_24_filled = 63585
ic_fluent_vehicle_truck_24_filled = 63586
ic_fluent_video_16_filled = 63587
ic_fluent_video_20_filled = 63588
ic_fluent_video_24_filled = 63589
ic_fluent_video_28_filled = 63590
ic_fluent_video_background_effect_24_filled = 63591
ic_fluent_video_clip_24_filled = 63592
ic_fluent_video_off_20_filled = 63593
ic_fluent_video_off_24_filled = 63594
ic_fluent_video_off_28_filled = 63595
ic_fluent_video_person_24_filled = 63596
ic_fluent_video_person_off_24_filled = 63597
ic_fluent_video_person_star_24_filled = 63598
ic_fluent_video_play_pause_24_filled = 63599
ic_fluent_video_security_20_filled = 63600
ic_fluent_video_security_24_filled = 63601
ic_fluent_video_switch_24_filled = 63602
ic_fluent_view_desktop_20_filled = 63603
ic_fluent_view_desktop_24_filled = 63604
ic_fluent_view_desktop_mobile_20_filled = 63605
ic_fluent_view_desktop_mobile_24_filled = 63606
ic_fluent_voicemail_16_filled = 63610
ic_fluent_voicemail_20_filled = 63611
ic_fluent_voicemail_24_filled = 63612
ic_fluent_walkie_talkie_24_filled = 63613
ic_fluent_walkie_talkie_28_filled = 63614
ic_fluent_wallpaper_24_filled = 63615
ic_fluent_warning_16_filled = 63616
ic_fluent_warning_20_filled = 63617
ic_fluent_warning_24_filled = 63618
ic_fluent_weather_blowing_snow_20_filled = 63619
ic_fluent_weather_blowing_snow_24_filled = 63620
ic_fluent_weather_blowing_snow_48_filled = 63621
ic_fluent_weather_cloudy_20_filled = 63622
ic_fluent_weather_cloudy_24_filled = 63623
ic_fluent_weather_cloudy_48_filled = 63624
ic_fluent_weather_duststorm_20_filled = 63625
ic_fluent_weather_duststorm_24_filled = 63626
ic_fluent_weather_duststorm_48_filled = 63627
ic_fluent_weather_fog_20_filled = 63628
ic_fluent_weather_fog_24_filled = 63629
ic_fluent_weather_fog_48_filled = 63630
ic_fluent_weather_hail_day_20_filled = 63631
ic_fluent_weather_hail_day_24_filled = 63632
ic_fluent_weather_hail_day_48_filled = 63633
ic_fluent_weather_hail_night_20_filled = 63634
ic_fluent_weather_hail_night_24_filled = 63635
ic_fluent_weather_hail_night_48_filled = 63636
ic_fluent_weather_moon_20_filled = 63637
ic_fluent_weather_moon_24_filled = 63638
ic_fluent_weather_moon_48_filled = 63639
ic_fluent_weather_partly_cloudy_day_20_filled = 63640
ic_fluent_weather_partly_cloudy_day_24_filled = 63641
ic_fluent_weather_partly_cloudy_day_48_filled = 63642
ic_fluent_weather_partly_cloudy_night_20_filled = 63643
ic_fluent_weather_partly_cloudy_night_24_filled = 63644
ic_fluent_weather_partly_cloudy_night_48_filled = 63645
ic_fluent_weather_rain_20_filled = 63646
ic_fluent_weather_rain_24_filled = 63647
ic_fluent_weather_rain_48_filled = 63648
ic_fluent_weather_rain_showers_day_20_filled = 63649
ic_fluent_weather_rain_showers_day_24_filled = 63650
ic_fluent_weather_rain_showers_day_48_filled = 63651
ic_fluent_weather_rain_showers_night_20_filled = 63652
ic_fluent_weather_rain_showers_night_24_filled = 63653
ic_fluent_weather_rain_showers_night_48_filled = 63654
ic_fluent_weather_rain_snow_20_filled = 63655
ic_fluent_weather_rain_snow_24_filled = 63656
ic_fluent_weather_rain_snow_48_filled = 63657
ic_fluent_weather_snow_20_filled = 63658
ic_fluent_weather_snow_24_filled = 63659
ic_fluent_weather_snow_48_filled = 63660
ic_fluent_weather_snow_shower_day_20_filled = 63661
ic_fluent_weather_snow_shower_day_24_filled = 63662
ic_fluent_weather_snow_shower_day_48_filled = 63663
ic_fluent_weather_snow_shower_night_20_filled = 63664
ic_fluent_weather_snow_shower_night_24_filled = 63665
ic_fluent_weather_snow_shower_night_48_filled = 63666
ic_fluent_weather_snowflake_20_filled = 63667
ic_fluent_weather_snowflake_24_filled = 63668
ic_fluent_weather_snowflake_48_filled = 63669
ic_fluent_weather_squalls_20_filled = 63670
ic_fluent_weather_squalls_24_filled = 63671
ic_fluent_weather_squalls_48_filled = 63672
ic_fluent_weather_sunny_20_filled = 63673
ic_fluent_weather_sunny_24_filled = 63674
ic_fluent_weather_sunny_48_filled = 63675
ic_fluent_weather_thunderstorm_20_filled = 63676
ic_fluent_weather_thunderstorm_24_filled = 63677
ic_fluent_weather_thunderstorm_48_filled = 63678
ic_fluent_web_asset_24_filled = 63679
ic_fluent_whiteboard_20_filled = 63682
ic_fluent_whiteboard_24_filled = 63683
ic_fluent_wifi_1_20_filled = 63684
ic_fluent_wifi_1_24_filled = 63685
ic_fluent_wifi_2_20_filled = 63686
ic_fluent_wifi_2_24_filled = 63687
ic_fluent_wifi_3_20_filled = 63688
ic_fluent_wifi_3_24_filled = 63689
ic_fluent_wifi_4_20_filled = 63690
ic_fluent_wifi_4_24_filled = 63691
ic_fluent_window_20_filled = 63693
ic_fluent_window_ad_20_filled = 63694
ic_fluent_window_dev_tools_16_filled = 63695
ic_fluent_window_dev_tools_20_filled = 63696
ic_fluent_window_dev_tools_24_filled = 63697
ic_fluent_window_inprivate_20_filled = 63698
ic_fluent_window_inprivate_account_20_filled = 63699
ic_fluent_window_multiple_20_filled = 63700
ic_fluent_window_new_20_filled = 63701
ic_fluent_window_shield_16_filled = 63702
ic_fluent_window_shield_20_filled = 63703
ic_fluent_window_shield_24_filled = 63704
ic_fluent_wrench_24_filled = 63705
ic_fluent_xbox_console_20_filled = 63706
ic_fluent_xbox_console_24_filled = 63707
ic_fluent_zoom_in_20_filled = 63708
ic_fluent_zoom_in_24_filled = 63709
ic_fluent_zoom_out_20_filled = 63710
ic_fluent_zoom_out_24_filled = 63711
ic_fluent_calendar_checkmark_24_filled = 63713
ic_fluent_add_square_24_filled = 63714
ic_fluent_apps_list_20_filled = 63715
ic_fluent_archive_16_filled = 63716
ic_fluent_arrow_autofit_height_24_filled = 63717
ic_fluent_arrow_autofit_width_24_filled = 63718
ic_fluent_arrow_counterclockwise_28_filled = 63719
ic_fluent_arrow_down_12_filled = 63720
ic_fluent_arrow_down_left_16_filled = 63721
ic_fluent_arrow_export_rtl_20_filled = 63722
ic_fluent_arrow_hook_down_left_16_filled = 63725
ic_fluent_arrow_hook_down_left_20_filled = 63726
ic_fluent_arrow_hook_down_left_24_filled = 63727
ic_fluent_arrow_hook_down_left_28_filled = 63728
ic_fluent_arrow_hook_down_right_16_filled = 63729
ic_fluent_arrow_hook_down_right_20_filled = 63730
ic_fluent_arrow_hook_down_right_24_filled = 63731
ic_fluent_arrow_hook_down_right_28_filled = 63732
ic_fluent_arrow_hook_up_left_16_filled = 63733
ic_fluent_arrow_hook_up_left_20_filled = 63734
ic_fluent_arrow_hook_up_left_24_filled = 63735
ic_fluent_arrow_hook_up_left_28_filled = 63736
ic_fluent_arrow_hook_up_right_16_filled = 63737
ic_fluent_arrow_hook_up_right_20_filled = 63738
ic_fluent_arrow_hook_up_right_24_filled = 63739
ic_fluent_arrow_hook_up_right_28_filled = 63740
ic_fluent_arrow_move_20_filled = 63741
ic_fluent_arrow_redo_32_filled = 63742
ic_fluent_arrow_redo_48_filled = 63743
ic_fluent_arrow_up_right_16_filled = 57646
ic_fluent_attach_arrow_right_20_filled = 57655
ic_fluent_attach_arrow_right_24_filled = 57656
ic_fluent_attach_text_24_filled = 57658
ic_fluent_backpack_12_filled = 57664
ic_fluent_backpack_16_filled = 57665
ic_fluent_backpack_20_filled = 57666
ic_fluent_backpack_24_filled = 57667
ic_fluent_backpack_28_filled = 57668
ic_fluent_backpack_48_filled = 57670
ic_fluent_balloon_16_filled = 57677
ic_fluent_bed_16_filled = 57689
ic_fluent_bluetooth_28_filled = 57694
ic_fluent_blur_16_filled = 57698
ic_fluent_blur_20_filled = 57699
ic_fluent_blur_24_filled = 57700
ic_fluent_blur_28_filled = 57701
ic_fluent_book_20_filled = 57714
ic_fluent_book_24_filled = 57715
ic_fluent_book_add_20_filled = 57716
ic_fluent_book_add_24_filled = 57717
ic_fluent_book_clock_24_filled = 57721
ic_fluent_book_coins_24_filled = 57723
ic_fluent_book_compass_24_filled = 57725
ic_fluent_book_database_24_filled = 57731
ic_fluent_book_exclamation_mark_24_filled = 57733
ic_fluent_book_information_24_filled = 57736
ic_fluent_book_letter_24_filled = 57738
ic_fluent_book_open_20_filled = 57740
ic_fluent_book_open_24_filled = 57741
ic_fluent_book_open_globe_24_filled = 57746
ic_fluent_book_pulse_24_filled = 57753
ic_fluent_book_question_mark_24_filled = 57755
ic_fluent_book_search_24_filled = 57758
ic_fluent_book_star_24_filled = 57760
ic_fluent_book_theta_24_filled = 57763
ic_fluent_border_all_24_filled = 57777
ic_fluent_border_bottom_24_filled = 57779
ic_fluent_border_bottom_double_24_filled = 57781
ic_fluent_border_bottom_thick_24_filled = 57783
ic_fluent_border_left_24_filled = 57785
ic_fluent_border_outside_24_filled = 57791
ic_fluent_border_outside_thick_24_filled = 57793
ic_fluent_border_right_24_filled = 57795
ic_fluent_border_top_24_filled = 57797
ic_fluent_border_top_bottom_24_filled = 57799
ic_fluent_border_top_bottom_double_24_filled = 57801
ic_fluent_border_top_bottom_thick_24_filled = 57803
ic_fluent_briefcase_12_filled = 57852
ic_fluent_briefcase_32_filled = 57855
ic_fluent_bug_16_filled = 57881
ic_fluent_bug_20_filled = 57882
ic_fluent_bug_24_filled = 57883
ic_fluent_building_bank_16_filled = 57888
ic_fluent_building_bank_20_filled = 57889
ic_fluent_building_bank_24_filled = 57890
ic_fluent_building_government_24_filled = 57905
ic_fluent_building_government_32_filled = 57906
ic_fluent_building_multiple_24_filled = 57912
ic_fluent_building_shop_16_filled = 57921
ic_fluent_building_shop_20_filled = 57922
ic_fluent_building_shop_24_filled = 57923
ic_fluent_building_skyscraper_16_filled = 57924
ic_fluent_building_skyscraper_20_filled = 57925
ic_fluent_building_skyscraper_24_filled = 57926
ic_fluent_calendar_cancel_16_filled = 57940
ic_fluent_calendar_clock_16_filled = 57943
ic_fluent_calendar_mention_20_filled = 57961
ic_fluent_calendar_person_24_filled = 57967
ic_fluent_calendar_question_mark_16_filled = 57970
ic_fluent_calendar_question_mark_20_filled = 57971
ic_fluent_calendar_question_mark_24_filled = 57972
ic_fluent_call_forward_16_filled = 58000
ic_fluent_call_forward_20_filled = 58001
ic_fluent_call_forward_28_filled = 58002
ic_fluent_call_forward_48_filled = 58003
ic_fluent_call_inbound_20_filled = 58004
ic_fluent_call_inbound_28_filled = 58005
ic_fluent_call_inbound_48_filled = 58006
ic_fluent_call_missed_28_filled = 58008
ic_fluent_call_missed_48_filled = 58009
ic_fluent_call_outbound_20_filled = 58010
ic_fluent_call_outbound_28_filled = 58011
ic_fluent_call_outbound_48_filled = 58012
ic_fluent_call_park_16_filled = 58013
ic_fluent_call_park_20_filled = 58014
ic_fluent_call_park_28_filled = 58015
ic_fluent_call_park_48_filled = 58016
ic_fluent_camera_edit_20_filled = 58035
ic_fluent_caret_up_12_filled = 58043
ic_fluent_caret_up_16_filled = 58044
ic_fluent_caret_up_20_filled = 58045
ic_fluent_caret_up_24_filled = 58046
ic_fluent_cart_16_filled = 58047
ic_fluent_cart_20_filled = 58048
ic_fluent_channel_28_filled = 58064
ic_fluent_channel_48_filled = 58065
ic_fluent_channel_add_16_filled = 58066
ic_fluent_channel_add_20_filled = 58067
ic_fluent_channel_add_24_filled = 58068
ic_fluent_channel_add_28_filled = 58069
ic_fluent_channel_add_48_filled = 58070
ic_fluent_channel_alert_16_filled = 58071
ic_fluent_channel_alert_20_filled = 58072
ic_fluent_channel_alert_24_filled = 58073
ic_fluent_channel_alert_28_filled = 58074
ic_fluent_channel_alert_48_filled = 58075
ic_fluent_channel_arrow_left_16_filled = 58076
ic_fluent_channel_arrow_left_20_filled = 58077
ic_fluent_channel_arrow_left_24_filled = 58078
ic_fluent_channel_arrow_left_28_filled = 58079
ic_fluent_channel_arrow_left_48_filled = 58080
ic_fluent_channel_dismiss_16_filled = 58081
ic_fluent_channel_dismiss_20_filled = 58082
ic_fluent_channel_dismiss_24_filled = 58083
ic_fluent_channel_dismiss_28_filled = 58084
ic_fluent_channel_dismiss_48_filled = 58085
ic_fluent_chat_16_filled = 58104
ic_fluent_checkmark_16_filled = 58137
ic_fluent_clipboard_paste_16_filled = 58223
ic_fluent_clock_dismiss_24_filled = 58248
ic_fluent_closed_caption_16_filled = 58253
ic_fluent_closed_caption_20_filled = 58254
ic_fluent_closed_caption_28_filled = 58255
ic_fluent_closed_caption_48_filled = 58257
ic_fluent_color_line_16_filled = 58324
ic_fluent_comment_12_filled = 58335
ic_fluent_comment_28_filled = 58336
ic_fluent_comment_48_filled = 58337
ic_fluent_comment_add_12_filled = 58338
ic_fluent_comment_add_16_filled = 58339
ic_fluent_comment_add_20_filled = 58340
ic_fluent_comment_add_28_filled = 58341
ic_fluent_comment_add_48_filled = 58342
ic_fluent_comment_arrow_left_12_filled = 58343
ic_fluent_comment_arrow_left_16_filled = 58344
ic_fluent_comment_arrow_left_20_filled = 58345
ic_fluent_comment_arrow_left_28_filled = 58347
ic_fluent_comment_arrow_left_48_filled = 58348
ic_fluent_comment_arrow_right_12_filled = 58349
ic_fluent_comment_arrow_right_16_filled = 58350
ic_fluent_comment_arrow_right_20_filled = 58351
ic_fluent_comment_arrow_right_28_filled = 58353
ic_fluent_comment_arrow_right_48_filled = 58354
ic_fluent_comment_checkmark_12_filled = 58355
ic_fluent_comment_checkmark_16_filled = 58356
ic_fluent_comment_checkmark_20_filled = 58357
ic_fluent_comment_checkmark_24_filled = 58358
ic_fluent_comment_checkmark_28_filled = 58359
ic_fluent_comment_checkmark_48_filled = 58360
ic_fluent_comment_edit_20_filled = 58363
ic_fluent_comment_edit_24_filled = 58364
ic_fluent_comment_off_16_filled = 58380
ic_fluent_comment_off_20_filled = 58381
ic_fluent_comment_off_24_filled = 58382
ic_fluent_comment_off_28_filled = 58383
ic_fluent_comment_off_48_filled = 58384
ic_fluent_contact_card_group_16_filled = 58392
ic_fluent_contact_card_group_20_filled = 58393
ic_fluent_contact_card_group_28_filled = 58394
ic_fluent_contact_card_group_48_filled = 58395
ic_fluent_convert_range_24_filled = 58410
ic_fluent_copy_add_24_filled = 58412
ic_fluent_copy_select_20_filled = 58416
ic_fluent_couch_12_filled = 58417
ic_fluent_couch_24_filled = 58419
ic_fluent_crop_20_filled = 58423
ic_fluent_currency_dollar_rupee_16_filled = 58444
ic_fluent_currency_dollar_rupee_20_filled = 58445
ic_fluent_currency_dollar_rupee_24_filled = 58446
ic_fluent_cursor_20_filled = 58447
ic_fluent_cursor_24_filled = 58448
ic_fluent_cursor_hover_16_filled = 58451
ic_fluent_cursor_hover_20_filled = 58452
ic_fluent_cursor_hover_24_filled = 58453
ic_fluent_cursor_hover_28_filled = 58454
ic_fluent_cursor_hover_32_filled = 58455
ic_fluent_cursor_hover_48_filled = 58456
ic_fluent_cursor_hover_off_16_filled = 58457
ic_fluent_cursor_hover_off_20_filled = 58458
ic_fluent_cursor_hover_off_24_filled = 58459
ic_fluent_cursor_hover_off_28_filled = 58460
ic_fluent_cursor_hover_off_48_filled = 58461
ic_fluent_data_bar_vertical_add_24_filled = 58465
ic_fluent_data_usage_20_filled = 58475
ic_fluent_decimal_arrow_left_24_filled = 58500
ic_fluent_decimal_arrow_right_24_filled = 58502
ic_fluent_delete_16_filled = 58503
ic_fluent_dentist_12_filled = 58510
ic_fluent_dentist_16_filled = 58511
ic_fluent_dentist_20_filled = 58512
ic_fluent_dentist_28_filled = 58513
ic_fluent_dentist_48_filled = 58514
ic_fluent_dismiss_circle_28_filled = 58574
ic_fluent_doctor_12_filled = 58590
ic_fluent_doctor_16_filled = 58591
ic_fluent_doctor_20_filled = 58592
ic_fluent_doctor_28_filled = 58593
ic_fluent_doctor_48_filled = 58594
ic_fluent_document_16_filled = 58595
ic_fluent_document_48_filled = 58597
ic_fluent_document_add_16_filled = 58598
ic_fluent_document_add_20_filled = 58599
ic_fluent_document_add_24_filled = 58600
ic_fluent_document_add_28_filled = 58601
ic_fluent_document_add_48_filled = 58602
ic_fluent_document_arrow_left_16_filled = 58605
ic_fluent_document_arrow_left_20_filled = 58606
ic_fluent_document_arrow_left_24_filled = 58607
ic_fluent_document_arrow_left_28_filled = 58608
ic_fluent_document_arrow_left_48_filled = 58609
ic_fluent_document_catch_up_16_filled = 58619
ic_fluent_document_catch_up_20_filled = 58620
ic_fluent_document_landscape_data_24_filled = 58651
ic_fluent_document_landscape_split_20_filled = 58652
ic_fluent_document_landscape_split_hint_20_filled = 58654
ic_fluent_document_page_break_20_filled = 58675
ic_fluent_drink_beer_16_filled = 58767
ic_fluent_drink_beer_20_filled = 58768
ic_fluent_drink_coffee_16_filled = 58769
ic_fluent_drink_margarita_16_filled = 58770
ic_fluent_drink_margarita_20_filled = 58771
ic_fluent_drink_wine_16_filled = 58774
ic_fluent_drink_wine_20_filled = 58775
ic_fluent_dual_screen_span_24_filled = 58803
ic_fluent_edit_32_filled = 58816
ic_fluent_edit_off_16_filled = 58819
ic_fluent_edit_off_24_filled = 58821
ic_fluent_edit_settings_24_filled = 58832
ic_fluent_emoji_add_16_filled = 58836
ic_fluent_emoji_hand_24_filled = 58844
ic_fluent_emoji_hand_28_filled = 58845
ic_fluent_eraser_20_filled = 58865
ic_fluent_eraser_24_filled = 58866
ic_fluent_eraser_medium_24_filled = 58868
ic_fluent_eraser_segment_24_filled = 58870
ic_fluent_eraser_small_24_filled = 58872
ic_fluent_error_circle_12_filled = 58874
ic_fluent_eye_tracking_off_16_filled = 58887
ic_fluent_eye_tracking_off_20_filled = 58888
ic_fluent_eye_tracking_off_24_filled = 58889
ic_fluent_f_stop_16_filled = 58894
ic_fluent_f_stop_20_filled = 58895
ic_fluent_f_stop_24_filled = 58896
ic_fluent_f_stop_28_filled = 58897
ic_fluent_fingerprint_48_filled = 58911
ic_fluent_fixed_width_24_filled = 58913
ic_fluent_flip_horizontal_24_filled = 58938
ic_fluent_flip_vertical_24_filled = 58944
ic_fluent_fluent_32_filled = 58955
ic_fluent_fluent_48_filled = 58956
ic_fluent_fluid_20_filled = 58958
ic_fluent_fluid_24_filled = 58959
ic_fluent_food_egg_16_filled = 59001
ic_fluent_food_egg_20_filled = 59002
ic_fluent_food_toast_16_filled = 59007
ic_fluent_food_toast_20_filled = 59008
ic_fluent_gavel_24_filled = 59044
ic_fluent_gavel_32_filled = 59045
ic_fluent_glasses_16_filled = 59062
ic_fluent_glasses_20_filled = 59063
ic_fluent_glasses_28_filled = 59064
ic_fluent_glasses_48_filled = 59065
ic_fluent_glasses_off_16_filled = 59066
ic_fluent_glasses_off_20_filled = 59067
ic_fluent_glasses_off_28_filled = 59068
ic_fluent_glasses_off_48_filled = 59069
ic_fluent_globe_16_filled = 59070
ic_fluent_hand_left_20_filled = 59112
ic_fluent_hand_right_24_filled = 59117
ic_fluent_hand_right_28_filled = 59118
ic_fluent_hat_graduation_16_filled = 59122
ic_fluent_hat_graduation_20_filled = 59123
ic_fluent_hat_graduation_24_filled = 59124
ic_fluent_hd_16_filled = 59125
ic_fluent_hd_20_filled = 59126
ic_fluent_hd_24_filled = 59127
ic_fluent_headset_16_filled = 59139
ic_fluent_headset_20_filled = 59140
ic_fluent_headset_48_filled = 59142
ic_fluent_heart_pulse_24_filled = 59151
ic_fluent_heart_pulse_32_filled = 59152
ic_fluent_home_16_filled = 59164
ic_fluent_home_32_filled = 59165
ic_fluent_home_48_filled = 59166
ic_fluent_image_arrow_counterclockwise_24_filled = 59180
ic_fluent_info_shield_20_filled = 59204
ic_fluent_key_multiple_20_filled = 59219
ic_fluent_line_horizontal_5_error_20_filled = 59259
ic_fluent_link_square_12_filled = 59267
ic_fluent_link_square_16_filled = 59268
ic_fluent_location_48_filled = 59274
ic_fluent_location_off_16_filled = 59286
ic_fluent_location_off_20_filled = 59287
ic_fluent_location_off_24_filled = 59288
ic_fluent_location_off_28_filled = 59289
ic_fluent_location_off_48_filled = 59290
ic_fluent_lock_multiple_24_filled = 59297
ic_fluent_lottery_24_filled = 59303
ic_fluent_mail_16_filled = 59311
ic_fluent_mail_read_16_filled = 59359
ic_fluent_math_format_linear_24_filled = 59372
ic_fluent_math_format_professional_24_filled = 59374
ic_fluent_math_formula_24_filled = 59377
ic_fluent_maximize_20_filled = 59385
ic_fluent_maximize_24_filled = 59386
ic_fluent_maximize_28_filled = 59387
ic_fluent_maximize_48_filled = 59388
ic_fluent_meet_now_16_filled = 59389
ic_fluent_mic_off_20_filled = 59404
ic_fluent_mic_off_48_filled = 59406
ic_fluent_mic_prohibited_24_filled = 59409
ic_fluent_more_circle_20_filled = 59439
ic_fluent_movies_and_tv_16_filled = 59449
ic_fluent_movies_and_tv_20_filled = 59450
ic_fluent_navigation_unread_24_filled = 59505
ic_fluent_number_symbol_dismiss_24_filled = 59545
ic_fluent_open_28_filled = 59548
ic_fluent_open_48_filled = 59549
ic_fluent_open_folder_16_filled = 59550
ic_fluent_open_folder_20_filled = 59551
ic_fluent_open_folder_28_filled = 59552
ic_fluent_open_folder_48_filled = 59553
ic_fluent_open_off_16_filled = 59554
ic_fluent_open_off_20_filled = 59555
ic_fluent_open_off_24_filled = 59556
ic_fluent_open_off_28_filled = 59557
ic_fluent_open_off_48_filled = 59558
ic_fluent_paint_brush_arrow_down_24_filled = 59574
ic_fluent_paint_brush_arrow_up_24_filled = 59576
ic_fluent_pause_12_filled = 59614
ic_fluent_payment_16_filled = 59622
ic_fluent_payment_28_filled = 59623
ic_fluent_people_prohibited_16_filled = 59669
ic_fluent_people_swap_16_filled = 59676
ic_fluent_people_swap_20_filled = 59677
ic_fluent_people_swap_24_filled = 59678
ic_fluent_people_swap_28_filled = 59679
ic_fluent_people_team_add_20_filled = 59683
ic_fluent_people_team_add_24_filled = 59684
ic_fluent_person_available_20_filled = 59702
ic_fluent_person_clock_16_filled = 59708
ic_fluent_person_clock_20_filled = 59709
ic_fluent_person_clock_24_filled = 59710
ic_fluent_person_delete_20_filled = 59711
ic_fluent_person_mail_16_filled = 59721
ic_fluent_person_mail_20_filled = 59722
ic_fluent_person_mail_24_filled = 59723
ic_fluent_person_mail_28_filled = 59724
ic_fluent_person_mail_48_filled = 59725
ic_fluent_person_prohibited_24_filled = 59733
ic_fluent_poll_20_filled = 59825
ic_fluent_pulse_24_filled = 59877
ic_fluent_qr_code_20_filled = 59892
ic_fluent_real_estate_24_filled = 59909
ic_fluent_ribbon_24_filled = 59952
ic_fluent_ribbon_star_20_filled = 59959
ic_fluent_ribbon_star_24_filled = 59960
ic_fluent_run_16_filled = 59975
ic_fluent_run_20_filled = 59976
ic_fluent_scales_24_filled = 59993
ic_fluent_scales_32_filled = 59994
ic_fluent_search_shield_20_filled = 60041
ic_fluent_shield_dismiss_shield_20_filled = 60118
ic_fluent_shifts_day_20_filled = 60140
ic_fluent_shifts_day_24_filled = 60141
ic_fluent_sidebar_search_ltr_20_filled = 60161
ic_fluent_sidebar_search_rtl_20_filled = 60162
ic_fluent_sign_out_20_filled = 60163
ic_fluent_slide_multiple_arrow_right_24_filled = 60200
ic_fluent_slide_search_24_filled = 60202
ic_fluent_slide_search_28_filled = 60203
ic_fluent_slide_size_24_filled = 60207
ic_fluent_slide_text_16_filled = 60208
ic_fluent_slide_text_20_filled = 60209
ic_fluent_slide_text_28_filled = 60210
ic_fluent_slide_text_48_filled = 60211
ic_fluent_speaker_0_16_filled = 60224
ic_fluent_speaker_0_20_filled = 60225
ic_fluent_speaker_0_28_filled = 60226
ic_fluent_speaker_0_48_filled = 60228
ic_fluent_speaker_1_16_filled = 60229
ic_fluent_speaker_1_20_filled = 60230
ic_fluent_speaker_1_28_filled = 60231
ic_fluent_speaker_1_48_filled = 60233
ic_fluent_speaker_bluetooth_28_filled = 60241
ic_fluent_speaker_off_16_filled = 60247
ic_fluent_speaker_off_20_filled = 60248
ic_fluent_speaker_off_48_filled = 60249
ic_fluent_speaker_usb_24_filled = 60253
ic_fluent_speaker_usb_28_filled = 60254
ic_fluent_sport_16_filled = 60270
ic_fluent_sport_20_filled = 60271
ic_fluent_sport_24_filled = 60272
ic_fluent_sport_american_football_24_filled = 60274
ic_fluent_sport_baseball_24_filled = 60276
ic_fluent_sport_basketball_24_filled = 60278
ic_fluent_sport_hockey_24_filled = 60280
ic_fluent_star_edit_24_filled = 60338
ic_fluent_tab_desktop_arrow_left_20_filled = 60389
ic_fluent_tab_prohibited_24_filled = 60395
ic_fluent_table_16_filled = 60398
ic_fluent_table_28_filled = 60399
ic_fluent_table_48_filled = 60401
ic_fluent_table_simple_16_filled = 60490
ic_fluent_table_simple_20_filled = 60491
ic_fluent_table_simple_24_filled = 60492
ic_fluent_table_simple_28_filled = 60493
ic_fluent_table_simple_48_filled = 60494
ic_fluent_tag_16_filled = 60522
ic_fluent_tasks_app_20_filled = 60573
ic_fluent_tent_12_filled = 60576
ic_fluent_tent_16_filled = 60577
ic_fluent_tent_20_filled = 60578
ic_fluent_tent_28_filled = 60579
ic_fluent_tent_48_filled = 60580
ic_fluent_text_bold_16_filled = 60624
ic_fluent_text_color_16_filled = 60659
ic_fluent_text_column_one_narrow_20_filled = 60663
ic_fluent_text_column_one_narrow_24_filled = 60664
ic_fluent_text_column_one_wide_20_filled = 60665
ic_fluent_text_column_one_wide_24_filled = 60666
ic_fluent_text_continuous_24_filled = 60670
ic_fluent_text_italic_16_filled = 60727
ic_fluent_text_underline_16_filled = 60775
ic_fluent_ticket_diagonal_16_filled = 60795
ic_fluent_ticket_diagonal_20_filled = 60796
ic_fluent_ticket_diagonal_24_filled = 60797
ic_fluent_ticket_diagonal_28_filled = 60798
ic_fluent_timer_16_filled = 60806
ic_fluent_timer_20_filled = 60808
ic_fluent_toggle_left_16_filled = 60815
ic_fluent_toggle_left_20_filled = 60816
ic_fluent_toggle_left_24_filled = 60817
ic_fluent_toggle_left_28_filled = 60818
ic_fluent_toggle_left_48_filled = 60819
ic_fluent_toggle_right_28_filled = 60823
ic_fluent_toggle_right_48_filled = 60824
ic_fluent_tv_16_filled = 60865
ic_fluent_tv_20_filled = 60866
ic_fluent_tv_24_filled = 60867
ic_fluent_tv_28_filled = 60868
ic_fluent_tv_48_filled = 60869
ic_fluent_vehicle_bicycle_16_filled = 60881
ic_fluent_vehicle_bicycle_20_filled = 60882
ic_fluent_vehicle_bus_16_filled = 60883
ic_fluent_vehicle_bus_20_filled = 60884
ic_fluent_vehicle_car_28_filled = 60888
ic_fluent_vehicle_car_48_filled = 60889
ic_fluent_vehicle_ship_16_filled = 60898
ic_fluent_vehicle_ship_20_filled = 60899
ic_fluent_vehicle_ship_24_filled = 60900
ic_fluent_vehicle_subway_16_filled = 60901
ic_fluent_vehicle_subway_20_filled = 60902
ic_fluent_vehicle_subway_24_filled = 60903
ic_fluent_vehicle_truck_16_filled = 60904
ic_fluent_vehicle_truck_20_filled = 60905
ic_fluent_video_clip_20_filled = 60927
ic_fluent_vote_20_filled = 60968
ic_fluent_vote_24_filled = 60969
ic_fluent_weather_drizzle_20_filled = 60990
ic_fluent_weather_drizzle_24_filled = 60991
ic_fluent_weather_drizzle_48_filled = 60992
ic_fluent_weather_haze_20_filled = 60993
ic_fluent_weather_haze_24_filled = 60994
ic_fluent_weather_haze_48_filled = 60995
ic_fluent_weather_moon_16_filled = 60996
ic_fluent_weather_moon_28_filled = 60997
ic_fluent_weather_moon_off_16_filled = 60998
ic_fluent_weather_moon_off_20_filled = 60999
ic_fluent_weather_moon_off_24_filled = 61000
ic_fluent_weather_moon_off_28_filled = 61001
ic_fluent_weather_moon_off_48_filled = 61002
ic_fluent_weather_sunny_high_20_filled = 61007
ic_fluent_weather_sunny_high_24_filled = 61008
ic_fluent_weather_sunny_high_48_filled = 61009
ic_fluent_weather_sunny_low_20_filled = 61010
ic_fluent_weather_sunny_low_24_filled = 61011
ic_fluent_weather_sunny_low_48_filled = 61012
ic_fluent_window_new_16_filled = 61050
ic_fluent_window_new_24_filled = 61051
ic_fluent_wrench_16_filled = 61061
ic_fluent_wrench_20_filled = 61062
ic_fluent_video_background_effect_20_filled = 60919
ic_fluent_alert_16_filled = 57364
ic_fluent_approvals_app_16_filled = 57439
ic_fluent_approvals_app_20_filled = 57440
ic_fluent_arrow_bounce_16_filled = 57478
ic_fluent_arrow_bounce_24_filled = 57480
ic_fluent_arrow_enter_up_20_filled = 57538
ic_fluent_arrow_enter_up_24_filled = 57539
ic_fluent_bookmark_multiple_20_filled = 57767
ic_fluent_briefcase_28_filled = 57854
ic_fluent_briefcase_48_filled = 57856
ic_fluent_building_20_filled = 57887
ic_fluent_chat_48_filled = 58106
ic_fluent_desktop_arrow_right_16_filled = 58516
ic_fluent_desktop_arrow_right_20_filled = 58517
ic_fluent_desktop_arrow_right_24_filled = 58518
ic_fluent_desktop_speaker_20_filled = 58544
ic_fluent_desktop_speaker_24_filled = 58545
ic_fluent_desktop_speaker_off_20_filled = 58546
ic_fluent_desktop_speaker_off_24_filled = 58547
ic_fluent_emoji_add_20_filled = 58837
ic_fluent_food_cake_20_filled = 59000
ic_fluent_grid_kanban_20_filled = 59092
ic_fluent_hand_right_20_filled = 59116
ic_fluent_hand_right_off_20_filled = 59119
ic_fluent_learning_app_20_filled = 59245
ic_fluent_learning_app_24_filled = 59246
ic_fluent_live_off_20_filled = 59272
ic_fluent_live_off_24_filled = 59273
ic_fluent_mic_prohibited_20_filled = 59408
ic_fluent_notebook_section_20_filled = 59527
ic_fluent_people_audience_20_filled = 59649
ic_fluent_people_call_16_filled = 59650
ic_fluent_people_call_20_filled = 59651
ic_fluent_person_call_16_filled = 59703
ic_fluent_person_call_20_filled = 59704
ic_fluent_phone_desktop_add_20_filled = 59755
ic_fluent_presenter_20_filled = 59855
ic_fluent_presenter_off_20_filled = 59856
ic_fluent_rectangle_landscape_20_filled = 59921
ic_fluent_ribbon_20_filled = 59951
ic_fluent_save_sync_20_filled = 59990
ic_fluent_shifts_20_filled = 60133
ic_fluent_shifts_checkmark_20_filled = 60138
ic_fluent_shifts_checkmark_24_filled = 60139
ic_fluent_slide_multiple_24_filled = 60198
ic_fluent_star_line_horizontal_3_20_filled = 60342
ic_fluent_star_line_horizontal_3_24_filled = 60343
ic_fluent_table_add_20_filled = 60403
ic_fluent_table_dismiss_20_filled = 60430
ic_fluent_table_dismiss_24_filled = 60431
ic_fluent_tap_double_20_filled = 60552
ic_fluent_tap_single_20_filled = 60555
ic_fluent_text_bullet_list_add_20_filled = 60627
ic_fluent_text_bullet_list_square_20_filled = 60640
ic_fluent_text_grammar_error_20_filled = 60698
ic_fluent_text_number_list_rtl_20_filled = 60736
ic_fluent_video_360_20_filled = 60913
ic_fluent_video_360_24_filled = 60914
ic_fluent_video_person_12_filled = 60936
ic_fluent_video_person_16_filled = 60937
ic_fluent_video_person_20_filled = 60938
ic_fluent_video_person_28_filled = 60939
ic_fluent_video_person_48_filled = 60940
ic_fluent_video_person_call_16_filled = 60941
ic_fluent_video_person_call_20_filled = 60942
ic_fluent_video_person_call_24_filled = 60943
ic_fluent_video_person_star_20_filled = 60951
ic_fluent_video_prohibited_20_filled = 60956
ic_fluent_video_switch_20_filled = 60960
ic_fluent_wifi_warning_20_filled = 61020
ic_fluent_album_24_filled = 57360
ic_fluent_album_add_24_filled = 57362
ic_fluent_alert_urgent_16_filled = 57373
ic_fluent_arrow_right_16_filled = 57579
ic_fluent_arrow_undo_16_filled = 57638
ic_fluent_arrow_up_left_16_filled = 57643
ic_fluent_arrow_up_left_20_filled = 57644
ic_fluent_backpack_add_20_filled = 57671
ic_fluent_backpack_add_24_filled = 57672
ic_fluent_backpack_add_28_filled = 57673
ic_fluent_backpack_add_48_filled = 57674
ic_fluent_bot_20_filled = 57804
ic_fluent_call_connecting_20_filled = 57996
ic_fluent_call_exclamation_20_filled = 57999
ic_fluent_call_transfer_20_filled = 58023
ic_fluent_camera_off_24_filled = 58037
ic_fluent_chat_bubbles_question_20_filled = 58111
ic_fluent_chat_mail_20_filled = 58115
ic_fluent_chat_off_20_filled = 58116
ic_fluent_checkmark_48_filled = 58138
ic_fluent_cloud_sync_20_filled = 58307
ic_fluent_content_view_20_filled = 58404
ic_fluent_cube_rotate_20_filled = 58436
ic_fluent_data_line_20_filled = 58468
ic_fluent_device_meeting_room_20_filled = 58558
ic_fluent_device_meeting_room_remote_20_filled = 58559
ic_fluent_draw_shape_24_filled = 58754
ic_fluent_draw_text_24_filled = 58756
ic_fluent_folder_arrow_up_16_filled = 58973
ic_fluent_folder_arrow_up_20_filled = 58974
ic_fluent_folder_arrow_up_24_filled = 58975
ic_fluent_folder_arrow_up_28_filled = 58976
ic_fluent_fps_30_16_filled = 59013
ic_fluent_fps_30_20_filled = 59014
ic_fluent_fps_30_24_filled = 59015
ic_fluent_fps_30_28_filled = 59016
ic_fluent_fps_30_48_filled = 59017
ic_fluent_fps_60_16_filled = 59018
ic_fluent_fps_60_20_filled = 59019
ic_fluent_fps_60_24_filled = 59020
ic_fluent_fps_60_28_filled = 59021
ic_fluent_fps_60_48_filled = 59022
ic_fluent_home_person_20_filled = 59172
ic_fluent_image_off_20_filled = 59193
ic_fluent_lasso_20_filled = 59236
ic_fluent_leaf_three_16_filled = 59242
ic_fluent_leaf_three_20_filled = 59243
ic_fluent_leaf_three_24_filled = 59244
ic_fluent_mic_sync_20_filled = 59428
ic_fluent_notebook_subsection_20_filled = 59529
ic_fluent_person_circle_20_filled = 59706
ic_fluent_pulse_20_filled = 59876
ic_fluent_pulse_square_24_filled = 59881
ic_fluent_ribbon_16_filled = 59950
ic_fluent_rotate_left_24_filled = 59968
ic_fluent_rotate_right_20_filled = 59969
ic_fluent_rotate_right_24_filled = 59970
ic_fluent_share_close_tray_20_filled = 60082
ic_fluent_square_multiple_20_filled = 60319
ic_fluent_star_emphasis_20_filled = 60339
ic_fluent_tv_arrow_right_20_filled = 60870
ic_fluent_video_person_star_off_20_filled = 60952
ic_fluent_video_recording_20_filled = 60959
ic_fluent_video_sync_20_filled = 60961
ic_fluent_breakout_room_20_filled = 57849
ic_fluent_content_view_gallery_20_filled = 58406
ic_fluent_door_tag_24_filled = 58743
ic_fluent_luggage_24_filled = 59306
ic_fluent_people_edit_20_filled = 59657
ic_fluent_channel_share_12_filled = 58086
ic_fluent_channel_share_16_filled = 58087
ic_fluent_channel_share_20_filled = 58088
ic_fluent_channel_share_24_filled = 58089
ic_fluent_channel_share_28_filled = 58090
ic_fluent_channel_share_48_filled = 58091
ic_fluent_people_error_16_filled = 59658
ic_fluent_people_error_20_filled = 59659
ic_fluent_people_error_24_filled = 59660
ic_fluent_puzzle_cube_16_filled = 59882
ic_fluent_puzzle_cube_20_filled = 59883
ic_fluent_puzzle_cube_24_filled = 59884
ic_fluent_puzzle_cube_28_filled = 59885
ic_fluent_puzzle_cube_48_filled = 59886
ic_fluent_arrow_circle_down_right_16_filled = 57486
ic_fluent_arrow_circle_down_right_24_filled = 57488
ic_fluent_arrow_circle_right_24_filled = 57500
ic_fluent_arrow_circle_up_16_filled = 57505
ic_fluent_arrow_circle_up_20_filled = 57506
ic_fluent_arrow_circle_up_24_filled = 57507
ic_fluent_arrow_circle_up_left_24_filled = 57512
ic_fluent_arrow_enter_left_20_filled = 57536
ic_fluent_arrow_enter_left_24_filled = 57537
ic_fluent_arrow_export_ltr_20_filled = 57543
ic_fluent_arrow_export_ltr_24_filled = 57544
ic_fluent_arrow_square_down_24_filled = 57591
ic_fluent_arrow_undo_32_filled = 57640
ic_fluent_arrow_undo_48_filled = 57641
ic_fluent_auto_fit_height_24_filled = 57660
ic_fluent_auto_fit_width_24_filled = 57662
ic_fluent_briefcase_medical_24_filled = 57858
ic_fluent_briefcase_medical_32_filled = 57859
ic_fluent_building_factory_24_filled = 57900
ic_fluent_calendar_arrow_down_24_filled = 57936
ic_fluent_call_16_filled = 57987
ic_fluent_call_20_filled = 57988
ic_fluent_call_24_filled = 57989
ic_fluent_call_28_filled = 57990
ic_fluent_call_missed_20_filled = 58007
ic_fluent_call_prohibited_16_filled = 58017
ic_fluent_call_prohibited_20_filled = 58018
ic_fluent_call_prohibited_24_filled = 58019
ic_fluent_call_prohibited_28_filled = 58020
ic_fluent_call_prohibited_48_filled = 58021
ic_fluent_center_horizontal_24_filled = 58061
ic_fluent_center_vertical_24_filled = 58063
ic_fluent_chevron_circle_down_24_filled = 58149
ic_fluent_chevron_circle_right_24_filled = 58163
ic_fluent_clipboard_image_24_filled = 58220
ic_fluent_comment_arrow_left_24_filled = 58346
ic_fluent_comment_arrow_right_24_filled = 58352
ic_fluent_comment_dismiss_24_filled = 58362
ic_fluent_component_2_double_tap_swipe_down_24_filled = 58387
ic_fluent_component_2_double_tap_swipe_up_24_filled = 58388
ic_fluent_copy_arrow_right_16_filled = 58413
ic_fluent_copy_arrow_right_24_filled = 58415
ic_fluent_currency_dollar_euro_16_filled = 58441
ic_fluent_currency_dollar_euro_20_filled = 58442
ic_fluent_currency_dollar_euro_24_filled = 58443
ic_fluent_delete_dismiss_24_filled = 58507
ic_fluent_delete_dismiss_28_filled = 58508
ic_fluent_document_prohibited_20_filled = 58682
ic_fluent_document_prohibited_24_filled = 58683
ic_fluent_document_sync_24_filled = 58709
ic_fluent_drink_to_go_24_filled = 58773
ic_fluent_dual_screen_header_24_filled = 58797
ic_fluent_fluent_24_filled = 58954
ic_fluent_folder_arrow_right_16_filled = 58968
ic_fluent_folder_arrow_right_20_filled = 58969
ic_fluent_folder_arrow_right_24_filled = 58970
ic_fluent_folder_arrow_right_28_filled = 58971
ic_fluent_folder_arrow_right_48_filled = 58972
ic_fluent_folder_arrow_up_48_filled = 58977
ic_fluent_folder_prohibited_20_filled = 58985
ic_fluent_folder_prohibited_24_filled = 58986
ic_fluent_folder_prohibited_28_filled = 58987
ic_fluent_folder_prohibited_48_filled = 58988
ic_fluent_folder_swap_16_filled = 58989
ic_fluent_folder_swap_20_filled = 58990
ic_fluent_folder_swap_24_filled = 58991
ic_fluent_full_screen_maximize_24_filled = 59026
ic_fluent_full_screen_minimize_24_filled = 59029
ic_fluent_image_multiple_20_filled = 59186
ic_fluent_image_multiple_24_filled = 59187
ic_fluent_image_multiple_28_filled = 59188
ic_fluent_leaf_one_16_filled = 59239
ic_fluent_leaf_one_20_filled = 59240
ic_fluent_leaf_one_24_filled = 59241
ic_fluent_link_dismiss_20_filled = 59265
ic_fluent_location_dismiss_24_filled = 59285
ic_fluent_lock_closed_12_filled = 59291
ic_fluent_lock_closed_16_filled = 59292
ic_fluent_lock_closed_20_filled = 59293
ic_fluent_lock_closed_24_filled = 59294
ic_fluent_lock_open_20_filled = 59299
ic_fluent_lock_open_24_filled = 59300
ic_fluent_lock_open_28_filled = 59301
ic_fluent_mail_inbox_all_24_filled = 59333
ic_fluent_mail_inbox_arrow_right_24_filled = 59336
ic_fluent_mail_inbox_arrow_up_20_filled = 59337
ic_fluent_mail_inbox_arrow_up_24_filled = 59338
ic_fluent_mail_off_24_filled = 59352
ic_fluent_more_horizontal_16_filled = 59441
ic_fluent_more_horizontal_20_filled = 59442
ic_fluent_more_horizontal_24_filled = 59443
ic_fluent_more_horizontal_28_filled = 59444
ic_fluent_more_horizontal_48_filled = 59446
ic_fluent_music_note_1_20_filled = 59487
ic_fluent_music_note_1_24_filled = 59488
ic_fluent_music_note_2_16_filled = 59489
ic_fluent_music_note_2_24_filled = 59491
ic_fluent_people_team_delete_24_filled = 59687
ic_fluent_phone_add_24_filled = 59751
ic_fluent_phone_arrow_right_20_filled = 59752
ic_fluent_phone_arrow_right_24_filled = 59753
ic_fluent_phone_dismiss_24_filled = 59757
ic_fluent_phone_lock_24_filled = 59766
ic_fluent_phone_span_in_16_filled = 59771
ic_fluent_phone_span_in_20_filled = 59772
ic_fluent_phone_span_in_24_filled = 59773
ic_fluent_phone_span_in_28_filled = 59774
ic_fluent_phone_span_out_16_filled = 59775
ic_fluent_phone_span_out_20_filled = 59776
ic_fluent_phone_span_out_24_filled = 59777
ic_fluent_phone_span_out_28_filled = 59778
ic_fluent_position_backward_20_filled = 59834
ic_fluent_position_backward_24_filled = 59835
ic_fluent_position_forward_20_filled = 59836
ic_fluent_position_forward_24_filled = 59837
ic_fluent_position_to_back_20_filled = 59838
ic_fluent_position_to_back_24_filled = 59839
ic_fluent_position_to_front_20_filled = 59840
ic_fluent_position_to_front_24_filled = 59841
ic_fluent_resize_large_16_filled = 59933
ic_fluent_resize_large_20_filled = 59934
ic_fluent_resize_large_24_filled = 59935
ic_fluent_resize_small_16_filled = 59936
ic_fluent_resize_small_20_filled = 59937
ic_fluent_resize_small_24_filled = 59938
ic_fluent_save_edit_20_filled = 59984
ic_fluent_save_edit_24_filled = 59985
ic_fluent_search_info_20_filled = 60039
ic_fluent_search_visual_16_filled = 60043
ic_fluent_search_visual_20_filled = 60044
ic_fluent_search_visual_24_filled = 60045
ic_fluent_select_all_on_24_filled = 60048
ic_fluent_share_screen_start_20_filled = 60099
ic_fluent_share_screen_start_24_filled = 60100
ic_fluent_share_screen_start_28_filled = 60101
ic_fluent_share_screen_stop_16_filled = 60103
ic_fluent_share_screen_stop_20_filled = 60104
ic_fluent_share_screen_stop_24_filled = 60105
ic_fluent_share_screen_stop_28_filled = 60106
ic_fluent_share_screen_stop_48_filled = 60107
ic_fluent_shield_dismiss_16_filled = 60117
ic_fluent_shifts_prohibited_24_filled = 60143
ic_fluent_shifts_question_mark_24_filled = 60145
ic_fluent_speaker_2_16_filled = 60234
ic_fluent_speaker_2_20_filled = 60235
ic_fluent_speaker_2_24_filled = 60236
ic_fluent_speaker_2_28_filled = 60237
ic_fluent_speaker_2_48_filled = 60239
ic_fluent_speaker_mute_16_filled = 60242
ic_fluent_speaker_mute_20_filled = 60243
ic_fluent_speaker_mute_24_filled = 60244
ic_fluent_speaker_mute_28_filled = 60245
ic_fluent_speaker_mute_48_filled = 60246
ic_fluent_star_arrow_right_end_24_filled = 60331
ic_fluent_subtract_12_filled = 60360
ic_fluent_subtract_16_filled = 60361
ic_fluent_subtract_20_filled = 60362
ic_fluent_subtract_24_filled = 60363
ic_fluent_subtract_28_filled = 60364
ic_fluent_subtract_48_filled = 60365
ic_fluent_tab_add_20_filled = 60383
ic_fluent_tab_add_24_filled = 60384
ic_fluent_tab_arrow_left_24_filled = 60386
ic_fluent_tab_shield_dismiss_20_filled = 60396
ic_fluent_tab_shield_dismiss_24_filled = 60397
ic_fluent_table_delete_column_24_filled = 60423
ic_fluent_table_delete_row_24_filled = 60427
ic_fluent_table_freeze_column_and_row_24_filled = 60441
ic_fluent_table_insert_column_24_filled = 60449
ic_fluent_table_insert_row_24_filled = 60453
ic_fluent_table_move_above_24_filled = 60465
ic_fluent_table_move_below_24_filled = 60469
ic_fluent_table_resize_column_24_filled = 60480
ic_fluent_table_resize_row_24_filled = 60484
ic_fluent_table_stack_above_24_filled = 60498
ic_fluent_table_stack_below_24_filled = 60502
ic_fluent_table_stack_left_24_filled = 60506
ic_fluent_table_stack_right_24_filled = 60510
ic_fluent_tag_question_mark_16_filled = 60544
ic_fluent_tag_question_mark_24_filled = 60546
ic_fluent_text_grammar_arrow_left_20_filled = 60690
ic_fluent_text_grammar_arrow_left_24_filled = 60691
ic_fluent_text_grammar_arrow_right_20_filled = 60692
ic_fluent_text_grammar_arrow_right_24_filled = 60693
ic_fluent_text_grammar_checkmark_20_filled = 60694
ic_fluent_text_grammar_checkmark_24_filled = 60695
ic_fluent_text_grammar_dismiss_20_filled = 60696
ic_fluent_text_grammar_dismiss_24_filled = 60697
ic_fluent_text_grammar_settings_20_filled = 60699
ic_fluent_text_grammar_settings_24_filled = 60700
ic_fluent_text_grammar_wand_16_filled = 60701
ic_fluent_text_grammar_wand_20_filled = 60702
ic_fluent_text_grammar_wand_24_filled = 60703
ic_fluent_text_paragraph_20_filled = 60738
ic_fluent_text_paragraph_24_filled = 60739
ic_fluent_text_paragraph_direction_20_filled = 60740
ic_fluent_text_paragraph_direction_24_filled = 60741
ic_fluent_text_position_behind_20_filled = 60747
ic_fluent_text_position_behind_24_filled = 60748
ic_fluent_text_position_front_20_filled = 60749
ic_fluent_text_position_front_24_filled = 60750
ic_fluent_text_position_line_20_filled = 60751
ic_fluent_text_position_line_24_filled = 60752
ic_fluent_text_position_square_20_filled = 60753
ic_fluent_text_position_square_24_filled = 60754
ic_fluent_text_position_through_20_filled = 60755
ic_fluent_text_position_through_24_filled = 60756
ic_fluent_text_position_tight_20_filled = 60757
ic_fluent_text_position_tight_24_filled = 60758
ic_fluent_text_position_top_bottom_20_filled = 60759
ic_fluent_text_position_top_bottom_24_filled = 60760
ic_fluent_textbox_align_center_20_filled = 60781
ic_fluent_textbox_align_center_24_filled = 60782
ic_fluent_thumb_like_16_filled = 60792
ic_fluent_ticket_horizontal_20_filled = 60799
ic_fluent_ticket_horizontal_24_filled = 60800
ic_fluent_wand_16_filled = 60982
ic_fluent_wand_20_filled = 60983
ic_fluent_wand_24_filled = 60984
ic_fluent_wand_28_filled = 60985
ic_fluent_wand_48_filled = 60986
ic_fluent_window_arrow_up_24_filled = 61036
ic_fluent_window_header_horizontal_20_filled = 61044
ic_fluent_window_header_vertical_20_filled = 61046
ic_fluent_accessibility_32_filled = 57345
ic_fluent_accessibility_checkmark_24_filled = 57348
ic_fluent_add_circle_16_filled = 57349
ic_fluent_add_circle_32_filled = 57350
ic_fluent_animal_rabbit_16_filled = 57424
ic_fluent_animal_rabbit_20_filled = 57425
ic_fluent_animal_rabbit_24_filled = 57426
ic_fluent_animal_rabbit_28_filled = 57427
ic_fluent_animal_turtle_16_filled = 57428
ic_fluent_animal_turtle_20_filled = 57429
ic_fluent_animal_turtle_24_filled = 57430
ic_fluent_animal_turtle_28_filled = 57431
ic_fluent_book_contacts_20_filled = 57726
ic_fluent_book_contacts_24_filled = 57727
ic_fluent_book_contacts_28_filled = 57728
ic_fluent_book_open_globe_20_filled = 57745
ic_fluent_calligraphy_pen_checkmark_20_filled = 58026
ic_fluent_calligraphy_pen_question_mark_20_filled = 58028
ic_fluent_cellular_5g_24_filled = 58055
ic_fluent_checkbox_1_24_filled = 58123
ic_fluent_checkbox_2_24_filled = 58125
ic_fluent_checkbox_arrow_right_24_filled = 58127
ic_fluent_checkbox_person_24_filled = 58134
ic_fluent_checkbox_warning_24_filled = 58136
ic_fluent_circle_edit_24_filled = 58186
ic_fluent_clock_32_filled = 58243
ic_fluent_cloud_16_filled = 58263
ic_fluent_cloud_32_filled = 58265
ic_fluent_comment_note_24_filled = 58379
ic_fluent_content_settings_32_filled = 58403
ic_fluent_desktop_mac_16_filled = 58532
ic_fluent_desktop_mac_32_filled = 58535
ic_fluent_document_arrow_right_24_filled = 58611
ic_fluent_document_checkmark_24_filled = 58622
ic_fluent_dual_screen_dismiss_24_filled = 58794
ic_fluent_dual_screen_speaker_24_filled = 58805
ic_fluent_filter_dismiss_24_filled = 58907
ic_fluent_filter_sync_24_filled = 58909
ic_fluent_folder_16_filled = 58960
ic_fluent_folder_32_filled = 58961
ic_fluent_globe_person_24_filled = 59077
ic_fluent_home_person_24_filled = 59173
ic_fluent_image_globe_24_filled = 59184
ic_fluent_inking_tool_32_filled = 59207
ic_fluent_key_16_filled = 59214
ic_fluent_key_32_filled = 59215
ic_fluent_line_style_24_filled = 59261
ic_fluent_math_formula_16_filled = 59375
ic_fluent_math_formula_32_filled = 59378
ic_fluent_notebook_add_24_filled = 59521
ic_fluent_notebook_section_arrow_right_24_filled = 59528
ic_fluent_notebook_subsection_24_filled = 59530
ic_fluent_orientation_20_filled = 59565
ic_fluent_people_32_filled = 59646
ic_fluent_person_note_24_filled = 59729
ic_fluent_phone_laptop_16_filled = 59762
ic_fluent_phone_laptop_32_filled = 59763
ic_fluent_phone_speaker_24_filled = 59780
ic_fluent_pi_24_filled = 59789
ic_fluent_premium_32_filled = 59843
ic_fluent_receipt_20_filled = 59910
ic_fluent_receipt_24_filled = 59911
ic_fluent_rss_24_filled = 59974
ic_fluent_screen_cut_20_filled = 60031
ic_fluent_screen_person_20_filled = 60032
ic_fluent_shape_exclude_16_filled = 60065
ic_fluent_shape_exclude_20_filled = 60066
ic_fluent_shape_exclude_24_filled = 60067
ic_fluent_shape_intersect_16_filled = 60068
ic_fluent_shape_intersect_20_filled = 60069
ic_fluent_shape_intersect_24_filled = 60070
ic_fluent_shape_subtract_16_filled = 60071
ic_fluent_shape_subtract_20_filled = 60072
ic_fluent_shape_subtract_24_filled = 60073
ic_fluent_shape_union_16_filled = 60074
ic_fluent_shape_union_20_filled = 60075
ic_fluent_shape_union_24_filled = 60076
ic_fluent_shifts_16_filled = 60132
ic_fluent_slide_settings_24_filled = 60205
ic_fluent_slide_transition_24_filled = 60213
ic_fluent_star_emphasis_32_filled = 60340
ic_fluent_table_32_filled = 60400
ic_fluent_table_cell_edit_24_filled = 60413
ic_fluent_tablet_speaker_24_filled = 60520
ic_fluent_target_32_filled = 60558
ic_fluent_timer_3_24_filled = 60811
ic_fluent_voicemail_28_filled = 60964
ic_fluent_walkie_talkie_20_filled = 60970
ic_fluent_warning_shield_20_filled = 60989
ic_fluent_add_subtract_circle_16_filled = 57354
ic_fluent_add_subtract_circle_20_filled = 57355
ic_fluent_add_subtract_circle_24_filled = 57356
ic_fluent_add_subtract_circle_28_filled = 57357
ic_fluent_add_subtract_circle_48_filled = 57358
ic_fluent_beach_16_filled = 57683
ic_fluent_beach_20_filled = 57684
ic_fluent_beach_24_filled = 57685
ic_fluent_beach_28_filled = 57686
ic_fluent_building_16_filled = 57886
ic_fluent_calendar_edit_16_filled = 57945
ic_fluent_calendar_edit_20_filled = 57946
ic_fluent_calendar_edit_24_filled = 57947
ic_fluent_calendar_ltr_20_filled = 57954
ic_fluent_calendar_ltr_24_filled = 57955
ic_fluent_calendar_ltr_28_filled = 57956
ic_fluent_calendar_rtl_20_filled = 57975
ic_fluent_calendar_rtl_24_filled = 57976
ic_fluent_calendar_rtl_28_filled = 57977
ic_fluent_circle_small_20_filled = 58195
ic_fluent_clipboard_16_filled = 58199
ic_fluent_clipboard_arrow_right_16_filled = 58201
ic_fluent_clipboard_arrow_right_20_filled = 58202
ic_fluent_clipboard_arrow_right_24_filled = 58203
ic_fluent_clipboard_text_ltr_20_filled = 58238
ic_fluent_clipboard_text_ltr_24_filled = 58239
ic_fluent_clipboard_text_rtl_20_filled = 58241
ic_fluent_clipboard_text_rtl_24_filled = 58242
ic_fluent_cube_sync_24_filled = 58438
ic_fluent_document_question_mark_16_filled = 58684
ic_fluent_document_question_mark_20_filled = 58685
ic_fluent_document_question_mark_24_filled = 58686
ic_fluent_door_arrow_left_20_filled = 58737
ic_fluent_drop_12_filled = 58778
ic_fluent_drop_16_filled = 58779
ic_fluent_drop_20_filled = 58780
ic_fluent_drop_24_filled = 58781
ic_fluent_drop_28_filled = 58782
ic_fluent_drop_48_filled = 58783
ic_fluent_dumbbell_16_filled = 58811
ic_fluent_dumbbell_20_filled = 58812
ic_fluent_dumbbell_24_filled = 58813
ic_fluent_dumbbell_28_filled = 58814
ic_fluent_edit_off_20_filled = 58820
ic_fluent_eyedropper_20_filled = 58890
ic_fluent_eyedropper_24_filled = 58891
ic_fluent_flag_off_16_filled = 58914
ic_fluent_flag_off_20_filled = 58915
ic_fluent_fps_120_20_filled = 59010
ic_fluent_fps_120_24_filled = 59011
ic_fluent_fps_240_20_filled = 59012
ic_fluent_guitar_16_filled = 59103
ic_fluent_guitar_20_filled = 59104
ic_fluent_guitar_24_filled = 59105
ic_fluent_guitar_28_filled = 59106
ic_fluent_key_command_16_filled = 59216
ic_fluent_more_vertical_16_filled = 59447
ic_fluent_people_checkmark_20_filled = 59653
ic_fluent_people_checkmark_24_filled = 59654
ic_fluent_play_circle_16_filled = 59813
ic_fluent_play_circle_20_filled = 59814
ic_fluent_play_circle_28_filled = 59815
ic_fluent_re_order_dots_horizontal_16_filled = 59900
ic_fluent_re_order_dots_horizontal_20_filled = 59901
ic_fluent_re_order_dots_horizontal_24_filled = 59902
ic_fluent_re_order_dots_vertical_16_filled = 59903
ic_fluent_re_order_dots_vertical_20_filled = 59904
ic_fluent_re_order_dots_vertical_24_filled = 59905
ic_fluent_scale_fill_20_filled = 59991
ic_fluent_skip_back_10_20_filled = 60164
ic_fluent_skip_forward_10_20_filled = 60169
ic_fluent_skip_forward_30_20_filled = 60174
ic_fluent_slide_eraser_24_filled = 60191
ic_fluent_split_horizontal_12_filled = 60256
ic_fluent_split_horizontal_16_filled = 60257
ic_fluent_split_horizontal_20_filled = 60258
ic_fluent_split_horizontal_24_filled = 60259
ic_fluent_split_horizontal_28_filled = 60260
ic_fluent_split_horizontal_32_filled = 60261
ic_fluent_split_horizontal_48_filled = 60262
ic_fluent_split_vertical_12_filled = 60263
ic_fluent_split_vertical_16_filled = 60264
ic_fluent_split_vertical_20_filled = 60265
ic_fluent_split_vertical_24_filled = 60266
ic_fluent_split_vertical_28_filled = 60267
ic_fluent_split_vertical_32_filled = 60268
ic_fluent_split_vertical_48_filled = 60269
ic_fluent_sport_soccer_20_filled = 60282
ic_fluent_sport_soccer_24_filled = 60283
ic_fluent_symbols_20_filled = 60379
ic_fluent_table_delete_column_20_filled = 60422
ic_fluent_table_delete_row_20_filled = 60426
ic_fluent_table_stack_above_20_filled = 60497
ic_fluent_table_stack_left_20_filled = 60505
ic_fluent_table_stack_right_20_filled = 60509
ic_fluent_task_list_ltr_20_filled = 60560
ic_fluent_task_list_ltr_24_filled = 60561
ic_fluent_task_list_rtl_20_filled = 60562
ic_fluent_task_list_rtl_24_filled = 60563
ic_fluent_tetris_app_16_filled = 60581
ic_fluent_tetris_app_20_filled = 60582
ic_fluent_tetris_app_24_filled = 60583
ic_fluent_tetris_app_28_filled = 60584
ic_fluent_tetris_app_32_filled = 60585
ic_fluent_tetris_app_48_filled = 60586
ic_fluent_text_bullet_list_ltr_20_filled = 60631
ic_fluent_text_bullet_list_ltr_24_filled = 60632
ic_fluent_text_bullet_list_rtl_20_filled = 60638
ic_fluent_text_bullet_list_rtl_24_filled = 60639
ic_fluent_vehicle_cab_16_filled = 60885
ic_fluent_vehicle_cab_20_filled = 60886
ic_fluent_vehicle_cab_28_filled = 60887
ic_fluent_vehicle_truck_profile_24_filled = 60911
ic_fluent_bot_add_20_filled = 57805
ic_fluent_chart_person_20_filled = 58099
ic_fluent_chart_person_24_filled = 58100
ic_fluent_chart_person_28_filled = 58101
ic_fluent_chart_person_48_filled = 58102
ic_fluent_mic_prohibited_16_filled = 59407
ic_fluent_mic_prohibited_28_filled = 59410
ic_fluent_mic_prohibited_48_filled = 59411
ic_fluent_tv_usb_16_filled = 60871
ic_fluent_tv_usb_20_filled = 60872
ic_fluent_tv_usb_24_filled = 60873
ic_fluent_tv_usb_28_filled = 60874
ic_fluent_tv_usb_48_filled = 60875
ic_fluent_video_360_off_20_filled = 60915
ic_fluent_video_prohibited_16_filled = 60955
ic_fluent_video_prohibited_24_filled = 60957
ic_fluent_video_prohibited_28_filled = 60958
ic_fluent_alert_32_filled = 57365
ic_fluent_arrow_down_left_20_filled = 57531
ic_fluent_arrow_step_back_16_filled = 57592
ic_fluent_arrow_step_in_16_filled = 57595
ic_fluent_arrow_step_out_16_filled = 57610
ic_fluent_arrow_step_over_16_filled = 57614
ic_fluent_arrow_up_right_20_filled = 57647
ic_fluent_backpack_32_filled = 57669
ic_fluent_book_contacts_32_filled = 57729
ic_fluent_bookmark_32_filled = 57765
ic_fluent_bookmark_multiple_24_filled = 57768
ic_fluent_branch_compare_16_filled = 57838
ic_fluent_branch_compare_20_filled = 57839
ic_fluent_branch_compare_24_filled = 57840
ic_fluent_branch_fork_16_filled = 57841
ic_fluent_branch_fork_20_filled = 57842
ic_fluent_branch_fork_24_filled = 57843
ic_fluent_calendar_ltr_16_filled = 57953
ic_fluent_calendar_ltr_32_filled = 57957
ic_fluent_calendar_rtl_32_filled = 57978
ic_fluent_call_32_filled = 57991
ic_fluent_calligraphy_pen_error_20_filled = 58027
ic_fluent_chat_32_filled = 58105
ic_fluent_clipboard_data_bar_32_filled = 58214
ic_fluent_clock_alarm_32_filled = 58245
ic_fluent_content_view_32_filled = 58405
ic_fluent_desktop_32_filled = 58515
ic_fluent_dismiss_square_multiple_16_filled = 58578
ic_fluent_document_32_filled = 58596
ic_fluent_document_pdf_32_filled = 58676
ic_fluent_food_pizza_20_filled = 59005
ic_fluent_food_pizza_24_filled = 59006
ic_fluent_globe_32_filled = 59071
ic_fluent_headset_32_filled = 59141
ic_fluent_heart_pulse_20_filled = 59150
ic_fluent_multiplier_1_2x_20_filled = 59451
ic_fluent_multiplier_1_2x_24_filled = 59452
ic_fluent_multiplier_1_2x_28_filled = 59453
ic_fluent_multiplier_1_2x_32_filled = 59454
ic_fluent_multiplier_1_2x_48_filled = 59455
ic_fluent_multiplier_1_5x_20_filled = 59456
ic_fluent_multiplier_1_5x_24_filled = 59457
ic_fluent_multiplier_1_5x_28_filled = 59458
ic_fluent_multiplier_1_5x_32_filled = 59459
ic_fluent_multiplier_1_5x_48_filled = 59460
ic_fluent_multiplier_1_8x_20_filled = 59461
ic_fluent_multiplier_1_8x_24_filled = 59462
ic_fluent_multiplier_1_8x_28_filled = 59463
ic_fluent_multiplier_1_8x_32_filled = 59464
ic_fluent_multiplier_1_8x_48_filled = 59465
ic_fluent_multiplier_1x_20_filled = 59466
ic_fluent_multiplier_1x_24_filled = 59467
ic_fluent_multiplier_1x_28_filled = 59468
ic_fluent_multiplier_1x_32_filled = 59469
ic_fluent_multiplier_1x_48_filled = 59470
ic_fluent_multiplier_2x_20_filled = 59471
ic_fluent_multiplier_2x_24_filled = 59472
ic_fluent_multiplier_2x_28_filled = 59473
ic_fluent_multiplier_2x_32_filled = 59474
ic_fluent_multiplier_2x_48_filled = 59475
ic_fluent_my_location_16_filled = 59499
ic_fluent_my_location_20_filled = 59500
ic_fluent_notepad_32_filled = 59533
ic_fluent_patient_32_filled = 59613
ic_fluent_people_team_32_filled = 59682
ic_fluent_pulse_32_filled = 59879
ic_fluent_remote_16_filled = 59927
ic_fluent_ribbon_32_filled = 59953
ic_fluent_shifts_32_filled = 60135
ic_fluent_skip_forward_10_24_filled = 60170
ic_fluent_skip_forward_10_28_filled = 60171
ic_fluent_skip_forward_10_32_filled = 60172
ic_fluent_skip_forward_10_48_filled = 60173
ic_fluent_skip_forward_30_24_filled = 60175
ic_fluent_skip_forward_30_28_filled = 60176
ic_fluent_skip_forward_30_32_filled = 60177
ic_fluent_skip_forward_30_48_filled = 60178
ic_fluent_subtract_square_multiple_16_filled = 60373
ic_fluent_text_sort_ascending_16_filled = 60762
ic_fluent_text_sort_ascending_24_filled = 60763
ic_fluent_text_sort_descending_16_filled = 60764
ic_fluent_text_sort_descending_24_filled = 60765
ic_fluent_video_person_call_32_filled = 60944
ic_fluent_weather_sunny_32_filled = 61006
ic_fluent_align_bottom_16_filled = 57374
ic_fluent_align_bottom_20_filled = 57375
ic_fluent_align_bottom_24_filled = 57376
ic_fluent_align_bottom_28_filled = 57377
ic_fluent_align_bottom_32_filled = 57378
ic_fluent_align_bottom_48_filled = 57379
ic_fluent_align_center_horizontal_16_filled = 57380
ic_fluent_align_center_horizontal_20_filled = 57381
ic_fluent_align_center_horizontal_24_filled = 57382
ic_fluent_align_center_horizontal_28_filled = 57383
ic_fluent_align_center_horizontal_32_filled = 57384
ic_fluent_align_center_horizontal_48_filled = 57385
ic_fluent_align_center_vertical_16_filled = 57386
ic_fluent_align_center_vertical_20_filled = 57387
ic_fluent_align_center_vertical_24_filled = 57388
ic_fluent_align_center_vertical_28_filled = 57389
ic_fluent_align_center_vertical_32_filled = 57390
ic_fluent_align_center_vertical_48_filled = 57391
ic_fluent_align_left_16_filled = 57394
ic_fluent_align_left_20_filled = 57395
ic_fluent_align_left_24_filled = 57396
ic_fluent_align_left_28_filled = 57397
ic_fluent_align_left_32_filled = 57398
ic_fluent_align_left_48_filled = 57399
ic_fluent_align_right_16_filled = 57400
ic_fluent_align_right_20_filled = 57401
ic_fluent_align_right_24_filled = 57402
ic_fluent_align_right_28_filled = 57403
ic_fluent_align_right_32_filled = 57404
ic_fluent_align_right_48_filled = 57405
ic_fluent_align_top_16_filled = 57417
ic_fluent_align_top_20_filled = 57418
ic_fluent_align_top_24_filled = 57419
ic_fluent_align_top_28_filled = 57420
ic_fluent_align_top_32_filled = 57421
ic_fluent_align_top_48_filled = 57422
ic_fluent_calculator_24_filled = 57927
ic_fluent_camera_16_filled = 58029
ic_fluent_group_dismiss_24_filled = 59094
ic_fluent_group_return_24_filled = 59097
ic_fluent_hand_left_16_filled = 59111
ic_fluent_hand_left_24_filled = 59113
ic_fluent_hand_left_28_filled = 59114
ic_fluent_hand_right_16_filled = 59115
ic_fluent_home_12_filled = 59163
ic_fluent_keyboard_shift_16_filled = 59230
ic_fluent_keyboard_shift_20_filled = 59231
ic_fluent_link_square_20_filled = 59269
ic_fluent_mail_inbox_checkmark_16_filled = 59339
ic_fluent_mail_inbox_checkmark_20_filled = 59340
ic_fluent_mail_inbox_checkmark_24_filled = 59341
ic_fluent_music_note_2_20_filled = 59490
ic_fluent_my_location_12_filled = 59498
ic_fluent_number_symbol_square_20_filled = 59546
ic_fluent_number_symbol_square_24_filled = 59547
ic_fluent_person_32_filled = 59693
ic_fluent_person_5_32_filled = 59695
ic_fluent_search_16_filled = 60036
ic_fluent_send_16_filled = 60055
ic_fluent_symbols_16_filled = 60378
ic_fluent_teddy_20_filled = 60574
ic_fluent_video_person_star_off_24_filled = 60953
ic_fluent_apps_add_in_16_filled = 57442
ic_fluent_apps_add_in_28_filled = 57443
ic_fluent_arrow_curve_down_left_16_filled = 57528
ic_fluent_arrow_curve_down_left_24_filled = 57529
ic_fluent_arrow_curve_down_left_28_filled = 57530
ic_fluent_arrow_upload_16_filled = 57650
ic_fluent_attach_12_filled = 57654
ic_fluent_board_16_filled = 57702
ic_fluent_board_20_filled = 57703
ic_fluent_board_28_filled = 57704
ic_fluent_board_split_16_filled = 57709
ic_fluent_board_split_20_filled = 57710
ic_fluent_board_split_24_filled = 57711
ic_fluent_board_split_28_filled = 57712
ic_fluent_board_split_48_filled = 57713
ic_fluent_calendar_empty_32_filled = 57948
ic_fluent_calendar_ltr_12_filled = 57952
ic_fluent_calendar_multiple_32_filled = 57963
ic_fluent_chevron_up_down_20_filled = 58180
ic_fluent_chevron_up_down_24_filled = 58181
ic_fluent_circle_12_filled = 58182
ic_fluent_circle_half_fill_12_filled = 58188
ic_fluent_circle_line_12_filled = 58190
ic_fluent_closed_caption_off_16_filled = 58258
ic_fluent_closed_caption_off_20_filled = 58259
ic_fluent_closed_caption_off_24_filled = 58260
ic_fluent_closed_caption_off_28_filled = 58261
ic_fluent_closed_caption_off_48_filled = 58262
ic_fluent_desktop_pulse_16_filled = 58536
ic_fluent_desktop_pulse_20_filled = 58537
ic_fluent_desktop_pulse_24_filled = 58538
ic_fluent_desktop_pulse_28_filled = 58539
ic_fluent_desktop_pulse_32_filled = 58540
ic_fluent_desktop_pulse_48_filled = 58541
ic_fluent_developer_board_20_filled = 58552
ic_fluent_dismiss_square_24_filled = 58577
ic_fluent_door_arrow_left_24_filled = 58738
ic_fluent_emoji_hand_20_filled = 58843
ic_fluent_filter_16_filled = 58903
ic_fluent_flash_16_filled = 58916
ic_fluent_flash_28_filled = 58919
ic_fluent_flash_checkmark_16_filled = 58922
ic_fluent_flash_checkmark_20_filled = 58923
ic_fluent_flash_checkmark_24_filled = 58924
ic_fluent_flash_checkmark_28_filled = 58925
ic_fluent_folder_prohibited_16_filled = 58984
ic_fluent_grid_16_filled = 59088
ic_fluent_headphones_20_filled = 59131
ic_fluent_headphones_32_filled = 59132
ic_fluent_headphones_48_filled = 59133
ic_fluent_headphones_sound_wave_20_filled = 59134
ic_fluent_headphones_sound_wave_24_filled = 59135
ic_fluent_headphones_sound_wave_28_filled = 59136
ic_fluent_headphones_sound_wave_32_filled = 59137
ic_fluent_headphones_sound_wave_48_filled = 59138
ic_fluent_home_checkmark_16_filled = 59168
ic_fluent_home_checkmark_20_filled = 59169
ic_fluent_ink_stroke_20_filled = 59205
ic_fluent_ink_stroke_24_filled = 59206
ic_fluent_library_16_filled = 59247
ic_fluent_library_20_filled = 59248
ic_fluent_list_16_filled = 59271
ic_fluent_location_arrow_left_48_filled = 59281
ic_fluent_location_arrow_right_48_filled = 59282
ic_fluent_location_arrow_up_48_filled = 59283
ic_fluent_mail_inbox_checkmark_28_filled = 59342
ic_fluent_map_20_filled = 59368
ic_fluent_multiplier_5x_20_filled = 59476
ic_fluent_multiplier_5x_24_filled = 59477
ic_fluent_multiplier_5x_28_filled = 59478
ic_fluent_multiplier_5x_32_filled = 59479
ic_fluent_multiplier_5x_48_filled = 59480
ic_fluent_music_note_2_play_20_filled = 59492
ic_fluent_notepad_12_filled = 59532
ic_fluent_organization_12_filled = 59560
ic_fluent_people_community_add_20_filled = 59655
ic_fluent_people_community_add_28_filled = 59656
ic_fluent_person_6_32_filled = 59697
ic_fluent_person_add_16_filled = 59699
ic_fluent_person_add_28_filled = 59700
ic_fluent_person_prohibited_16_filled = 59732
ic_fluent_person_prohibited_28_filled = 59734
ic_fluent_pin_28_filled = 59796
ic_fluent_pin_32_filled = 59797
ic_fluent_pin_48_filled = 59798
ic_fluent_premium_person_20_filled = 59845
ic_fluent_premium_person_24_filled = 59846
ic_fluent_prohibited_multiple_16_filled = 59864
ic_fluent_prohibited_multiple_20_filled = 59865
ic_fluent_prohibited_multiple_24_filled = 59866
ic_fluent_read_aloud_16_filled = 59906
ic_fluent_read_aloud_28_filled = 59907
ic_fluent_shield_16_filled = 60108
ic_fluent_shield_28_filled = 60109
ic_fluent_shield_48_filled = 60110
ic_fluent_shield_checkmark_16_filled = 60112
ic_fluent_shield_checkmark_20_filled = 60113
ic_fluent_shield_checkmark_24_filled = 60114
ic_fluent_shield_checkmark_28_filled = 60115
ic_fluent_shield_checkmark_48_filled = 60116
ic_fluent_top_speed_20_filled = 60827
ic_fluent_checkmark_circle_12_filled = 58139
ic_fluent_add_square_multiple_16_filled = 57352
ic_fluent_add_square_multiple_20_filled = 57353
ic_fluent_arrow_forward_48_filled = 57553
ic_fluent_arrow_sync_16_filled = 57616
ic_fluent_book_open_28_filled = 57742
ic_fluent_book_open_32_filled = 57743
ic_fluent_book_open_48_filled = 57744
ic_fluent_book_open_microphone_20_filled = 57747
ic_fluent_book_open_microphone_24_filled = 57748
ic_fluent_book_open_microphone_28_filled = 57749
ic_fluent_book_open_microphone_32_filled = 57750
ic_fluent_book_open_microphone_48_filled = 57751
ic_fluent_briefcase_off_16_filled = 57860
ic_fluent_briefcase_off_20_filled = 57861
ic_fluent_briefcase_off_24_filled = 57862
ic_fluent_briefcase_off_28_filled = 57863
ic_fluent_briefcase_off_32_filled = 57864
ic_fluent_briefcase_off_48_filled = 57865
ic_fluent_building_bank_28_filled = 57891
ic_fluent_building_bank_48_filled = 57892
ic_fluent_building_bank_link_16_filled = 57893
ic_fluent_building_bank_link_20_filled = 57894
ic_fluent_building_bank_link_24_filled = 57895
ic_fluent_building_bank_link_28_filled = 57896
ic_fluent_building_bank_link_48_filled = 57897
ic_fluent_calendar_mail_16_filled = 57959
ic_fluent_calendar_rtl_12_filled = 57973
ic_fluent_calendar_rtl_16_filled = 57974
ic_fluent_chevron_double_up_16_filled = 58177
ic_fluent_chevron_double_up_20_filled = 58178
ic_fluent_cloud_28_filled = 58264
ic_fluent_cloud_off_16_filled = 58300
ic_fluent_cloud_off_20_filled = 58301
ic_fluent_cloud_off_28_filled = 58302
ic_fluent_cloud_off_32_filled = 58303
ic_fluent_cloud_sync_16_filled = 58306
ic_fluent_cloud_sync_24_filled = 58308
ic_fluent_cloud_sync_28_filled = 58309
ic_fluent_cloud_sync_32_filled = 58310
ic_fluent_cloud_sync_48_filled = 58311
ic_fluent_dismiss_square_20_filled = 58576
ic_fluent_document_footer_16_filled = 58632
ic_fluent_document_footer_dismiss_24_filled = 58635
ic_fluent_document_header_16_filled = 58636
ic_fluent_document_header_arrow_down_16_filled = 58638
ic_fluent_document_header_dismiss_24_filled = 58642
ic_fluent_document_header_footer_16_filled = 58643
ic_fluent_document_ribbon_16_filled = 58693
ic_fluent_document_ribbon_20_filled = 58694
ic_fluent_document_ribbon_24_filled = 58695
ic_fluent_document_ribbon_28_filled = 58696
ic_fluent_document_ribbon_32_filled = 58697
ic_fluent_document_ribbon_48_filled = 58698
ic_fluent_door_arrow_left_16_filled = 58736
ic_fluent_drive_train_24_filled = 58777
ic_fluent_engine_24_filled = 58861
ic_fluent_folder_mail_16_filled = 58979
ic_fluent_folder_sync_16_filled = 58992
ic_fluent_gas_24_filled = 59038
ic_fluent_gas_pump_24_filled = 59040
ic_fluent_mail_dismiss_16_filled = 59327
ic_fluent_mail_prohibited_16_filled = 59357
ic_fluent_mic_sparkle_16_filled = 59425
ic_fluent_mic_sparkle_20_filled = 59426
ic_fluent_mic_sparkle_24_filled = 59427
ic_fluent_notepad_person_20_filled = 59536
ic_fluent_notepad_person_24_filled = 59537
ic_fluent_pin_off_16_filled = 59799
ic_fluent_pin_off_48_filled = 59802
ic_fluent_skip_forward_tab_24_filled = 60180
ic_fluent_square_arrow_forward_16_filled = 60293
ic_fluent_square_arrow_forward_20_filled = 60294
ic_fluent_square_arrow_forward_24_filled = 60295
ic_fluent_square_arrow_forward_28_filled = 60296
ic_fluent_square_arrow_forward_32_filled = 60297
ic_fluent_square_arrow_forward_48_filled = 60298
ic_fluent_subtract_square_multiple_20_filled = 60374
ic_fluent_transmission_24_filled = 60829
ic_fluent_wifi_off_20_filled = 61017
ic_fluent_wifi_off_24_filled = 61018
ic_fluent_animal_cat_16_filled = 61702
ic_fluent_animal_cat_20_filled = 61734
ic_fluent_animal_cat_24_filled = 61735
ic_fluent_animal_cat_28_filled = 61736
ic_fluent_archive_settings_16_filled = 61737
ic_fluent_arrow_circle_down_20_filled = 61740
ic_fluent_arrow_circle_down_24_filled = 61741
ic_fluent_arrow_circle_down_double_20_filled = 61742
ic_fluent_arrow_circle_down_double_24_filled = 61743
ic_fluent_arrow_circle_down_split_20_filled = 61763
ic_fluent_arrow_circle_down_split_24_filled = 61764
ic_fluent_arrow_down_32_filled = 61772
ic_fluent_arrow_down_48_filled = 61773
ic_fluent_arrow_fit_16_filled = 61774
ic_fluent_arrow_left_16_filled = 61828
ic_fluent_arrow_left_32_filled = 61833
ic_fluent_arrow_left_48_filled = 61854
ic_fluent_arrow_reset_20_filled = 61855
ic_fluent_arrow_reset_24_filled = 61856
ic_fluent_arrow_right_32_filled = 61858
ic_fluent_arrow_right_48_filled = 61863
ic_fluent_arrow_sort_16_filled = 61867
ic_fluent_arrow_sort_down_16_filled = 61868
ic_fluent_arrow_sort_down_lines_16_filled = 61869
ic_fluent_arrow_sort_up_16_filled = 61875
ic_fluent_arrow_up_16_filled = 61876
ic_fluent_arrow_up_32_filled = 61880
ic_fluent_arrow_up_48_filled = 61881
ic_fluent_barcode_scanner_20_filled = 61882
ic_fluent_barcode_scanner_24_filled = 61924
ic_fluent_beaker_edit_20_filled = 61925
ic_fluent_beaker_edit_24_filled = 61926
ic_fluent_book_toolbox_20_filled = 61927
ic_fluent_bookmark_add_20_filled = 61928
ic_fluent_bookmark_add_24_filled = 61929
ic_fluent_bowl_chopsticks_16_filled = 61930
ic_fluent_bowl_chopsticks_20_filled = 61931
ic_fluent_bowl_chopsticks_24_filled = 61932
ic_fluent_bowl_chopsticks_28_filled = 61933
ic_fluent_brain_circuit_20_filled = 61934
ic_fluent_briefcase_medical_20_filled = 61935
ic_fluent_broom_16_filled = 61950
ic_fluent_building_bank_toolbox_20_filled = 61951
ic_fluent_calendar_info_16_filled = 61955
ic_fluent_calendar_multiple_16_filled = 61956
ic_fluent_call_checkmark_20_filled = 61959
ic_fluent_call_dismiss_20_filled = 61960
ic_fluent_call_dismiss_24_filled = 61963
ic_fluent_call_pause_20_filled = 61964
ic_fluent_call_pause_24_filled = 61965
ic_fluent_chat_help_20_filled = 61984
ic_fluent_chat_settings_20_filled = 61985
ic_fluent_chat_settings_24_filled = 61993
ic_fluent_check_20_filled = 62075
ic_fluent_checkbox_checked_16_filled = 62076
ic_fluent_checkbox_checked_sync_16_filled = 62077
ic_fluent_checkmark_starburst_16_filled = 62083
ic_fluent_chevron_double_down_16_filled = 62084
ic_fluent_chevron_double_left_16_filled = 62085
ic_fluent_chevron_double_right_16_filled = 62119
ic_fluent_circle_half_fill_16_filled = 62218
ic_fluent_clipboard_heart_20_filled = 62219
ic_fluent_clipboard_pulse_20_filled = 62242
ic_fluent_clipboard_settings_20_filled = 62253
ic_fluent_clock_arrow_download_20_filled = 62254
ic_fluent_cloud_add_16_filled = 62255
ic_fluent_cloud_edit_16_filled = 62256
ic_fluent_cloud_flow_20_filled = 62263
ic_fluent_cloud_link_16_filled = 62264
ic_fluent_code_16_filled = 62265
ic_fluent_comment_error_16_filled = 62288
ic_fluent_comment_lightning_20_filled = 62289
ic_fluent_comment_lightning_24_filled = 62305
ic_fluent_contact_card_16_filled = 62306
ic_fluent_contact_card_link_16_filled = 62307
ic_fluent_contract_down_left_16_filled = 62308
ic_fluent_contract_down_left_20_filled = 62323
ic_fluent_contract_down_left_24_filled = 62324
ic_fluent_contract_down_left_28_filled = 62325
ic_fluent_contract_down_left_32_filled = 62331
ic_fluent_contract_down_left_48_filled = 62359
ic_fluent_credit_card_toolbox_20_filled = 62360
ic_fluent_data_bar_horizontal_20_filled = 62363
ic_fluent_data_usage_edit_20_filled = 62386
ic_fluent_desktop_sync_16_filled = 62387
ic_fluent_device_meeting_room_16_filled = 62388
ic_fluent_device_meeting_room_24_filled = 62389
ic_fluent_device_meeting_room_28_filled = 62390
ic_fluent_device_meeting_room_32_filled = 62391
ic_fluent_device_meeting_room_48_filled = 62396
ic_fluent_device_meeting_room_remote_16_filled = 62397
ic_fluent_device_meeting_room_remote_24_filled = 62402
ic_fluent_device_meeting_room_remote_28_filled = 62413
ic_fluent_device_meeting_room_remote_32_filled = 62444
ic_fluent_device_meeting_room_remote_48_filled = 62445
ic_fluent_dismiss_32_filled = 62450
ic_fluent_dismiss_48_filled = 62463
ic_fluent_document_arrow_up_16_filled = 62464
ic_fluent_document_bullet_list_20_filled = 62465
ic_fluent_document_bullet_list_24_filled = 62466
ic_fluent_document_link_20_filled = 62467
ic_fluent_document_link_24_filled = 62468
ic_fluent_document_person_16_filled = 62501
ic_fluent_document_settings_16_filled = 62502
ic_fluent_document_split_hint_24_filled = 62503
ic_fluent_document_split_hint_off_24_filled = 62504
ic_fluent_edit_arrow_back_16_filled = 62509
ic_fluent_equal_off_20_filled = 62510
ic_fluent_error_circle_settings_16_filled = 62511
ic_fluent_expand_up_left_16_filled = 62512
ic_fluent_expand_up_left_20_filled = 62517
ic_fluent_expand_up_left_24_filled = 62518
ic_fluent_expand_up_left_28_filled = 62519
ic_fluent_expand_up_left_32_filled = 62543
ic_fluent_expand_up_left_48_filled = 62544
ic_fluent_expand_up_right_16_filled = 62547
ic_fluent_expand_up_right_20_filled = 62548
ic_fluent_expand_up_right_24_filled = 62577
ic_fluent_expand_up_right_28_filled = 62620
ic_fluent_expand_up_right_32_filled = 62621
ic_fluent_expand_up_right_48_filled = 62622
ic_fluent_fax_16_filled = 62648
ic_fluent_flow_16_filled = 62649
ic_fluent_folder_globe_16_filled = 62651
ic_fluent_folder_person_16_filled = 62672
ic_fluent_gauge_20_filled = 62673
ic_fluent_gauge_24_filled = 62674
ic_fluent_gift_card_16_filled = 62679
ic_fluent_gift_card_20_filled = 62680
ic_fluent_gift_card_add_20_filled = 62681
ic_fluent_globe_location_20_filled = 62694
ic_fluent_globe_star_16_filled = 62709
ic_fluent_globe_video_20_filled = 62727
ic_fluent_headset_add_20_filled = 62728
ic_fluent_headset_add_24_filled = 62729
ic_fluent_heart_28_filled = 62730
ic_fluent_heart_broken_16_filled = 62731
ic_fluent_laptop_dismiss_16_filled = 62735
ic_fluent_mail_add_16_filled = 62743
ic_fluent_mail_add_20_filled = 62761
ic_fluent_mail_alert_16_filled = 62762
ic_fluent_mail_alert_20_filled = 62772
ic_fluent_mail_alert_24_filled = 62773
ic_fluent_mail_arrow_down_16_filled = 62774
ic_fluent_mail_arrow_up_20_filled = 62775
ic_fluent_mail_arrow_up_24_filled = 62805
ic_fluent_mail_checkmark_16_filled = 62806
ic_fluent_mail_clock_16_filled = 62811
ic_fluent_mail_clock_24_filled = 62812
ic_fluent_mail_dismiss_20_filled = 62813
ic_fluent_mail_dismiss_24_filled = 62814
ic_fluent_mail_error_20_filled = 62815
ic_fluent_mail_error_24_filled = 62823
ic_fluent_mail_inbox_arrow_down_16_filled = 62824
ic_fluent_mail_link_20_filled = 62863
ic_fluent_mail_link_24_filled = 62870
ic_fluent_mail_pause_16_filled = 62896
ic_fluent_mail_prohibited_20_filled = 62933
ic_fluent_mail_prohibited_24_filled = 62956
ic_fluent_mail_settings_16_filled = 62957
ic_fluent_mail_shield_16_filled = 62962
ic_fluent_mail_template_20_filled = 62963
ic_fluent_mail_template_24_filled = 62967
ic_fluent_mail_warning_16_filled = 62968
ic_fluent_meet_now_28_filled = 62976
ic_fluent_meet_now_32_filled = 62977
ic_fluent_meet_now_48_filled = 63035
ic_fluent_megaphone_loud_20_filled = 63061
ic_fluent_microscope_20_filled = 63062
ic_fluent_microscope_24_filled = 63065
ic_fluent_molecule_16_filled = 63066
ic_fluent_molecule_20_filled = 63075
ic_fluent_molecule_24_filled = 63076
ic_fluent_molecule_28_filled = 63079
ic_fluent_molecule_32_filled = 63080
ic_fluent_molecule_48_filled = 63081
ic_fluent_note_16_filled = 63085
ic_fluent_note_pin_16_filled = 63086
ic_fluent_notepad_16_filled = 63087
ic_fluent_notepad_edit_16_filled = 63088
ic_fluent_open_32_filled = 63089
ic_fluent_padding_down_20_filled = 63115
ic_fluent_padding_down_24_filled = 63116
ic_fluent_padding_left_20_filled = 63134
ic_fluent_padding_left_24_filled = 63143
ic_fluent_padding_right_20_filled = 63144
ic_fluent_padding_right_24_filled = 63145
ic_fluent_padding_top_20_filled = 63165
ic_fluent_padding_top_24_filled = 63170
ic_fluent_patch_20_filled = 63171
ic_fluent_patch_24_filled = 63172
ic_fluent_pause_circle_20_filled = 63173
ic_fluent_people_sync_16_filled = 63174
ic_fluent_people_toolbox_16_filled = 63187
ic_fluent_person_chat_16_filled = 63188
ic_fluent_person_chat_20_filled = 63194
ic_fluent_person_chat_24_filled = 63196
ic_fluent_person_info_16_filled = 63199
ic_fluent_person_lock_16_filled = 63201
ic_fluent_person_lock_20_filled = 63202
ic_fluent_person_subtract_16_filled = 63222
ic_fluent_phone_16_filled = 63223
ic_fluent_phone_checkmark_16_filled = 63224
ic_fluent_pill_16_filled = 63225
ic_fluent_pill_20_filled = 63226
ic_fluent_pill_24_filled = 63227
ic_fluent_pill_28_filled = 63228
ic_fluent_print_16_filled = 63235
ic_fluent_print_add_20_filled = 63237
ic_fluent_production_20_filled = 63238
ic_fluent_production_24_filled = 63239
ic_fluent_production_checkmark_20_filled = 63244
ic_fluent_production_checkmark_24_filled = 63245
ic_fluent_prohibited_16_filled = 63246
ic_fluent_ratio_one_to_one_20_filled = 63251
ic_fluent_ratio_one_to_one_24_filled = 63252
ic_fluent_receipt_add_20_filled = 63253
ic_fluent_receipt_bag_20_filled = 63262
ic_fluent_receipt_cube_20_filled = 63301
ic_fluent_receipt_money_20_filled = 63302
ic_fluent_record_12_filled = 63303
ic_fluent_record_28_filled = 63309
ic_fluent_record_32_filled = 63310
ic_fluent_record_48_filled = 63311
ic_fluent_record_stop_12_filled = 63344
ic_fluent_record_stop_16_filled = 63345
ic_fluent_record_stop_20_filled = 63346
ic_fluent_record_stop_24_filled = 63347
ic_fluent_record_stop_28_filled = 63348
ic_fluent_record_stop_32_filled = 63356
ic_fluent_record_stop_48_filled = 63357
ic_fluent_ribbon_add_20_filled = 63358
ic_fluent_ribbon_add_24_filled = 63359
ic_fluent_server_20_filled = 63361
ic_fluent_server_24_filled = 63364
ic_fluent_shield_badge_20_filled = 63365
ic_fluent_shopping_bag_16_filled = 63366
ic_fluent_shopping_bag_20_filled = 63367
ic_fluent_shopping_bag_24_filled = 63368
ic_fluent_slide_multiple_search_20_filled = 63371
ic_fluent_slide_multiple_search_24_filled = 63372
ic_fluent_smartwatch_20_filled = 63373
ic_fluent_smartwatch_24_filled = 63374
ic_fluent_smartwatch_dot_20_filled = 63390
ic_fluent_smartwatch_dot_24_filled = 63391
ic_fluent_square_multiple_24_filled = 63396
ic_fluent_stack_16_filled = 63397
ic_fluent_stack_20_filled = 63402
ic_fluent_stack_24_filled = 63422
ic_fluent_subtract_circle_16_filled = 63423
ic_fluent_subtract_circle_20_filled = 63432
ic_fluent_subtract_circle_24_filled = 63433
ic_fluent_subtract_circle_28_filled = 63436
ic_fluent_subtract_circle_32_filled = 63437
ic_fluent_tag_multiple_16_filled = 63438
ic_fluent_target_arrow_16_filled = 63439
ic_fluent_target_arrow_20_filled = 63440
ic_fluent_text_bullet_list_square_edit_20_filled = 63441
ic_fluent_text_bullet_list_square_edit_24_filled = 63442
ic_fluent_tooltip_quote_20_filled = 63443
ic_fluent_vehicle_car_profile_ltr_16_filled = 63461
ic_fluent_vehicle_car_profile_rtl_16_filled = 63462
ic_fluent_vehicle_truck_profile_16_filled = 63490
ic_fluent_voicemail_arrow_back_16_filled = 63491
ic_fluent_voicemail_arrow_forward_16_filled = 63492
ic_fluent_voicemail_subtract_16_filled = 63509
ic_fluent_wifi_warning_24_filled = 63510
ic_fluent_window_edit_16_filled = 63517
ic_fluent_arrow_sort_down_20_filled = 63518
ic_fluent_arrow_sort_down_24_filled = 63530
ic_fluent_arrow_sort_up_20_filled = 63531
ic_fluent_arrow_sort_up_24_filled = 63546
ic_fluent_arrow_turn_bidirectional_down_right_24_filled = 63547
ic_fluent_arrow_turn_right_24_filled = 63569
ic_fluent_book_question_mark_rtl_24_filled = 63570
ic_fluent_brain_circuit_24_filled = 63571
ic_fluent_building_bank_toolbox_24_filled = 63572
ic_fluent_calendar_checkmark_28_filled = 63607
ic_fluent_calendar_search_16_filled = 63608
ic_fluent_call_park_32_filled = 63609
ic_fluent_chat_bubbles_question_16_filled = 63680
ic_fluent_chat_multiple_16_filled = 63681
ic_fluent_chat_multiple_20_filled = 63712
ic_fluent_chat_multiple_24_filled = 63723
ic_fluent_checkmark_32_filled = 63724
ic_fluent_checkmark_circle_32_filled = 58140
ic_fluent_clipboard_bullet_list_ltr_16_filled = 58204
ic_fluent_clipboard_bullet_list_rtl_16_filled = 58206
ic_fluent_column_edit_20_filled = 58328
ic_fluent_column_edit_24_filled = 58329
ic_fluent_contact_card_28_filled = 58389
ic_fluent_contact_card_32_filled = 58390
ic_fluent_contact_card_48_filled = 58391
ic_fluent_diagram_24_filled = 58561
ic_fluent_dismiss_circle_32_filled = 58575
ic_fluent_document_arrow_down_16_filled = 58603
ic_fluent_document_bullet_list_clock_20_filled = 58613
ic_fluent_document_bullet_list_clock_24_filled = 58614
ic_fluent_document_bullet_list_off_24_filled = 58618
ic_fluent_document_multiple_16_filled = 58667
ic_fluent_document_pill_20_filled = 58680
ic_fluent_document_pill_24_filled = 58681
ic_fluent_document_save_20_filled = 58699
ic_fluent_document_save_24_filled = 58700
ic_fluent_door_16_filled = 58733
ic_fluent_dual_screen_arrow_up_24_filled = 58788
ic_fluent_dual_screen_closed_alert_24_filled = 58791
ic_fluent_emoji_multiple_20_filled = 58847
ic_fluent_emoji_multiple_24_filled = 58848
ic_fluent_gantt_chart_20_filled = 59035
ic_fluent_gantt_chart_24_filled = 59036
ic_fluent_gift_card_add_24_filled = 59050
ic_fluent_hand_draw_24_filled = 59109
ic_fluent_image_arrow_back_24_filled = 59178
ic_fluent_image_arrow_forward_24_filled = 59182
ic_fluent_image_multiple_16_filled = 59185
ic_fluent_image_reflection_24_filled = 59197
ic_fluent_image_shadow_24_filled = 59199
ic_fluent_mail_arrow_double_back_16_filled = 59316
ic_fluent_mail_arrow_forward_16_filled = 59319
ic_fluent_mail_attach_16_filled = 59322
ic_fluent_more_horizontal_32_filled = 59445
ic_fluent_more_vertical_32_filled = 59448
ic_fluent_organization_16_filled = 59561
ic_fluent_organization_32_filled = 59562
ic_fluent_organization_48_filled = 59563
ic_fluent_orientation_24_filled = 59566
ic_fluent_people_list_16_filled = 59661
ic_fluent_people_money_20_filled = 59667
ic_fluent_people_money_24_filled = 59668
ic_fluent_person_pill_20_filled = 59730
ic_fluent_person_pill_24_filled = 59731
ic_fluent_person_settings_16_filled = 59735
ic_fluent_pivot_20_filled = 59807
ic_fluent_pivot_24_filled = 59808
ic_fluent_play_12_filled = 59809
ic_fluent_print_add_24_filled = 59862
ic_fluent_pulse_28_filled = 59878
ic_fluent_receipt_add_24_filled = 59912
ic_fluent_receipt_bag_24_filled = 59913
ic_fluent_receipt_cube_24_filled = 59914
ic_fluent_scan_object_20_filled = 60009
ic_fluent_scan_object_24_filled = 60010
ic_fluent_search_12_filled = 60035
ic_fluent_search_32_filled = 60037
ic_fluent_search_48_filled = 60038
ic_fluent_share_16_filled = 60079
ic_fluent_shield_badge_24_filled = 60111
ic_fluent_shield_lock_16_filled = 60120
ic_fluent_slide_eraser_16_filled = 60189
ic_fluent_slide_eraser_20_filled = 60190
ic_fluent_slide_grid_24_filled = 60193
ic_fluent_square_16_filled = 60285
ic_fluent_square_add_16_filled = 60291
ic_fluent_square_hint_arrow_back_16_filled = 60310
ic_fluent_steps_20_filled = 60345
ic_fluent_steps_24_filled = 60346
ic_fluent_tab_desktop_bottom_24_filled = 60391
ic_fluent_tab_desktop_multiple_bottom_24_filled = 60393
ic_fluent_task_list_square_add_20_filled = 60564
ic_fluent_task_list_square_add_24_filled = 60565
ic_fluent_task_list_square_ltr_20_filled = 60567
ic_fluent_task_list_square_ltr_24_filled = 60568
ic_fluent_task_list_square_rtl_20_filled = 60570
ic_fluent_task_list_square_rtl_24_filled = 60571
ic_fluent_text_align_distributed_evenly_24_filled = 60600
ic_fluent_text_align_distributed_vertical_24_filled = 60602
ic_fluent_text_align_justify_low_24_filled = 60604
ic_fluent_textbox_more_24_filled = 60788
ic_fluent_video_32_filled = 60912
ic_fluent_video_48_filled = 60916
ic_fluent_video_clip_16_filled = 60926
ic_fluent_window_ad_person_20_filled = 61027
ic_fluent_window_dev_edit_16_filled = 61041
ic_fluent_arrow_autofit_height_dotted_24_filled = 57465
ic_fluent_arrow_autofit_width_dotted_24_filled = 57470
ic_fluent_multiselect_rtl_16_filled = 59484
ic_fluent_animal_dog_16_filled = 57423
ic_fluent_archive_settings_20_filled = 57456
ic_fluent_arrow_clockwise_16_filled = 57514
ic_fluent_arrow_clockwise_dashes_20_filled = 57518
ic_fluent_arrow_clockwise_dashes_24_filled = 57519
ic_fluent_arrow_counterclockwise_dashes_20_filled = 57526
ic_fluent_arrow_counterclockwise_dashes_24_filled = 57527
ic_fluent_arrow_export_ltr_16_filled = 57542
ic_fluent_arrow_export_up_20_filled = 57547
ic_fluent_arrow_export_up_24_filled = 57548
ic_fluent_bin_full_20_filled = 57692
ic_fluent_bin_full_24_filled = 57693
ic_fluent_book_toolbox_24_filled = 57764
ic_fluent_box_16_filled = 57806
ic_fluent_braces_variable_20_filled = 57835
ic_fluent_braces_variable_24_filled = 57836
ic_fluent_briefcase_16_filled = 57853
ic_fluent_briefcase_medical_16_filled = 57857
ic_fluent_building_retail_20_filled = 57913
ic_fluent_building_retail_money_20_filled = 57914
ic_fluent_building_retail_money_24_filled = 57915
ic_fluent_building_retail_shield_20_filled = 57917
ic_fluent_building_retail_shield_24_filled = 57918
ic_fluent_building_retail_toolbox_20_filled = 57919
ic_fluent_building_retail_toolbox_24_filled = 57920
ic_fluent_calculator_multiple_20_filled = 57930
ic_fluent_calculator_multiple_24_filled = 57931
ic_fluent_calendar_3_day_16_filled = 57932
ic_fluent_calendar_arrow_right_16_filled = 57937
ic_fluent_calendar_day_16_filled = 57944
ic_fluent_calendar_info_20_filled = 57951
ic_fluent_calendar_settings_16_filled = 57981
ic_fluent_call_checkmark_24_filled = 57995
ic_fluent_call_end_16_filled = 57998
ic_fluent_camera_dome_16_filled = 58030
ic_fluent_camera_dome_20_filled = 58031
ic_fluent_camera_dome_24_filled = 58032
ic_fluent_camera_dome_28_filled = 58033
ic_fluent_camera_dome_48_filled = 58034
ic_fluent_chat_12_filled = 58103
ic_fluent_chevron_double_down_20_filled = 58174
ic_fluent_chevron_double_left_20_filled = 58175
ic_fluent_chevron_double_right_20_filled = 58176
ic_fluent_clipboard_bullet_list_ltr_20_filled = 58205
ic_fluent_clipboard_bullet_list_rtl_20_filled = 58207
ic_fluent_clipboard_checkmark_20_filled = 58208
ic_fluent_clipboard_checkmark_24_filled = 58209
ic_fluent_clipboard_error_20_filled = 58216
ic_fluent_clipboard_error_24_filled = 58217
ic_fluent_clipboard_heart_24_filled = 58218
ic_fluent_clipboard_task_20_filled = 58226
ic_fluent_clipboard_task_24_filled = 58227
ic_fluent_clipboard_task_add_20_filled = 58228
ic_fluent_clipboard_task_add_24_filled = 58229
ic_fluent_clipboard_task_list_ltr_20_filled = 58230
ic_fluent_clipboard_task_list_ltr_24_filled = 58231
ic_fluent_clock_alarm_16_filled = 58244
ic_fluent_cloud_add_20_filled = 58266
ic_fluent_cloud_edit_20_filled = 58297
ic_fluent_cloud_link_20_filled = 58299
ic_fluent_color_16_filled = 58321
ic_fluent_column_triple_20_filled = 58330
ic_fluent_column_triple_edit_20_filled = 58331
ic_fluent_column_triple_edit_24_filled = 58332
ic_fluent_comment_error_20_filled = 58365
ic_fluent_communication_person_20_filled = 58385
ic_fluent_communication_person_24_filled = 58386
ic_fluent_contact_card_link_20_filled = 58396
ic_fluent_data_trending_16_filled = 58472
ic_fluent_data_trending_20_filled = 58473
ic_fluent_data_trending_24_filled = 58474
ic_fluent_data_usage_edit_24_filled = 58476
ic_fluent_database_20_filled = 58482
ic_fluent_database_24_filled = 58483
ic_fluent_database_search_20_filled = 58494
ic_fluent_database_search_24_filled = 58495
ic_fluent_delete_arrow_back_16_filled = 58504
ic_fluent_desktop_edit_16_filled = 58523
ic_fluent_dismiss_circle_12_filled = 58573
ic_fluent_divider_tall_16_filled = 58586
ic_fluent_document_arrow_down_20_filled = 58604
ic_fluent_document_heart_20_filled = 58644
ic_fluent_document_heart_24_filled = 58645
ic_fluent_document_heart_pulse_20_filled = 58646
ic_fluent_document_heart_pulse_24_filled = 58647
ic_fluent_document_multiple_20_filled = 58668
ic_fluent_document_multiple_prohibited_20_filled = 58672
ic_fluent_document_multiple_prohibited_24_filled = 58673
ic_fluent_document_search_16_filled = 58701
ic_fluent_door_20_filled = 58734
ic_fluent_emoji_laugh_16_filled = 58846
ic_fluent_equal_off_24_filled = 58864
ic_fluent_error_circle_settings_20_filled = 58875
ic_fluent_eye_off_16_filled = 58881
ic_fluent_fax_20_filled = 58901
ic_fluent_filter_dismiss_16_filled = 58905
ic_fluent_filter_dismiss_20_filled = 58906
ic_fluent_flashlight_16_filled = 58933
ic_fluent_flashlight_20_filled = 58934
ic_fluent_flow_20_filled = 58948
ic_fluent_fluid_16_filled = 58957
ic_fluent_folder_add_16_filled = 58962
ic_fluent_folder_globe_20_filled = 58978
ic_fluent_folder_mail_20_filled = 58980
ic_fluent_folder_person_20_filled = 58983
ic_fluent_folder_sync_20_filled = 58993
ic_fluent_food_16_filled = 58995
ic_fluent_food_cake_16_filled = 58999
ic_fluent_full_screen_maximize_16_filled = 59024
ic_fluent_full_screen_maximize_20_filled = 59025
ic_fluent_gif_16_filled = 59047
ic_fluent_gift_16_filled = 59048
ic_fluent_globe_star_20_filled = 59082
ic_fluent_globe_surface_20_filled = 59083
ic_fluent_globe_surface_24_filled = 59084
ic_fluent_heart_broken_20_filled = 59146
ic_fluent_history_16_filled = 59154
ic_fluent_image_prohibited_20_filled = 59194
ic_fluent_image_prohibited_24_filled = 59195
ic_fluent_info_12_filled = 59203
ic_fluent_iot_20_filled = 59211
ic_fluent_iot_24_filled = 59212
ic_fluent_mail_open_person_16_filled = 59353
ic_fluent_mail_template_16_filled = 59365
ic_fluent_navigation_16_filled = 59501
ic_fluent_news_16_filled = 59508
ic_fluent_note_edit_20_filled = 59516
ic_fluent_note_edit_24_filled = 59517
ic_fluent_notepad_edit_20_filled = 59534
ic_fluent_people_list_20_filled = 59662
ic_fluent_people_settings_24_filled = 59674
ic_fluent_people_team_toolbox_20_filled = 59690
ic_fluent_people_team_toolbox_24_filled = 59691
ic_fluent_person_feedback_16_filled = 59714
ic_fluent_person_money_20_filled = 59726
ic_fluent_person_money_24_filled = 59727
ic_fluent_phone_eraser_16_filled = 59758
ic_fluent_port_hdmi_24_filled = 59827
ic_fluent_port_micro_usb_24_filled = 59829
ic_fluent_port_usb_a_24_filled = 59831
ic_fluent_port_usb_c_24_filled = 59833
ic_fluent_prohibited_12_filled = 59863
ic_fluent_receipt_play_20_filled = 59916
ic_fluent_receipt_play_24_filled = 59917
ic_fluent_save_search_20_filled = 59989
ic_fluent_search_settings_20_filled = 60040
ic_fluent_shield_lock_20_filled = 60121
ic_fluent_square_add_20_filled = 60292
ic_fluent_star_line_horizontal_3_16_filled = 60341
ic_fluent_stream_20_filled = 60350
ic_fluent_stream_24_filled = 60351
ic_fluent_syringe_20_filled = 60380
ic_fluent_syringe_24_filled = 60381
ic_fluent_tag_dismiss_20_filled = 60527
ic_fluent_tag_dismiss_24_filled = 60528
ic_fluent_target_arrow_24_filled = 60559
ic_fluent_temperature_16_filled = 60575
ic_fluent_thumb_dislike_16_filled = 60791
ic_fluent_tooltip_quote_24_filled = 60826
ic_fluent_umbrella_20_filled = 60876
ic_fluent_umbrella_24_filled = 60877
ic_fluent_vehicle_truck_profile_20_filled = 60910
ic_fluent_video_add_20_filled = 60917
ic_fluent_video_add_24_filled = 60918
ic_fluent_warning_12_filled = 60987
ic_fluent_window_dev_edit_20_filled = 61042
ic_fluent_xray_20_filled = 61065
ic_fluent_xray_24_filled = 61066
ic_fluent_arrow_autofit_down_24_filled = 57462
ic_fluent_arrow_autofit_up_24_filled = 57467
ic_fluent_clipboard_task_list_rtl_20_filled = 58232
ic_fluent_clipboard_task_list_rtl_24_filled = 58233
ic_fluent_comma_24_filled = 58334
ic_fluent_text_align_center_rotate_270_24_filled = 60595
ic_fluent_text_align_justify_rotate_90_24_filled = 60608
ic_fluent_text_align_left_rotate_270_24_filled = 60612
ic_fluent_text_align_right_rotate_270_24_filled = 60619
ic_fluent_text_strikethrough_16_filled = 60766
ic_fluent_text_strikethrough_20_filled = 60767
ic_fluent_text_strikethrough_24_filled = 60768
ic_fluent_textbox_align_bottom_rotate_90_24_filled = 60780
ic_fluent_textbox_align_middle_rotate_90_24_filled = 60784
ic_fluent_textbox_align_top_rotate_90_24_filled = 60786
ic_fluent_arrow_clockwise_12_filled = 57513
ic_fluent_arrow_clockwise_28_filled = 57515
ic_fluent_arrow_clockwise_32_filled = 57516
ic_fluent_arrow_clockwise_48_filled = 57517
ic_fluent_arrow_counterclockwise_12_filled = 57522
ic_fluent_arrow_counterclockwise_16_filled = 57523
ic_fluent_arrow_counterclockwise_32_filled = 57524
ic_fluent_arrow_counterclockwise_48_filled = 57525
ic_fluent_arrow_rotate_clockwise_16_filled = 57580
ic_fluent_arrow_split_20_filled = 57588
ic_fluent_battery_checkmark_24_filled = 57681
ic_fluent_book_open_16_filled = 57739
ic_fluent_broad_activity_feed_16_filled = 57878
ic_fluent_broad_activity_feed_20_filled = 57879
ic_fluent_calendar_pattern_20_filled = 57965
ic_fluent_calendar_person_16_filled = 57966
ic_fluent_calendar_phone_16_filled = 57968
ic_fluent_calendar_phone_20_filled = 57969
ic_fluent_calendar_search_20_filled = 57980
ic_fluent_calendar_star_16_filled = 57982
ic_fluent_chat_arrow_back_16_filled = 58107
ic_fluent_chat_arrow_back_20_filled = 58108
ic_fluent_chat_arrow_double_back_16_filled = 58109
ic_fluent_chat_arrow_double_back_20_filled = 58110
ic_fluent_check_24_filled = 58121
ic_fluent_checkbox_checked_sync_20_filled = 58128
ic_fluent_chevron_up_down_16_filled = 58179
ic_fluent_cursor_click_20_filled = 58449
ic_fluent_cursor_click_24_filled = 58450
ic_fluent_directions_16_filled = 58572
ic_fluent_divider_tall_20_filled = 58587
ic_fluent_document_arrow_up_20_filled = 58612
ic_fluent_document_dismiss_16_filled = 58629
ic_fluent_document_link_16_filled = 58655
ic_fluent_document_person_20_filled = 58679
ic_fluent_edit_arrow_back_20_filled = 58818
ic_fluent_emoji_sad_16_filled = 58849
ic_fluent_globe_clock_16_filled = 59073
ic_fluent_globe_clock_20_filled = 59074
ic_fluent_immersive_reader_16_filled = 59200
ic_fluent_link_dismiss_16_filled = 59264
ic_fluent_lock_open_16_filled = 59298
ic_fluent_luggage_16_filled = 59304
ic_fluent_luggage_20_filled = 59305
ic_fluent_mail_arrow_double_back_20_filled = 59317
ic_fluent_mail_arrow_down_20_filled = 59318
ic_fluent_mail_arrow_forward_20_filled = 59320
ic_fluent_mail_attach_20_filled = 59323
ic_fluent_mail_checkmark_20_filled = 59326
ic_fluent_mail_error_16_filled = 59331
ic_fluent_mail_inbox_arrow_down_20_filled = 59334
ic_fluent_mail_pause_20_filled = 59356
ic_fluent_mail_settings_20_filled = 59363
ic_fluent_mail_shield_20_filled = 59364
ic_fluent_note_pin_20_filled = 59518
ic_fluent_pause_circle_24_filled = 59617
ic_fluent_people_checkmark_16_filled = 59652
ic_fluent_people_sync_20_filled = 59680
ic_fluent_people_toolbox_20_filled = 59692
ic_fluent_person_settings_20_filled = 59736
ic_fluent_phone_checkmark_20_filled = 59754
ic_fluent_play_16_filled = 59810
ic_fluent_play_28_filled = 59811
ic_fluent_play_32_filled = 59812
ic_fluent_receipt_money_24_filled = 59915
ic_fluent_save_16_filled = 59979
ic_fluent_shield_error_16_filled = 60119
ic_fluent_sport_soccer_16_filled = 60281
ic_fluent_square_20_filled = 60286
ic_fluent_tag_multiple_20_filled = 60540
ic_fluent_text_quote_16_filled = 60761
ic_fluent_vehicle_car_profile_ltr_20_filled = 60896
ic_fluent_vehicle_car_profile_rtl_20_filled = 60897
ic_fluent_weather_partly_cloudy_day_16_filled = 61003
ic_fluent_weather_sunny_16_filled = 61004
ic_fluent_text_direction_horizontal_left_20_filled = 60675
ic_fluent_text_direction_horizontal_left_24_filled = 60676
ic_fluent_text_direction_horizontal_right_20_filled = 60677
ic_fluent_text_direction_horizontal_right_24_filled = 60678
ic_fluent_text_direction_rotate_270_right_20_filled = 60679
ic_fluent_text_direction_rotate_270_right_24_filled = 60680
ic_fluent_text_direction_rotate_90_left_20_filled = 60681
ic_fluent_text_direction_rotate_90_left_24_filled = 60682
ic_fluent_text_direction_rotate_90_right_20_filled = 60683
ic_fluent_text_direction_rotate_90_right_24_filled = 60684
ic_fluent_arrow_autofit_content_24_filled = 57460
ic_fluent_arrow_trending_lines_20_filled = 57628
ic_fluent_arrow_trending_lines_24_filled = 57629
ic_fluent_calendar_error_24_filled = 57950
ic_fluent_cellular_warning_24_filled = 58059
ic_fluent_cloud_arrow_down_16_filled = 58273
ic_fluent_cloud_arrow_down_20_filled = 58274
ic_fluent_cloud_arrow_down_24_filled = 58275
ic_fluent_cloud_arrow_down_28_filled = 58276
ic_fluent_cloud_arrow_down_32_filled = 58277
ic_fluent_cloud_arrow_down_48_filled = 58278
ic_fluent_cloud_arrow_up_16_filled = 58279
ic_fluent_cloud_arrow_up_20_filled = 58280
ic_fluent_cloud_arrow_up_24_filled = 58281
ic_fluent_cloud_arrow_up_28_filled = 58282
ic_fluent_cloud_arrow_up_32_filled = 58283
ic_fluent_cloud_arrow_up_48_filled = 58284
ic_fluent_cloud_checkmark_16_filled = 58285
ic_fluent_cloud_checkmark_20_filled = 58286
ic_fluent_cloud_checkmark_24_filled = 58287
ic_fluent_cloud_checkmark_28_filled = 58288
ic_fluent_cloud_checkmark_32_filled = 58289
ic_fluent_cloud_checkmark_48_filled = 58290
ic_fluent_cloud_dismiss_16_filled = 58291
ic_fluent_cloud_dismiss_20_filled = 58292
ic_fluent_cloud_dismiss_24_filled = 58293
ic_fluent_cloud_dismiss_28_filled = 58294
ic_fluent_cloud_dismiss_32_filled = 58295
ic_fluent_cloud_dismiss_48_filled = 58296
ic_fluent_grid_dots_20_filled = 59089
ic_fluent_grid_dots_24_filled = 59090
ic_fluent_grid_dots_28_filled = 59091
ic_fluent_ios_arrow_ltr_24_filled = 59209
ic_fluent_ios_arrow_rtl_24_filled = 59210
ic_fluent_mail_multiple_16_filled = 59347
ic_fluent_mail_multiple_20_filled = 59348
ic_fluent_mail_multiple_24_filled = 59349
ic_fluent_panel_bottom_20_filled = 59578
ic_fluent_panel_left_16_filled = 59581
ic_fluent_panel_left_20_filled = 59582
ic_fluent_panel_left_24_filled = 59583
ic_fluent_panel_left_28_filled = 59584
ic_fluent_panel_left_48_filled = 59585
ic_fluent_panel_right_16_filled = 59598
ic_fluent_panel_right_20_filled = 59599
ic_fluent_panel_right_24_filled = 59600
ic_fluent_panel_right_28_filled = 59601
ic_fluent_panel_right_48_filled = 59602
ic_fluent_panel_right_contract_16_filled = 59603
ic_fluent_panel_right_contract_20_filled = 59604
ic_fluent_panel_right_contract_24_filled = 59605
ic_fluent_panel_right_expand_20_filled = 59606
ic_fluent_puzzle_piece_16_filled = 59888
ic_fluent_puzzle_piece_20_filled = 59889
ic_fluent_puzzle_piece_24_filled = 59890
ic_fluent_scan_table_24_filled = 60012
ic_fluent_scan_text_24_filled = 60014
ic_fluent_scan_type_20_filled = 60025
ic_fluent_scan_type_24_filled = 60026
ic_fluent_scan_type_off_20_filled = 60029
ic_fluent_shield_task_16_filled = 60127
ic_fluent_shield_task_20_filled = 60128
ic_fluent_shield_task_24_filled = 60129
ic_fluent_shield_task_28_filled = 60130
ic_fluent_shield_task_48_filled = 60131
ic_fluent_square_multiple_16_filled = 60318
ic_fluent_stack_star_16_filled = 60325
ic_fluent_stack_star_20_filled = 60326
ic_fluent_stack_star_24_filled = 60327
ic_fluent_subtract_circle_arrow_back_16_filled = 60367
ic_fluent_subtract_circle_arrow_back_20_filled = 60368
ic_fluent_subtract_circle_arrow_forward_16_filled = 60369
ic_fluent_subtract_circle_arrow_forward_20_filled = 60370
ic_fluent_text_add_t_24_filled = 60591
ic_fluent_text_more_24_filled = 60729
ic_fluent_text_t_20_filled = 60771
ic_fluent_text_t_24_filled = 60772
ic_fluent_usb_plug_20_filled = 60879
ic_fluent_usb_plug_24_filled = 60880
ic_fluent_wifi_lock_24_filled = 61016
ic_fluent_arrow_bidirectional_up_down_12_filled = 57474
ic_fluent_arrow_bidirectional_up_down_16_filled = 57475
ic_fluent_arrow_bidirectional_up_down_20_filled = 57476
ic_fluent_arrow_bidirectional_up_down_24_filled = 57477
ic_fluent_arrow_circle_down_up_20_filled = 57489
ic_fluent_arrow_circle_left_12_filled = 57490
ic_fluent_arrow_circle_left_16_filled = 57491
ic_fluent_arrow_circle_right_12_filled = 57497
ic_fluent_arrow_circle_right_16_filled = 57498
ic_fluent_arrow_eject_20_filled = 57534
ic_fluent_arrow_export_rtl_16_filled = 57545
ic_fluent_arrow_left_12_filled = 57559
ic_fluent_arrow_move_inward_20_filled = 57564
ic_fluent_arrow_redo_16_filled = 57572
ic_fluent_arrow_right_12_filled = 57578
ic_fluent_arrow_step_in_12_filled = 57594
ic_fluent_arrow_step_in_left_12_filled = 57599
ic_fluent_arrow_step_in_left_16_filled = 57600
ic_fluent_arrow_step_in_right_12_filled = 57604
ic_fluent_arrow_step_in_right_16_filled = 57605
ic_fluent_arrow_step_out_12_filled = 57609
ic_fluent_arrow_sync_off_16_filled = 57621
ic_fluent_arrow_sync_off_20_filled = 57622
ic_fluent_arrow_up_12_filled = 57642
ic_fluent_bezier_curve_square_12_filled = 57690
ic_fluent_border_all_16_filled = 57775
ic_fluent_border_all_20_filled = 57776
ic_fluent_braces_20_filled = 57833
ic_fluent_building_lighthouse_20_filled = 57910
ic_fluent_calendar_assistant_16_filled = 57939
ic_fluent_center_vertical_20_filled = 58062
ic_fluent_chat_dismiss_16_filled = 58112
ic_fluent_chat_warning_16_filled = 58119
ic_fluent_checkbox_indeterminate_16_filled = 58129
ic_fluent_checkbox_indeterminate_20_filled = 58130
ic_fluent_checkbox_indeterminate_24_filled = 58131
ic_fluent_chevron_circle_right_12_filled = 58160
ic_fluent_circle_off_16_filled = 58193
ic_fluent_clipboard_pulse_24_filled = 58224
ic_fluent_clock_arrow_download_24_filled = 58246
ic_fluent_cloud_flow_24_filled = 58298
ic_fluent_cloud_swap_20_filled = 58304
ic_fluent_cloud_swap_24_filled = 58305
ic_fluent_code_circle_20_filled = 58318
ic_fluent_comment_multiple_28_filled = 58367
ic_fluent_comment_multiple_checkmark_16_filled = 58369
ic_fluent_comment_multiple_checkmark_20_filled = 58370
ic_fluent_comment_multiple_checkmark_24_filled = 58371
ic_fluent_comment_multiple_checkmark_28_filled = 58372
ic_fluent_cube_12_filled = 58426
ic_fluent_developer_board_search_20_filled = 58555
ic_fluent_document_arrow_right_20_filled = 58610
ic_fluent_document_chevron_double_24_filled = 58624
ic_fluent_document_css_24_filled = 58626
ic_fluent_document_javascript_24_filled = 58649
ic_fluent_document_multiple_percent_20_filled = 58670
ic_fluent_document_percent_20_filled = 58677
ic_fluent_document_percent_24_filled = 58678
ic_fluent_document_settings_20_filled = 58702
ic_fluent_document_split_hint_16_filled = 58703
ic_fluent_document_split_hint_20_filled = 58704
ic_fluent_document_sync_16_filled = 58707
ic_fluent_document_sync_20_filled = 58708
ic_fluent_door_arrow_right_16_filled = 58739
ic_fluent_door_arrow_right_20_filled = 58740
ic_fluent_dual_screen_20_filled = 58784
ic_fluent_glance_20_filled = 59057
ic_fluent_glance_horizontal_20_filled = 59060
ic_fluent_highlight_link_20_filled = 59153
ic_fluent_keyboard_123_24_filled = 59223
ic_fluent_laptop_dismiss_20_filled = 59235
ic_fluent_link_dismiss_24_filled = 59266
ic_fluent_panel_bottom_contract_20_filled = 59579
ic_fluent_panel_bottom_expand_20_filled = 59580
ic_fluent_panel_left_expand_20_filled = 59591
ic_fluent_panel_separate_window_20_filled = 59607
ic_fluent_panel_top_contract_20_filled = 59608
ic_fluent_panel_top_expand_20_filled = 59609
ic_fluent_pause_off_16_filled = 59618
ic_fluent_person_circle_12_filled = 59705
ic_fluent_person_info_20_filled = 59716
ic_fluent_phone_12_filled = 59749
ic_fluent_replay_20_filled = 59930
ic_fluent_square_12_filled = 60284
ic_fluent_square_dismiss_16_filled = 60299
ic_fluent_square_dismiss_20_filled = 60300
ic_fluent_subtract_circle_12_filled = 60366
ic_fluent_tag_circle_20_filled = 60525
ic_fluent_text_bullet_list_ltr_16_filled = 60630
ic_fluent_text_bullet_list_rtl_16_filled = 60637
ic_fluent_text_header_1_24_filled = 60704
ic_fluent_text_header_2_24_filled = 60705
ic_fluent_text_header_3_24_filled = 60706
ic_fluent_text_period_asterisk_20_filled = 60746
ic_fluent_timeline_20_filled = 60803
ic_fluent_triangle_12_filled = 60836
ic_fluent_wifi_settings_20_filled = 61019
ic_fluent_window_16_filled = 61021
ic_fluent_window_24_filled = 61022
ic_fluent_window_ad_off_20_filled = 61026
ic_fluent_window_arrow_up_16_filled = 61034
ic_fluent_window_arrow_up_20_filled = 61035
ic_fluent_window_console_20_filled = 61039
ic_fluent_window_header_horizontal_off_20_filled = 61045
ic_fluent_window_multiple_16_filled = 61048
ic_fluent_zoom_in_16_filled = 61070
ic_fluent_zoom_out_16_filled = 61071
ic_fluent_align_end_horizontal_20_filled = 57392
ic_fluent_align_end_vertical_20_filled = 57393
ic_fluent_align_space_around_horizontal_20_filled = 57406
ic_fluent_align_space_around_vertical_20_filled = 57407
ic_fluent_align_space_between_horizontal_20_filled = 57408
ic_fluent_align_space_between_vertical_20_filled = 57409
ic_fluent_align_space_evenly_horizontal_20_filled = 57410
ic_fluent_align_space_evenly_vertical_20_filled = 57411
ic_fluent_align_space_fit_vertical_20_filled = 57412
ic_fluent_align_start_horizontal_20_filled = 57413
ic_fluent_align_start_vertical_20_filled = 57414
ic_fluent_align_stretch_horizontal_20_filled = 57415
ic_fluent_align_stretch_vertical_20_filled = 57416
ic_fluent_arrow_collapse_all_20_filled = 57520
ic_fluent_arrow_collapse_all_24_filled = 57521
ic_fluent_arrow_wrap_20_filled = 57651
ic_fluent_arrow_wrap_off_20_filled = 57652
ic_fluent_center_horizontal_20_filled = 58060
ic_fluent_document_multiple_24_filled = 58669
ic_fluent_document_multiple_percent_24_filled = 58671
ic_fluent_document_table_16_filled = 58710
ic_fluent_document_table_20_filled = 58711
ic_fluent_document_table_24_filled = 58712
ic_fluent_glance_horizontal_12_filled = 59059
ic_fluent_panel_left_expand_16_filled = 59590
ic_fluent_square_shadow_12_filled = 60320
ic_fluent_text_baseline_20_filled = 60623
ic_fluent_arrow_circle_down_12_filled = 57481
ic_fluent_arrow_circle_down_16_filled = 57482
ic_fluent_arrow_circle_down_28_filled = 57483
ic_fluent_arrow_circle_down_32_filled = 57484
ic_fluent_arrow_circle_down_48_filled = 57485
ic_fluent_arrow_circle_left_20_filled = 57492
ic_fluent_arrow_circle_left_24_filled = 57493
ic_fluent_arrow_circle_left_28_filled = 57494
ic_fluent_arrow_circle_left_32_filled = 57495
ic_fluent_arrow_circle_left_48_filled = 57496
ic_fluent_arrow_circle_right_20_filled = 57499
ic_fluent_arrow_circle_right_28_filled = 57501
ic_fluent_arrow_circle_right_32_filled = 57502
ic_fluent_arrow_circle_right_48_filled = 57503
ic_fluent_arrow_circle_up_12_filled = 57504
ic_fluent_arrow_circle_up_28_filled = 57508
ic_fluent_arrow_circle_up_32_filled = 57509
ic_fluent_arrow_circle_up_48_filled = 57510
ic_fluent_arrow_trending_checkmark_20_filled = 57623
ic_fluent_arrow_trending_checkmark_24_filled = 57624
ic_fluent_arrow_trending_settings_20_filled = 57630
ic_fluent_arrow_trending_settings_24_filled = 57631
ic_fluent_balloon_12_filled = 57676
ic_fluent_calendar_work_week_28_filled = 57986
ic_fluent_channel_subtract_16_filled = 58092
ic_fluent_channel_subtract_20_filled = 58093
ic_fluent_channel_subtract_24_filled = 58094
ic_fluent_channel_subtract_28_filled = 58095
ic_fluent_channel_subtract_48_filled = 58096
ic_fluent_clipboard_settings_24_filled = 58225
ic_fluent_cloud_archive_16_filled = 58267
ic_fluent_cloud_archive_20_filled = 58268
ic_fluent_cloud_words_16_filled = 58312
ic_fluent_cloud_words_20_filled = 58313
ic_fluent_cloud_words_24_filled = 58314
ic_fluent_cloud_words_28_filled = 58315
ic_fluent_cloud_words_32_filled = 58316
ic_fluent_cloud_words_48_filled = 58317
ic_fluent_column_arrow_right_20_filled = 58326
ic_fluent_control_button_20_filled = 58407
ic_fluent_control_button_24_filled = 58408
ic_fluent_credit_card_person_20_filled = 58420
ic_fluent_credit_card_person_24_filled = 58421
ic_fluent_credit_card_toolbox_24_filled = 58422
ic_fluent_cube_link_20_filled = 58429
ic_fluent_delete_lines_20_filled = 58509
ic_fluent_dialpad_28_filled = 58562
ic_fluent_dialpad_32_filled = 58563
ic_fluent_dialpad_48_filled = 58564
ic_fluent_diversity_20_filled = 58580
ic_fluent_diversity_24_filled = 58581
ic_fluent_diversity_28_filled = 58582
ic_fluent_diversity_48_filled = 58583
ic_fluent_food_cake_12_filled = 58998
ic_fluent_globe_prohibited_20_filled = 59078
ic_fluent_globe_search_20_filled = 59079
ic_fluent_globe_video_28_filled = 59085
ic_fluent_globe_video_32_filled = 59086
ic_fluent_globe_video_48_filled = 59087
ic_fluent_guardian_20_filled = 59098
ic_fluent_guardian_24_filled = 59099
ic_fluent_guardian_28_filled = 59100
ic_fluent_guardian_48_filled = 59101
ic_fluent_hat_graduation_12_filled = 59121
ic_fluent_lock_closed_32_filled = 59295
ic_fluent_money_calculator_20_filled = 59430
ic_fluent_money_calculator_24_filled = 59431
ic_fluent_money_settings_20_filled = 59438
ic_fluent_options_48_filled = 59559
ic_fluent_pause_settings_20_filled = 59621
ic_fluent_person_lock_24_filled = 59720
ic_fluent_person_note_20_filled = 59728
ic_fluent_road_cone_16_filled = 59961
ic_fluent_road_cone_20_filled = 59962
ic_fluent_road_cone_24_filled = 59963
ic_fluent_road_cone_28_filled = 59964
ic_fluent_road_cone_32_filled = 59965
ic_fluent_road_cone_48_filled = 59966
ic_fluent_scan_thumb_up_16_filled = 60015
ic_fluent_scan_thumb_up_20_filled = 60016
ic_fluent_scan_thumb_up_24_filled = 60017
ic_fluent_scan_thumb_up_28_filled = 60018
ic_fluent_scan_thumb_up_48_filled = 60019
ic_fluent_share_48_filled = 60081
ic_fluent_speaker_0_32_filled = 60227
ic_fluent_speaker_1_32_filled = 60232
ic_fluent_speaker_2_32_filled = 60238
ic_fluent_sticker_12_filled = 60347
ic_fluent_toolbox_12_filled = 60825
ic_fluent_vehicle_car_collision_16_filled = 60890
ic_fluent_vehicle_car_collision_20_filled = 60891
ic_fluent_vehicle_car_collision_24_filled = 60892
ic_fluent_vehicle_car_collision_48_filled = 60895
ic_fluent_wallet_20_filled = 60972
ic_fluent_wallet_24_filled = 60973
ic_fluent_whiteboard_48_filled = 61014
ic_fluent_call_48_filled = 57992
ic_fluent_closed_caption_32_filled = 58256
ic_fluent_desktop_keyboard_16_filled = 58528
ic_fluent_desktop_keyboard_20_filled = 58529
ic_fluent_desktop_keyboard_24_filled = 58530
ic_fluent_desktop_keyboard_28_filled = 58531
ic_fluent_heart_12_filled = 59143
ic_fluent_image_alt_text_16_filled = 59176
ic_fluent_inking_tool_accent_32_filled = 59208
ic_fluent_mail_12_filled = 59310
ic_fluent_more_circle_32_filled = 59440
ic_fluent_number_symbol_32_filled = 59542
ic_fluent_poll_16_filled = 59824
ic_fluent_rectangle_landscape_12_filled = 59919
ic_fluent_rectangle_landscape_16_filled = 59920
ic_fluent_rectangle_landscape_24_filled = 59922
ic_fluent_rectangle_landscape_28_filled = 59923
ic_fluent_rectangle_landscape_32_filled = 59924
ic_fluent_rectangle_landscape_48_filled = 59925
ic_fluent_scan_thumb_up_off_16_filled = 60020
ic_fluent_scan_thumb_up_off_20_filled = 60021
ic_fluent_scan_thumb_up_off_24_filled = 60022
ic_fluent_scan_thumb_up_off_28_filled = 60023
ic_fluent_scan_thumb_up_off_48_filled = 60024
ic_fluent_send_clock_24_filled = 60056
ic_fluent_share_screen_person_16_filled = 60083
ic_fluent_share_screen_person_20_filled = 60084
ic_fluent_share_screen_person_24_filled = 60085
ic_fluent_share_screen_person_28_filled = 60086
ic_fluent_share_screen_person_overlay_16_filled = 60087
ic_fluent_share_screen_person_overlay_20_filled = 60088
ic_fluent_share_screen_person_overlay_24_filled = 60089
ic_fluent_share_screen_person_overlay_28_filled = 60090
ic_fluent_share_screen_person_overlay_inside_16_filled = 60091
ic_fluent_share_screen_person_overlay_inside_20_filled = 60092
ic_fluent_share_screen_person_overlay_inside_24_filled = 60093
ic_fluent_share_screen_person_overlay_inside_28_filled = 60094
ic_fluent_slide_microphone_32_filled = 60196
ic_fluent_snooze_20_filled = 60214
ic_fluent_tag_32_filled = 60524
ic_fluent_tag_dismiss_16_filled = 60526
ic_fluent_tag_lock_16_filled = 60532
ic_fluent_tag_lock_20_filled = 60533
ic_fluent_tag_lock_24_filled = 60534
ic_fluent_tag_lock_32_filled = 60535
ic_fluent_tag_lock_accent_16_filled = 60536
ic_fluent_tag_lock_accent_20_filled = 60537
ic_fluent_tag_lock_accent_24_filled = 60538
ic_fluent_tag_lock_accent_32_filled = 60539
ic_fluent_text_align_center_16_filled = 60592
ic_fluent_text_align_left_16_filled = 60609
ic_fluent_text_align_right_16_filled = 60616
ic_fluent_text_change_case_16_filled = 60656
ic_fluent_text_clear_formatting_16_filled = 60657
ic_fluent_text_color_accent_16_filled = 60660
ic_fluent_text_color_accent_20_filled = 60661
ic_fluent_text_color_accent_24_filled = 60662
ic_fluent_text_font_size_16_filled = 60689
ic_fluent_text_indent_decrease_ltr_16_filled = 60707
ic_fluent_text_indent_decrease_ltr_20_filled = 60708
ic_fluent_text_indent_decrease_ltr_24_filled = 60709
ic_fluent_text_indent_decrease_rtl_16_filled = 60714
ic_fluent_text_indent_decrease_rtl_20_filled = 60715
ic_fluent_text_indent_decrease_rtl_24_filled = 60716
ic_fluent_text_indent_increase_ltr_16_filled = 60717
ic_fluent_text_indent_increase_ltr_20_filled = 60718
ic_fluent_text_indent_increase_ltr_24_filled = 60719
ic_fluent_text_indent_increase_rtl_16_filled = 60724
ic_fluent_text_indent_increase_rtl_20_filled = 60725
ic_fluent_text_indent_increase_rtl_24_filled = 60726
ic_fluent_text_number_list_ltr_16_filled = 60730
ic_fluent_text_number_list_rtl_16_filled = 60735
ic_fluent_text_paragraph_direction_left_16_filled = 60742
ic_fluent_text_paragraph_direction_left_20_filled = 60743
ic_fluent_text_paragraph_direction_right_16_filled = 60744
ic_fluent_text_paragraph_direction_right_20_filled = 60745
ic_fluent_text_subscript_16_filled = 60769
ic_fluent_text_superscript_16_filled = 60770
ic_fluent_apps_list_detail_20_filled = 57444
ic_fluent_apps_list_detail_24_filled = 57445
ic_fluent_arrow_maximize_32_filled = 57560
ic_fluent_arrow_outline_up_right_32_filled = 57568
ic_fluent_arrow_up_right_32_filled = 57648
ic_fluent_box_edit_20_filled = 57817
ic_fluent_box_edit_24_filled = 57818
ic_fluent_box_toolbox_20_filled = 57831
ic_fluent_box_toolbox_24_filled = 57832
ic_fluent_chat_video_20_filled = 58117
ic_fluent_chat_video_24_filled = 58118
ic_fluent_circle_32_filled = 58183
ic_fluent_database_link_20_filled = 58488
ic_fluent_database_link_24_filled = 58489
ic_fluent_diamond_32_filled = 58570
ic_fluent_document_text_20_filled = 58723
ic_fluent_document_text_24_filled = 58724
ic_fluent_document_text_link_20_filled = 58729
ic_fluent_document_text_link_24_filled = 58730
ic_fluent_globe_shield_20_filled = 59080
ic_fluent_globe_shield_24_filled = 59081
ic_fluent_line_32_filled = 59253
ic_fluent_line_dashes_32_filled = 59257
ic_fluent_number_symbol_28_filled = 59541
ic_fluent_number_symbol_48_filled = 59543
ic_fluent_oval_32_filled = 59571
ic_fluent_pentagon_32_filled = 59643
ic_fluent_play_circle_48_filled = 59816
ic_fluent_projection_screen_16_filled = 59868
ic_fluent_projection_screen_20_filled = 59869
ic_fluent_projection_screen_24_filled = 59870
ic_fluent_projection_screen_28_filled = 59871
ic_fluent_projection_screen_dismiss_16_filled = 59872
ic_fluent_projection_screen_dismiss_20_filled = 59873
ic_fluent_projection_screen_dismiss_24_filled = 59874
ic_fluent_projection_screen_dismiss_28_filled = 59875
ic_fluent_rhombus_32_filled = 59947
ic_fluent_save_arrow_right_20_filled = 59981
ic_fluent_save_arrow_right_24_filled = 59982
ic_fluent_shortpick_20_filled = 60159
ic_fluent_shortpick_24_filled = 60160
ic_fluent_sparkle_16_filled = 60219
ic_fluent_sparkle_20_filled = 60220
ic_fluent_sparkle_24_filled = 60221
ic_fluent_sparkle_28_filled = 60222
ic_fluent_sparkle_48_filled = 60223
ic_fluent_square_32_filled = 60289
ic_fluent_subtract_square_24_filled = 60372
ic_fluent_text_case_lowercase_16_filled = 60647
ic_fluent_text_case_lowercase_20_filled = 60648
ic_fluent_text_case_lowercase_24_filled = 60649
ic_fluent_text_case_title_16_filled = 60650
ic_fluent_text_case_title_20_filled = 60651
ic_fluent_text_case_title_24_filled = 60652
ic_fluent_text_case_uppercase_16_filled = 60653
ic_fluent_text_case_uppercase_20_filled = 60654
ic_fluent_text_case_uppercase_24_filled = 60655
ic_fluent_triangle_32_filled = 60839
ic_fluent_video_person_sparkle_16_filled = 60946
ic_fluent_video_person_sparkle_20_filled = 60947
ic_fluent_video_person_sparkle_24_filled = 60948
ic_fluent_video_person_sparkle_28_filled = 60949
ic_fluent_video_person_sparkle_48_filled = 60950
ic_fluent_accessibility_48_filled = 57346
ic_fluent_archive_multiple_16_filled = 57453
ic_fluent_archive_multiple_20_filled = 57454
ic_fluent_archive_multiple_24_filled = 57455
ic_fluent_arrow_reset_32_filled = 57576
ic_fluent_arrow_reset_48_filled = 57577
ic_fluent_box_20_filled = 57807
ic_fluent_box_24_filled = 57808
ic_fluent_box_dismiss_20_filled = 57815
ic_fluent_box_dismiss_24_filled = 57816
ic_fluent_clear_formatting_16_filled = 58197
ic_fluent_clear_formatting_20_filled = 58198
ic_fluent_clipboard_clock_20_filled = 58210
ic_fluent_clipboard_clock_24_filled = 58211
ic_fluent_cloud_archive_24_filled = 58269
ic_fluent_cloud_archive_28_filled = 58270
ic_fluent_cloud_archive_32_filled = 58271
ic_fluent_cloud_archive_48_filled = 58272
ic_fluent_document_table_arrow_right_20_filled = 58713
ic_fluent_document_table_arrow_right_24_filled = 58714
ic_fluent_document_table_checkmark_20_filled = 58715
ic_fluent_document_table_checkmark_24_filled = 58716
ic_fluent_document_text_clock_20_filled = 58725
ic_fluent_document_text_clock_24_filled = 58726
ic_fluent_flash_settings_20_filled = 58931
ic_fluent_flash_settings_24_filled = 58932
ic_fluent_games_16_filled = 59030
ic_fluent_games_20_filled = 59031
ic_fluent_games_28_filled = 59032
ic_fluent_games_32_filled = 59033
ic_fluent_games_48_filled = 59034
ic_fluent_hand_draw_28_filled = 59110
ic_fluent_lasso_28_filled = 59237
ic_fluent_money_dismiss_20_filled = 59432
ic_fluent_money_dismiss_24_filled = 59433
ic_fluent_money_off_20_filled = 59436
ic_fluent_money_off_24_filled = 59437
ic_fluent_note_28_filled = 59512
ic_fluent_note_48_filled = 59513
ic_fluent_person_lightbulb_20_filled = 59718
ic_fluent_person_lightbulb_24_filled = 59719
ic_fluent_picture_in_picture_enter_16_filled = 59790
ic_fluent_picture_in_picture_enter_20_filled = 59791
ic_fluent_picture_in_picture_enter_24_filled = 59792
ic_fluent_picture_in_picture_exit_16_filled = 59793
ic_fluent_picture_in_picture_exit_20_filled = 59794
ic_fluent_picture_in_picture_exit_24_filled = 59795
ic_fluent_plug_connected_20_filled = 59819
ic_fluent_sanitize_20_filled = 59977
ic_fluent_sanitize_24_filled = 59978
ic_fluent_settings_32_filled = 60061
ic_fluent_settings_48_filled = 60062
ic_fluent_shapes_28_filled = 60077
ic_fluent_shapes_48_filled = 60078
ic_fluent_shopping_bag_percent_20_filled = 60153
ic_fluent_shopping_bag_percent_24_filled = 60154
ic_fluent_shopping_bag_tag_20_filled = 60157
ic_fluent_shopping_bag_tag_24_filled = 60158
ic_fluent_stack_arrow_forward_20_filled = 60323
ic_fluent_stack_arrow_forward_24_filled = 60324
ic_fluent_table_lightning_20_filled = 60456
ic_fluent_table_lightning_24_filled = 60457
ic_fluent_table_link_20_filled = 60460
ic_fluent_table_link_24_filled = 60461
ic_fluent_text_t_28_filled = 60773
ic_fluent_text_t_48_filled = 60774
ic_fluent_thumb_like_28_filled = 60793
ic_fluent_thumb_like_48_filled = 60794
ic_fluent_video_off_32_filled = 60934
ic_fluent_video_off_48_filled = 60935
ic_fluent_bookmark_search_20_filled = 57773
ic_fluent_bookmark_search_24_filled = 57774
ic_fluent_building_factory_16_filled = 57898
ic_fluent_building_factory_20_filled = 57899
ic_fluent_building_factory_28_filled = 57901
ic_fluent_building_factory_32_filled = 57902
ic_fluent_building_factory_48_filled = 57903
ic_fluent_calendar_chat_20_filled = 57941
ic_fluent_calendar_chat_24_filled = 57942
ic_fluent_calendar_toolbox_20_filled = 57983
ic_fluent_calendar_toolbox_24_filled = 57984
ic_fluent_camera_switch_20_filled = 58038
ic_fluent_comment_multiple_32_filled = 58368
ic_fluent_comment_multiple_link_16_filled = 58373
ic_fluent_comment_multiple_link_20_filled = 58374
ic_fluent_comment_multiple_link_24_filled = 58375
ic_fluent_comment_multiple_link_28_filled = 58376
ic_fluent_comment_multiple_link_32_filled = 58377
ic_fluent_contact_card_ribbon_16_filled = 58397
ic_fluent_contact_card_ribbon_20_filled = 58398
ic_fluent_contact_card_ribbon_24_filled = 58399
ic_fluent_contact_card_ribbon_28_filled = 58400
ic_fluent_contact_card_ribbon_32_filled = 58401
ic_fluent_contact_card_ribbon_48_filled = 58402
ic_fluent_database_person_20_filled = 58491
ic_fluent_database_person_24_filled = 58492
ic_fluent_document_flowchart_20_filled = 58630
ic_fluent_document_flowchart_24_filled = 58631
ic_fluent_document_table_search_20_filled = 58719
ic_fluent_document_table_search_24_filled = 58720
ic_fluent_document_text_extract_20_filled = 58727
ic_fluent_document_text_extract_24_filled = 58728
ic_fluent_fast_forward_16_filled = 58899
ic_fluent_fast_forward_28_filled = 58900
ic_fluent_flowchart_20_filled = 58949
ic_fluent_flowchart_24_filled = 58950
ic_fluent_flowchart_circle_20_filled = 58951
ic_fluent_flowchart_circle_24_filled = 58952
ic_fluent_folder_sync_24_filled = 58994
ic_fluent_heart_circle_16_filled = 59147
ic_fluent_heart_circle_20_filled = 59148
ic_fluent_heart_circle_24_filled = 59149
ic_fluent_megaphone_loud_24_filled = 59390
ic_fluent_people_lock_20_filled = 59665
ic_fluent_people_lock_24_filled = 59666
ic_fluent_person_circle_24_filled = 59707
ic_fluent_phone_update_checkmark_20_filled = 59783
ic_fluent_phone_update_checkmark_24_filled = 59784
ic_fluent_plug_connected_24_filled = 59820
ic_fluent_rewind_16_filled = 59941
ic_fluent_rewind_28_filled = 59942
ic_fluent_save_multiple_20_filled = 59987
ic_fluent_save_multiple_24_filled = 59988
ic_fluent_scan_type_checkmark_20_filled = 60027
ic_fluent_scan_type_checkmark_24_filled = 60028
ic_fluent_select_object_skew_20_filled = 60049
ic_fluent_select_object_skew_24_filled = 60050
ic_fluent_select_object_skew_dismiss_20_filled = 60051
ic_fluent_select_object_skew_dismiss_24_filled = 60052
ic_fluent_select_object_skew_edit_20_filled = 60053
ic_fluent_select_object_skew_edit_24_filled = 60054
ic_fluent_shopping_bag_dismiss_20_filled = 60149
ic_fluent_shopping_bag_dismiss_24_filled = 60150
ic_fluent_shopping_bag_pause_20_filled = 60151
ic_fluent_shopping_bag_pause_24_filled = 60152
ic_fluent_tag_error_16_filled = 60529
ic_fluent_tag_error_20_filled = 60530
ic_fluent_tag_error_24_filled = 60531
ic_fluent_tag_multiple_24_filled = 60541
ic_fluent_tag_question_mark_20_filled = 60545
ic_fluent_tag_question_mark_32_filled = 60547
ic_fluent_text_column_one_wide_lightning_20_filled = 60667
ic_fluent_text_column_one_wide_lightning_24_filled = 60668
ic_fluent_text_font_info_16_filled = 60686
ic_fluent_text_font_info_20_filled = 60687
ic_fluent_text_font_info_24_filled = 60688
ic_fluent_tray_item_add_20_filled = 60830
ic_fluent_tray_item_add_24_filled = 60831
ic_fluent_tray_item_remove_20_filled = 60832
ic_fluent_tray_item_remove_24_filled = 60833
ic_fluent_vehicle_truck_bag_20_filled = 60906
ic_fluent_vehicle_truck_bag_24_filled = 60907
ic_fluent_checkmark_starburst_20_filled = 58143
ic_fluent_checkmark_starburst_24_filled = 58144
ic_fluent_access_time_20_filled = 57344
ic_fluent_accessibility_checkmark_20_filled = 57347
ic_fluent_add_square_20_filled = 57351
ic_fluent_album_20_filled = 57359
ic_fluent_album_add_20_filled = 57361
ic_fluent_alert_on_20_filled = 57370
ic_fluent_app_generic_20_filled = 57436
ic_fluent_app_recent_20_filled = 57437
ic_fluent_app_title_20_filled = 57438
ic_fluent_arrow_autofit_down_20_filled = 57461
ic_fluent_arrow_autofit_height_20_filled = 57463
ic_fluent_arrow_autofit_height_dotted_20_filled = 57464
ic_fluent_arrow_autofit_up_20_filled = 57466
ic_fluent_arrow_autofit_width_20_filled = 57468
ic_fluent_arrow_autofit_width_dotted_20_filled = 57469
ic_fluent_arrow_bounce_20_filled = 57479
ic_fluent_arrow_circle_down_right_20_filled = 57487
ic_fluent_arrow_circle_up_left_20_filled = 57511
ic_fluent_arrow_expand_20_filled = 57541
ic_fluent_arrow_fit_20_filled = 57549
ic_fluent_arrow_minimize_vertical_20_filled = 57563
ic_fluent_arrow_sort_down_lines_24_filled = 57586
ic_fluent_arrow_square_down_20_filled = 57590
ic_fluent_arrow_step_back_20_filled = 57593
ic_fluent_arrow_step_in_left_20_filled = 57601
ic_fluent_arrow_step_in_right_20_filled = 57606
ic_fluent_arrow_step_out_20_filled = 57611
ic_fluent_arrow_step_over_20_filled = 57615
ic_fluent_arrow_turn_bidirectional_down_right_20_filled = 57636
ic_fluent_arrow_turn_right_20_filled = 57637
ic_fluent_arrows_bidirectional_20_filled = 57653
ic_fluent_attach_text_20_filled = 57657
ic_fluent_auto_fit_height_20_filled = 57659
ic_fluent_auto_fit_width_20_filled = 57661
ic_fluent_autocorrect_20_filled = 57663
ic_fluent_badge_20_filled = 57675
ic_fluent_battery_checkmark_20_filled = 57680
ic_fluent_battery_warning_20_filled = 57682
ic_fluent_bluetooth_connected_20_filled = 57695
ic_fluent_bluetooth_disabled_20_filled = 57696
ic_fluent_bluetooth_searching_20_filled = 57697
ic_fluent_bookmark_multiple_16_filled = 57766
ic_fluent_bookmark_multiple_28_filled = 57769
ic_fluent_bookmark_multiple_32_filled = 57770
ic_fluent_bookmark_multiple_48_filled = 57771
ic_fluent_branch_fork_hint_20_filled = 57844
ic_fluent_branch_fork_hint_24_filled = 57845
ic_fluent_branch_fork_link_20_filled = 57846
ic_fluent_branch_fork_link_24_filled = 57847
ic_fluent_calendar_ltr_48_filled = 57958
ic_fluent_calendar_rtl_48_filled = 57979
ic_fluent_data_usage_toolbox_20_filled = 58478
ic_fluent_data_usage_toolbox_24_filled = 58479
ic_fluent_desktop_cursor_16_filled = 58519
ic_fluent_desktop_cursor_20_filled = 58520
ic_fluent_desktop_cursor_24_filled = 58521
ic_fluent_desktop_cursor_28_filled = 58522
ic_fluent_desktop_flow_20_filled = 58526
ic_fluent_desktop_flow_24_filled = 58527
ic_fluent_desktop_signal_20_filled = 58542
ic_fluent_desktop_signal_24_filled = 58543
ic_fluent_emoji_sad_slight_20_filled = 58850
ic_fluent_emoji_sad_slight_24_filled = 58851
ic_fluent_emoji_smile_slight_20_filled = 58852
ic_fluent_emoji_smile_slight_24_filled = 58853
ic_fluent_food_apple_20_filled = 58996
ic_fluent_food_apple_24_filled = 58997
ic_fluent_mail_edit_20_filled = 59329
ic_fluent_mail_edit_24_filled = 59330
ic_fluent_person_arrow_left_16_filled = 59701
ic_fluent_person_edit_20_filled = 59712
ic_fluent_person_edit_24_filled = 59713
ic_fluent_scan_dash_12_filled = 60002
ic_fluent_scan_dash_16_filled = 60003
ic_fluent_scan_dash_20_filled = 60004
ic_fluent_scan_dash_24_filled = 60005
ic_fluent_scan_dash_28_filled = 60006
ic_fluent_scan_dash_32_filled = 60007
ic_fluent_scan_dash_48_filled = 60008
ic_fluent_square_hint_20_filled = 60303
ic_fluent_square_hint_24_filled = 60304
ic_fluent_tag_off_20_filled = 60542
ic_fluent_tag_off_24_filled = 60543
ic_fluent_text_box_settings_20_filled = 60625
ic_fluent_text_box_settings_24_filled = 60626
ic_fluent_vehicle_truck_cube_20_filled = 60908
ic_fluent_vehicle_truck_cube_24_filled = 60909
ic_fluent_arrow_forward_down_lightning_20_filled = 57554
ic_fluent_arrow_forward_down_lightning_24_filled = 57555
ic_fluent_arrow_forward_down_person_20_filled = 57556
ic_fluent_arrow_forward_down_person_24_filled = 57557
ic_fluent_arrow_step_in_28_filled = 57598
ic_fluent_arrow_step_in_left_24_filled = 57602
ic_fluent_arrow_step_in_left_28_filled = 57603
ic_fluent_arrow_step_in_right_24_filled = 57607
ic_fluent_arrow_step_in_right_28_filled = 57608
ic_fluent_arrow_step_out_24_filled = 57612
ic_fluent_arrow_step_out_28_filled = 57613
ic_fluent_arrow_trending_text_20_filled = 57632
ic_fluent_arrow_trending_text_24_filled = 57633
ic_fluent_arrow_trending_wrench_20_filled = 57634
ic_fluent_arrow_trending_wrench_24_filled = 57635
ic_fluent_battery_10_20_filled = 57678
ic_fluent_beach_32_filled = 57687
ic_fluent_beach_48_filled = 57688
ic_fluent_book_clock_20_filled = 57720
ic_fluent_book_coins_20_filled = 57722
ic_fluent_book_compass_20_filled = 57724
ic_fluent_book_database_20_filled = 57730
ic_fluent_book_exclamation_mark_20_filled = 57732
ic_fluent_book_globe_20_filled = 57734
ic_fluent_book_information_20_filled = 57735
ic_fluent_book_letter_20_filled = 57737
ic_fluent_book_pulse_20_filled = 57752
ic_fluent_book_question_mark_20_filled = 57754
ic_fluent_book_question_mark_rtl_20_filled = 57756
ic_fluent_book_search_20_filled = 57757
ic_fluent_book_star_20_filled = 57759
ic_fluent_book_theta_20_filled = 57762
ic_fluent_bookmark_off_20_filled = 57772
ic_fluent_border_bottom_20_filled = 57778
ic_fluent_border_bottom_double_20_filled = 57780
ic_fluent_border_bottom_thick_20_filled = 57782
ic_fluent_border_left_20_filled = 57784
ic_fluent_border_none_20_filled = 57788
ic_fluent_border_outside_20_filled = 57790
ic_fluent_border_outside_thick_20_filled = 57792
ic_fluent_border_right_20_filled = 57794
ic_fluent_border_top_20_filled = 57796
ic_fluent_border_top_bottom_20_filled = 57798
ic_fluent_border_top_bottom_double_20_filled = 57800
ic_fluent_border_top_bottom_thick_20_filled = 57802
ic_fluent_branch_20_filled = 57837
ic_fluent_brightness_high_16_filled = 57866
ic_fluent_brightness_high_20_filled = 57867
ic_fluent_brightness_high_24_filled = 57868
ic_fluent_brightness_high_28_filled = 57869
ic_fluent_brightness_high_32_filled = 57870
ic_fluent_brightness_high_48_filled = 57871
ic_fluent_brightness_low_16_filled = 57872
ic_fluent_brightness_low_20_filled = 57873
ic_fluent_brightness_low_24_filled = 57874
ic_fluent_brightness_low_28_filled = 57875
ic_fluent_brightness_low_32_filled = 57876
ic_fluent_brightness_low_48_filled = 57877
ic_fluent_building_government_20_filled = 57904
ic_fluent_building_multiple_20_filled = 57911
ic_fluent_chat_dismiss_20_filled = 58113
ic_fluent_chat_dismiss_24_filled = 58114
ic_fluent_cube_tree_20_filled = 58439
ic_fluent_cube_tree_24_filled = 58440
ic_fluent_draw_image_20_filled = 58751
ic_fluent_draw_image_24_filled = 58752
ic_fluent_draw_shape_20_filled = 58753
ic_fluent_draw_text_20_filled = 58755
ic_fluent_drawer_add_20_filled = 58757
ic_fluent_drawer_add_24_filled = 58758
ic_fluent_drawer_arrow_download_20_filled = 58759
ic_fluent_drawer_arrow_download_24_filled = 58760
ic_fluent_drawer_dismiss_20_filled = 58761
ic_fluent_drawer_dismiss_24_filled = 58762
ic_fluent_drawer_play_20_filled = 58763
ic_fluent_drawer_play_24_filled = 58764
ic_fluent_drawer_subtract_20_filled = 58765
ic_fluent_drawer_subtract_24_filled = 58766
ic_fluent_emoji_28_filled = 58833
ic_fluent_emoji_32_filled = 58834
ic_fluent_emoji_48_filled = 58835
ic_fluent_emoji_sparkle_16_filled = 58854
ic_fluent_emoji_sparkle_20_filled = 58855
ic_fluent_emoji_sparkle_24_filled = 58856
ic_fluent_emoji_sparkle_28_filled = 58857
ic_fluent_emoji_sparkle_32_filled = 58858
ic_fluent_emoji_sparkle_48_filled = 58859
ic_fluent_flip_horizontal_16_filled = 58936
ic_fluent_flip_horizontal_20_filled = 58937
ic_fluent_flip_horizontal_28_filled = 58939
ic_fluent_flip_horizontal_32_filled = 58940
ic_fluent_flip_horizontal_48_filled = 58941
ic_fluent_flip_vertical_16_filled = 58942
ic_fluent_flip_vertical_20_filled = 58943
ic_fluent_flip_vertical_28_filled = 58945
ic_fluent_flip_vertical_32_filled = 58946
ic_fluent_flip_vertical_48_filled = 58947
ic_fluent_food_grains_20_filled = 59003
ic_fluent_food_grains_24_filled = 59004
ic_fluent_gift_card_arrow_right_20_filled = 59051
ic_fluent_gift_card_arrow_right_24_filled = 59052
ic_fluent_heart_32_filled = 59144
ic_fluent_heart_48_filled = 59145
ic_fluent_link_12_filled = 59262
ic_fluent_link_32_filled = 59263
ic_fluent_luggage_28_filled = 59307
ic_fluent_luggage_32_filled = 59308
ic_fluent_luggage_48_filled = 59309
ic_fluent_money_hand_20_filled = 59434
ic_fluent_money_hand_24_filled = 59435
ic_fluent_next_28_filled = 59509
ic_fluent_next_32_filled = 59510
ic_fluent_next_48_filled = 59511
ic_fluent_people_list_28_filled = 59664
ic_fluent_previous_28_filled = 59857
ic_fluent_previous_32_filled = 59858
ic_fluent_previous_48_filled = 59859
ic_fluent_question_circle_32_filled = 59894
ic_fluent_text_paragraph_16_filled = 60737
ic_fluent_vehicle_car_collision_28_filled = 60893
ic_fluent_vehicle_car_collision_32_filled = 60894
ic_fluent_video_clip_multiple_16_filled = 60928
ic_fluent_video_clip_multiple_20_filled = 60929
ic_fluent_video_clip_multiple_24_filled = 60930
ic_fluent_wallet_28_filled = 60974
ic_fluent_wallet_32_filled = 60975
ic_fluent_wallet_48_filled = 60976
ic_fluent_weather_sunny_28_filled = 61005
ic_fluent_wrench_screwdriver_20_filled = 61063
ic_fluent_wrench_screwdriver_24_filled = 61064
ic_fluent_arrow_between_down_20_filled = 57471
ic_fluent_arrow_between_down_24_filled = 57472
ic_fluent_arrow_redo_28_filled = 57573
ic_fluent_arrow_sync_checkmark_20_filled = 57617
ic_fluent_arrow_sync_checkmark_24_filled = 57618
ic_fluent_arrow_sync_dismiss_20_filled = 57619
ic_fluent_arrow_sync_dismiss_24_filled = 57620
ic_fluent_calculator_arrow_clockwise_20_filled = 57928
ic_fluent_calculator_arrow_clockwise_24_filled = 57929
ic_fluent_calendar_arrow_down_20_filled = 57935
ic_fluent_calendar_arrow_right_24_filled = 57938
ic_fluent_calendar_error_20_filled = 57949
ic_fluent_calendar_mail_20_filled = 57960
ic_fluent_calendar_week_numbers_20_filled = 57985
ic_fluent_call_add_20_filled = 57994
ic_fluent_camera_off_20_filled = 58036
ic_fluent_cellular_off_20_filled = 58056
ic_fluent_chevron_circle_down_32_filled = 58151
ic_fluent_chevron_circle_up_32_filled = 58172
ic_fluent_circle_48_filled = 58184
ic_fluent_clock_pause_20_filled = 58249
ic_fluent_clock_pause_24_filled = 58250
ic_fluent_diamond_16_filled = 58566
ic_fluent_diamond_20_filled = 58567
ic_fluent_diamond_24_filled = 58568
ic_fluent_diamond_28_filled = 58569
ic_fluent_diamond_48_filled = 58571
ic_fluent_door_28_filled = 58735
ic_fluent_door_arrow_right_28_filled = 58741
ic_fluent_immersive_reader_28_filled = 59201
ic_fluent_key_reset_20_filled = 59220
ic_fluent_key_reset_24_filled = 59221
ic_fluent_lightbulb_filament_48_filled = 59250
ic_fluent_line_20_filled = 59251
ic_fluent_line_24_filled = 59252
ic_fluent_line_48_filled = 59254
ic_fluent_line_dashes_20_filled = 59255
ic_fluent_line_dashes_24_filled = 59256
ic_fluent_line_dashes_48_filled = 59258
ic_fluent_mail_arrow_up_16_filled = 59321
ic_fluent_notepad_person_16_filled = 59535
ic_fluent_oval_16_filled = 59567
ic_fluent_oval_20_filled = 59568
ic_fluent_oval_24_filled = 59569
ic_fluent_oval_28_filled = 59570
ic_fluent_oval_48_filled = 59572
ic_fluent_pentagon_48_filled = 59644
ic_fluent_people_add_28_filled = 59648
ic_fluent_people_list_24_filled = 59663
ic_fluent_people_queue_20_filled = 59671
ic_fluent_people_queue_24_filled = 59672
ic_fluent_people_settings_28_filled = 59675
ic_fluent_print_28_filled = 59860
ic_fluent_rhombus_16_filled = 59943
ic_fluent_rhombus_20_filled = 59944
ic_fluent_rhombus_24_filled = 59945
ic_fluent_rhombus_28_filled = 59946
ic_fluent_rhombus_48_filled = 59948
ic_fluent_screen_search_20_filled = 60033
ic_fluent_screen_search_24_filled = 60034
ic_fluent_settings_chat_20_filled = 60063
ic_fluent_settings_chat_24_filled = 60064
ic_fluent_share_screen_person_p_16_filled = 60095
ic_fluent_share_screen_person_p_20_filled = 60096
ic_fluent_share_screen_person_p_24_filled = 60097
ic_fluent_share_screen_person_p_28_filled = 60098
ic_fluent_slide_add_16_filled = 60182
ic_fluent_slide_add_20_filled = 60183
ic_fluent_slide_add_28_filled = 60184
ic_fluent_slide_add_32_filled = 60185
ic_fluent_slide_add_48_filled = 60186
ic_fluent_slide_arrow_right_20_filled = 60187
ic_fluent_slide_arrow_right_24_filled = 60188
ic_fluent_sound_wave_circle_24_filled = 60217
ic_fluent_square_48_filled = 60290
ic_fluent_star_48_filled = 60328
ic_fluent_star_add_28_filled = 60329
ic_fluent_star_dismiss_16_filled = 60333
ic_fluent_star_dismiss_20_filled = 60334
ic_fluent_star_dismiss_24_filled = 60335
ic_fluent_star_dismiss_28_filled = 60336
ic_fluent_star_edit_20_filled = 60337
ic_fluent_star_settings_20_filled = 60344
ic_fluent_triangle_48_filled = 60840
ic_fluent_trophy_28_filled = 60856
ic_fluent_trophy_32_filled = 60857
ic_fluent_trophy_48_filled = 60858
ic_fluent_trophy_off_16_filled = 60859
ic_fluent_trophy_off_20_filled = 60860
ic_fluent_trophy_off_24_filled = 60861
ic_fluent_trophy_off_28_filled = 60862
ic_fluent_trophy_off_32_filled = 60863
ic_fluent_trophy_off_48_filled = 60864
ic_fluent_window_28_filled = 61023
ic_fluent_window_32_filled = 61024
ic_fluent_window_48_filled = 61025
ic_fluent_window_apps_16_filled = 61028
ic_fluent_window_apps_20_filled = 61029
ic_fluent_window_apps_24_filled = 61030
ic_fluent_window_apps_28_filled = 61031
ic_fluent_window_apps_32_filled = 61032
ic_fluent_window_apps_48_filled = 61033
ic_fluent_window_wrench_16_filled = 61055
ic_fluent_window_wrench_20_filled = 61056
ic_fluent_window_wrench_24_filled = 61057
ic_fluent_window_wrench_28_filled = 61058
ic_fluent_window_wrench_32_filled = 61059
ic_fluent_window_wrench_48_filled = 61060
ic_fluent_arrow_down_left_32_filled = 57532
ic_fluent_arrow_down_left_48_filled = 57533
ic_fluent_arrow_maximize_48_filled = 57561
ic_fluent_arrow_maximize_vertical_48_filled = 57562
ic_fluent_arrow_outline_up_right_48_filled = 57569
ic_fluent_arrow_up_left_48_filled = 57645
ic_fluent_arrow_up_right_48_filled = 57649
ic_fluent_book_arrow_clockwise_20_filled = 57718
ic_fluent_book_arrow_clockwise_24_filled = 57719
ic_fluent_box_arrow_left_20_filled = 57809
ic_fluent_box_arrow_left_24_filled = 57810
ic_fluent_box_arrow_up_20_filled = 57811
ic_fluent_box_arrow_up_24_filled = 57812
ic_fluent_box_checkmark_20_filled = 57813
ic_fluent_box_checkmark_24_filled = 57814
ic_fluent_box_multiple_20_filled = 57819
ic_fluent_box_multiple_24_filled = 57820
ic_fluent_box_multiple_arrow_left_20_filled = 57821
ic_fluent_box_multiple_arrow_left_24_filled = 57822
ic_fluent_box_multiple_arrow_right_20_filled = 57823
ic_fluent_box_multiple_arrow_right_24_filled = 57824
ic_fluent_box_multiple_checkmark_20_filled = 57825
ic_fluent_box_multiple_checkmark_24_filled = 57826
ic_fluent_box_multiple_search_20_filled = 57827
ic_fluent_box_multiple_search_24_filled = 57828
ic_fluent_box_search_20_filled = 57829
ic_fluent_box_search_24_filled = 57830
ic_fluent_cellular_warning_20_filled = 58058
ic_fluent_chart_multiple_20_filled = 58097
ic_fluent_chart_multiple_24_filled = 58098
ic_fluent_checkbox_arrow_right_20_filled = 58126
ic_fluent_checkbox_warning_20_filled = 58135
ic_fluent_clock_toolbox_20_filled = 58251
ic_fluent_clock_toolbox_24_filled = 58252
ic_fluent_cube_multiple_20_filled = 58430
ic_fluent_cube_multiple_24_filled = 58431
ic_fluent_desktop_toolbox_20_filled = 58550
ic_fluent_desktop_toolbox_24_filled = 58551
ic_fluent_document_bullet_list_multiple_20_filled = 58615
ic_fluent_document_bullet_list_multiple_24_filled = 58616
ic_fluent_document_queue_20_filled = 58687
ic_fluent_document_queue_24_filled = 58688
ic_fluent_document_queue_add_20_filled = 58689
ic_fluent_document_queue_add_24_filled = 58690
ic_fluent_document_queue_multiple_20_filled = 58691
ic_fluent_document_queue_multiple_24_filled = 58692
ic_fluent_document_table_cube_20_filled = 58717
ic_fluent_document_table_cube_24_filled = 58718
ic_fluent_document_table_truck_20_filled = 58721
ic_fluent_document_table_truck_24_filled = 58722
ic_fluent_document_text_toolbox_20_filled = 58731
ic_fluent_document_text_toolbox_24_filled = 58732
ic_fluent_equal_circle_20_filled = 58862
ic_fluent_equal_circle_24_filled = 58863
ic_fluent_gift_card_money_20_filled = 59053
ic_fluent_gift_card_money_24_filled = 59054
ic_fluent_gift_card_multiple_20_filled = 59055
ic_fluent_gift_card_multiple_24_filled = 59056
ic_fluent_image_multiple_32_filled = 59189
ic_fluent_image_multiple_48_filled = 59190
ic_fluent_mail_alert_28_filled = 59312
ic_fluent_puzzle_piece_shield_20_filled = 59891
ic_fluent_ribbon_12_filled = 59949
ic_fluent_ribbon_off_12_filled = 59954
ic_fluent_ribbon_off_16_filled = 59955
ic_fluent_ribbon_off_20_filled = 59956
ic_fluent_ribbon_off_24_filled = 59957
ic_fluent_ribbon_off_32_filled = 59958
ic_fluent_share_28_filled = 60080
ic_fluent_shopping_bag_arrow_left_20_filled = 60147
ic_fluent_shopping_bag_arrow_left_24_filled = 60148
ic_fluent_shopping_bag_play_20_filled = 60155
ic_fluent_shopping_bag_play_24_filled = 60156
ic_fluent_square_24_filled = 60287
ic_fluent_square_28_filled = 60288
ic_fluent_square_hint_16_filled = 60302
ic_fluent_square_hint_28_filled = 60305
ic_fluent_square_hint_32_filled = 60306
ic_fluent_square_hint_48_filled = 60307
ic_fluent_square_hint_apps_20_filled = 60308
ic_fluent_square_hint_apps_24_filled = 60309
ic_fluent_square_hint_sparkles_16_filled = 60312
ic_fluent_square_hint_sparkles_20_filled = 60313
ic_fluent_square_hint_sparkles_24_filled = 60314
ic_fluent_square_hint_sparkles_28_filled = 60315
ic_fluent_square_hint_sparkles_32_filled = 60316
ic_fluent_square_hint_sparkles_48_filled = 60317
ic_fluent_tablet_12_filled = 60515
ic_fluent_tablet_16_filled = 60516
ic_fluent_tablet_32_filled = 60517
ic_fluent_tablet_48_filled = 60518
ic_fluent_tag_reset_20_filled = 60548
ic_fluent_tag_reset_24_filled = 60549
ic_fluent_tag_search_20_filled = 60550
ic_fluent_tag_search_24_filled = 60551
ic_fluent_tap_double_32_filled = 60553
ic_fluent_tap_double_48_filled = 60554
ic_fluent_tap_single_32_filled = 60556
ic_fluent_tap_single_48_filled = 60557
ic_fluent_timer_12_filled = 60805
ic_fluent_timer_28_filled = 60809
ic_fluent_timer_32_filled = 60812
ic_fluent_timer_48_filled = 60813
ic_fluent_board_heart_16_filled = 57706
ic_fluent_board_heart_20_filled = 57707
ic_fluent_board_heart_24_filled = 57708
ic_fluent_braces_24_filled = 57834
ic_fluent_breakout_room_24_filled = 57850
ic_fluent_breakout_room_28_filled = 57851
ic_fluent_chat_warning_20_filled = 58120
ic_fluent_checkbox_person_16_filled = 58132
ic_fluent_checkbox_person_20_filled = 58133
ic_fluent_chevron_circle_down_12_filled = 58146
ic_fluent_chevron_circle_down_16_filled = 58147
ic_fluent_chevron_circle_down_20_filled = 58148
ic_fluent_chevron_circle_down_28_filled = 58150
ic_fluent_chevron_circle_down_48_filled = 58152
ic_fluent_chevron_circle_left_12_filled = 58153
ic_fluent_chevron_circle_left_16_filled = 58154
ic_fluent_chevron_circle_left_20_filled = 58155
ic_fluent_chevron_circle_left_24_filled = 58156
ic_fluent_chevron_circle_left_28_filled = 58157
ic_fluent_chevron_circle_left_32_filled = 58158
ic_fluent_chevron_circle_left_48_filled = 58159
ic_fluent_chevron_circle_right_16_filled = 58161
ic_fluent_chevron_circle_right_20_filled = 58162
ic_fluent_chevron_circle_right_28_filled = 58164
ic_fluent_chevron_circle_right_32_filled = 58165
ic_fluent_chevron_circle_right_48_filled = 58166
ic_fluent_chevron_circle_up_12_filled = 58167
ic_fluent_chevron_circle_up_16_filled = 58168
ic_fluent_chevron_circle_up_20_filled = 58169
ic_fluent_chevron_circle_up_24_filled = 58170
ic_fluent_chevron_circle_up_28_filled = 58171
ic_fluent_chevron_circle_up_48_filled = 58173
ic_fluent_circle_edit_20_filled = 58185
ic_fluent_circle_line_20_filled = 58191
ic_fluent_circle_off_20_filled = 58194
ic_fluent_class_20_filled = 58196
ic_fluent_clipboard_data_bar_20_filled = 58212
ic_fluent_clipboard_data_bar_24_filled = 58213
ic_fluent_clipboard_image_20_filled = 58219
ic_fluent_clipboard_more_20_filled = 58221
ic_fluent_clock_dismiss_20_filled = 58247
ic_fluent_comment_dismiss_20_filled = 58361
ic_fluent_comment_error_24_filled = 58366
ic_fluent_comment_note_20_filled = 58378
ic_fluent_convert_range_20_filled = 58409
ic_fluent_copy_add_20_filled = 58411
ic_fluent_copy_arrow_right_20_filled = 58414
ic_fluent_couch_20_filled = 58418
ic_fluent_crop_interim_20_filled = 58424
ic_fluent_crop_interim_off_20_filled = 58425
ic_fluent_cube_sync_20_filled = 58437
ic_fluent_dark_theme_20_filled = 58462
ic_fluent_data_area_20_filled = 58463
ic_fluent_data_bar_vertical_add_20_filled = 58464
ic_fluent_data_funnel_20_filled = 58466
ic_fluent_data_histogram_20_filled = 58467
ic_fluent_data_scatter_20_filled = 58469
ic_fluent_data_sunburst_20_filled = 58470
ic_fluent_data_treemap_20_filled = 58471
ic_fluent_data_waterfall_20_filled = 58480
ic_fluent_data_whisker_20_filled = 58481
ic_fluent_document_lock_16_filled = 58656
ic_fluent_document_lock_20_filled = 58657
ic_fluent_document_lock_24_filled = 58658
ic_fluent_document_lock_28_filled = 58659
ic_fluent_document_lock_32_filled = 58660
ic_fluent_document_lock_48_filled = 58661
ic_fluent_eyedropper_off_20_filled = 58892
ic_fluent_eyedropper_off_24_filled = 58893
ic_fluent_globe_person_20_filled = 59076
ic_fluent_mail_open_person_20_filled = 59354
ic_fluent_mail_open_person_24_filled = 59355
ic_fluent_resize_24_filled = 59931
ic_fluent_resize_image_20_filled = 59932
ic_fluent_scan_camera_16_filled = 59997
ic_fluent_scan_camera_20_filled = 59998
ic_fluent_scan_camera_24_filled = 59999
ic_fluent_scan_camera_28_filled = 60000
ic_fluent_scan_camera_48_filled = 60001
ic_fluent_style_guide_20_filled = 60355
ic_fluent_tab_desktop_16_filled = 60387
ic_fluent_tab_desktop_24_filled = 60388
ic_fluent_tab_desktop_bottom_20_filled = 60390
ic_fluent_approvals_app_32_filled = 57441
ic_fluent_arrow_export_rtl_24_filled = 57546
ic_fluent_arrow_sort_down_lines_20_filled = 57585
ic_fluent_arrow_step_in_20_filled = 57596
ic_fluent_arrow_step_in_24_filled = 57597
ic_fluent_battery_10_24_filled = 57679
ic_fluent_bezier_curve_square_20_filled = 57691
ic_fluent_border_none_24_filled = 57789
ic_fluent_calendar_pattern_16_filled = 57964
ic_fluent_caret_down_right_12_filled = 58039
ic_fluent_caret_down_right_16_filled = 58040
ic_fluent_caret_down_right_20_filled = 58041
ic_fluent_caret_down_right_24_filled = 58042
ic_fluent_cellular_off_24_filled = 58057
ic_fluent_eye_12_filled = 58877
ic_fluent_eye_16_filled = 58878
ic_fluent_eye_20_filled = 58879
ic_fluent_eye_24_filled = 58880
ic_fluent_eye_off_20_filled = 58882
ic_fluent_eye_off_24_filled = 58883
ic_fluent_eye_tracking_16_filled = 58884
ic_fluent_eye_tracking_20_filled = 58885
ic_fluent_eye_tracking_24_filled = 58886
ic_fluent_flash_20_filled = 58917
ic_fluent_flash_24_filled = 58918
ic_fluent_hdr_off_24_filled = 59130
ic_fluent_mic_16_filled = 59398
ic_fluent_mic_20_filled = 59399
ic_fluent_mic_24_filled = 59400
ic_fluent_mic_28_filled = 59401
ic_fluent_mic_32_filled = 59402
ic_fluent_mic_48_filled = 59403
ic_fluent_multiselect_ltr_16_filled = 59481
ic_fluent_multiselect_ltr_20_filled = 59482
ic_fluent_multiselect_ltr_24_filled = 59483
ic_fluent_multiselect_rtl_20_filled = 59485
ic_fluent_multiselect_rtl_24_filled = 59486
ic_fluent_panel_left_contract_16_filled = 59586
ic_fluent_panel_left_contract_20_filled = 59587
ic_fluent_panel_left_contract_24_filled = 59588
ic_fluent_person_tag_20_filled = 59744
ic_fluent_person_tag_24_filled = 59745
ic_fluent_person_tag_28_filled = 59746
ic_fluent_person_tag_32_filled = 59747
ic_fluent_person_tag_48_filled = 59748
ic_fluent_share_screen_start_48_filled = 60102
ic_fluent_shield_lock_24_filled = 60122
ic_fluent_shield_lock_28_filled = 60123
ic_fluent_shield_lock_48_filled = 60124
ic_fluent_skip_back_10_24_filled = 60165
ic_fluent_skip_back_10_28_filled = 60166
ic_fluent_skip_back_10_32_filled = 60167
ic_fluent_skip_back_10_48_filled = 60168
ic_fluent_table_stack_below_20_filled = 60501
ic_fluent_textbox_16_filled = 60778
ic_fluent_textbox_rotate_90_20_filled = 60789
ic_fluent_textbox_rotate_90_24_filled = 60790
ic_fluent_board_games_20_filled = 57705
ic_fluent_building_home_16_filled = 57907
ic_fluent_building_home_20_filled = 57908
ic_fluent_building_home_24_filled = 57909
ic_fluent_color_fill_16_filled = 58322
ic_fluent_color_fill_28_filled = 58323
ic_fluent_decimal_arrow_left_20_filled = 58499
ic_fluent_decimal_arrow_right_20_filled = 58501
ic_fluent_delete_arrow_back_20_filled = 58505
ic_fluent_delete_dismiss_20_filled = 58506
ic_fluent_desktop_edit_20_filled = 58524
ic_fluent_desktop_edit_24_filled = 58525
ic_fluent_desktop_mac_20_filled = 58533
ic_fluent_desktop_mac_24_filled = 58534
ic_fluent_desktop_sync_20_filled = 58548
ic_fluent_desktop_sync_24_filled = 58549
ic_fluent_developer_board_search_24_filled = 58556
ic_fluent_device_eq_20_filled = 58557
ic_fluent_diagram_20_filled = 58560
ic_fluent_dialpad_off_20_filled = 58565
ic_fluent_dismiss_square_multiple_20_filled = 58579
ic_fluent_divider_short_16_filled = 58584
ic_fluent_divider_short_20_filled = 58585
ic_fluent_dock_20_filled = 58588
ic_fluent_dock_row_20_filled = 58589
ic_fluent_document_bullet_list_off_20_filled = 58617
ic_fluent_document_checkmark_20_filled = 58621
ic_fluent_document_chevron_double_20_filled = 58623
ic_fluent_document_css_20_filled = 58625
ic_fluent_document_footer_20_filled = 58633
ic_fluent_document_footer_dismiss_20_filled = 58634
ic_fluent_document_header_20_filled = 58637
ic_fluent_document_header_arrow_down_20_filled = 58639
ic_fluent_document_header_arrow_down_24_filled = 58640
ic_fluent_document_header_dismiss_20_filled = 58641
ic_fluent_document_javascript_20_filled = 58648
ic_fluent_document_landscape_data_20_filled = 58650
ic_fluent_document_landscape_split_24_filled = 58653
ic_fluent_double_tap_swipe_down_20_filled = 58746
ic_fluent_double_tap_swipe_down_24_filled = 58747
ic_fluent_double_tap_swipe_up_20_filled = 58748
ic_fluent_double_tap_swipe_up_24_filled = 58749
ic_fluent_location_add_16_filled = 59275
ic_fluent_location_add_20_filled = 59276
ic_fluent_location_add_24_filled = 59277
ic_fluent_math_symbols_16_filled = 59379
ic_fluent_math_symbols_20_filled = 59380
ic_fluent_math_symbols_24_filled = 59381
ic_fluent_math_symbols_28_filled = 59382
ic_fluent_math_symbols_32_filled = 59383
ic_fluent_math_symbols_48_filled = 59384
ic_fluent_password_16_filled = 59610
ic_fluent_password_20_filled = 59611
ic_fluent_people_prohibited_24_filled = 59670
ic_fluent_sticker_add_20_filled = 60348
ic_fluent_subtract_square_20_filled = 60371
ic_fluent_system_20_filled = 60382
ic_fluent_table_add_16_filled = 60402
ic_fluent_table_add_28_filled = 60404
ic_fluent_table_cell_edit_16_filled = 60411
ic_fluent_table_cell_edit_20_filled = 60412
ic_fluent_table_cell_edit_28_filled = 60414
ic_fluent_table_cells_merge_16_filled = 60415
ic_fluent_table_cells_merge_28_filled = 60416
ic_fluent_table_cells_split_16_filled = 60417
ic_fluent_table_cells_split_28_filled = 60418
ic_fluent_table_delete_column_16_filled = 60421
ic_fluent_table_delete_column_28_filled = 60424
ic_fluent_table_delete_row_16_filled = 60425
ic_fluent_table_delete_row_28_filled = 60428
ic_fluent_table_dismiss_16_filled = 60429
ic_fluent_table_dismiss_28_filled = 60432
ic_fluent_table_edit_16_filled = 60433
ic_fluent_table_edit_20_filled = 60434
ic_fluent_table_edit_28_filled = 60435
ic_fluent_table_freeze_column_16_filled = 60436
ic_fluent_table_freeze_column_20_filled = 60437
ic_fluent_table_freeze_column_28_filled = 60438
ic_fluent_table_freeze_column_and_row_16_filled = 60439
ic_fluent_table_freeze_column_and_row_20_filled = 60440
ic_fluent_table_freeze_column_and_row_28_filled = 60442
ic_fluent_table_freeze_row_16_filled = 60443
ic_fluent_table_freeze_row_20_filled = 60444
ic_fluent_table_freeze_row_28_filled = 60445
ic_fluent_table_insert_column_16_filled = 60447
ic_fluent_table_insert_column_20_filled = 60448
ic_fluent_table_insert_column_28_filled = 60450
ic_fluent_table_insert_row_16_filled = 60451
ic_fluent_table_insert_row_20_filled = 60452
ic_fluent_table_insert_row_28_filled = 60454
ic_fluent_table_lightning_16_filled = 60455
ic_fluent_table_lightning_28_filled = 60458
ic_fluent_table_link_16_filled = 60459
ic_fluent_table_link_28_filled = 60462
ic_fluent_table_move_above_16_filled = 60463
ic_fluent_table_move_above_20_filled = 60464
ic_fluent_table_move_above_28_filled = 60466
ic_fluent_table_move_below_16_filled = 60467
ic_fluent_table_move_below_20_filled = 60468
ic_fluent_table_move_below_28_filled = 60470
ic_fluent_table_move_left_16_filled = 60471
ic_fluent_table_move_left_20_filled = 60472
ic_fluent_table_move_left_28_filled = 60473
ic_fluent_table_move_right_16_filled = 60474
ic_fluent_table_move_right_20_filled = 60475
ic_fluent_table_move_right_28_filled = 60476
ic_fluent_table_resize_column_16_filled = 60478
ic_fluent_table_resize_column_20_filled = 60479
ic_fluent_table_resize_column_28_filled = 60481
ic_fluent_table_resize_row_16_filled = 60482
ic_fluent_table_resize_row_20_filled = 60483
ic_fluent_table_resize_row_28_filled = 60485
ic_fluent_table_settings_16_filled = 60487
ic_fluent_table_settings_20_filled = 60488
ic_fluent_table_settings_28_filled = 60489
ic_fluent_table_stack_above_16_filled = 60496
ic_fluent_table_stack_above_28_filled = 60499
ic_fluent_table_stack_below_16_filled = 60500
ic_fluent_table_stack_below_28_filled = 60503
ic_fluent_table_stack_left_16_filled = 60504
ic_fluent_table_stack_left_28_filled = 60507
ic_fluent_table_stack_right_16_filled = 60508
ic_fluent_table_stack_right_28_filled = 60511
ic_fluent_table_switch_16_filled = 60512
ic_fluent_table_switch_20_filled = 60513
ic_fluent_table_switch_28_filled = 60514
ic_fluent_tablet_speaker_20_filled = 60519
ic_fluent_text_align_distributed_evenly_20_filled = 60599
ic_fluent_text_align_distributed_vertical_20_filled = 60601
ic_fluent_text_align_justify_low_20_filled = 60603
ic_fluent_text_continuous_20_filled = 60669
ic_fluent_textbox_align_bottom_rotate_90_20_filled = 60779
ic_fluent_textbox_align_middle_rotate_90_20_filled = 60783
ic_fluent_textbox_align_top_rotate_90_20_filled = 60785
ic_fluent_textbox_more_20_filled = 60787
ic_fluent_video_chat_16_filled = 60920
ic_fluent_video_chat_20_filled = 60921
ic_fluent_video_chat_24_filled = 60922
ic_fluent_arrow_paragraph_20_filled = 57570
ic_fluent_clipboard_edit_20_filled = 58215
ic_fluent_clipboard_note_20_filled = 58222
ic_fluent_document_mention_16_filled = 58662
ic_fluent_document_mention_20_filled = 58663
ic_fluent_document_mention_24_filled = 58664
ic_fluent_document_mention_28_filled = 58665
ic_fluent_document_mention_48_filled = 58666
ic_fluent_document_split_hint_off_16_filled = 58705
ic_fluent_document_split_hint_off_20_filled = 58706
ic_fluent_door_tag_20_filled = 58742
ic_fluent_double_swipe_down_20_filled = 58744
ic_fluent_double_swipe_up_20_filled = 58745
ic_fluent_drag_20_filled = 58750
ic_fluent_drink_to_go_20_filled = 58772
ic_fluent_drive_train_20_filled = 58776
ic_fluent_dual_screen_add_20_filled = 58785
ic_fluent_dual_screen_arrow_right_20_filled = 58786
ic_fluent_dual_screen_arrow_up_20_filled = 58787
ic_fluent_dual_screen_clock_20_filled = 58789
ic_fluent_dual_screen_closed_alert_20_filled = 58790
ic_fluent_dual_screen_desktop_20_filled = 58792
ic_fluent_dual_screen_dismiss_20_filled = 58793
ic_fluent_dual_screen_group_20_filled = 58795
ic_fluent_dual_screen_header_20_filled = 58796
ic_fluent_dual_screen_lock_20_filled = 58798
ic_fluent_dual_screen_mirror_20_filled = 58799
ic_fluent_dual_screen_pagination_20_filled = 58800
ic_fluent_dual_screen_settings_20_filled = 58801
ic_fluent_dual_screen_span_20_filled = 58802
ic_fluent_dual_screen_speaker_20_filled = 58804
ic_fluent_dual_screen_status_bar_20_filled = 58806
ic_fluent_dual_screen_tablet_20_filled = 58807
ic_fluent_dual_screen_update_20_filled = 58808
ic_fluent_dual_screen_vertical_scroll_20_filled = 58809
ic_fluent_dual_screen_vibrate_20_filled = 58810
ic_fluent_edit_settings_20_filled = 58831
ic_fluent_engine_20_filled = 58860
ic_fluent_eraser_medium_20_filled = 58867
ic_fluent_eraser_segment_20_filled = 58869
ic_fluent_eraser_small_20_filled = 58871
ic_fluent_eraser_tool_20_filled = 58873
ic_fluent_extended_dock_20_filled = 58876
ic_fluent_fast_acceleration_20_filled = 58898
ic_fluent_filter_sync_20_filled = 58908
ic_fluent_fingerprint_20_filled = 58910
ic_fluent_fixed_width_20_filled = 58912
ic_fluent_flash_auto_20_filled = 58921
ic_fluent_flash_off_20_filled = 58929
ic_fluent_flashlight_off_20_filled = 58935
ic_fluent_fluent_20_filled = 58953
ic_fluent_form_new_20_filled = 59009
ic_fluent_fps_960_20_filled = 59023
ic_fluent_full_screen_minimize_16_filled = 59027
ic_fluent_full_screen_minimize_20_filled = 59028
ic_fluent_gas_20_filled = 59037
ic_fluent_gas_pump_20_filled = 59039
ic_fluent_gavel_20_filled = 59043
ic_fluent_gesture_20_filled = 59046
ic_fluent_gift_card_24_filled = 59049
ic_fluent_glance_default_12_filled = 59058
ic_fluent_glance_horizontal_24_filled = 59061
ic_fluent_globe_add_20_filled = 59072
ic_fluent_globe_desktop_20_filled = 59075
ic_fluent_group_dismiss_20_filled = 59093
ic_fluent_group_list_20_filled = 59095
ic_fluent_group_return_20_filled = 59096
ic_fluent_guest_add_20_filled = 59102
ic_fluent_hand_draw_20_filled = 59108
ic_fluent_home_add_20_filled = 59167
ic_fluent_mail_dismiss_28_filled = 59328
ic_fluent_mail_inbox_all_20_filled = 59332
ic_fluent_mail_inbox_arrow_right_20_filled = 59335
ic_fluent_mail_list_16_filled = 59343
ic_fluent_mail_multiple_28_filled = 59350
ic_fluent_mail_off_20_filled = 59351
ic_fluent_mic_settings_20_filled = 59424
ic_fluent_navigation_unread_20_filled = 59504
ic_fluent_new_20_filled = 59507
ic_fluent_notebook_20_filled = 59519
ic_fluent_notebook_add_20_filled = 59520
ic_fluent_notebook_error_20_filled = 59523
ic_fluent_notebook_lightning_20_filled = 59525
ic_fluent_notebook_question_mark_20_filled = 59526
ic_fluent_number_symbol_dismiss_20_filled = 59544
ic_fluent_pair_20_filled = 59577
ic_fluent_patient_20_filled = 59612
ic_fluent_pause_off_20_filled = 59619
ic_fluent_pause_settings_16_filled = 59620
ic_fluent_people_sync_28_filled = 59681
ic_fluent_phone_add_20_filled = 59750
ic_fluent_phone_dismiss_20_filled = 59756
ic_fluent_phone_lock_20_filled = 59765
ic_fluent_phone_page_header_20_filled = 59767
ic_fluent_phone_pagination_20_filled = 59768
ic_fluent_phone_screen_time_20_filled = 59769
ic_fluent_phone_status_bar_20_filled = 59781
ic_fluent_phone_update_20_filled = 59782
ic_fluent_phone_vertical_scroll_20_filled = 59785
ic_fluent_phone_vibrate_20_filled = 59786
ic_fluent_photo_filter_20_filled = 59787
ic_fluent_pi_20_filled = 59788
ic_fluent_port_hdmi_20_filled = 59826
ic_fluent_predictions_20_filled = 59842
ic_fluent_pulse_square_20_filled = 59880
ic_fluent_remote_20_filled = 59928
ic_fluent_reorder_20_filled = 59929
ic_fluent_resize_video_20_filled = 59940
ic_fluent_rotate_left_20_filled = 59967
ic_fluent_router_20_filled = 59971
ic_fluent_scan_20_filled = 59996
ic_fluent_scan_table_20_filled = 60011
ic_fluent_scan_text_20_filled = 60013
ic_fluent_search_square_20_filled = 60042
ic_fluent_service_bell_20_filled = 60060
ic_fluent_shifts_add_20_filled = 60136
ic_fluent_shifts_prohibited_20_filled = 60142
ic_fluent_shifts_question_mark_20_filled = 60144
ic_fluent_slide_grid_20_filled = 60192
ic_fluent_slide_settings_20_filled = 60204
ic_fluent_slide_transition_20_filled = 60212
ic_fluent_spacebar_20_filled = 60218
ic_fluent_speaker_settings_20_filled = 60250
ic_fluent_speaker_settings_28_filled = 60251
ic_fluent_star_arrow_right_end_20_filled = 60330
ic_fluent_star_arrow_right_start_20_filled = 60332
ic_fluent_storage_20_filled = 60349
ic_fluent_sub_grid_20_filled = 60356
ic_fluent_text_density_16_filled = 60671
ic_fluent_text_density_20_filled = 60672
ic_fluent_video_person_off_20_filled = 60945
ic_fluent_voicemail_arrow_back_20_filled = 60965
ic_fluent_voicemail_arrow_forward_20_filled = 60966
ic_fluent_voicemail_arrow_subtract_20_filled = 60967
ic_fluent_web_asset_20_filled = 61013
ic_fluent_archive_32_filled = 57446
ic_fluent_archive_settings_24_filled = 57457
ic_fluent_arrow_enter_20_filled = 57535
ic_fluent_arrow_exit_20_filled = 57540
ic_fluent_arrow_join_20_filled = 57558
ic_fluent_arrow_trending_down_16_filled = 57625
ic_fluent_arrow_trending_down_20_filled = 57626
ic_fluent_arrow_trending_down_24_filled = 57627
ic_fluent_book_template_20_filled = 57761
ic_fluent_border_left_right_20_filled = 57786
ic_fluent_border_left_right_24_filled = 57787
ic_fluent_building_retail_more_20_filled = 57916
ic_fluent_calendar_add_16_filled = 57933
ic_fluent_calendar_add_28_filled = 57934
ic_fluent_cellular_3g_20_filled = 58052
ic_fluent_cellular_4g_20_filled = 58053
ic_fluent_cellular_5g_20_filled = 58054
ic_fluent_checkbox_1_20_filled = 58122
ic_fluent_checkbox_2_20_filled = 58124
ic_fluent_checkmark_note_20_filled = 58141
ic_fluent_code_text_20_filled = 58319
ic_fluent_code_text_edit_20_filled = 58320
ic_fluent_column_20_filled = 58325
ic_fluent_cube_add_20_filled = 58427
ic_fluent_cube_quick_16_filled = 58432
ic_fluent_cube_quick_20_filled = 58433
ic_fluent_cube_quick_24_filled = 58434
ic_fluent_cube_quick_28_filled = 58435
ic_fluent_database_arrow_down_20_filled = 58484
ic_fluent_database_arrow_right_20_filled = 58485
ic_fluent_database_arrow_up_20_filled = 58486
ic_fluent_database_lightning_20_filled = 58487
ic_fluent_database_plug_connected_20_filled = 58493
ic_fluent_database_warning_20_filled = 58497
ic_fluent_database_window_20_filled = 58498
ic_fluent_developer_board_lightning_20_filled = 58553
ic_fluent_developer_board_lightning_toolbox_20_filled = 58554
ic_fluent_edit_28_filled = 58815
ic_fluent_edit_48_filled = 58817
ic_fluent_edit_off_28_filled = 58822
ic_fluent_edit_off_32_filled = 58823
ic_fluent_edit_off_48_filled = 58824
ic_fluent_edit_prohibited_16_filled = 58825
ic_fluent_edit_prohibited_20_filled = 58826
ic_fluent_edit_prohibited_24_filled = 58827
ic_fluent_edit_prohibited_28_filled = 58828
ic_fluent_edit_prohibited_32_filled = 58829
ic_fluent_edit_prohibited_48_filled = 58830
ic_fluent_emoji_edit_16_filled = 58838
ic_fluent_emoji_edit_20_filled = 58839
ic_fluent_emoji_edit_24_filled = 58840
ic_fluent_emoji_edit_28_filled = 58841
ic_fluent_emoji_edit_48_filled = 58842
ic_fluent_filter_add_20_filled = 58904
ic_fluent_flash_add_20_filled = 58920
ic_fluent_flash_flow_16_filled = 58926
ic_fluent_flash_flow_20_filled = 58927
ic_fluent_flash_flow_24_filled = 58928
ic_fluent_flash_play_20_filled = 58930
ic_fluent_folder_arrow_left_16_filled = 58963
ic_fluent_folder_arrow_left_20_filled = 58964
ic_fluent_folder_arrow_left_24_filled = 58965
ic_fluent_folder_arrow_left_28_filled = 58966
ic_fluent_folder_arrow_left_32_filled = 58967
ic_fluent_gauge_add_20_filled = 59042
ic_fluent_hand_draw_16_filled = 59107
ic_fluent_hard_drive_20_filled = 59120
ic_fluent_hdr_20_filled = 59128
ic_fluent_hdr_off_20_filled = 59129
ic_fluent_home_database_20_filled = 59170
ic_fluent_image_add_20_filled = 59175
ic_fluent_image_arrow_back_20_filled = 59177
ic_fluent_image_arrow_counterclockwise_20_filled = 59179
ic_fluent_image_arrow_forward_20_filled = 59181
ic_fluent_image_globe_20_filled = 59183
ic_fluent_image_reflection_20_filled = 59196
ic_fluent_image_shadow_20_filled = 59198
ic_fluent_incognito_20_filled = 59202
ic_fluent_key_command_20_filled = 59217
ic_fluent_key_command_24_filled = 59218
ic_fluent_keyboard_123_20_filled = 59222
ic_fluent_keyboard_dock_20_filled = 59225
ic_fluent_keyboard_layout_float_20_filled = 59226
ic_fluent_keyboard_layout_one_handed_left_20_filled = 59227
ic_fluent_keyboard_layout_resize_20_filled = 59228
ic_fluent_keyboard_layout_split_20_filled = 59229
ic_fluent_keyboard_shift_uppercase_16_filled = 59232
ic_fluent_keyboard_shift_uppercase_20_filled = 59233
ic_fluent_keyboard_tab_20_filled = 59234
ic_fluent_launcher_settings_20_filled = 59238
ic_fluent_lightbulb_circle_20_filled = 59249
ic_fluent_line_style_20_filled = 59260
ic_fluent_link_toolbox_20_filled = 59270
ic_fluent_location_add_left_20_filled = 59278
ic_fluent_location_add_right_20_filled = 59279
ic_fluent_location_add_up_20_filled = 59280
ic_fluent_location_dismiss_20_filled = 59284
ic_fluent_mail_all_read_16_filled = 59313
ic_fluent_mail_all_read_24_filled = 59314
ic_fluent_mail_all_read_28_filled = 59315
ic_fluent_mail_list_20_filled = 59344
ic_fluent_mail_list_24_filled = 59345
ic_fluent_mail_list_28_filled = 59346
ic_fluent_mail_read_multiple_16_filled = 59360
ic_fluent_mail_read_multiple_24_filled = 59361
ic_fluent_mail_read_multiple_28_filled = 59362
ic_fluent_math_format_professional_20_filled = 59373
ic_fluent_math_formula_20_filled = 59376
ic_fluent_mention_arrow_down_20_filled = 59394
ic_fluent_mention_brackets_20_filled = 59395
ic_fluent_music_note_off_1_20_filled = 59493
ic_fluent_music_note_off_1_24_filled = 59494
ic_fluent_music_note_off_2_16_filled = 59495
ic_fluent_music_note_off_2_20_filled = 59496
ic_fluent_music_note_off_2_24_filled = 59497
ic_fluent_navigation_location_target_20_filled = 59502
ic_fluent_navigation_play_20_filled = 59503
ic_fluent_number_circle_1_16_filled = 59538
ic_fluent_number_circle_1_20_filled = 59539
ic_fluent_number_circle_1_24_filled = 59540
ic_fluent_panel_left_contract_28_filled = 59589
ic_fluent_panel_left_expand_24_filled = 59592
ic_fluent_panel_left_expand_28_filled = 59593
ic_fluent_panel_left_focus_right_16_filled = 59594
ic_fluent_panel_left_focus_right_20_filled = 59595
ic_fluent_panel_left_focus_right_24_filled = 59596
ic_fluent_panel_left_focus_right_28_filled = 59597
ic_fluent_pen_16_filled = 59624
ic_fluent_pen_20_filled = 59625
ic_fluent_pen_24_filled = 59626
ic_fluent_pen_28_filled = 59627
ic_fluent_pen_32_filled = 59628
ic_fluent_pen_48_filled = 59629
ic_fluent_pen_off_16_filled = 59630
ic_fluent_pen_off_20_filled = 59631
ic_fluent_pen_off_24_filled = 59632
ic_fluent_pen_off_28_filled = 59633
ic_fluent_pen_off_32_filled = 59634
ic_fluent_pen_off_48_filled = 59635
ic_fluent_pen_prohibited_16_filled = 59636
ic_fluent_pen_prohibited_20_filled = 59637
ic_fluent_pen_prohibited_24_filled = 59638
ic_fluent_pen_prohibited_28_filled = 59639
ic_fluent_pen_prohibited_32_filled = 59640
ic_fluent_pen_prohibited_48_filled = 59641
ic_fluent_person_key_20_filled = 59717
ic_fluent_phone_link_setup_20_filled = 59764
ic_fluent_pipeline_20_filled = 59803
ic_fluent_pipeline_add_20_filled = 59804
ic_fluent_pipeline_play_20_filled = 59806
ic_fluent_play_settings_20_filled = 59817
ic_fluent_plug_connected_add_20_filled = 59821
ic_fluent_plug_connected_checkmark_20_filled = 59822
ic_fluent_presence_available_20_filled = 59847
ic_fluent_presence_available_24_filled = 59848
ic_fluent_presence_away_20_filled = 59849
ic_fluent_presence_away_24_filled = 59850
ic_fluent_presence_busy_20_filled = 59851
ic_fluent_presence_busy_24_filled = 59852
ic_fluent_presence_dnd_20_filled = 59853
ic_fluent_presence_dnd_24_filled = 59854
ic_fluent_prohibited_note_20_filled = 59867
ic_fluent_puzzle_cube_piece_20_filled = 59887
ic_fluent_ram_20_filled = 59899
ic_fluent_receipt_search_20_filled = 59918
ic_fluent_rectangle_portrait_location_target_20_filled = 59926
ic_fluent_save_image_20_filled = 59986
ic_fluent_scan_16_filled = 59995
ic_fluent_server_multiple_20_filled = 60058
ic_fluent_server_play_20_filled = 60059
ic_fluent_shield_person_20_filled = 60125
ic_fluent_shield_person_add_20_filled = 60126
ic_fluent_split_hint_20_filled = 60255
ic_fluent_squares_nested_20_filled = 60322
ic_fluent_stream_input_20_filled = 60352
ic_fluent_stream_input_output_20_filled = 60353
ic_fluent_stream_output_20_filled = 60354
ic_fluent_table_bottom_row_16_filled = 60405
ic_fluent_table_bottom_row_20_filled = 60406
ic_fluent_table_bottom_row_24_filled = 60407
ic_fluent_table_bottom_row_28_filled = 60408
ic_fluent_table_bottom_row_32_filled = 60409
ic_fluent_table_bottom_row_48_filled = 60410
ic_fluent_table_checker_20_filled = 60419
ic_fluent_table_copy_20_filled = 60420
ic_fluent_table_image_20_filled = 60446
ic_fluent_table_multiple_20_filled = 60477
ic_fluent_table_search_20_filled = 60486
ic_fluent_table_split_20_filled = 60495
ic_fluent_task_list_square_database_20_filled = 60566
ic_fluent_text_bullet_list_checkmark_20_filled = 60628
ic_fluent_text_bullet_list_dismiss_20_filled = 60629
ic_fluent_text_bullet_list_square_clock_20_filled = 60641
ic_fluent_text_bullet_list_square_person_20_filled = 60642
ic_fluent_text_bullet_list_square_search_20_filled = 60643
ic_fluent_text_bullet_list_square_settings_20_filled = 60644
ic_fluent_text_bullet_list_square_shield_20_filled = 60645
ic_fluent_text_bullet_list_square_toolbox_20_filled = 60646
ic_fluent_text_density_24_filled = 60673
ic_fluent_text_density_28_filled = 60674
ic_fluent_text_expand_20_filled = 60685
ic_fluent_timer_off_20_filled = 60814
ic_fluent_triangle_16_filled = 60837
ic_fluent_triangle_20_filled = 60838
ic_fluent_triangle_down_12_filled = 60841
ic_fluent_triangle_down_16_filled = 60842
ic_fluent_triangle_down_20_filled = 60843
ic_fluent_triangle_down_32_filled = 60844
ic_fluent_triangle_down_48_filled = 60845
ic_fluent_triangle_left_12_filled = 60846
ic_fluent_triangle_left_16_filled = 60847
ic_fluent_triangle_left_20_filled = 60848
ic_fluent_triangle_left_32_filled = 60849
ic_fluent_triangle_left_48_filled = 60850
ic_fluent_triangle_right_12_filled = 60851
ic_fluent_triangle_right_16_filled = 60852
ic_fluent_triangle_right_20_filled = 60853
ic_fluent_triangle_right_32_filled = 60854
ic_fluent_triangle_right_48_filled = 60855
ic_fluent_video_chat_28_filled = 60923
ic_fluent_video_chat_32_filled = 60924
ic_fluent_video_chat_48_filled = 60925
ic_fluent_virtual_network_20_filled = 60962
ic_fluent_virtual_network_toolbox_20_filled = 60963
ic_fluent_wallet_16_filled = 60971
ic_fluent_wallet_credit_card_16_filled = 60977
ic_fluent_wallet_credit_card_20_filled = 60978
ic_fluent_wallet_credit_card_24_filled = 60979
ic_fluent_wallet_credit_card_32_filled = 60980
ic_fluent_window_bullet_list_20_filled = 61037
ic_fluent_window_bullet_list_add_20_filled = 61038
ic_fluent_window_database_20_filled = 61040
ic_fluent_window_location_target_20_filled = 61047
ic_fluent_window_multiple_swap_20_filled = 61049
ic_fluent_window_play_20_filled = 61052
ic_fluent_window_settings_20_filled = 61053
ic_fluent_window_text_20_filled = 61054
ic_fluent_archive_arrow_back_16_filled = 57447
ic_fluent_archive_arrow_back_20_filled = 57448
ic_fluent_archive_arrow_back_24_filled = 57449
ic_fluent_archive_arrow_back_28_filled = 57450
ic_fluent_archive_arrow_back_32_filled = 57451
ic_fluent_archive_arrow_back_48_filled = 57452
ic_fluent_circle_multiple_subtract_checkmark_20_filled = 58192
ic_fluent_database_multiple_20_filled = 58490
ic_fluent_image_multiple_off_16_filled = 59191
ic_fluent_keyboard_16_filled = 59224
ic_fluent_lock_multiple_20_filled = 59296
ic_fluent_lottery_20_filled = 59302
ic_fluent_mail_warning_20_filled = 59366
ic_fluent_mail_warning_24_filled = 59367
ic_fluent_match_app_layout_20_filled = 59370
ic_fluent_math_format_linear_20_filled = 59371
ic_fluent_megaphone_off_16_filled = 59391
ic_fluent_megaphone_off_20_filled = 59392
ic_fluent_megaphone_off_28_filled = 59393
ic_fluent_merge_20_filled = 59397
ic_fluent_mic_off_32_filled = 59405
ic_fluent_mobile_optimized_20_filled = 59429
ic_fluent_network_check_20_filled = 59506
ic_fluent_note_add_28_filled = 59514
ic_fluent_note_add_48_filled = 59515
ic_fluent_notebook_sync_20_filled = 59531
ic_fluent_organization_horizontal_20_filled = 59564
ic_fluent_paint_brush_arrow_down_20_filled = 59573
ic_fluent_paint_brush_arrow_up_20_filled = 59575
ic_fluent_pentagon_20_filled = 59642
ic_fluent_person_accounts_20_filled = 59698
ic_fluent_person_subtract_20_filled = 59737
ic_fluent_pin_off_28_filled = 59800
ic_fluent_pin_off_32_filled = 59801
ic_fluent_point_scan_20_filled = 59823
ic_fluent_port_usb_a_20_filled = 59830
ic_fluent_question_circle_12_filled = 59893
ic_fluent_row_triple_20_filled = 59972
ic_fluent_scratchpad_20_filled = 60030
ic_fluent_shifts_availability_20_filled = 60137
ic_fluent_skip_forward_tab_20_filled = 60179
ic_fluent_sleep_20_filled = 60181
ic_fluent_slide_multiple_20_filled = 60197
ic_fluent_slide_multiple_arrow_right_20_filled = 60199
ic_fluent_slide_size_20_filled = 60206
ic_fluent_sound_wave_circle_20_filled = 60216
ic_fluent_sport_american_football_20_filled = 60273
ic_fluent_sport_baseball_20_filled = 60275
ic_fluent_sport_hockey_20_filled = 60279
ic_fluent_square_hint_arrow_back_20_filled = 60311
ic_fluent_square_shadow_20_filled = 60321
ic_fluent_tab_arrow_left_20_filled = 60385
ic_fluent_tab_prohibited_20_filled = 60394
ic_fluent_text_collapse_20_filled = 60658
ic_fluent_text_more_20_filled = 60728
ic_fluent_time_and_weather_20_filled = 60801
ic_fluent_transmission_20_filled = 60828
ic_fluent_video_play_pause_20_filled = 60954
ic_fluent_arrow_next_12_filled = 57565
ic_fluent_arrow_previous_12_filled = 57571
ic_fluent_data_usage_settings_20_filled = 58477
ic_fluent_document_multiple_sync_20_filled = 58674
ic_fluent_filter_12_filled = 58902
ic_fluent_history_28_filled = 59155
ic_fluent_history_32_filled = 59156
ic_fluent_history_48_filled = 59157
ic_fluent_history_dismiss_20_filled = 59158
ic_fluent_history_dismiss_24_filled = 59159
ic_fluent_history_dismiss_28_filled = 59160
ic_fluent_history_dismiss_32_filled = 59161
ic_fluent_history_dismiss_48_filled = 59162
ic_fluent_home_more_20_filled = 59171
ic_fluent_people_search_20_filled = 59673
ic_fluent_people_team_delete_16_filled = 59685
ic_fluent_people_team_delete_20_filled = 59686
ic_fluent_people_team_delete_28_filled = 59688
ic_fluent_people_team_delete_32_filled = 59689
ic_fluent_person_5_20_filled = 59694
ic_fluent_person_6_20_filled = 59696
ic_fluent_person_sync_24_filled = 59740
ic_fluent_phone_eraser_20_filled = 59759
ic_fluent_phone_shake_20_filled = 59770
ic_fluent_phone_speaker_20_filled = 59779
ic_fluent_radar_20_filled = 59896
ic_fluent_radar_checkmark_20_filled = 59897
ic_fluent_radar_rectangle_multiple_20_filled = 59898
ic_fluent_real_estate_20_filled = 59908
ic_fluent_resize_table_20_filled = 59939
ic_fluent_shifts_30_minutes_20_filled = 60134
ic_fluent_sound_source_20_filled = 60215
ic_fluent_subtitles_16_filled = 60357
ic_fluent_subtitles_20_filled = 60358
ic_fluent_subtitles_24_filled = 60359
ic_fluent_task_list_square_person_20_filled = 60569
ic_fluent_task_list_square_settings_20_filled = 60572
ic_fluent_timer_10_20_filled = 60804
ic_fluent_timer_2_20_filled = 60807
ic_fluent_timer_3_20_filled = 60810
ic_fluent_tree_deciduous_20_filled = 60834
ic_fluent_tree_evergreen_20_filled = 60835
ic_fluent_uninstall_app_20_filled = 60878
ic_fluent_alert_badge_16_filled = 57367
ic_fluent_alert_badge_20_filled = 57368
ic_fluent_alert_badge_24_filled = 57369
ic_fluent_archive_settings_28_filled = 57458
ic_fluent_arrow_between_up_20_filled = 57473
ic_fluent_arrow_fit_in_16_filled = 57550
ic_fluent_arrow_fit_in_20_filled = 57551
ic_fluent_arrow_forward_28_filled = 57552
ic_fluent_arrow_reply_28_filled = 57574
ic_fluent_arrow_reply_all_28_filled = 57575
ic_fluent_arrow_undo_28_filled = 57639
ic_fluent_branch_request_20_filled = 57848
ic_fluent_broom_28_filled = 57880
ic_fluent_bug_arrow_counterclockwise_20_filled = 57884
ic_fluent_bug_prohibited_20_filled = 57885
ic_fluent_calendar_multiple_28_filled = 57962
ic_fluent_call_add_16_filled = 57993
ic_fluent_call_dismiss_16_filled = 57997
ic_fluent_call_transfer_16_filled = 58022
ic_fluent_call_warning_16_filled = 58024
ic_fluent_call_warning_20_filled = 58025
ic_fluent_checkmark_square_20_filled = 58142
ic_fluent_circle_eraser_20_filled = 58187
ic_fluent_column_double_compare_20_filled = 58327
ic_fluent_comma_20_filled = 58333
ic_fluent_cube_arrow_curve_down_20_filled = 58428
ic_fluent_database_switch_20_filled = 58496
ic_fluent_document_data_20_filled = 58627
ic_fluent_folder_mail_24_filled = 58981
ic_fluent_folder_mail_28_filled = 58982
ic_fluent_gather_20_filled = 59041
ic_fluent_image_32_filled = 59174
ic_fluent_mail_attach_24_filled = 59324
ic_fluent_mail_attach_28_filled = 59325
ic_fluent_mail_prohibited_28_filled = 59358
ic_fluent_markdown_20_filled = 59369
ic_fluent_merge_16_filled = 59396
ic_fluent_notebook_arrow_curve_down_20_filled = 59522
ic_fluent_notebook_eye_20_filled = 59524
ic_fluent_person_sync_16_filled = 59738
ic_fluent_person_sync_20_filled = 59739
ic_fluent_person_sync_28_filled = 59741
ic_fluent_person_sync_32_filled = 59742
ic_fluent_person_sync_48_filled = 59743
ic_fluent_phone_key_20_filled = 59760
ic_fluent_phone_key_24_filled = 59761
ic_fluent_pipeline_arrow_curve_down_20_filled = 59805
ic_fluent_print_32_filled = 59861
ic_fluent_save_28_filled = 59980
ic_fluent_select_all_off_20_filled = 60046
ic_fluent_select_all_on_20_filled = 60047
ic_fluent_square_eraser_20_filled = 60301
ic_fluent_tab_desktop_multiple_bottom_20_filled = 60392
ic_fluent_tag_28_filled = 60523
ic_fluent_text_indent_decrease_rotate_270_24_filled = 60711
ic_fluent_text_indent_decrease_rotate_90_24_filled = 60713
ic_fluent_text_indent_increase_rotate_270_24_filled = 60721
ic_fluent_text_indent_increase_rotate_90_24_filled = 60723
ic_fluent_text_number_list_rotate_270_24_filled = 60732
ic_fluent_text_number_list_rotate_90_24_filled = 60734
ic_fluent_text_whole_word_20_filled = 60776
ic_fluent_time_picker_20_filled = 60802
ic_fluent_video_clip_off_16_filled = 60931
ic_fluent_video_clip_off_20_filled = 60932
ic_fluent_video_clip_off_24_filled = 60933
ic_fluent_wallpaper_20_filled = 60981
ic_fluent_warning_28_filled = 60988
ic_fluent_wifi_lock_20_filled = 61015
ic_fluent_alert_12_filled = 57363
ic_fluent_alert_48_filled = 57366
ic_fluent_alert_snooze_12_filled = 57371
ic_fluent_alert_snooze_16_filled = 57372
ic_fluent_arrow_autofit_content_20_filled = 57459
ic_fluent_arrow_split_16_filled = 57587
ic_fluent_arrow_split_24_filled = 57589
ic_fluent_catch_up_16_filled = 58049
ic_fluent_catch_up_20_filled = 58050
ic_fluent_catch_up_24_filled = 58051
ic_fluent_chess_20_filled = 58145
ic_fluent_circle_image_20_filled = 58189
ic_fluent_image_multiple_off_20_filled = 59192
ic_fluent_mic_pulse_16_filled = 59412
ic_fluent_mic_pulse_20_filled = 59413
ic_fluent_mic_pulse_24_filled = 59414
ic_fluent_mic_pulse_28_filled = 59415
ic_fluent_mic_pulse_32_filled = 59416
ic_fluent_mic_pulse_48_filled = 59417
ic_fluent_mic_pulse_off_16_filled = 59418
ic_fluent_mic_pulse_off_20_filled = 59419
ic_fluent_mic_pulse_off_24_filled = 59420
ic_fluent_mic_pulse_off_28_filled = 59421
ic_fluent_mic_pulse_off_32_filled = 59422
ic_fluent_mic_pulse_off_48_filled = 59423
ic_fluent_pause_28_filled = 59615
ic_fluent_pause_32_filled = 59616
ic_fluent_playing_cards_20_filled = 59818
ic_fluent_premium_person_16_filled = 59844
ic_fluent_quiz_new_20_filled = 59895
ic_fluent_save_copy_20_filled = 59983
ic_fluent_send_copy_20_filled = 60057
ic_fluent_slide_hide_20_filled = 60194
ic_fluent_slide_microphone_20_filled = 60195
ic_fluent_slide_search_20_filled = 60201
ic_fluent_sport_basketball_20_filled = 60277
ic_fluent_swipe_down_20_filled = 60375
ic_fluent_swipe_right_20_filled = 60376
ic_fluent_swipe_up_20_filled = 60377
ic_fluent_tabs_20_filled = 60521
ic_fluent_text_12_filled = 60587
ic_fluent_text_16_filled = 60588
ic_fluent_text_32_filled = 60589
ic_fluent_text_add_20_filled = 60590
ic_fluent_text_indent_decrease_rotate_270_20_filled = 60710
ic_fluent_text_indent_decrease_rotate_90_20_filled = 60712
ic_fluent_text_indent_increase_rotate_270_20_filled = 60720
ic_fluent_text_indent_increase_rotate_90_20_filled = 60722
ic_fluent_text_number_list_rotate_270_20_filled = 60731
ic_fluent_text_number_list_rotate_90_20_filled = 60733
ic_fluent_text_wrap_20_filled = 60777
ic_fluent_toggle_multiple_16_filled = 60820
ic_fluent_toggle_multiple_20_filled = 60821
ic_fluent_toggle_multiple_24_filled = 60822
ic_fluent_window_edit_20_filled = 61043
ic_fluent_zoom_fit_16_filled = 61067
ic_fluent_zoom_fit_20_filled = 61068
ic_fluent_zoom_fit_24_filled = 61069
ic_fluent_app_folder_16_filled = 57432
ic_fluent_app_folder_28_filled = 57433
ic_fluent_app_folder_32_filled = 57434
ic_fluent_app_folder_48_filled = 57435
ic_fluent_arrow_outline_up_right_20_filled = 57566
ic_fluent_arrow_outline_up_right_24_filled = 57567
ic_fluent_clipboard_32_filled = 58200
ic_fluent_clipboard_text_32_filled = 58234
ic_fluent_clipboard_text_edit_20_filled = 58235
ic_fluent_clipboard_text_edit_24_filled = 58236
ic_fluent_clipboard_text_edit_32_filled = 58237
ic_fluent_document_data_24_filled = 58628
ic_fluent_joystick_20_filled = 59213
ic_fluent_people_12_filled = 59645
ic_fluent_people_48_filled = 59647
ic_fluent_person_heart_24_filled = 59715
ic_fluent_port_micro_usb_20_filled = 59828
ic_fluent_port_usb_c_20_filled = 59832
ic_fluent_rss_20_filled = 59973
ic_fluent_scales_20_filled = 59992
ic_fluent_shifts_team_20_filled = 60146
ic_fluent_speaker_bluetooth_20_filled = 60240
ic_fluent_speaker_usb_20_filled = 60252
ic_fluent_text_align_center_rotate_270_16_filled = 60593
ic_fluent_text_align_center_rotate_270_20_filled = 60594
ic_fluent_text_align_center_rotate_90_16_filled = 60596
ic_fluent_text_align_center_rotate_90_20_filled = 60597
ic_fluent_text_align_center_rotate_90_24_filled = 60598
ic_fluent_text_align_justify_rotate_270_20_filled = 60605
ic_fluent_text_align_justify_rotate_270_24_filled = 60606
ic_fluent_text_align_justify_rotate_90_20_filled = 60607
ic_fluent_text_align_left_rotate_270_16_filled = 60610
ic_fluent_text_align_left_rotate_270_20_filled = 60611
ic_fluent_text_align_left_rotate_90_16_filled = 60613
ic_fluent_text_align_left_rotate_90_20_filled = 60614
ic_fluent_text_align_left_rotate_90_24_filled = 60615
ic_fluent_text_align_right_rotate_270_16_filled = 60617
ic_fluent_text_align_right_rotate_270_20_filled = 60618
ic_fluent_text_align_right_rotate_90_16_filled = 60620
ic_fluent_text_align_right_rotate_90_20_filled = 60621
ic_fluent_text_align_right_rotate_90_24_filled = 60622
ic_fluent_clipboard_text_ltr_32_filled = 58240
ic_fluent_braces_16_filled = 61072
ic_fluent_braces_28_filled = 61073
ic_fluent_braces_32_filled = 61074
ic_fluent_braces_48_filled = 61075
ic_fluent_branch_fork_32_filled = 61076
ic_fluent_calendar_data_bar_16_filled = 61077
ic_fluent_calendar_data_bar_20_filled = 61078
ic_fluent_calendar_data_bar_24_filled = 61079
ic_fluent_calendar_data_bar_28_filled = 61080
ic_fluent_clipboard_3_day_16_filled = 61081
ic_fluent_clipboard_3_day_20_filled = 61082
ic_fluent_clipboard_3_day_24_filled = 61083
ic_fluent_clipboard_day_16_filled = 61084
ic_fluent_clipboard_day_20_filled = 61085
ic_fluent_clipboard_day_24_filled = 61086
ic_fluent_clipboard_month_16_filled = 61087
ic_fluent_clipboard_month_20_filled = 61088
ic_fluent_clipboard_month_24_filled = 61089
ic_fluent_content_view_gallery_24_filled = 61090
ic_fluent_content_view_gallery_28_filled = 61091
ic_fluent_data_bar_vertical_16_filled = 61092
ic_fluent_delete_12_filled = 61093
ic_fluent_delete_32_filled = 61094
ic_fluent_form_20_filled = 61095
ic_fluent_form_24_filled = 61096
ic_fluent_form_28_filled = 61097
ic_fluent_form_48_filled = 61098
ic_fluent_mail_read_multiple_20_filled = 61099
ic_fluent_mail_read_multiple_32_filled = 61100
ic_fluent_megaphone_loud_16_filled = 61101
ic_fluent_panel_right_add_20_filled = 61102
ic_fluent_person_note_16_filled = 61103
ic_fluent_shield_globe_16_filled = 61104
ic_fluent_shield_globe_20_filled = 61105
ic_fluent_shield_globe_24_filled = 61106
ic_fluent_square_multiple_28_filled = 61107
ic_fluent_square_multiple_32_filled = 61108
ic_fluent_square_multiple_48_filled = 61109
ic_fluent_table_calculator_20_filled = 61110
ic_fluent_xbox_controller_16_filled = 61111
ic_fluent_xbox_controller_20_filled = 61112
ic_fluent_xbox_controller_24_filled = 61113
ic_fluent_xbox_controller_28_filled = 61114
ic_fluent_xbox_controller_32_filled = 61115
ic_fluent_xbox_controller_48_filled = 61116
ic_fluent_apps_32_filled = 61117
ic_fluent_arrow_paragraph_16_filled = 61118
ic_fluent_arrow_paragraph_24_filled = 61119
ic_fluent_beaker_32_filled = 61120
ic_fluent_building_retail_more_32_filled = 61122
ic_fluent_calendar_month_32_filled = 61123
ic_fluent_content_view_24_filled = 61124
ic_fluent_content_view_28_filled = 61125
ic_fluent_credit_card_clock_20_filled = 61126
ic_fluent_credit_card_clock_24_filled = 61127
ic_fluent_credit_card_clock_28_filled = 61128
ic_fluent_credit_card_clock_32_filled = 61129
ic_fluent_cube_32_filled = 61130
ic_fluent_data_bar_vertical_32_filled = 61131
ic_fluent_database_32_filled = 61132
ic_fluent_document_data_32_filled = 61133
ic_fluent_folder_people_20_filled = 61134
ic_fluent_folder_people_24_filled = 61135
ic_fluent_gauge_32_filled = 61136
ic_fluent_hand_left_chat_16_filled = 61137
ic_fluent_hand_left_chat_20_filled = 61138
ic_fluent_hand_left_chat_24_filled = 61139
ic_fluent_hand_left_chat_28_filled = 61140
ic_fluent_home_database_24_filled = 61141
ic_fluent_home_database_32_filled = 61142
ic_fluent_home_more_24_filled = 61143
ic_fluent_home_more_32_filled = 61144
ic_fluent_notebook_32_filled = 61145
ic_fluent_payment_32_filled = 61146
ic_fluent_payment_48_filled = 61147
ic_fluent_person_running_20_filled = 61148
ic_fluent_pipeline_24_filled = 61149
ic_fluent_pipeline_32_filled = 61150
ic_fluent_stack_32_filled = 61151
ic_fluent_text_align_justify_low_rotate_270_20_filled = 61152
ic_fluent_text_align_justify_low_rotate_270_24_filled = 61153
ic_fluent_text_align_justify_low_rotate_90_20_filled = 61154
ic_fluent_text_align_justify_low_rotate_90_24_filled = 61155
ic_fluent_animal_rabbit_32_filled = 61121
ic_fluent_animal_rabbit_off_20_filled = 61156
ic_fluent_animal_rabbit_off_32_filled = 61157
ic_fluent_beaker_off_20_filled = 61158
ic_fluent_beaker_off_32_filled = 61159
ic_fluent_bowl_salad_20_filled = 61160
ic_fluent_bowl_salad_24_filled = 61161
ic_fluent_building_retail_more_24_filled = 61162
ic_fluent_connected_16_filled = 61163
ic_fluent_connected_20_filled = 61164
ic_fluent_document_text_16_filled = 61165
ic_fluent_drink_bottle_20_filled = 61166
ic_fluent_drink_bottle_32_filled = 61167
ic_fluent_drink_bottle_off_20_filled = 61168
ic_fluent_drink_bottle_off_32_filled = 61169
ic_fluent_earth_32_filled = 61170
ic_fluent_earth_leaf_16_filled = 61171
ic_fluent_earth_leaf_20_filled = 61172
ic_fluent_earth_leaf_24_filled = 61173
ic_fluent_earth_leaf_32_filled = 61174
ic_fluent_feed_16_filled = 61175
ic_fluent_feed_20_filled = 61176
ic_fluent_feed_24_filled = 61177
ic_fluent_feed_28_filled = 61178
ic_fluent_filmstrip_20_filled = 61179
ic_fluent_filmstrip_24_filled = 61180
ic_fluent_food_carrot_20_filled = 61181
ic_fluent_food_carrot_24_filled = 61182
ic_fluent_food_fish_20_filled = 61183
ic_fluent_food_fish_24_filled = 61184
ic_fluent_hand_open_heart_20_filled = 61185
ic_fluent_hand_open_heart_32_filled = 61186
ic_fluent_hand_wave_16_filled = 61187
ic_fluent_hand_wave_20_filled = 61188
ic_fluent_hand_wave_24_filled = 61189
ic_fluent_handshake_32_filled = 61190
ic_fluent_leaf_one_32_filled = 61191
ic_fluent_leaf_two_32_filled = 61192
ic_fluent_notebook_16_filled = 61193
ic_fluent_person_heart_20_filled = 61194
ic_fluent_person_star_16_filled = 61195
ic_fluent_person_star_20_filled = 61196
ic_fluent_person_star_24_filled = 61197
ic_fluent_person_star_28_filled = 61198
ic_fluent_person_star_32_filled = 61199
ic_fluent_person_star_48_filled = 61200
ic_fluent_pipeline_add_32_filled = 61201
ic_fluent_recycle_20_filled = 61202
ic_fluent_recycle_32_filled = 61203
ic_fluent_reward_12_filled = 61204
ic_fluent_slide_link_20_filled = 61205
ic_fluent_slide_link_24_filled = 61206
ic_fluent_food_chicken_leg_16_filled = 61207
ic_fluent_food_chicken_leg_20_filled = 61208
ic_fluent_food_chicken_leg_24_filled = 61209
ic_fluent_food_chicken_leg_32_filled = 61210
ic_fluent_form_multiple_20_filled = 61211
ic_fluent_form_multiple_24_filled = 61212
ic_fluent_form_multiple_28_filled = 61213
ic_fluent_form_multiple_48_filled = 61214
ic_fluent_laser_tool_20_filled = 61215
ic_fluent_shield_32_filled = 61216
ic_fluent_shield_question_16_filled = 61217
ic_fluent_shield_question_20_filled = 61218
ic_fluent_shield_question_24_filled = 61219
ic_fluent_shield_question_32_filled = 61220
ic_fluent_heart_broken_24_filled = 61221
ic_fluent_layer_diagonal_20_filled = 61222
ic_fluent_layer_diagonal_person_20_filled = 61223
ic_fluent_text_wrap_16_filled = 61224
ic_fluent_text_wrap_off_16_filled = 61225
ic_fluent_text_wrap_off_20_filled = 61226
ic_fluent_text_wrap_off_24_filled = 61227
ic_fluent_trophy_lock_16_filled = 61228
ic_fluent_trophy_lock_20_filled = 61229
ic_fluent_trophy_lock_24_filled = 61230
ic_fluent_trophy_lock_28_filled = 61231
ic_fluent_trophy_lock_32_filled = 61232
ic_fluent_trophy_lock_48_filled = 61233
ic_fluent_arrow_repeat_1_16_filled = 61234
ic_fluent_arrow_repeat_1_20_filled = 61235
ic_fluent_arrow_repeat_1_24_filled = 61236
ic_fluent_arrow_shuffle_16_filled = 61237
ic_fluent_arrow_shuffle_20_filled = 61238
ic_fluent_arrow_shuffle_24_filled = 61239
ic_fluent_arrow_shuffle_28_filled = 61240
ic_fluent_arrow_shuffle_32_filled = 61241
ic_fluent_arrow_shuffle_48_filled = 61242
ic_fluent_arrow_shuffle_off_16_filled = 61243
ic_fluent_arrow_shuffle_off_20_filled = 61244
ic_fluent_arrow_shuffle_off_24_filled = 61245
ic_fluent_arrow_shuffle_off_28_filled = 61246
ic_fluent_arrow_shuffle_off_32_filled = 61247
ic_fluent_arrow_shuffle_off_48_filled = 61248
ic_fluent_building_desktop_16_filled = 61249
ic_fluent_building_desktop_20_filled = 61250
ic_fluent_building_desktop_24_filled = 61251
ic_fluent_calendar_empty_48_filled = 61252
ic_fluent_calendar_lock_16_filled = 61253
ic_fluent_calendar_lock_20_filled = 61254
ic_fluent_calendar_lock_24_filled = 61255
ic_fluent_calendar_lock_28_filled = 61256
ic_fluent_calendar_lock_32_filled = 61257
ic_fluent_calendar_lock_48_filled = 61258
ic_fluent_calendar_settings_24_filled = 61259
ic_fluent_calendar_settings_28_filled = 61260
ic_fluent_calendar_settings_32_filled = 61261
ic_fluent_calendar_settings_48_filled = 61262
ic_fluent_call_12_filled = 61263
ic_fluent_call_missed_12_filled = 61264
ic_fluent_chat_add_16_filled = 61265
ic_fluent_chat_add_20_filled = 61266
ic_fluent_chat_add_24_filled = 61267
ic_fluent_chat_add_28_filled = 61268
ic_fluent_chat_add_32_filled = 61269
ic_fluent_chat_add_48_filled = 61270
ic_fluent_chat_cursor_16_filled = 61271
ic_fluent_chat_cursor_20_filled = 61272
ic_fluent_chat_cursor_24_filled = 61273
ic_fluent_chat_empty_12_filled = 61274
ic_fluent_chat_empty_16_filled = 61275
ic_fluent_chat_empty_20_filled = 61276
ic_fluent_chat_empty_24_filled = 61277
ic_fluent_chat_empty_28_filled = 61278
ic_fluent_chat_empty_32_filled = 61279
ic_fluent_chat_empty_48_filled = 61280
ic_fluent_circle_image_16_filled = 61281
ic_fluent_circle_image_24_filled = 61282
ic_fluent_circle_image_28_filled = 61283
ic_fluent_code_text_16_filled = 61284
ic_fluent_desktop_checkmark_16_filled = 61285
ic_fluent_desktop_checkmark_20_filled = 61286
ic_fluent_desktop_checkmark_24_filled = 61287
ic_fluent_fire_16_filled = 61288
ic_fluent_fire_20_filled = 61289
ic_fluent_fire_24_filled = 61290
ic_fluent_hourglass_20_filled = 61291
ic_fluent_hourglass_24_filled = 61292
ic_fluent_hourglass_half_20_filled = 61293
ic_fluent_hourglass_half_24_filled = 61294
ic_fluent_hourglass_one_quarter_20_filled = 61295
ic_fluent_hourglass_one_quarter_24_filled = 61296
ic_fluent_hourglass_three_quarter_20_filled = 61297
ic_fluent_hourglass_three_quarter_24_filled = 61298
ic_fluent_ink_stroke_arrow_down_20_filled = 61299
ic_fluent_ink_stroke_arrow_down_24_filled = 61300
ic_fluent_ink_stroke_arrow_up_down_20_filled = 61301
ic_fluent_ink_stroke_arrow_up_down_24_filled = 61302
ic_fluent_megaphone_circle_20_filled = 61303
ic_fluent_megaphone_circle_24_filled = 61304
ic_fluent_person_alert_16_filled = 61329
ic_fluent_person_alert_20_filled = 61330
ic_fluent_person_alert_24_filled = 61331
ic_fluent_person_arrow_back_16_filled = 61332
ic_fluent_person_arrow_back_20_filled = 61333
ic_fluent_person_arrow_back_24_filled = 61334
ic_fluent_person_arrow_back_28_filled = 61335
ic_fluent_person_arrow_back_32_filled = 61336
ic_fluent_person_arrow_back_48_filled = 61337
ic_fluent_person_link_16_filled = 61338
ic_fluent_person_link_20_filled = 61339
ic_fluent_person_link_24_filled = 61340
ic_fluent_person_link_28_filled = 61341
ic_fluent_person_link_32_filled = 61342
ic_fluent_person_link_48_filled = 61343
ic_fluent_phone_28_filled = 61344
ic_fluent_phone_32_filled = 61345
ic_fluent_phone_48_filled = 61346
ic_fluent_phone_chat_16_filled = 61347
ic_fluent_phone_chat_20_filled = 61348
ic_fluent_phone_chat_24_filled = 61349
ic_fluent_phone_chat_28_filled = 61350
ic_fluent_premium_12_filled = 61351
ic_fluent_shield_add_16_filled = 61352
ic_fluent_shield_add_20_filled = 61353
ic_fluent_shield_add_24_filled = 61354
ic_fluent_sparkle_circle_20_filled = 61355
ic_fluent_sparkle_circle_24_filled = 61356
ic_fluent_task_list_square_ltr_16_filled = 61357
ic_fluent_task_list_square_rtl_16_filled = 61358
ic_fluent_text_direction_horizontal_ltr_20_filled = 61361
ic_fluent_text_direction_horizontal_ltr_24_filled = 61362
ic_fluent_text_direction_horizontal_rtl_20_filled = 61363
ic_fluent_text_direction_horizontal_rtl_24_filled = 61364
ic_fluent_text_direction_rotate_90_ltr_20_filled = 61365
ic_fluent_text_direction_rotate_90_ltr_24_filled = 61366
ic_fluent_text_direction_rotate_90_rtl_20_filled = 61367
ic_fluent_text_direction_rotate_90_rtl_24_filled = 61368
ic_fluent_app_generic_32_filled = 61369
ic_fluent_code_block_16_filled = 61370
ic_fluent_code_block_20_filled = 61371
ic_fluent_code_block_24_filled = 61372
ic_fluent_code_block_28_filled = 61373
ic_fluent_code_block_32_filled = 61374
ic_fluent_code_block_48_filled = 61375
ic_fluent_data_bar_vertical_star_16_filled = 61376
ic_fluent_data_bar_vertical_star_20_filled = 61377
ic_fluent_data_bar_vertical_star_24_filled = 61378
ic_fluent_data_bar_vertical_star_32_filled = 61379
ic_fluent_database_arrow_right_32_filled = 61380
ic_fluent_document_sync_32_filled = 61381
ic_fluent_equal_off_12_filled = 61382
ic_fluent_equal_off_16_filled = 61383
ic_fluent_eye_28_filled = 61384
ic_fluent_eye_32_filled = 61385
ic_fluent_eye_48_filled = 61386
ic_fluent_eye_lines_20_filled = 61387
ic_fluent_eye_lines_24_filled = 61388
ic_fluent_eye_lines_28_filled = 61389
ic_fluent_eye_lines_32_filled = 61390
ic_fluent_eye_lines_48_filled = 61391
ic_fluent_text_bullet_list_square_person_32_filled = 61395
ic_fluent_weather_snowflake_32_filled = 61396
ic_fluent_window_database_24_filled = 61397
ic_fluent_arrow_trending_12_filled = 61398
ic_fluent_building_people_16_filled = 61399
ic_fluent_building_people_20_filled = 61400
ic_fluent_building_people_24_filled = 61401
ic_fluent_cloud_error_16_filled = 61402
ic_fluent_cloud_error_20_filled = 61403
ic_fluent_cloud_error_24_filled = 61404
ic_fluent_cloud_error_28_filled = 61405
ic_fluent_cloud_error_32_filled = 61406
ic_fluent_cloud_error_48_filled = 61407
ic_fluent_couch_32_filled = 61408
ic_fluent_couch_48_filled = 61409
ic_fluent_database_arrow_right_24_filled = 61410
ic_fluent_dishwasher_20_filled = 61411
ic_fluent_dishwasher_24_filled = 61412
ic_fluent_dishwasher_32_filled = 61413
ic_fluent_dishwasher_48_filled = 61414
ic_fluent_elevator_20_filled = 61415
ic_fluent_elevator_24_filled = 61416
ic_fluent_elevator_32_filled = 61417
ic_fluent_feed_32_filled = 61418
ic_fluent_feed_48_filled = 61419
ic_fluent_fireplace_20_filled = 61420
ic_fluent_fireplace_24_filled = 61421
ic_fluent_fireplace_32_filled = 61422
ic_fluent_fireplace_48_filled = 61423
ic_fluent_mention_12_filled = 61424
ic_fluent_oven_20_filled = 61425
ic_fluent_oven_24_filled = 61426
ic_fluent_oven_32_filled = 61427
ic_fluent_oven_48_filled = 61428
ic_fluent_panel_left_32_filled = 61430
ic_fluent_panel_left_add_16_filled = 61431
ic_fluent_panel_left_add_20_filled = 61432
ic_fluent_panel_left_add_24_filled = 61433
ic_fluent_panel_left_add_28_filled = 61434
ic_fluent_panel_left_add_32_filled = 61435
ic_fluent_panel_left_add_48_filled = 61436
ic_fluent_panel_left_key_16_filled = 61437
ic_fluent_panel_left_key_20_filled = 61438
ic_fluent_panel_left_key_24_filled = 61439
ic_fluent_panel_right_32_filled = 61440
ic_fluent_status_12_filled = 61441
ic_fluent_vehicle_car_parking_20_filled = 61442
ic_fluent_vehicle_car_parking_24_filled = 61443
ic_fluent_vehicle_car_profile_ltr_24_filled = 61444
ic_fluent_vehicle_car_profile_rtl_24_filled = 61445
ic_fluent_washer_20_filled = 61446
ic_fluent_washer_24_filled = 61447
ic_fluent_washer_32_filled = 61448
ic_fluent_washer_48_filled = 61449
ic_fluent_accessibility_checkmark_28_filled = 61450
ic_fluent_accessibility_checkmark_32_filled = 61451
ic_fluent_accessibility_checkmark_48_filled = 61452
ic_fluent_add_circle_12_filled = 61453
ic_fluent_arrow_turn_down_right_20_filled = 61454
ic_fluent_arrow_turn_down_right_48_filled = 61455
ic_fluent_arrow_turn_down_up_20_filled = 61456
ic_fluent_arrow_turn_down_up_48_filled = 61457
ic_fluent_arrow_turn_left_down_20_filled = 61458
ic_fluent_arrow_turn_left_down_48_filled = 61459
ic_fluent_arrow_turn_left_right_20_filled = 61460
ic_fluent_arrow_turn_left_right_48_filled = 61461
ic_fluent_arrow_turn_left_up_20_filled = 61462
ic_fluent_arrow_turn_left_up_48_filled = 61463
ic_fluent_arrow_turn_right_48_filled = 61464
ic_fluent_arrow_turn_right_down_20_filled = 61465
ic_fluent_arrow_turn_right_down_48_filled = 61466
ic_fluent_arrow_turn_right_left_20_filled = 61467
ic_fluent_arrow_turn_right_left_48_filled = 61468
ic_fluent_arrow_turn_right_up_20_filled = 61469
ic_fluent_arrow_turn_right_up_48_filled = 61470
ic_fluent_arrow_turn_up_down_20_filled = 61471
ic_fluent_arrow_turn_up_down_48_filled = 61472
ic_fluent_arrow_turn_up_left_20_filled = 61473
ic_fluent_arrow_turn_up_left_48_filled = 61474
ic_fluent_building_townhouse_20_filled = 61475
ic_fluent_building_townhouse_24_filled = 61476
ic_fluent_building_townhouse_32_filled = 61477
ic_fluent_camera_sparkles_20_filled = 61478
ic_fluent_camera_sparkles_24_filled = 61479
ic_fluent_chat_bubbles_question_28_filled = 61482
ic_fluent_chat_bubbles_question_32_filled = 61483
ic_fluent_crop_16_filled = 61484
ic_fluent_crop_28_filled = 61485
ic_fluent_crop_32_filled = 61486
ic_fluent_crop_48_filled = 61487
ic_fluent_data_trending_28_filled = 61488
ic_fluent_data_trending_32_filled = 61489
ic_fluent_data_trending_48_filled = 61490
ic_fluent_document_database_20_filled = 61491
ic_fluent_document_database_24_filled = 61492
ic_fluent_earth_48_filled = 61493
ic_fluent_earth_leaf_48_filled = 61494
ic_fluent_elevator_48_filled = 61495
ic_fluent_home_split_20_filled = 61496
ic_fluent_home_split_24_filled = 61497
ic_fluent_home_split_32_filled = 61498
ic_fluent_home_split_48_filled = 61499
ic_fluent_leaf_two_48_filled = 61500
ic_fluent_panel_right_cursor_20_filled = 61501
ic_fluent_panel_right_cursor_24_filled = 61502
ic_fluent_person_board_28_filled = 61503
ic_fluent_person_board_32_filled = 61504
ic_fluent_person_circle_28_filled = 61505
ic_fluent_person_circle_32_filled = 61506
ic_fluent_person_square_20_filled = 61507
ic_fluent_person_square_24_filled = 61508
ic_fluent_person_starburst_20_filled = 61509
ic_fluent_person_starburst_24_filled = 61510
ic_fluent_receipt_sparkles_20_filled = 61511
ic_fluent_receipt_sparkles_24_filled = 61512
ic_fluent_ruler_28_filled = 61513
ic_fluent_ruler_32_filled = 61514
ic_fluent_ruler_48_filled = 61515
ic_fluent_scan_qr_code_24_filled = 61516
ic_fluent_showerhead_20_filled = 61517
ic_fluent_showerhead_24_filled = 61518
ic_fluent_showerhead_32_filled = 61519
ic_fluent_slide_text_multiple_16_filled = 61520
ic_fluent_slide_text_multiple_20_filled = 61521
ic_fluent_slide_text_multiple_24_filled = 61522
ic_fluent_slide_text_multiple_32_filled = 61523
ic_fluent_swimming_pool_20_filled = 61524
ic_fluent_swimming_pool_24_filled = 61525
ic_fluent_swimming_pool_32_filled = 61526
ic_fluent_swimming_pool_48_filled = 61527
ic_fluent_temperature_32_filled = 61528
ic_fluent_temperature_48_filled = 61529
ic_fluent_vehicle_car_32_filled = 61530
ic_fluent_vehicle_car_parking_16_filled = 61531
ic_fluent_vehicle_car_parking_32_filled = 61532
ic_fluent_vehicle_car_parking_48_filled = 61533
ic_fluent_vehicle_car_profile_ltr_clock_16_filled = 61534
ic_fluent_vehicle_car_profile_ltr_clock_20_filled = 61535
ic_fluent_vehicle_car_profile_ltr_clock_24_filled = 61536
ic_fluent_video_people_32_filled = 61537
ic_fluent_water_16_filled = 61538
ic_fluent_water_20_filled = 61539
ic_fluent_water_24_filled = 61540
ic_fluent_water_32_filled = 61541
ic_fluent_water_48_filled = 61542
ic_fluent_arrow_turn_down_left_20_filled = 61543
ic_fluent_arrow_turn_down_left_48_filled = 61544
ic_fluent_autosum_16_filled = 61545
ic_fluent_bubble_multiple_20_filled = 61546
ic_fluent_calculator_16_filled = 61547
ic_fluent_calculator_multiple_16_filled = 61548
ic_fluent_camera_sparkles_16_filled = 61549
ic_fluent_crown_16_filled = 61550
ic_fluent_crown_20_filled = 61551
ic_fluent_flag_checkered_20_filled = 61552
ic_fluent_glance_horizontal_16_filled = 61553
ic_fluent_glance_horizontal_sparkles_16_filled = 61554
ic_fluent_glance_horizontal_sparkles_24_filled = 61555
ic_fluent_grid_circles_24_filled = 61556
ic_fluent_grid_circles_28_filled = 61557
ic_fluent_heart_circle_hint_16_filled = 61558
ic_fluent_heart_circle_hint_20_filled = 61559
ic_fluent_heart_circle_hint_24_filled = 61560
ic_fluent_heart_circle_hint_28_filled = 61561
ic_fluent_heart_circle_hint_32_filled = 61562
ic_fluent_heart_circle_hint_48_filled = 61563
ic_fluent_lightbulb_28_filled = 61564
ic_fluent_lightbulb_32_filled = 61565
ic_fluent_lightbulb_48_filled = 61566
ic_fluent_lightbulb_person_16_filled = 61567
ic_fluent_lightbulb_person_20_filled = 61568
ic_fluent_lightbulb_person_24_filled = 61569
ic_fluent_lightbulb_person_28_filled = 61570
ic_fluent_lightbulb_person_32_filled = 61571
ic_fluent_lightbulb_person_48_filled = 61572
ic_fluent_megaphone_loud_28_filled = 61573
ic_fluent_megaphone_loud_32_filled = 61574
ic_fluent_person_walking_20_filled = 61575
ic_fluent_person_walking_24_filled = 61576
ic_fluent_receipt_16_filled = 61577
ic_fluent_receipt_28_filled = 61578
ic_fluent_receipt_sparkles_16_filled = 61579
ic_fluent_scan_text_16_filled = 61580
ic_fluent_scan_text_28_filled = 61581
ic_fluent_table_calculator_16_filled = 61582
ic_fluent_table_simple_checkmark_16_filled = 61583
ic_fluent_table_simple_checkmark_20_filled = 61584
ic_fluent_table_simple_checkmark_24_filled = 61585
ic_fluent_table_simple_checkmark_28_filled = 61586
ic_fluent_table_simple_checkmark_32_filled = 61587
ic_fluent_table_simple_checkmark_48_filled = 61588
ic_fluent_tabs_16_filled = 61589
ic_fluent_text_underline_double_20_filled = 61590
ic_fluent_text_underline_double_24_filled = 61591
ic_fluent_xbox_controller_error_20_filled = 61592
ic_fluent_xbox_controller_error_24_filled = 61593
ic_fluent_xbox_controller_error_32_filled = 61594
ic_fluent_xbox_controller_error_48_filled = 61595
ic_fluent_align_distribute_bottom_16_filled = 61596
ic_fluent_align_distribute_left_16_filled = 61597
ic_fluent_align_distribute_right_16_filled = 61598
ic_fluent_align_distribute_top_16_filled = 61599
ic_fluent_align_stretch_horizontal_16_filled = 61600
ic_fluent_align_stretch_vertical_16_filled = 61601
ic_fluent_arrow_next_16_filled = 61602
ic_fluent_arrow_previous_16_filled = 61603
ic_fluent_braces_checkmark_16_filled = 61604
ic_fluent_braces_dismiss_16_filled = 61605
ic_fluent_branch_16_filled = 61606
ic_fluent_calendar_arrow_counterclockwise_16_filled = 61607
ic_fluent_calendar_arrow_counterclockwise_20_filled = 61608
ic_fluent_calendar_arrow_counterclockwise_24_filled = 61609
ic_fluent_calendar_arrow_counterclockwise_28_filled = 61610
ic_fluent_calendar_arrow_counterclockwise_32_filled = 61611
ic_fluent_calendar_arrow_counterclockwise_48_filled = 61612
ic_fluent_calendar_play_16_filled = 61613
ic_fluent_calendar_play_20_filled = 61614
ic_fluent_calendar_play_24_filled = 61615
ic_fluent_calendar_play_28_filled = 61616
ic_fluent_calendar_shield_16_filled = 61617
ic_fluent_calendar_shield_20_filled = 61618
ic_fluent_calendar_shield_24_filled = 61619
ic_fluent_calendar_shield_28_filled = 61620
ic_fluent_calendar_shield_32_filled = 61621
ic_fluent_calendar_shield_48_filled = 61622
ic_fluent_call_transfer_24_filled = 61623
ic_fluent_call_transfer_32_filled = 61624
ic_fluent_camera_off_16_filled = 61625
ic_fluent_cd_16_filled = 61626
ic_fluent_certificate_16_filled = 61627
ic_fluent_clipboard_error_16_filled = 61628
ic_fluent_clipboard_multiple_16_filled = 61629
ic_fluent_clipboard_note_16_filled = 61630
ic_fluent_clipboard_task_16_filled = 61631
ic_fluent_clipboard_text_ltr_16_filled = 61632
ic_fluent_clipboard_text_rtl_16_filled = 61633
ic_fluent_cloud_add_24_filled = 61634
ic_fluent_cloud_edit_24_filled = 61635
ic_fluent_cloud_link_24_filled = 61636
ic_fluent_code_cs_16_filled = 61637
ic_fluent_code_cs_rectangle_16_filled = 61638
ic_fluent_code_fs_16_filled = 61639
ic_fluent_code_fs_rectangle_16_filled = 61640
ic_fluent_code_js_16_filled = 61641
ic_fluent_code_js_rectangle_16_filled = 61642
ic_fluent_code_py_16_filled = 61643
ic_fluent_code_py_rectangle_16_filled = 61644
ic_fluent_code_rb_16_filled = 61645
ic_fluent_code_rb_rectangle_16_filled = 61646
ic_fluent_code_text_off_16_filled = 61647
ic_fluent_code_ts_16_filled = 61648
ic_fluent_code_ts_rectangle_16_filled = 61649
ic_fluent_code_vb_16_filled = 61650
ic_fluent_code_vb_rectangle_16_filled = 61651
ic_fluent_cone_16_filled = 61652
ic_fluent_data_bar_horizontal_descending_16_filled = 61653
ic_fluent_data_bar_vertical_ascending_16_filled = 61654
ic_fluent_database_16_filled = 61655
ic_fluent_database_stack_16_filled = 61656
ic_fluent_developer_board_16_filled = 61657
ic_fluent_document_contract_16_filled = 61658
ic_fluent_document_cs_16_filled = 61659
ic_fluent_document_css_16_filled = 61660
ic_fluent_document_data_16_filled = 61661
ic_fluent_document_fs_16_filled = 61662
ic_fluent_document_js_16_filled = 61663
ic_fluent_document_number_1_16_filled = 61664
ic_fluent_document_py_16_filled = 61665
ic_fluent_document_rb_16_filled = 61666
ic_fluent_document_target_16_filled = 61667
ic_fluent_document_ts_16_filled = 61668
ic_fluent_document_vb_16_filled = 61669
ic_fluent_eyedropper_16_filled = 61670
ic_fluent_folder_multiple_16_filled = 61671
ic_fluent_folder_open_vertical_16_filled = 61672
ic_fluent_gantt_chart_16_filled = 61673
ic_fluent_hard_drive_16_filled = 61674
ic_fluent_hourglass_16_filled = 61675
ic_fluent_hourglass_half_16_filled = 61676
ic_fluent_hourglass_one_quarter_16_filled = 61677
ic_fluent_hourglass_three_quarter_16_filled = 61678
ic_fluent_keyboard_mouse_16_filled = 61679
ic_fluent_memory_16_filled = 61680
ic_fluent_more_circle_16_filled = 61681
ic_fluent_more_circle_24_filled = 61682
ic_fluent_more_circle_28_filled = 61683
ic_fluent_more_circle_48_filled = 61684
ic_fluent_network_adapter_16_filled = 61685
ic_fluent_people_star_16_filled = 61686
ic_fluent_people_star_20_filled = 61687
ic_fluent_people_star_24_filled = 61688
ic_fluent_people_star_28_filled = 61689
ic_fluent_people_star_32_filled = 61690
ic_fluent_people_star_48_filled = 61691
ic_fluent_person_search_16_filled = 61692
ic_fluent_person_search_32_filled = 61693
ic_fluent_person_standing_16_filled = 61694
ic_fluent_person_walking_16_filled = 61695
ic_fluent_play_multiple_16_filled = 61696
ic_fluent_radio_button_16_filled = 61779
ic_fluent_radio_button_off_16_filled = 61781
ic_fluent_ram_16_filled = 61905
ic_fluent_save_multiple_16_filled = 61906
ic_fluent_script_16_filled = 61915
ic_fluent_server_16_filled = 61916
ic_fluent_server_surface_16_filled = 61917
ic_fluent_server_surface_multiple_16_filled = 61958
ic_fluent_shield_12_filled = 61983
ic_fluent_slide_text_person_16_filled = 61999
ic_fluent_slide_text_person_20_filled = 62043
ic_fluent_slide_text_person_24_filled = 62044
ic_fluent_slide_text_person_28_filled = 62045
ic_fluent_slide_text_person_32_filled = 62046
ic_fluent_slide_text_person_48_filled = 62169
ic_fluent_spray_can_16_filled = 62170
ic_fluent_step_16_filled = 62183
ic_fluent_steps_16_filled = 62184
ic_fluent_table_lock_16_filled = 62185
ic_fluent_table_lock_20_filled = 62188
ic_fluent_table_lock_24_filled = 62189
ic_fluent_table_lock_28_filled = 62190
ic_fluent_table_lock_32_filled = 62210
ic_fluent_table_lock_48_filled = 62217
ic_fluent_text_t_tag_16_filled = 62246
ic_fluent_translate_16_filled = 62247
ic_fluent_video_person_32_filled = 62350
ic_fluent_video_person_clock_16_filled = 62354
ic_fluent_video_person_clock_20_filled = 62452
ic_fluent_video_person_clock_24_filled = 62453
ic_fluent_video_person_clock_28_filled = 62454
ic_fluent_video_person_clock_32_filled = 62455
ic_fluent_video_person_clock_48_filled = 62456
ic_fluent_voicemail_32_filled = 62457
ic_fluent_web_asset_16_filled = 62458
ic_fluent_chat_multiple_28_filled = 60633
ic_fluent_chat_multiple_32_filled = 60634
ic_fluent_document_landscape_split_hint_24_filled = 60635
ic_fluent_glance_12_filled = 60636
ic_fluent_location_arrow_left_20_filled = 61305
ic_fluent_location_arrow_right_20_filled = 61306
ic_fluent_location_arrow_up_20_filled = 61307
ic_fluent_notebook_section_arrow_right_20_filled = 61308
ic_fluent_person_search_20_filled = 61309
ic_fluent_person_search_24_filled = 61310
ic_fluent_re_order_20_filled = 61311
ic_fluent_text_add_t_20_filled = 61312
ic_fluent_text_align_justify_low_90_20_filled = 61313
ic_fluent_text_align_justify_low_90_24_filled = 61314
ic_fluent_text_bullet_list_ltr_90_20_filled = 61315
ic_fluent_text_bullet_list_ltr_90_24_filled = 61316
ic_fluent_text_bullet_list_ltr_rotate_270_24_filled = 61317
ic_fluent_text_bullet_list_rtl_90_20_filled = 61318
ic_fluent_text_description_ltr_20_filled = 61319
ic_fluent_text_description_ltr_24_filled = 61320
ic_fluent_text_description_rtl_20_filled = 61321
ic_fluent_text_description_rtl_24_filled = 61322
ic_fluent_text_indent_decrease_ltr_90_20_filled = 61323
ic_fluent_text_indent_decrease_ltr_90_24_filled = 61324
ic_fluent_text_indent_decrease_ltr_rotate_270_20_filled = 61325
ic_fluent_text_indent_decrease_ltr_rotate_270_24_filled = 61326
ic_fluent_text_indent_decrease_rtl_90_20_filled = 61327
ic_fluent_text_indent_decrease_rtl_90_24_filled = 61328
ic_fluent_text_indent_decrease_rtl_rotate_270_20_filled = 61359
ic_fluent_text_indent_decrease_rtl_rotate_270_24_filled = 61360
ic_fluent_text_indent_increase_ltr_90_20_filled = 61392
ic_fluent_text_indent_increase_ltr_90_24_filled = 61393
ic_fluent_text_indent_increase_ltr_rotate_270_20_filled = 61394
ic_fluent_text_indent_increase_ltr_rotate_270_24_filled = 61429
ic_fluent_text_indent_increase_rtl_90_20_filled = 61480
ic_fluent_text_indent_increase_rtl_90_24_filled = 61481
ic_fluent_text_indent_increase_rtl_rotate_270_20_filled = 62459
ic_fluent_text_indent_increase_rtl_rotate_270_24_filled = 62488
ic_fluent_text_number_list_ltr_90_20_filled = 62489
ic_fluent_text_number_list_ltr_90_24_filled = 62650
ic_fluent_text_number_list_ltr_rotate_270_20_filled = 62741
ic_fluent_text_number_list_ltr_rotate_270_24_filled = 62742
ic_fluent_text_number_list_rtl_90_20_filled = 62797
ic_fluent_text_number_list_rtl_90_24_filled = 62798
ic_fluent_text_number_list_rtl_rotate_270_20_filled = 62799
ic_fluent_text_number_list_rtl_rotate_270_24_filled = 62800
ic_fluent_text_t_12_filled = 62801
ic_fluent_text_t_16_filled = 62821
ic_fluent_text_t_32_filled = 62822
ic_fluent_textbox_settings_20_filled = 62857
ic_fluent_textbox_settings_24_filled = 62858
ic_fluent_voicemail_subtract_20_filled = 62871
ic_fluent_add_32_filled = 62882
ic_fluent_add_48_filled = 62883
ic_fluent_apps_48_filled = 62884
ic_fluent_arrow_trending_sparkle_20_filled = 62885
ic_fluent_arrow_trending_sparkle_24_filled = 62886
ic_fluent_bluetooth_16_filled = 62887
ic_fluent_bluetooth_32_filled = 63098
ic_fluent_bluetooth_48_filled = 63150
ic_fluent_bot_sparkle_20_filled = 63151
ic_fluent_bot_sparkle_24_filled = 63152
ic_fluent_box_search_16_filled = 63208
ic_fluent_building_32_filled = 63209
ic_fluent_building_48_filled = 63210
ic_fluent_calendar_error_16_filled = 63216
ic_fluent_call_forward_32_filled = 63403
ic_fluent_chat_multiple_heart_16_filled = 63404
ic_fluent_chat_multiple_heart_20_filled = 63463
ic_fluent_chat_multiple_heart_24_filled = 63464
ic_fluent_chat_multiple_heart_28_filled = 63465
ic_fluent_chat_multiple_heart_32_filled = 63466
ic_fluent_chat_sparkle_16_filled = 63467
ic_fluent_chat_sparkle_20_filled = 63468
ic_fluent_chat_sparkle_24_filled = 63469
ic_fluent_chat_sparkle_28_filled = 63470
ic_fluent_chat_sparkle_32_filled = 63498
ic_fluent_chat_sparkle_48_filled = 63499
ic_fluent_clipboard_checkmark_16_filled = 63538
ic_fluent_clock_lock_16_filled = 63539
ic_fluent_clock_lock_20_filled = 63573
ic_fluent_clock_lock_24_filled = 63574
ic_fluent_clover_16_filled = 63692
ic_fluent_clover_20_filled = 983040
ic_fluent_clover_24_filled = 983041
ic_fluent_clover_28_filled = 983042
ic_fluent_clover_32_filled = 983043
ic_fluent_clover_48_filled = 983044
ic_fluent_comment_link_16_filled = 983045
ic_fluent_comment_link_20_filled = 983046
ic_fluent_comment_link_24_filled = 983047
ic_fluent_comment_link_28_filled = 983048
ic_fluent_comment_link_48_filled = 983049
ic_fluent_copy_32_filled = 983050
ic_fluent_copy_select_24_filled = 983051
ic_fluent_database_48_filled = 983052
ic_fluent_database_multiple_32_filled = 983053
ic_fluent_device_eq_16_filled = 983054
ic_fluent_document_100_16_filled = 983055
ic_fluent_document_100_20_filled = 983056
ic_fluent_document_100_24_filled = 983057
ic_fluent_document_border_20_filled = 983058
ic_fluent_document_border_24_filled = 983059
ic_fluent_document_border_32_filled = 983060
ic_fluent_document_border_print_20_filled = 983061
ic_fluent_document_border_print_24_filled = 983062
ic_fluent_document_border_print_32_filled = 983063
ic_fluent_document_bullet_list_16_filled = 983064
ic_fluent_document_bullet_list_arrow_left_16_filled = 983065
ic_fluent_document_bullet_list_arrow_left_20_filled = 983066
ic_fluent_document_bullet_list_arrow_left_24_filled = 983067
ic_fluent_document_bullet_list_cube_16_filled = 983068
ic_fluent_document_bullet_list_cube_20_filled = 983069
ic_fluent_document_bullet_list_cube_24_filled = 983070
ic_fluent_document_data_link_16_filled = 983071
ic_fluent_document_data_link_20_filled = 983072
ic_fluent_document_data_link_24_filled = 983073
ic_fluent_document_data_link_32_filled = 983074
ic_fluent_document_fit_16_filled = 983075
ic_fluent_document_fit_20_filled = 983076
ic_fluent_document_fit_24_filled = 983077
ic_fluent_document_folder_16_filled = 983078
ic_fluent_document_folder_20_filled = 983079
ic_fluent_document_folder_24_filled = 983080
ic_fluent_document_one_page_16_filled = 983081
ic_fluent_document_one_page_add_16_filled = 983082
ic_fluent_document_one_page_add_20_filled = 983083
ic_fluent_document_one_page_add_24_filled = 983084
ic_fluent_document_one_page_columns_20_filled = 983085
ic_fluent_document_one_page_columns_24_filled = 983086
ic_fluent_document_one_page_link_16_filled = 983087
ic_fluent_document_one_page_link_20_filled = 983088
ic_fluent_document_one_page_link_24_filled = 983089
ic_fluent_document_print_20_filled = 983090
ic_fluent_document_print_24_filled = 983091
ic_fluent_document_print_28_filled = 983092
ic_fluent_document_print_32_filled = 983093
ic_fluent_document_print_48_filled = 983094
ic_fluent_emoji_angry_16_filled = 983095
ic_fluent_emoji_hand_16_filled = 983096
ic_fluent_emoji_meh_16_filled = 983097
ic_fluent_filmstrip_16_filled = 983098
ic_fluent_filmstrip_32_filled = 983099
ic_fluent_filmstrip_play_16_filled = 983100
ic_fluent_filmstrip_play_20_filled = 983101
ic_fluent_filmstrip_play_24_filled = 983102
ic_fluent_filmstrip_play_32_filled = 983103
ic_fluent_flag_32_filled = 983104
ic_fluent_flag_clock_16_filled = 983105
ic_fluent_flag_clock_20_filled = 983106
ic_fluent_flag_clock_24_filled = 983107
ic_fluent_flag_clock_28_filled = 983108
ic_fluent_flag_clock_32_filled = 983109
ic_fluent_flag_clock_48_filled = 983110
ic_fluent_glasses_32_filled = 983111
ic_fluent_glasses_off_32_filled = 983112
ic_fluent_globe_surface_32_filled = 983113
ic_fluent_home_more_48_filled = 983114
ic_fluent_image_border_16_filled = 983115
ic_fluent_image_border_20_filled = 983116
ic_fluent_image_border_24_filled = 983117
ic_fluent_image_border_28_filled = 983118
ic_fluent_image_border_32_filled = 983119
ic_fluent_image_border_48_filled = 983120
ic_fluent_image_circle_16_filled = 983121
ic_fluent_image_circle_20_filled = 983122
ic_fluent_image_circle_24_filled = 983123
ic_fluent_image_circle_28_filled = 983124
ic_fluent_image_circle_32_filled = 983125
ic_fluent_image_circle_48_filled = 983126
ic_fluent_image_table_16_filled = 983127
ic_fluent_image_table_20_filled = 983128
ic_fluent_image_table_24_filled = 983129
ic_fluent_image_table_28_filled = 983130
ic_fluent_image_table_32_filled = 983131
ic_fluent_image_table_48_filled = 983132
ic_fluent_info_32_filled = 983133
ic_fluent_info_48_filled = 983134
ic_fluent_iot_16_filled = 983135
ic_fluent_iot_alert_16_filled = 983136
ic_fluent_iot_alert_20_filled = 983137
ic_fluent_iot_alert_24_filled = 983138
ic_fluent_line_horizontal_4_20_filled = 983139
ic_fluent_line_horizontal_4_search_20_filled = 983140
ic_fluent_line_thickness_20_filled = 983141
ic_fluent_line_thickness_24_filled = 983142
ic_fluent_location_arrow_12_filled = 983143
ic_fluent_location_arrow_16_filled = 983144
ic_fluent_location_arrow_20_filled = 983145
ic_fluent_location_arrow_24_filled = 983146
ic_fluent_location_arrow_28_filled = 983147
ic_fluent_location_arrow_32_filled = 983148
ic_fluent_location_arrow_48_filled = 983149
ic_fluent_location_arrow_left_16_filled = 983150
ic_fluent_location_arrow_right_16_filled = 983151
ic_fluent_location_arrow_up_16_filled = 983152
ic_fluent_mail_arrow_double_back_24_filled = 983153
ic_fluent_mail_checkmark_24_filled = 983154
ic_fluent_mail_unread_12_filled = 983155
ic_fluent_map_16_filled = 983156
ic_fluent_mention_32_filled = 983157
ic_fluent_mention_48_filled = 983158
ic_fluent_panel_left_header_16_filled = 983159
ic_fluent_panel_left_header_20_filled = 983160
ic_fluent_panel_left_header_24_filled = 983161
ic_fluent_panel_left_header_28_filled = 983162
ic_fluent_panel_left_header_32_filled = 983163
ic_fluent_panel_left_header_48_filled = 983164
ic_fluent_panel_left_header_add_16_filled = 983165
ic_fluent_panel_left_header_add_20_filled = 983166
ic_fluent_panel_left_header_add_24_filled = 983167
ic_fluent_panel_left_header_add_28_filled = 983168
ic_fluent_panel_left_header_add_32_filled = 983169
ic_fluent_panel_left_header_add_48_filled = 983170
ic_fluent_panel_left_header_key_16_filled = 983171
ic_fluent_panel_left_header_key_20_filled = 983172
ic_fluent_panel_left_header_key_24_filled = 983173
ic_fluent_people_call_24_filled = 983174
ic_fluent_people_community_32_filled = 983175
ic_fluent_people_community_48_filled = 983176
ic_fluent_person_feedback_28_filled = 983177
ic_fluent_person_feedback_32_filled = 983178
ic_fluent_person_feedback_48_filled = 983179
ic_fluent_phone_desktop_32_filled = 983180
ic_fluent_phone_desktop_48_filled = 983181
ic_fluent_play_circle_hint_16_filled = 983182
ic_fluent_play_circle_hint_20_filled = 983183
ic_fluent_play_circle_hint_24_filled = 983184
ic_fluent_poll_horizontal_16_filled = 983185
ic_fluent_poll_horizontal_20_filled = 983186
ic_fluent_poll_horizontal_24_filled = 983187
ic_fluent_projection_screen_text_24_filled = 983188
ic_fluent_receipt_32_filled = 983189
ic_fluent_receipt_money_16_filled = 983190
ic_fluent_send_32_filled = 983191
ic_fluent_send_48_filled = 983192
ic_fluent_service_bell_16_filled = 983193
ic_fluent_shifts_activity_16_filled = 983194
ic_fluent_slash_forward_12_filled = 983195
ic_fluent_slash_forward_16_filled = 983196
ic_fluent_slash_forward_20_filled = 983197
ic_fluent_slash_forward_24_filled = 983198
ic_fluent_space_3d_16_filled = 983199
ic_fluent_space_3d_20_filled = 983200
ic_fluent_space_3d_24_filled = 983201
ic_fluent_space_3d_28_filled = 983202
ic_fluent_space_3d_32_filled = 983203
ic_fluent_space_3d_48_filled = 983204
ic_fluent_sparkle_32_filled = 983205
ic_fluent_sparkle_circle_16_filled = 983206
ic_fluent_sparkle_circle_28_filled = 983207
ic_fluent_sparkle_circle_32_filled = 983208
ic_fluent_sparkle_circle_48_filled = 983209
ic_fluent_star_arrow_back_16_filled = 983210
ic_fluent_star_arrow_back_20_filled = 983211
ic_fluent_star_arrow_back_24_filled = 983212
ic_fluent_table_simple_multiple_20_filled = 983213
ic_fluent_table_simple_multiple_24_filled = 983214
ic_fluent_text_abc_underline_double_32_filled = 983215
ic_fluent_text_column_one_semi_narrow_20_filled = 983216
ic_fluent_text_column_one_semi_narrow_24_filled = 983217
ic_fluent_text_expand_16_filled = 983218
ic_fluent_text_position_square_left_16_filled = 983219
ic_fluent_text_position_square_left_20_filled = 983220
ic_fluent_text_position_square_left_24_filled = 983221
ic_fluent_text_position_square_right_16_filled = 983222
ic_fluent_text_position_square_right_20_filled = 983223
ic_fluent_text_position_square_right_24_filled = 983224
ic_fluent_text_underline_character_u_16_filled = 983225
ic_fluent_text_underline_character_u_20_filled = 983226
ic_fluent_text_underline_character_u_24_filled = 983227
ic_fluent_translate_off_16_filled = 983228
ic_fluent_translate_off_20_filled = 983229
ic_fluent_translate_off_24_filled = 983230
ic_fluent_video_background_effect_16_filled = 983231
ic_fluent_video_background_effect_28_filled = 983232
ic_fluent_video_background_effect_32_filled = 983233
ic_fluent_video_background_effect_48_filled = 983234
ic_fluent_video_background_effect_horizontal_16_filled = 983235
ic_fluent_video_background_effect_horizontal_20_filled = 983236
ic_fluent_video_background_effect_horizontal_24_filled = 983237
ic_fluent_video_background_effect_horizontal_28_filled = 983238
ic_fluent_video_background_effect_horizontal_32_filled = 983239
ic_fluent_video_background_effect_horizontal_48_filled = 983240
ic_fluent_video_clip_28_filled = 983241
ic_fluent_video_clip_32_filled = 983242
ic_fluent_video_clip_48_filled = 983243
ic_fluent_voicemail_48_filled = 983244
ic_fluent_arrow_circle_up_right_20_filled = 983245
ic_fluent_arrow_circle_up_right_24_filled = 983246
ic_fluent_backspace_16_filled = 983247
ic_fluent_binder_triangle_20_filled = 983248
ic_fluent_binder_triangle_24_filled = 983249
ic_fluent_binder_triangle_32_filled = 983250
ic_fluent_bow_tie_20_filled = 983251
ic_fluent_bow_tie_24_filled = 983252
ic_fluent_circle_28_filled = 983253
ic_fluent_document_one_page_sparkle_16_filled = 983254
ic_fluent_document_one_page_sparkle_20_filled = 983255
ic_fluent_document_one_page_sparkle_24_filled = 983256
ic_fluent_emoji_hand_32_filled = 983257
ic_fluent_emoji_hand_48_filled = 983258
ic_fluent_frame_16_filled = 983259
ic_fluent_frame_20_filled = 983260
ic_fluent_frame_24_filled = 983261
ic_fluent_lock_closed_key_16_filled = 983262
ic_fluent_lock_closed_key_20_filled = 983263
ic_fluent_lock_closed_key_24_filled = 983264
ic_fluent_mountain_location_bottom_20_filled = 983265
ic_fluent_mountain_location_bottom_24_filled = 983266
ic_fluent_mountain_location_bottom_28_filled = 983267
ic_fluent_mountain_location_top_20_filled = 983268
ic_fluent_mountain_location_top_24_filled = 983269
ic_fluent_mountain_location_top_28_filled = 983270
ic_fluent_mountain_trail_20_filled = 983271
ic_fluent_mountain_trail_24_filled = 983272
ic_fluent_mountain_trail_28_filled = 983273
ic_fluent_pen_dismiss_16_filled = 983274
ic_fluent_pen_dismiss_20_filled = 983275
ic_fluent_pen_dismiss_24_filled = 983276
ic_fluent_pen_dismiss_28_filled = 983277
ic_fluent_pen_dismiss_32_filled = 983278
ic_fluent_pen_dismiss_48_filled = 983279
ic_fluent_phone_edit_20_filled = 983280
ic_fluent_phone_edit_24_filled = 983281
ic_fluent_send_beaker_16_filled = 983282
ic_fluent_send_beaker_20_filled = 983283
ic_fluent_send_beaker_24_filled = 983284
ic_fluent_send_beaker_28_filled = 983285
ic_fluent_send_beaker_32_filled = 983286
ic_fluent_send_beaker_48_filled = 983287
ic_fluent_slide_text_sparkle_16_filled = 983288
ic_fluent_slide_text_sparkle_20_filled = 983289
ic_fluent_slide_text_sparkle_24_filled = 983290
ic_fluent_slide_text_sparkle_28_filled = 983291
ic_fluent_slide_text_sparkle_32_filled = 983292
ic_fluent_slide_text_sparkle_48_filled = 983293
ic_fluent_stack_vertical_20_filled = 983294
ic_fluent_stack_vertical_24_filled = 983295
ic_fluent_table_column_top_bottom_20_filled = 983296
ic_fluent_table_column_top_bottom_24_filled = 983297
ic_fluent_table_offset_20_filled = 983298
ic_fluent_table_offset_24_filled = 983299
ic_fluent_table_offset_add_20_filled = 983300
ic_fluent_table_offset_add_24_filled = 983301
ic_fluent_table_offset_less_than_or_equal_to_20_filled = 983302
ic_fluent_table_offset_less_than_or_equal_to_24_filled = 983303
ic_fluent_table_offset_settings_20_filled = 983304
ic_fluent_table_offset_settings_24_filled = 983305
ic_fluent_vehicle_cable_car_20_filled = 983306
ic_fluent_vehicle_cable_car_24_filled = 983307
ic_fluent_vehicle_cable_car_28_filled = 983308
ic_fluent_arrow_autofit_height_in_20_filled = 983309
ic_fluent_arrow_autofit_height_in_24_filled = 983310
ic_fluent_circle_hint_16_filled = 983311
ic_fluent_circle_hint_20_filled = 983312
ic_fluent_cloud_database_20_filled = 983313
ic_fluent_cloud_desktop_20_filled = 983314
ic_fluent_code_circle_24_filled = 983315
ic_fluent_code_circle_32_filled = 983316
ic_fluent_column_single_16_filled = 983317
ic_fluent_desktop_arrow_down_16_filled = 983318
ic_fluent_desktop_arrow_down_20_filled = 983319
ic_fluent_desktop_arrow_down_24_filled = 983320
ic_fluent_desktop_tower_20_filled = 983321
ic_fluent_desktop_tower_24_filled = 983322
ic_fluent_document_checkmark_16_filled = 983323
ic_fluent_document_key_20_filled = 983324
ic_fluent_dust_20_filled = 983325
ic_fluent_dust_24_filled = 983326
ic_fluent_dust_28_filled = 983327
ic_fluent_edit_arrow_back_24_filled = 983328
ic_fluent_emoji_hint_16_filled = 983329
ic_fluent_emoji_hint_20_filled = 983330
ic_fluent_emoji_hint_24_filled = 983331
ic_fluent_emoji_hint_28_filled = 983332
ic_fluent_emoji_hint_32_filled = 983333
ic_fluent_emoji_hint_48_filled = 983334
ic_fluent_folder_list_16_filled = 983335
ic_fluent_folder_list_20_filled = 983336
ic_fluent_lightbulb_checkmark_20_filled = 983337
ic_fluent_line_horizontal_4_16_filled = 983338
ic_fluent_line_horizontal_4_search_16_filled = 983339
ic_fluent_math_format_professional_16_filled = 983340
ic_fluent_mold_20_filled = 983341
ic_fluent_mold_24_filled = 983342
ic_fluent_mold_28_filled = 983343
ic_fluent_people_team_48_filled = 983344
ic_fluent_person_desktop_20_filled = 983345
ic_fluent_person_ribbon_16_filled = 983346
ic_fluent_person_ribbon_20_filled = 983347
ic_fluent_person_wrench_20_filled = 983348
ic_fluent_plant_grass_20_filled = 983349
ic_fluent_plant_grass_24_filled = 983350
ic_fluent_plant_grass_28_filled = 983351
ic_fluent_plant_ragweed_20_filled = 983352
ic_fluent_plant_ragweed_24_filled = 983353
ic_fluent_plant_ragweed_28_filled = 983354
ic_fluent_settings_cog_multiple_20_filled = 983355
ic_fluent_settings_cog_multiple_24_filled = 983356
ic_fluent_slide_content_24_filled = 983357
ic_fluent_slide_record_16_filled = 983358
ic_fluent_slide_record_20_filled = 983359
ic_fluent_slide_record_24_filled = 983360
ic_fluent_slide_record_28_filled = 983361
ic_fluent_slide_record_48_filled = 983362
ic_fluent_stack_add_20_filled = 983363
ic_fluent_stack_add_24_filled = 983364
ic_fluent_star_checkmark_16_filled = 983365
ic_fluent_star_checkmark_20_filled = 983366
ic_fluent_star_checkmark_24_filled = 983367
ic_fluent_star_checkmark_28_filled = 983368
ic_fluent_stream_32_filled = 983369
ic_fluent_subtract_square_16_filled = 983370
ic_fluent_table_default_32_filled = 983371
ic_fluent_table_simple_32_filled = 983372
ic_fluent_table_simple_exclude_16_filled = 983373
ic_fluent_table_simple_exclude_20_filled = 983374
ic_fluent_table_simple_exclude_24_filled = 983375
ic_fluent_table_simple_exclude_28_filled = 983376
ic_fluent_table_simple_exclude_32_filled = 983377
ic_fluent_table_simple_exclude_48_filled = 983378
ic_fluent_table_simple_include_16_filled = 983379
ic_fluent_table_simple_include_20_filled = 983380
ic_fluent_table_simple_include_24_filled = 983381
ic_fluent_table_simple_include_28_filled = 983382
ic_fluent_table_simple_include_32_filled = 983383
ic_fluent_table_simple_include_48_filled = 983384
ic_fluent_tablet_laptop_20_filled = 983385
ic_fluent_textbox_align_middle_16_filled = 983386
ic_fluent_tree_deciduous_24_filled = 983387
ic_fluent_tree_deciduous_28_filled = 983388
ic_fluent_app_generic_48_filled = 983389
ic_fluent_arrow_enter_16_filled = 983390
ic_fluent_arrow_sprint_16_filled = 983391
ic_fluent_arrow_sprint_20_filled = 983392
ic_fluent_beaker_settings_16_filled = 983393
ic_fluent_beaker_settings_20_filled = 983394
ic_fluent_binder_triangle_16_filled = 983395
ic_fluent_book_default_20_filled = 983396
ic_fluent_book_dismiss_16_filled = 983397
ic_fluent_book_dismiss_20_filled = 983398
ic_fluent_button_16_filled = 983399
ic_fluent_button_20_filled = 983400
ic_fluent_card_ui_20_filled = 983401
ic_fluent_card_ui_24_filled = 983402
ic_fluent_chevron_down_up_16_filled = 983403
ic_fluent_chevron_down_up_20_filled = 983404
ic_fluent_chevron_down_up_24_filled = 983405
ic_fluent_column_single_compare_16_filled = 983406
ic_fluent_column_single_compare_20_filled = 983407
ic_fluent_crop_sparkle_24_filled = 983408
ic_fluent_cursor_16_filled = 983409
ic_fluent_cursor_prohibited_16_filled = 983410
ic_fluent_cursor_prohibited_20_filled = 983411
ic_fluent_data_histogram_16_filled = 983412
ic_fluent_document_image_16_filled = 983413
ic_fluent_document_image_20_filled = 983414
ic_fluent_document_java_16_filled = 983415
ic_fluent_document_java_20_filled = 983416
ic_fluent_document_one_page_beaker_16_filled = 983417
ic_fluent_document_one_page_multiple_16_filled = 983418
ic_fluent_document_one_page_multiple_20_filled = 983419
ic_fluent_document_one_page_multiple_24_filled = 983420
ic_fluent_document_sass_16_filled = 983421
ic_fluent_document_sass_20_filled = 983422
ic_fluent_document_yml_16_filled = 983423
ic_fluent_document_yml_20_filled = 983424
ic_fluent_filmstrip_split_16_filled = 983425
ic_fluent_filmstrip_split_20_filled = 983426
ic_fluent_filmstrip_split_24_filled = 983427
ic_fluent_filmstrip_split_32_filled = 983428
ic_fluent_gavel_16_filled = 983429
ic_fluent_gavel_prohibited_16_filled = 983430
ic_fluent_gavel_prohibited_20_filled = 983431
ic_fluent_gift_open_16_filled = 983432
ic_fluent_gift_open_20_filled = 983433
ic_fluent_gift_open_24_filled = 983434
ic_fluent_globe_12_filled = 983435
ic_fluent_grid_kanban_16_filled = 983436
ic_fluent_image_stack_16_filled = 983437
ic_fluent_image_stack_20_filled = 983438
ic_fluent_laptop_shield_16_filled = 983439
ic_fluent_laptop_shield_20_filled = 983440
ic_fluent_list_bar_16_filled = 983441
ic_fluent_list_bar_20_filled = 983442
ic_fluent_list_bar_tree_16_filled = 983443
ic_fluent_list_bar_tree_20_filled = 983444
ic_fluent_list_bar_tree_offset_16_filled = 983445
ic_fluent_list_bar_tree_offset_20_filled = 983446
ic_fluent_list_rtl_16_filled = 983447
ic_fluent_list_rtl_20_filled = 983448
ic_fluent_panel_left_text_16_filled = 983449
ic_fluent_panel_left_text_20_filled = 983450
ic_fluent_panel_left_text_24_filled = 983451
ic_fluent_panel_left_text_28_filled = 983452
ic_fluent_panel_left_text_32_filled = 983453
ic_fluent_panel_left_text_48_filled = 983454
ic_fluent_panel_left_text_add_16_filled = 983455
ic_fluent_panel_left_text_add_20_filled = 983456
ic_fluent_panel_left_text_add_24_filled = 983457
ic_fluent_panel_left_text_add_28_filled = 983458
ic_fluent_panel_left_text_add_32_filled = 983459
ic_fluent_panel_left_text_add_48_filled = 983460
ic_fluent_panel_left_text_dismiss_16_filled = 983461
ic_fluent_panel_left_text_dismiss_20_filled = 983462
ic_fluent_panel_left_text_dismiss_24_filled = 983463
ic_fluent_panel_left_text_dismiss_28_filled = 983464
ic_fluent_panel_left_text_dismiss_32_filled = 983465
ic_fluent_panel_left_text_dismiss_48_filled = 983466
ic_fluent_person_lightning_16_filled = 983467
ic_fluent_person_lightning_20_filled = 983468
ic_fluent_text_bullet_list_square_16_filled = 983469
ic_fluent_text_bullet_list_square_32_filled = 983470
ic_fluent_text_bullet_list_square_sparkle_16_filled = 983471
ic_fluent_text_bullet_list_square_sparkle_20_filled = 983472
ic_fluent_text_bullet_list_square_sparkle_24_filled = 983473
ic_fluent_translate_auto_16_filled = 983474
ic_fluent_translate_auto_20_filled = 983475
ic_fluent_translate_auto_24_filled = 983476
ic_fluent_airplane_landing_16_filled = 57581
ic_fluent_airplane_landing_20_filled = 57582
ic_fluent_airplane_landing_24_filled = 57583
ic_fluent_align_space_evenly_horizontal_24_filled = 57584
ic_fluent_align_space_evenly_vertical_24_filled = 983477
ic_fluent_align_straighten_20_filled = 983478
ic_fluent_align_straighten_24_filled = 983479
ic_fluent_arrow_flow_diagonal_up_right_16_filled = 983480
ic_fluent_arrow_flow_diagonal_up_right_20_filled = 983481
ic_fluent_arrow_flow_diagonal_up_right_24_filled = 983482
ic_fluent_arrow_flow_diagonal_up_right_32_filled = 983483
ic_fluent_arrow_flow_up_right_16_filled = 983484
ic_fluent_arrow_flow_up_right_20_filled = 983485
ic_fluent_arrow_flow_up_right_24_filled = 983486
ic_fluent_arrow_flow_up_right_32_filled = 983487
ic_fluent_arrow_flow_up_right_rectangle_multiple_20_filled = 983488
ic_fluent_arrow_flow_up_right_rectangle_multiple_24_filled = 983489
ic_fluent_arrow_square_up_right_20_filled = 983490
ic_fluent_arrow_square_up_right_24_filled = 983491
ic_fluent_bin_recycle_20_filled = 983492
ic_fluent_bin_recycle_24_filled = 983493
ic_fluent_bin_recycle_full_20_filled = 983494
ic_fluent_bin_recycle_full_24_filled = 983495
ic_fluent_briefcase_search_20_filled = 983496
ic_fluent_briefcase_search_24_filled = 983497
ic_fluent_circle_line_16_filled = 983498
ic_fluent_desk_20_filled = 983499
ic_fluent_desk_24_filled = 983500
ic_fluent_filmstrip_48_filled = 983501
ic_fluent_filmstrip_off_48_filled = 983502
ic_fluent_flash_32_filled = 983503
ic_fluent_flow_24_filled = 983504
ic_fluent_flow_32_filled = 983505
ic_fluent_heart_pulse_checkmark_20_filled = 983506
ic_fluent_heart_pulse_error_20_filled = 983507
ic_fluent_heart_pulse_warning_20_filled = 983508
ic_fluent_home_heart_16_filled = 983509
ic_fluent_home_heart_20_filled = 983510
ic_fluent_home_heart_24_filled = 983511
ic_fluent_home_heart_32_filled = 983512
ic_fluent_image_off_28_filled = 983513
ic_fluent_image_off_32_filled = 983514
ic_fluent_image_off_48_filled = 983515
ic_fluent_money_hand_16_filled = 983516
ic_fluent_money_settings_16_filled = 983517
ic_fluent_money_settings_24_filled = 983518
ic_fluent_people_edit_16_filled = 983519
ic_fluent_people_edit_24_filled = 983520
ic_fluent_triangle_up_20_filled = 983521
ic_fluent_add_square_16_filled = 983522
ic_fluent_add_square_28_filled = 983523
ic_fluent_add_square_32_filled = 983524
ic_fluent_add_square_48_filled = 983525
ic_fluent_arrow_routing_20_filled = 983526
ic_fluent_arrow_routing_24_filled = 983527
ic_fluent_arrow_routing_rectangle_multiple_20_filled = 983528
ic_fluent_arrow_routing_rectangle_multiple_24_filled = 983529
ic_fluent_book_add_28_filled = 983530
ic_fluent_book_default_28_filled = 983531
ic_fluent_folder_lightning_16_filled = 983532
ic_fluent_folder_lightning_20_filled = 983533
ic_fluent_folder_lightning_24_filled = 983534
ic_fluent_hat_graduation_28_filled = 983535
ic_fluent_image_sparkle_16_filled = 983536
ic_fluent_image_sparkle_20_filled = 983537
ic_fluent_image_sparkle_24_filled = 983538
ic_fluent_mail_32_filled = 983539
ic_fluent_person_info_24_filled = 983540
ic_fluent_prohibited_32_filled = 983541
ic_fluent_prohibited_multiple_28_filled = 983542
ic_fluent_spinner_ios_16_filled = 983543
ic_fluent_star_emphasis_16_filled = 983544
ic_fluent_text_direction_rotate_315_right_20_filled = 983545
ic_fluent_text_direction_rotate_315_right_24_filled = 983546
ic_fluent_text_direction_rotate_45_right_20_filled = 983547
ic_fluent_text_direction_rotate_45_right_24_filled = 983548
ic_fluent_arrow_outline_down_left_16_filled = 983549
ic_fluent_arrow_outline_down_left_20_filled = 983550
ic_fluent_arrow_outline_down_left_24_filled = 983551
ic_fluent_arrow_outline_down_left_28_filled = 983552
ic_fluent_arrow_outline_down_left_32_filled = 983553
ic_fluent_arrow_outline_down_left_48_filled = 983554
ic_fluent_arrow_step_in_diagonal_down_left_16_filled = 983555
ic_fluent_arrow_step_in_diagonal_down_left_20_filled = 983556
ic_fluent_arrow_step_in_diagonal_down_left_24_filled = 983557
ic_fluent_arrow_step_in_diagonal_down_left_28_filled = 983558
ic_fluent_arrow_up_square_settings_24_filled = 983559
ic_fluent_briefcase_person_24_filled = 983560
ic_fluent_building_cloud_24_filled = 983561
ic_fluent_calendar_eye_20_filled = 983562
ic_fluent_clipboard_paste_32_filled = 983563
ic_fluent_cloud_bidirectional_20_filled = 983564
ic_fluent_cloud_bidirectional_24_filled = 983565
ic_fluent_comment_edit_16_filled = 983566
ic_fluent_crown_24_filled = 983567
ic_fluent_crown_subtract_24_filled = 983568
ic_fluent_flag_pride_32_filled = 983569
ic_fluent_flag_pride_intersex_inclusive_progress_16_filled = 983570
ic_fluent_flag_pride_intersex_inclusive_progress_20_filled = 983571
ic_fluent_flag_pride_intersex_inclusive_progress_24_filled = 983572
ic_fluent_flag_pride_intersex_inclusive_progress_28_filled = 983573
ic_fluent_flag_pride_intersex_inclusive_progress_32_filled = 983574
ic_fluent_flag_pride_intersex_inclusive_progress_48_filled = 983575
ic_fluent_flag_pride_philadelphia_16_filled = 983576
ic_fluent_flag_pride_philadelphia_20_filled = 983577
ic_fluent_flag_pride_philadelphia_24_filled = 983578
ic_fluent_flag_pride_philadelphia_28_filled = 983579
ic_fluent_flag_pride_philadelphia_32_filled = 983580
ic_fluent_flag_pride_philadelphia_48_filled = 983581
ic_fluent_flag_pride_progress_16_filled = 983582
ic_fluent_flag_pride_progress_20_filled = 983583
ic_fluent_flag_pride_progress_24_filled = 983584
ic_fluent_flag_pride_progress_28_filled = 983585
ic_fluent_flag_pride_progress_32_filled = 983586
ic_fluent_flag_pride_progress_48_filled = 983587
ic_fluent_folder_add_32_filled = 983588
ic_fluent_folder_arrow_left_48_filled = 983589
ic_fluent_folder_arrow_right_32_filled = 983590
ic_fluent_folder_arrow_up_32_filled = 983591
ic_fluent_folder_link_16_filled = 983592
ic_fluent_folder_link_32_filled = 983593
ic_fluent_folder_prohibited_32_filled = 983594
ic_fluent_hat_graduation_sparkle_20_filled = 983595
ic_fluent_hat_graduation_sparkle_24_filled = 983596
ic_fluent_hat_graduation_sparkle_28_filled = 983597
ic_fluent_kiosk_24_filled = 983598
ic_fluent_laptop_multiple_24_filled = 983599
ic_fluent_link_add_24_filled = 983600
ic_fluent_link_settings_24_filled = 983601
ic_fluent_lock_closed_28_filled = 983602
ic_fluent_lock_closed_48_filled = 983603
ic_fluent_lock_open_12_filled = 983604
ic_fluent_lock_open_32_filled = 983605
ic_fluent_lock_open_48_filled = 983606
ic_fluent_paint_brush_32_filled = 983607
ic_fluent_pause_circle_32_filled = 983608
ic_fluent_pause_circle_48_filled = 983609
ic_fluent_pen_sparkle_16_filled = 983610
ic_fluent_pen_sparkle_20_filled = 983611
ic_fluent_pen_sparkle_24_filled = 983612
ic_fluent_pen_sparkle_28_filled = 983613
ic_fluent_pen_sparkle_32_filled = 983614
ic_fluent_pen_sparkle_48_filled = 983615
ic_fluent_person_phone_24_filled = 983616
ic_fluent_person_subtract_24_filled = 983617
ic_fluent_phone_briefcase_24_filled = 983618
ic_fluent_phone_multiple_24_filled = 983619
ic_fluent_phone_multiple_settings_24_filled = 983620
ic_fluent_phone_person_24_filled = 983621
ic_fluent_phone_subtract_24_filled = 983622
ic_fluent_plug_connected_settings_20_filled = 983623
ic_fluent_plug_connected_settings_24_filled = 983624
ic_fluent_rectangle_landscape_hint_copy_16_filled = 983625
ic_fluent_rectangle_landscape_hint_copy_20_filled = 983626
ic_fluent_rectangle_landscape_hint_copy_24_filled = 983627
ic_fluent_script_20_filled = 983628
ic_fluent_script_24_filled = 983629
ic_fluent_script_32_filled = 983630
ic_fluent_server_link_24_filled = 983631
ic_fluent_signature_32_filled = 983632
ic_fluent_speaker_mute_32_filled = 983633
ic_fluent_tab_desktop_28_filled = 983634
ic_fluent_tab_desktop_link_16_filled = 983635
ic_fluent_tab_desktop_link_20_filled = 983636
ic_fluent_tab_desktop_link_24_filled = 983637
ic_fluent_tab_desktop_link_28_filled = 983638
ic_fluent_table_arrow_up_20_filled = 983639
ic_fluent_table_arrow_up_24_filled = 983640
ic_fluent_tablet_laptop_24_filled = 983641
ic_fluent_thumb_like_dislike_16_filled = 983642
ic_fluent_thumb_like_dislike_20_filled = 983643
ic_fluent_thumb_like_dislike_24_filled = 983644
ic_fluent_warning_32_filled = 983645
ic_fluent_number_circle_1_28_filled = 983646
ic_fluent_number_circle_1_32_filled = 983647
ic_fluent_number_circle_1_48_filled = 983648
ic_fluent_number_circle_2_16_filled = 983649
ic_fluent_number_circle_2_20_filled = 983650
ic_fluent_number_circle_2_24_filled = 983651
ic_fluent_number_circle_2_28_filled = 983652
ic_fluent_number_circle_2_32_filled = 983653
ic_fluent_number_circle_2_48_filled = 983654
ic_fluent_number_circle_3_16_filled = 983655
ic_fluent_number_circle_3_20_filled = 983656
ic_fluent_number_circle_3_24_filled = 983657
ic_fluent_number_circle_3_28_filled = 983658
ic_fluent_number_circle_3_32_filled = 983659
ic_fluent_number_circle_3_48_filled = 983660
ic_fluent_number_circle_4_16_filled = 983661
ic_fluent_number_circle_4_20_filled = 983662
ic_fluent_number_circle_4_24_filled = 983663
ic_fluent_number_circle_4_28_filled = 983664
ic_fluent_number_circle_4_32_filled = 983665
ic_fluent_number_circle_4_48_filled = 983666
ic_fluent_number_circle_5_16_filled = 983667
ic_fluent_number_circle_5_20_filled = 983668
ic_fluent_number_circle_5_24_filled = 983669
ic_fluent_number_circle_5_28_filled = 983670
ic_fluent_number_circle_5_32_filled = 983671
ic_fluent_number_circle_5_48_filled = 983672
ic_fluent_add_square_multiple_24_filled = 983673
ic_fluent_braces_variable_48_filled = 983674
ic_fluent_cube_48_filled = 983675
ic_fluent_desk_16_filled = 983676
ic_fluent_desk_28_filled = 983677
ic_fluent_desk_32_filled = 983678
ic_fluent_desk_48_filled = 983679
ic_fluent_folder_open_vertical_24_filled = 983680
ic_fluent_globe_48_filled = 983681
ic_fluent_globe_shield_48_filled = 983682
ic_fluent_hand_right_off_16_filled = 983683
ic_fluent_hand_right_off_24_filled = 983684
ic_fluent_hand_right_off_28_filled = 983685
ic_fluent_hat_graduation_sparkle_16_filled = 983686
ic_fluent_key_multiple_16_filled = 983687
ic_fluent_key_multiple_24_filled = 983688
ic_fluent_link_multiple_16_filled = 983689
ic_fluent_link_multiple_20_filled = 983690
ic_fluent_link_multiple_24_filled = 983691
ic_fluent_mail_off_16_filled = 983692
ic_fluent_person_edit_48_filled = 983693
ic_fluent_plug_disconnected_48_filled = 983694
ic_fluent_stream_48_filled = 983695
ic_fluent_text_bullet_list_square_48_filled = 983696
ic_fluent_text_bullet_list_square_shield_48_filled = 983697
ic_fluent_arrow_export_16_filled = 983698
ic_fluent_arrow_export_20_filled = 983699
ic_fluent_arrow_export_24_filled = 983700
ic_fluent_calendar_12_filled = 983701
ic_fluent_calendar_16_filled = 983702
ic_fluent_calendar_20_filled = 983703
ic_fluent_calendar_24_filled = 983704
ic_fluent_calendar_28_filled = 983705
ic_fluent_calendar_32_filled = 983706
ic_fluent_calendar_48_filled = 983707
ic_fluent_calendar_date_20_filled = 983708
ic_fluent_calendar_date_24_filled = 983709
ic_fluent_calendar_date_28_filled = 983710
ic_fluent_clipboard_bullet_list_16_filled = 983711
ic_fluent_clipboard_bullet_list_20_filled = 983712
ic_fluent_ios_arrow_24_filled = 983713
ic_fluent_text_bullet_list_16_filled = 983714
ic_fluent_text_bullet_list_20_filled = 983715
ic_fluent_text_bullet_list_24_filled = 983716
ic_fluent_text_bullet_list_270_24_filled = 983717
ic_fluent_text_bullet_list_90_20_filled = 983718
ic_fluent_text_bullet_list_90_24_filled = 983719
ic_fluent_text_column_wide_20_filled = 983720
ic_fluent_text_column_wide_24_filled = 983721
ic_fluent_text_indent_decrease_16_filled = 983722
ic_fluent_text_indent_decrease_20_filled = 983723
ic_fluent_text_indent_decrease_24_filled = 983724
ic_fluent_text_indent_increase_16_filled = 983725
ic_fluent_text_indent_increase_20_filled = 983726
ic_fluent_text_indent_increase_24_filled = 983727
ic_fluent_vehicle_car_profile_16_filled = 983728
ic_fluent_vehicle_car_profile_20_filled = 983729
ic_fluent_vehicle_car_profile_24_filled = 983730
ic_fluent_arrow_bidirectional_left_right_16_filled = 983731
ic_fluent_arrow_bidirectional_left_right_20_filled = 983732
ic_fluent_arrow_bidirectional_left_right_24_filled = 983733
ic_fluent_arrow_bidirectional_left_right_28_filled = 983734
ic_fluent_arrow_swap_16_filled = 983735
ic_fluent_arrow_swap_28_filled = 983736
ic_fluent_building_mosque_12_filled = 983737
ic_fluent_building_mosque_16_filled = 983738
ic_fluent_building_mosque_20_filled = 983739
ic_fluent_building_mosque_24_filled = 983740
ic_fluent_building_mosque_28_filled = 983741
ic_fluent_building_mosque_32_filled = 983742
ic_fluent_building_mosque_48_filled = 983743
ic_fluent_checkmark_circle_square_16_filled = 983744
ic_fluent_checkmark_circle_square_20_filled = 983745
ic_fluent_checkmark_circle_square_24_filled = 983746
ic_fluent_heart_off_16_filled = 983747
ic_fluent_heart_off_20_filled = 983748
ic_fluent_heart_off_24_filled = 983749
ic_fluent_hexagon_16_filled = 983750
ic_fluent_hexagon_20_filled = 983751
ic_fluent_hexagon_three_16_filled = 983752
ic_fluent_hexagon_three_20_filled = 983753
ic_fluent_line_horizontal_1_16_filled = 983754
ic_fluent_line_horizontal_1_24_filled = 983755
ic_fluent_line_horizontal_1_28_filled = 983756
ic_fluent_line_horizontal_1_dashes_16_filled = 983757
ic_fluent_line_horizontal_1_dashes_20_filled = 983758
ic_fluent_line_horizontal_1_dashes_24_filled = 983759
ic_fluent_line_horizontal_1_dashes_28_filled = 983760
ic_fluent_line_horizontal_2_dashes_solid_16_filled = 983761
ic_fluent_line_horizontal_2_dashes_solid_20_filled = 983762
ic_fluent_line_horizontal_2_dashes_solid_24_filled = 983763
ic_fluent_line_horizontal_2_dashes_solid_28_filled = 983764
ic_fluent_mic_record_20_filled = 983765
ic_fluent_mic_record_24_filled = 983766
ic_fluent_mic_record_28_filled = 983767
ic_fluent_open_12_filled = 983768
ic_fluent_remix_add_16_filled = 983769
ic_fluent_remix_add_20_filled = 983770
ic_fluent_remix_add_24_filled = 983771
ic_fluent_remix_add_32_filled = 983772
ic_fluent_video_person_sparkle_off_20_filled = 983773
ic_fluent_video_person_sparkle_off_24_filled = 983774
ic_fluent_voicemail_shield_20_filled = 983775
ic_fluent_voicemail_shield_24_filled = 983776
ic_fluent_voicemail_shield_32_filled = 983777
ic_fluent_window_database_32_filled = 983778
ic_fluent_cast_multiple_20_filled = 983779
ic_fluent_cast_multiple_24_filled = 983780
ic_fluent_cast_multiple_28_filled = 983781
ic_fluent_circle_hint_half_vertical_16_filled = 983782
ic_fluent_circle_hint_half_vertical_20_filled = 983783
ic_fluent_circle_hint_half_vertical_24_filled = 983784
ic_fluent_flash_sparkle_20_filled = 983785
ic_fluent_flash_sparkle_24_filled = 983786
ic_fluent_hexagon_12_filled = 983787
ic_fluent_hexagon_24_filled = 983788
ic_fluent_hexagon_three_12_filled = 983789
ic_fluent_hexagon_three_24_filled = 983790
ic_fluent_next_frame_20_filled = 983791
ic_fluent_next_frame_24_filled = 983792
ic_fluent_previous_frame_20_filled = 983793
ic_fluent_previous_frame_24_filled = 983794
ic_fluent_textbox_align_bottom_center_16_filled = 983795
ic_fluent_textbox_align_bottom_center_20_filled = 983796
ic_fluent_textbox_align_bottom_center_24_filled = 983797
ic_fluent_textbox_align_bottom_left_16_filled = 983798
ic_fluent_textbox_align_bottom_left_20_filled = 983799
ic_fluent_textbox_align_bottom_left_24_filled = 983800
ic_fluent_textbox_align_bottom_right_16_filled = 983801
ic_fluent_textbox_align_bottom_right_20_filled = 983802
ic_fluent_textbox_align_bottom_right_24_filled = 983803
ic_fluent_textbox_align_center_16_filled = 983804
ic_fluent_textbox_align_middle_left_16_filled = 983805
ic_fluent_textbox_align_middle_left_20_filled = 983806
ic_fluent_textbox_align_middle_left_24_filled = 983807
ic_fluent_textbox_align_middle_right_16_filled = 983808
ic_fluent_textbox_align_middle_right_20_filled = 983809
ic_fluent_textbox_align_middle_right_24_filled = 983810
ic_fluent_textbox_align_top_center_16_filled = 983811
ic_fluent_textbox_align_top_center_20_filled = 983812
ic_fluent_textbox_align_top_center_24_filled = 983813
ic_fluent_textbox_align_top_left_16_filled = 983814
ic_fluent_textbox_align_top_left_20_filled = 983815
ic_fluent_textbox_align_top_left_24_filled = 983816
ic_fluent_textbox_align_top_right_16_filled = 983817
ic_fluent_textbox_align_top_right_20_filled = 983818
ic_fluent_textbox_align_top_right_24_filled = 983819
ic_fluent_triangle_down_24_filled = 983820
ic_fluent_call_end_12_filled = 983821
ic_fluent_call_end_32_filled = 983822
ic_fluent_call_end_48_filled = 983823
ic_fluent_content_view_gallery_16_filled = 983824
ic_fluent_content_view_gallery_lightning_16_filled = 983825
ic_fluent_content_view_gallery_lightning_20_filled = 983826
ic_fluent_content_view_gallery_lightning_24_filled = 983827
ic_fluent_content_view_gallery_lightning_28_filled = 983828
ic_fluent_globe_arrow_forward_16_filled = 983829
ic_fluent_globe_arrow_forward_20_filled = 983830
ic_fluent_globe_arrow_forward_24_filled = 983831
ic_fluent_globe_arrow_forward_32_filled = 983832
ic_fluent_hard_drive_24_filled = 983833
ic_fluent_hard_drive_32_filled = 983834
ic_fluent_hard_drive_call_24_filled = 983835
ic_fluent_hard_drive_call_32_filled = 983836
ic_fluent_mail_rewind_16_filled = 983837
ic_fluent_mail_rewind_20_filled = 983838
ic_fluent_mail_rewind_24_filled = 983839
ic_fluent_panel_right_gallery_16_filled = 983840
ic_fluent_panel_right_gallery_20_filled = 983841
ic_fluent_panel_right_gallery_24_filled = 983842
ic_fluent_panel_right_gallery_28_filled = 983843
ic_fluent_panel_top_gallery_16_filled = 983844
ic_fluent_panel_top_gallery_20_filled = 983845
ic_fluent_panel_top_gallery_24_filled = 983846
ic_fluent_panel_top_gallery_28_filled = 983847
ic_fluent_rectangle_landscape_sparkle_16_filled = 983848
ic_fluent_rectangle_landscape_sparkle_20_filled = 983849
ic_fluent_rectangle_landscape_sparkle_24_filled = 983850
ic_fluent_rectangle_landscape_sparkle_28_filled = 983851
ic_fluent_rectangle_landscape_sparkle_32_filled = 983852
ic_fluent_scan_person_16_filled = 983853
ic_fluent_scan_person_20_filled = 983854
ic_fluent_scan_person_24_filled = 983855
ic_fluent_scan_person_28_filled = 983856
ic_fluent_scan_person_48_filled = 983857
ic_fluent_voicemail_shield_16_filled = 983858
ic_fluent_chevron_down_32_filled = 983859
ic_fluent_chevron_left_32_filled = 983860
ic_fluent_chevron_right_32_filled = 983861
ic_fluent_chevron_up_32_filled = 983862
ic_fluent_document_lightning_16_filled = 983863
ic_fluent_document_lightning_20_filled = 983864
ic_fluent_document_lightning_24_filled = 983865
ic_fluent_document_lightning_28_filled = 983866
ic_fluent_document_lightning_32_filled = 983867
ic_fluent_document_lightning_48_filled = 983868
ic_fluent_edit_12_filled = 983869
ic_fluent_server_link_16_filled = 983870
ic_fluent_server_link_20_filled = 983871
ic_fluent_step_20_filled = 983872
ic_fluent_step_24_filled = 983873
ic_fluent_tab_desktop_multiple_add_20_filled = 983874
ic_fluent_text_description_16_filled = 983875
ic_fluent_text_description_28_filled = 983876
ic_fluent_text_description_32_filled = 983877
ic_fluent_text_grammar_lightning_16_filled = 983878
ic_fluent_text_grammar_lightning_20_filled = 983879
ic_fluent_text_grammar_lightning_24_filled = 983880
ic_fluent_text_grammar_lightning_28_filled = 983881
ic_fluent_text_grammar_lightning_32_filled = 983882
ic_fluent_beaker_add_20_filled = 983883
ic_fluent_beaker_add_24_filled = 983884
ic_fluent_beaker_dismiss_20_filled = 983885
ic_fluent_beaker_dismiss_24_filled = 983886
ic_fluent_document_cube_20_filled = 983887
ic_fluent_document_cube_24_filled = 983888
ic_fluent_drawer_20_filled = 983889
ic_fluent_drawer_24_filled = 983890
ic_fluent_filmstrip_image_20_filled = 983891
ic_fluent_filmstrip_image_24_filled = 983892
ic_fluent_number_circle_0_16_filled = 983893
ic_fluent_number_circle_0_20_filled = 983894
ic_fluent_number_circle_0_24_filled = 983895
ic_fluent_number_circle_0_28_filled = 983896
ic_fluent_number_circle_0_32_filled = 983897
ic_fluent_number_circle_0_48_filled = 983898
ic_fluent_number_circle_6_16_filled = 983899
ic_fluent_number_circle_6_20_filled = 983900
ic_fluent_number_circle_6_24_filled = 983901
ic_fluent_number_circle_6_28_filled = 983902
ic_fluent_number_circle_6_32_filled = 983903
ic_fluent_number_circle_6_48_filled = 983904
ic_fluent_number_circle_7_16_filled = 983905
ic_fluent_number_circle_7_20_filled = 983906
ic_fluent_number_circle_7_24_filled = 983907
ic_fluent_number_circle_7_28_filled = 983908
ic_fluent_number_circle_7_32_filled = 983909
ic_fluent_number_circle_7_48_filled = 983910
ic_fluent_number_circle_8_16_filled = 983911
ic_fluent_number_circle_8_20_filled = 983912
ic_fluent_number_circle_8_24_filled = 983913
ic_fluent_number_circle_8_28_filled = 983914
ic_fluent_number_circle_8_32_filled = 983915
ic_fluent_number_circle_8_48_filled = 983916
ic_fluent_number_circle_9_16_filled = 983917
ic_fluent_number_circle_9_20_filled = 983918
ic_fluent_number_circle_9_24_filled = 983919
ic_fluent_number_circle_9_28_filled = 983920
ic_fluent_number_circle_9_32_filled = 983921
ic_fluent_number_circle_9_48_filled = 983922
ic_fluent_server_12_filled = 983923
ic_fluent_square_hint_hexagon_12_filled = 983924
ic_fluent_square_hint_hexagon_16_filled = 983925
ic_fluent_square_hint_hexagon_20_filled = 983926
ic_fluent_square_hint_hexagon_24_filled = 983927
ic_fluent_square_hint_hexagon_28_filled = 983928
ic_fluent_square_hint_hexagon_32_filled = 983929
ic_fluent_square_hint_hexagon_48_filled = 983930
ic_fluent_tab_desktop_multiple_16_filled = 983931
ic_fluent_tab_desktop_multiple_add_16_filled = 983932
ic_fluent_target_add_20_filled = 983933
ic_fluent_target_add_24_filled = 983934
ic_fluent_target_dismiss_20_filled = 983935
ic_fluent_target_dismiss_24_filled = 983936
ic_fluent_text_header_1_lines_16_filled = 983937
ic_fluent_text_header_1_lines_20_filled = 983938
ic_fluent_text_header_1_lines_24_filled = 983939
ic_fluent_text_header_1_lines_caret_16_filled = 983940
ic_fluent_text_header_1_lines_caret_20_filled = 983941
ic_fluent_text_header_1_lines_caret_24_filled = 983942
ic_fluent_text_header_2_lines_16_filled = 983943
ic_fluent_text_header_2_lines_20_filled = 983944
ic_fluent_text_header_2_lines_24_filled = 983945
ic_fluent_text_header_2_lines_caret_16_filled = 983946
ic_fluent_text_header_2_lines_caret_20_filled = 983947
ic_fluent_text_header_2_lines_caret_24_filled = 983948
ic_fluent_text_header_3_lines_16_filled = 983949
ic_fluent_text_header_3_lines_20_filled = 983950
ic_fluent_text_header_3_lines_24_filled = 983951
ic_fluent_text_header_3_lines_caret_16_filled = 983952
ic_fluent_text_header_3_lines_caret_20_filled = 983953
ic_fluent_text_header_3_lines_caret_24_filled = 983954
ic_fluent_arrow_download_28_filled = 983955
ic_fluent_arrow_download_32_filled = 983956
ic_fluent_arrow_expand_16_filled = 983957
ic_fluent_arrow_export_up_16_filled = 983958
ic_fluent_arrow_import_16_filled = 983959
ic_fluent_arrow_up_right_dashes_16_filled = 983960
ic_fluent_battery_10_16_filled = 983961
ic_fluent_beaker_empty_16_filled = 983962
ic_fluent_book_16_filled = 983963
ic_fluent_border_none_16_filled = 983964
ic_fluent_branch_request_16_filled = 983965
ic_fluent_clipboard_task_list_16_filled = 983966
ic_fluent_cut_16_filled = 983967
ic_fluent_folder_search_16_filled = 983968
ic_fluent_folder_search_20_filled = 983969
ic_fluent_folder_search_24_filled = 983970
ic_fluent_hexagon_28_filled = 983971
ic_fluent_hexagon_32_filled = 983972
ic_fluent_hexagon_48_filled = 983973
ic_fluent_plug_connected_16_filled = 983974
ic_fluent_plug_disconnected_16_filled = 983975
ic_fluent_projection_screen_text_20_filled = 983976
ic_fluent_rss_16_filled = 983977
ic_fluent_shape_organic_16_filled = 983978
ic_fluent_shape_organic_20_filled = 983979
ic_fluent_shape_organic_24_filled = 983980
ic_fluent_shape_organic_28_filled = 983981
ic_fluent_shape_organic_32_filled = 983982
ic_fluent_shape_organic_48_filled = 983983
ic_fluent_teardrop_bottom_right_16_filled = 983984
ic_fluent_teardrop_bottom_right_20_filled = 983985
ic_fluent_teardrop_bottom_right_24_filled = 983986
ic_fluent_teardrop_bottom_right_28_filled = 983987
ic_fluent_teardrop_bottom_right_32_filled = 983988
ic_fluent_teardrop_bottom_right_48_filled = 983989
ic_fluent_text_edit_style_16_filled = 983990
ic_fluent_text_whole_word_16_filled = 983991
ic_fluent_triangle_24_filled = 983992
ic_fluent_triangle_28_filled = 983993
ic_fluent_text_asterisk_16_filled = 983994
ic_fluent_arrow_download_off_16_filled = 983995
ic_fluent_arrow_download_off_20_filled = 983996
ic_fluent_arrow_download_off_24_filled = 983997
ic_fluent_arrow_download_off_28_filled = 983998
ic_fluent_arrow_download_off_32_filled = 983999
ic_fluent_arrow_download_off_48_filled = 984000
ic_fluent_border_inside_16_filled = 984001
ic_fluent_border_inside_20_filled = 984002
ic_fluent_border_inside_24_filled = 984003
ic_fluent_chat_lock_16_filled = 984004
ic_fluent_chat_lock_20_filled = 984005
ic_fluent_chat_lock_24_filled = 984006
ic_fluent_chat_lock_28_filled = 984007
ic_fluent_error_circle_48_filled = 984008
ic_fluent_full_screen_maximize_28_filled = 984009
ic_fluent_full_screen_maximize_32_filled = 984010
ic_fluent_full_screen_minimize_28_filled = 984011
ic_fluent_full_screen_minimize_32_filled = 984012
ic_fluent_link_person_16_filled = 984013
ic_fluent_link_person_20_filled = 984014
ic_fluent_link_person_24_filled = 984015
ic_fluent_link_person_32_filled = 984016
ic_fluent_link_person_48_filled = 984017
ic_fluent_people_chat_16_filled = 984018
ic_fluent_people_chat_20_filled = 984019
ic_fluent_people_chat_24_filled = 984020
ic_fluent_person_support_28_filled = 984021
ic_fluent_shapes_32_filled = 984022
ic_fluent_slide_text_edit_16_filled = 984023
ic_fluent_slide_text_edit_20_filled = 984024
ic_fluent_slide_text_edit_24_filled = 984025
ic_fluent_slide_text_edit_28_filled = 984026
ic_fluent_subtract_circle_48_filled = 984027
ic_fluent_subtract_parentheses_16_filled = 984028
ic_fluent_subtract_parentheses_20_filled = 984029
ic_fluent_subtract_parentheses_24_filled = 984030
ic_fluent_subtract_parentheses_28_filled = 984031
ic_fluent_subtract_parentheses_32_filled = 984032
ic_fluent_subtract_parentheses_48_filled = 984033
ic_fluent_warning_48_filled = 984034
ic_fluent_alert_on_16_filled = 984035
ic_fluent_arrow_down_exclamation_16_filled = 984036
ic_fluent_arrow_down_exclamation_20_filled = 984037
ic_fluent_arrow_fit_24_filled = 984038
ic_fluent_arrow_fit_in_24_filled = 984039
ic_fluent_book_32_filled = 984040
ic_fluent_book_database_16_filled = 984041
ic_fluent_book_database_32_filled = 984042
ic_fluent_book_toolbox_16_filled = 984043
ic_fluent_building_desktop_32_filled = 984044
ic_fluent_building_government_16_filled = 984045
ic_fluent_building_government_search_16_filled = 984046
ic_fluent_building_government_search_20_filled = 984047
ic_fluent_building_government_search_24_filled = 984048
ic_fluent_building_government_search_32_filled = 984049
ic_fluent_calendar_record_16_filled = 984050
ic_fluent_calendar_record_20_filled = 984051
ic_fluent_calendar_record_24_filled = 984052
ic_fluent_calendar_record_28_filled = 984053
ic_fluent_calendar_record_32_filled = 984054
ic_fluent_calendar_record_48_filled = 984055
ic_fluent_clipboard_28_filled = 984056
ic_fluent_clipboard_math_formula_16_filled = 984057
ic_fluent_clipboard_math_formula_20_filled = 984058
ic_fluent_clipboard_math_formula_24_filled = 984059
ic_fluent_clipboard_math_formula_28_filled = 984060
ic_fluent_clipboard_math_formula_32_filled = 984061
ic_fluent_clipboard_number_123_16_filled = 984062
ic_fluent_clipboard_number_123_20_filled = 984063
ic_fluent_clipboard_number_123_24_filled = 984064
ic_fluent_clipboard_number_123_28_filled = 984065
ic_fluent_clipboard_number_123_32_filled = 984066
ic_fluent_collections_16_filled = 984067
ic_fluent_communication_shield_16_filled = 984068
ic_fluent_communication_shield_20_filled = 984069
ic_fluent_communication_shield_24_filled = 984070
ic_fluent_dialpad_question_mark_20_filled = 984071
ic_fluent_dialpad_question_mark_24_filled = 984072
ic_fluent_document_briefcase_16_filled = 984073
ic_fluent_document_briefcase_32_filled = 984074
ic_fluent_document_search_32_filled = 984075
ic_fluent_fingerprint_16_filled = 984076
ic_fluent_fingerprint_32_filled = 984077
ic_fluent_folder_person_24_filled = 984078
ic_fluent_folder_person_28_filled = 984079
ic_fluent_folder_person_32_filled = 984080
ic_fluent_folder_person_48_filled = 984081
ic_fluent_hat_graduation_add_16_filled = 984082
ic_fluent_hat_graduation_add_20_filled = 984083
ic_fluent_hat_graduation_add_24_filled = 984084
ic_fluent_layer_diagonal_add_20_filled = 984085
ic_fluent_library_32_filled = 984086
ic_fluent_lightbulb_filament_32_filled = 984087
ic_fluent_link_add_16_filled = 984088
ic_fluent_link_add_20_filled = 984089
ic_fluent_lock_shield_16_filled = 984090
ic_fluent_lock_shield_28_filled = 984091
ic_fluent_lock_shield_32_filled = 984092
ic_fluent_person_voice_16_filled = 984093
ic_fluent_person_warning_16_filled = 984094
ic_fluent_person_warning_20_filled = 984095
ic_fluent_person_warning_24_filled = 984096
ic_fluent_person_warning_28_filled = 984097
ic_fluent_person_warning_32_filled = 984098
ic_fluent_person_warning_48_filled = 984099
ic_fluent_scan_type_off_24_filled = 984100
ic_fluent_screenshot_16_filled = 984101
ic_fluent_screenshot_record_16_filled = 984102
ic_fluent_screenshot_record_20_filled = 984103
ic_fluent_screenshot_record_24_filled = 984104
ic_fluent_slide_search_16_filled = 984105
ic_fluent_slide_search_32_filled = 984106
ic_fluent_vehicle_subway_clock_16_filled = 984107
ic_fluent_vehicle_subway_clock_20_filled = 984108
ic_fluent_vehicle_subway_clock_24_filled = 984109
ic_fluent_video_clip_optimize_16_filled = 984110
ic_fluent_video_clip_optimize_20_filled = 984111
ic_fluent_video_clip_optimize_24_filled = 984112
ic_fluent_video_clip_optimize_28_filled = 984113
ic_fluent_video_person_pulse_16_filled = 984114
ic_fluent_video_person_pulse_20_filled = 984115
ic_fluent_video_person_pulse_24_filled = 984116
ic_fluent_video_person_pulse_28_filled = 984117
ic_fluent_archive_settings_32_filled = 984118
ic_fluent_arrow_forward_32_filled = 984119
ic_fluent_arrow_reply_32_filled = 984120
ic_fluent_arrow_reply_all_32_filled = 984121
ic_fluent_attach_32_filled = 984122
ic_fluent_autocorrect_32_filled = 984123
ic_fluent_broom_32_filled = 984124
ic_fluent_calendar_note_16_filled = 984125
ic_fluent_calendar_note_20_filled = 984126
ic_fluent_calendar_note_24_filled = 984127
ic_fluent_calendar_note_32_filled = 984128
ic_fluent_checkmark_underline_circle_24_filled = 984129
ic_fluent_data_bar_vertical_ascending_20_filled = 984130
ic_fluent_data_bar_vertical_ascending_24_filled = 984131
ic_fluent_diversity_16_filled = 984132
ic_fluent_filter_32_filled = 984133
ic_fluent_folder_mail_32_filled = 984134
ic_fluent_glance_horizontal_32_filled = 984135
ic_fluent_glance_horizontal_sparkle_32_filled = 984136
ic_fluent_globe_arrow_up_16_filled = 984137
ic_fluent_globe_arrow_up_20_filled = 984138
ic_fluent_globe_arrow_up_24_filled = 984139
ic_fluent_globe_error_16_filled = 984140
ic_fluent_globe_error_20_filled = 984141
ic_fluent_globe_error_24_filled = 984142
ic_fluent_globe_prohibited_16_filled = 984143
ic_fluent_globe_prohibited_24_filled = 984144
ic_fluent_globe_sync_16_filled = 984145
ic_fluent_globe_sync_20_filled = 984146
ic_fluent_globe_sync_24_filled = 984147
ic_fluent_globe_warning_16_filled = 984148
ic_fluent_globe_warning_20_filled = 984149
ic_fluent_globe_warning_24_filled = 984150
ic_fluent_important_32_filled = 984151
ic_fluent_layer_diagonal_16_filled = 984152
ic_fluent_layer_diagonal_person_16_filled = 984153
ic_fluent_mail_multiple_32_filled = 984154
ic_fluent_mail_read_32_filled = 984155
ic_fluent_mail_unread_32_filled = 984156
ic_fluent_mailbox_16_filled = 984157
ic_fluent_mailbox_20_filled = 984158
ic_fluent_organization_horizontal_16_filled = 984159
ic_fluent_organization_horizontal_24_filled = 984160
ic_fluent_people_list_32_filled = 984161
ic_fluent_person_add_32_filled = 984162
ic_fluent_person_square_16_filled = 984163
ic_fluent_person_square_32_filled = 984164
ic_fluent_person_square_checkmark_16_filled = 984165
ic_fluent_person_square_checkmark_20_filled = 984166
ic_fluent_person_square_checkmark_24_filled = 984167
ic_fluent_person_square_checkmark_32_filled = 984168
ic_fluent_phone_footer_arrow_down_20_filled = 984169
ic_fluent_phone_footer_arrow_down_24_filled = 984170
ic_fluent_phone_header_arrow_up_20_filled = 984171
ic_fluent_phone_header_arrow_up_24_filled = 984172
ic_fluent_poll_32_filled = 984173
ic_fluent_question_32_filled = 984174
ic_fluent_screenshot_28_filled = 984175
ic_fluent_screenshot_record_28_filled = 984176
ic_fluent_star_32_filled = 984177
ic_fluent_text_density_32_filled = 984178
ic_fluent_text_edit_style_character_a_32_filled = 984179
ic_fluent_wrench_screwdriver_32_filled = 984180
ic_fluent_arrow_clockwise_dashes_16_filled = 984181
ic_fluent_arrow_clockwise_dashes_32_filled = 984182
ic_fluent_building_swap_16_filled = 984183
ic_fluent_building_swap_20_filled = 984184
ic_fluent_building_swap_24_filled = 984185
ic_fluent_building_swap_32_filled = 984186
ic_fluent_building_swap_48_filled = 984187
ic_fluent_certificate_32_filled = 984188
ic_fluent_clipboard_brush_16_filled = 984189
ic_fluent_clipboard_brush_20_filled = 984190
ic_fluent_clipboard_brush_24_filled = 984191
ic_fluent_clipboard_brush_28_filled = 984192
ic_fluent_clipboard_brush_32_filled = 984193
ic_fluent_cloud_beaker_16_filled = 984194
ic_fluent_cloud_beaker_20_filled = 984195
ic_fluent_cloud_beaker_24_filled = 984196
ic_fluent_cloud_beaker_28_filled = 984197
ic_fluent_cloud_beaker_32_filled = 984198
ic_fluent_cloud_beaker_48_filled = 984199
ic_fluent_cloud_cube_16_filled = 984200
ic_fluent_cloud_cube_20_filled = 984201
ic_fluent_cloud_cube_24_filled = 984202
ic_fluent_cloud_cube_28_filled = 984203
ic_fluent_cloud_cube_32_filled = 984204
ic_fluent_cloud_cube_48_filled = 984205
ic_fluent_contract_up_right_16_filled = 984206
ic_fluent_contract_up_right_20_filled = 984207
ic_fluent_contract_up_right_24_filled = 984208
ic_fluent_contract_up_right_28_filled = 984209
ic_fluent_contract_up_right_32_filled = 984210
ic_fluent_contract_up_right_48_filled = 984211
ic_fluent_document_data_lock_16_filled = 984212
ic_fluent_document_data_lock_20_filled = 984213
ic_fluent_document_data_lock_24_filled = 984214
ic_fluent_document_data_lock_32_filled = 984215
ic_fluent_glance_horizontal_sparkles_20_filled = 984216
ic_fluent_layout_cell_four_16_filled = 984217
ic_fluent_layout_cell_four_20_filled = 984218
ic_fluent_layout_cell_four_24_filled = 984219
ic_fluent_layout_cell_four_focus_bottom_left_16_filled = 984220
ic_fluent_layout_cell_four_focus_bottom_left_20_filled = 984221
ic_fluent_layout_cell_four_focus_bottom_left_24_filled = 984222
ic_fluent_layout_cell_four_focus_bottom_right_16_filled = 984223
ic_fluent_layout_cell_four_focus_bottom_right_20_filled = 984224
ic_fluent_layout_cell_four_focus_bottom_right_24_filled = 984225
ic_fluent_layout_cell_four_focus_top_left_16_filled = 984226
ic_fluent_layout_cell_four_focus_top_left_20_filled = 984227
ic_fluent_layout_cell_four_focus_top_left_24_filled = 984228
ic_fluent_layout_cell_four_focus_top_right_16_filled = 984229
ic_fluent_layout_cell_four_focus_top_right_20_filled = 984230
ic_fluent_layout_cell_four_focus_top_right_24_filled = 984231
ic_fluent_layout_column_four_16_filled = 984232
ic_fluent_layout_column_four_20_filled = 984233
ic_fluent_layout_column_four_24_filled = 984234
ic_fluent_layout_column_four_focus_center_left_16_filled = 984235
ic_fluent_layout_column_four_focus_center_left_20_filled = 984236
ic_fluent_layout_column_four_focus_center_left_24_filled = 984237
ic_fluent_layout_column_four_focus_center_right_16_filled = 984238
ic_fluent_layout_column_four_focus_center_right_20_filled = 984239
ic_fluent_layout_column_four_focus_center_right_24_filled = 984240
ic_fluent_layout_column_four_focus_left_16_filled = 984241
ic_fluent_layout_column_four_focus_left_20_filled = 984242
ic_fluent_layout_column_four_focus_left_24_filled = 984243
ic_fluent_layout_column_four_focus_right_16_filled = 984244
ic_fluent_layout_column_four_focus_right_20_filled = 984245
ic_fluent_layout_column_four_focus_right_24_filled = 984246
ic_fluent_layout_column_one_third_left_16_filled = 984247
ic_fluent_layout_column_one_third_left_20_filled = 984248
ic_fluent_layout_column_one_third_left_24_filled = 984249
ic_fluent_layout_column_one_third_right_16_filled = 984250
ic_fluent_layout_column_one_third_right_20_filled = 984251
ic_fluent_layout_column_one_third_right_24_filled = 984252
ic_fluent_layout_column_one_third_right_hint_16_filled = 984253
ic_fluent_layout_column_one_third_right_hint_20_filled = 984254
ic_fluent_layout_column_one_third_right_hint_24_filled = 984255
ic_fluent_layout_column_three_16_filled = 984256
ic_fluent_layout_column_three_20_filled = 984257
ic_fluent_layout_column_three_24_filled = 984258
ic_fluent_layout_column_three_focus_center_16_filled = 984259
ic_fluent_layout_column_three_focus_center_20_filled = 984260
ic_fluent_layout_column_three_focus_center_24_filled = 984261
ic_fluent_layout_column_three_focus_left_16_filled = 984262
ic_fluent_layout_column_three_focus_left_20_filled = 984263
ic_fluent_layout_column_three_focus_left_24_filled = 984264
ic_fluent_layout_column_three_focus_right_16_filled = 984265
ic_fluent_layout_column_three_focus_right_20_filled = 984266
ic_fluent_layout_column_three_focus_right_24_filled = 984267
ic_fluent_layout_column_two_16_filled = 984268
ic_fluent_layout_column_two_20_filled = 984269
ic_fluent_layout_column_two_24_filled = 984270
ic_fluent_layout_column_two_focus_left_16_filled = 984271
ic_fluent_layout_column_two_focus_left_20_filled = 984272
ic_fluent_layout_column_two_focus_left_24_filled = 984273
ic_fluent_layout_column_two_focus_right_16_filled = 984274
ic_fluent_layout_column_two_focus_right_20_filled = 984275
ic_fluent_layout_column_two_focus_right_24_filled = 984276
ic_fluent_layout_column_two_split_left_16_filled = 984277
ic_fluent_layout_column_two_split_left_20_filled = 984278
ic_fluent_layout_column_two_split_left_24_filled = 984279
ic_fluent_layout_column_two_split_left_focus_bottom_left_16_filled = 984280
ic_fluent_layout_column_two_split_left_focus_bottom_left_20_filled = 984281
ic_fluent_layout_column_two_split_left_focus_bottom_left_24_filled = 984282
ic_fluent_layout_column_two_split_left_focus_right_16_filled = 984283
ic_fluent_layout_column_two_split_left_focus_right_20_filled = 984284
ic_fluent_layout_column_two_split_left_focus_right_24_filled = 984285
ic_fluent_layout_column_two_split_left_focus_top_left_16_filled = 984286
ic_fluent_layout_column_two_split_left_focus_top_left_20_filled = 984287
ic_fluent_layout_column_two_split_left_focus_top_left_24_filled = 984288
ic_fluent_layout_column_two_split_right_16_filled = 984289
ic_fluent_layout_column_two_split_right_20_filled = 984290
ic_fluent_layout_column_two_split_right_24_filled = 984291
ic_fluent_layout_column_two_split_right_focus_bottom_right_16_filled = 984292
ic_fluent_layout_column_two_split_right_focus_bottom_right_20_filled = 984293
ic_fluent_layout_column_two_split_right_focus_bottom_right_24_filled = 984294
ic_fluent_layout_column_two_split_right_focus_left_16_filled = 984295
ic_fluent_layout_column_two_split_right_focus_left_20_filled = 984296
ic_fluent_layout_column_two_split_right_focus_left_24_filled = 984297
ic_fluent_layout_column_two_split_right_focus_top_right_16_filled = 984298
ic_fluent_layout_column_two_split_right_focus_top_right_20_filled = 984299
ic_fluent_layout_column_two_split_right_focus_top_right_24_filled = 984300
ic_fluent_layout_row_four_16_filled = 984301
ic_fluent_layout_row_four_20_filled = 984302
ic_fluent_layout_row_four_24_filled = 984303
ic_fluent_layout_row_four_focus_bottom_16_filled = 984304
ic_fluent_layout_row_four_focus_bottom_20_filled = 984305
ic_fluent_layout_row_four_focus_bottom_24_filled = 984306
ic_fluent_layout_row_four_focus_center_bottom_16_filled = 984307
ic_fluent_layout_row_four_focus_center_bottom_20_filled = 984308
ic_fluent_layout_row_four_focus_center_bottom_24_filled = 984309
ic_fluent_layout_row_four_focus_center_top_16_filled = 984310
ic_fluent_layout_row_four_focus_center_top_20_filled = 984311
ic_fluent_layout_row_four_focus_center_top_24_filled = 984312
ic_fluent_layout_row_four_focus_top_16_filled = 984313
ic_fluent_layout_row_four_focus_top_20_filled = 984314
ic_fluent_layout_row_four_focus_top_24_filled = 984315
ic_fluent_layout_row_three_16_filled = 984316
ic_fluent_layout_row_three_20_filled = 984317
ic_fluent_layout_row_three_24_filled = 984318
ic_fluent_layout_row_three_focus_bottom_16_filled = 984319
ic_fluent_layout_row_three_focus_bottom_20_filled = 984320
ic_fluent_layout_row_three_focus_bottom_24_filled = 984321
ic_fluent_layout_row_three_focus_center_16_filled = 984322
ic_fluent_layout_row_three_focus_center_20_filled = 984323
ic_fluent_layout_row_three_focus_center_24_filled = 984324
ic_fluent_layout_row_three_focus_top_16_filled = 984325
ic_fluent_layout_row_three_focus_top_20_filled = 984326
ic_fluent_layout_row_three_focus_top_24_filled = 984327
ic_fluent_layout_row_two_16_filled = 984328
ic_fluent_layout_row_two_20_filled = 984329
ic_fluent_layout_row_two_24_filled = 984330
ic_fluent_layout_row_two_focus_bottom_16_filled = 984331
ic_fluent_layout_row_two_focus_bottom_20_filled = 984332
ic_fluent_layout_row_two_focus_bottom_24_filled = 984333
ic_fluent_layout_row_two_focus_top_16_filled = 984334
ic_fluent_layout_row_two_focus_top_20_filled = 984335
ic_fluent_layout_row_two_focus_top_24_filled = 984336
ic_fluent_layout_row_two_split_bottom_16_filled = 984337
ic_fluent_layout_row_two_split_bottom_20_filled = 984338
ic_fluent_layout_row_two_split_bottom_24_filled = 984339
ic_fluent_layout_row_two_split_bottom_focus_bottom_left_16_filled = 984340
ic_fluent_layout_row_two_split_bottom_focus_bottom_left_20_filled = 984341
ic_fluent_layout_row_two_split_bottom_focus_bottom_left_24_filled = 984342
ic_fluent_layout_row_two_split_bottom_focus_bottom_right_16_filled = 984343
ic_fluent_layout_row_two_split_bottom_focus_bottom_right_20_filled = 984344
ic_fluent_layout_row_two_split_bottom_focus_bottom_right_24_filled = 984345
ic_fluent_layout_row_two_split_bottom_focus_top_16_filled = 984346
ic_fluent_layout_row_two_split_bottom_focus_top_20_filled = 984347
ic_fluent_layout_row_two_split_bottom_focus_top_24_filled = 984348
ic_fluent_layout_row_two_split_top_16_filled = 984349
ic_fluent_layout_row_two_split_top_20_filled = 984350
ic_fluent_layout_row_two_split_top_24_filled = 984351
ic_fluent_layout_row_two_split_top_focus_bottom_16_filled = 984352
ic_fluent_layout_row_two_split_top_focus_bottom_20_filled = 984353
ic_fluent_layout_row_two_split_top_focus_bottom_24_filled = 984354
ic_fluent_layout_row_two_split_top_focus_top_left_16_filled = 984355
ic_fluent_layout_row_two_split_top_focus_top_left_20_filled = 984356
ic_fluent_layout_row_two_split_top_focus_top_left_24_filled = 984357
ic_fluent_layout_row_two_split_top_focus_top_right_16_filled = 984358
ic_fluent_layout_row_two_split_top_focus_top_right_20_filled = 984359
ic_fluent_layout_row_two_split_top_focus_top_right_24_filled = 984360
ic_fluent_location_target_square_16_filled = 984361
ic_fluent_location_target_square_20_filled = 984362
ic_fluent_location_target_square_24_filled = 984363
ic_fluent_location_target_square_32_filled = 984364
ic_fluent_resize_16_filled = 984365
ic_fluent_resize_28_filled = 984366
ic_fluent_resize_32_filled = 984367
ic_fluent_resize_48_filled = 984368
ic_fluent_select_all_off_16_filled = 984369
ic_fluent_select_all_on_16_filled = 984370
ic_fluent_share_android_16_filled = 984371
ic_fluent_share_android_32_filled = 984372
ic_fluent_text_arrow_down_right_column_16_filled = 984373
ic_fluent_text_arrow_down_right_column_20_filled = 984374
ic_fluent_text_arrow_down_right_column_24_filled = 984375
ic_fluent_text_arrow_down_right_column_28_filled = 984376
ic_fluent_text_arrow_down_right_column_32_filled = 984377
ic_fluent_text_arrow_down_right_column_48_filled = 984378
ic_fluent_text_effects_sparkle_20_filled = 984379
ic_fluent_text_effects_sparkle_24_filled = 984380
ic_fluent_whiteboard_16_filled = 984381
ic_fluent_whiteboard_off_16_filled = 984382
ic_fluent_whiteboard_off_20_filled = 984383
ic_fluent_whiteboard_off_24_filled = 984384
ic_fluent_flowchart_16_filled = 984385
ic_fluent_flowchart_32_filled = 984386
ic_fluent_layer_diagonal_24_filled = 984387
ic_fluent_layer_diagonal_person_24_filled = 984388
ic_fluent_poll_off_16_filled = 984389
ic_fluent_poll_off_20_filled = 984390
ic_fluent_poll_off_24_filled = 984391
ic_fluent_poll_off_32_filled = 984392
ic_fluent_rectangle_landscape_sparkle_48_filled = 984393
ic_fluent_rectangle_landscape_sync_16_filled = 984394
ic_fluent_rectangle_landscape_sync_20_filled = 984395
ic_fluent_rectangle_landscape_sync_24_filled = 984396
ic_fluent_rectangle_landscape_sync_28_filled = 984397
ic_fluent_rectangle_landscape_sync_off_16_filled = 984398
ic_fluent_rectangle_landscape_sync_off_20_filled = 984399
ic_fluent_rectangle_landscape_sync_off_24_filled = 984400
ic_fluent_rectangle_landscape_sync_off_28_filled = 984401
ic_fluent_seat_16_filled = 984402
ic_fluent_seat_20_filled = 984403
ic_fluent_seat_24_filled = 984404
ic_fluent_seat_add_16_filled = 984405
ic_fluent_seat_add_20_filled = 984406
ic_fluent_seat_add_24_filled = 984407
ic_fluent_speaker_box_16_filled = 984408
ic_fluent_speaker_box_20_filled = 984409
ic_fluent_speaker_box_24_filled = 984410
ic_fluent_text_edit_style_character_ga_32_filled = 984411
ic_fluent_window_ad_24_filled = 984412
ic_fluent_wrench_settings_20_filled = 984413
ic_fluent_wrench_settings_24_filled = 984414
ic_fluent_building_lighthouse_24_filled = 984415
ic_fluent_building_lighthouse_32_filled = 984416
ic_fluent_building_lighthouse_48_filled = 984417
ic_fluent_calendar_link_24_filled = 984418
ic_fluent_calendar_link_28_filled = 984419
ic_fluent_calendar_video_24_filled = 984420
ic_fluent_calendar_video_28_filled = 984421
ic_fluent_cookies_16_filled = 984422
ic_fluent_cookies_28_filled = 984423
ic_fluent_cookies_32_filled = 984424
ic_fluent_cookies_48_filled = 984425
ic_fluent_hard_drive_28_filled = 984426
ic_fluent_hard_drive_48_filled = 984427
ic_fluent_laptop_32_filled = 984428
ic_fluent_laptop_settings_20_filled = 984429
ic_fluent_laptop_settings_24_filled = 984430
ic_fluent_laptop_settings_32_filled = 984431
ic_fluent_people_audience_32_filled = 984432
ic_fluent_shopping_bag_add_20_filled = 984433
ic_fluent_shopping_bag_add_24_filled = 984434
ic_fluent_street_sign_20_filled = 984435
ic_fluent_street_sign_24_filled = 984436
ic_fluent_video_link_24_filled = 984437
ic_fluent_video_link_28_filled = 984438
ic_fluent_building_lighthouse_16_filled = 984439
ic_fluent_calendar_sparkle_16_filled = 984440
ic_fluent_calendar_sparkle_20_filled = 984441
ic_fluent_calendar_sparkle_24_filled = 984442
ic_fluent_calendar_sparkle_28_filled = 984443
ic_fluent_calendar_sparkle_32_filled = 984444
ic_fluent_calendar_sparkle_48_filled = 984445
ic_fluent_calendar_template_20_filled = 984446
ic_fluent_calendar_template_24_filled = 984447
ic_fluent_calendar_template_32_filled = 984448
ic_fluent_clipboard_12_filled = 984449
ic_fluent_clipboard_48_filled = 984450
ic_fluent_compose_12_filled = 984451
ic_fluent_compose_32_filled = 984452
ic_fluent_compose_48_filled = 984453
ic_fluent_globe_28_filled = 984454
ic_fluent_guest_12_filled = 984455
ic_fluent_guest_32_filled = 984456
ic_fluent_guest_48_filled = 984457
ic_fluent_laptop_briefcase_20_filled = 984458
ic_fluent_laptop_briefcase_24_filled = 984459
ic_fluent_laptop_briefcase_32_filled = 984460
ic_fluent_layer_diagonal_sparkle_16_filled = 984461
ic_fluent_layer_diagonal_sparkle_20_filled = 984462
ic_fluent_layer_diagonal_sparkle_24_filled = 984463
ic_fluent_payment_wireless_16_filled = 984464
ic_fluent_payment_wireless_20_filled = 984465
ic_fluent_payment_wireless_24_filled = 984466
ic_fluent_payment_wireless_28_filled = 984467
ic_fluent_payment_wireless_32_filled = 984468
ic_fluent_payment_wireless_48_filled = 984469
ic_fluent_status_28_filled = 984470
ic_fluent_status_32_filled = 984471
ic_fluent_status_48_filled = 984472
ic_fluent_video_off_16_filled = 984473
ic_fluent_checkmark_circle_warning_16_filled = 984474
ic_fluent_checkmark_circle_warning_20_filled = 984475
ic_fluent_checkmark_circle_warning_24_filled = 984476
ic_fluent_cloud_arrow_right_16_filled = 984477
ic_fluent_cloud_arrow_right_20_filled = 984478
ic_fluent_cloud_arrow_right_24_filled = 984479
ic_fluent_document_arrow_down_24_filled = 984480
ic_fluent_document_signature_16_filled = 984481
ic_fluent_document_signature_20_filled = 984482
ic_fluent_document_signature_24_filled = 984483
ic_fluent_document_signature_28_filled = 984484
ic_fluent_document_signature_32_filled = 984485
ic_fluent_document_signature_48_filled = 984486
ic_fluent_home_garage_20_filled = 984487
ic_fluent_home_garage_24_filled = 984488
ic_fluent_image_split_20_filled = 984489
ic_fluent_image_split_24_filled = 984490
ic_fluent_laptop_48_filled = 984491
ic_fluent_line_flow_diagonal_up_right_16_filled = 984492
ic_fluent_line_flow_diagonal_up_right_20_filled = 984493
ic_fluent_line_flow_diagonal_up_right_24_filled = 984494
ic_fluent_line_flow_diagonal_up_right_32_filled = 984495
ic_fluent_mail_arrow_clockwise_16_filled = 984496
ic_fluent_mail_arrow_clockwise_20_filled = 984497
ic_fluent_mail_arrow_clockwise_24_filled = 984498
ic_fluent_person_passkey_16_filled = 984499
ic_fluent_person_passkey_20_filled = 984500
ic_fluent_person_passkey_24_filled = 984501
ic_fluent_person_passkey_28_filled = 984502
ic_fluent_person_passkey_32_filled = 984503
ic_fluent_person_passkey_48_filled = 984504
ic_fluent_person_prohibited_32_filled = 984505
ic_fluent_person_ribbon_24_filled = 984506
ic_fluent_plant_cattail_20_filled = 984507
ic_fluent_plant_cattail_24_filled = 984508
ic_fluent_storage_16_filled = 984509
ic_fluent_storage_28_filled = 984510
ic_fluent_storage_32_filled = 984511
ic_fluent_storage_48_filled = 984512
ic_fluent_video_clip_wand_16_filled = 984513
ic_fluent_video_clip_wand_20_filled = 984514
ic_fluent_video_clip_wand_24_filled = 984515
ic_fluent_window_fingerprint_16_filled = 984516
ic_fluent_window_fingerprint_20_filled = 984517
ic_fluent_window_fingerprint_24_filled = 984518
ic_fluent_window_fingerprint_28_filled = 984519
ic_fluent_window_fingerprint_32_filled = 984520
ic_fluent_window_fingerprint_48_filled = 984521
ic_fluent_accessibility_error_20_filled = 984522
ic_fluent_accessibility_error_24_filled = 984523
ic_fluent_accessibility_question_mark_20_filled = 984524
ic_fluent_accessibility_question_mark_24_filled = 984525
ic_fluent_arrow_down_exclamation_24_filled = 984526
ic_fluent_arrow_sort_up_lines_16_filled = 984527
ic_fluent_arrow_sort_up_lines_20_filled = 984528
ic_fluent_arrow_sort_up_lines_24_filled = 984529
ic_fluent_arrow_up_exclamation_16_filled = 984530
ic_fluent_arrow_up_exclamation_20_filled = 984531
ic_fluent_arrow_up_exclamation_24_filled = 984532
ic_fluent_bench_20_filled = 984533
ic_fluent_bench_24_filled = 984534
ic_fluent_building_lighthouse_28_filled = 984535
ic_fluent_calendar_video_20_filled = 984536
ic_fluent_clock_bill_16_filled = 984537
ic_fluent_clock_bill_20_filled = 984538
ic_fluent_clock_bill_24_filled = 984539
ic_fluent_clock_bill_32_filled = 984540
ic_fluent_data_usage_16_filled = 984541
ic_fluent_data_usage_settings_16_filled = 984542
ic_fluent_data_usage_settings_24_filled = 984543
ic_fluent_edit_person_20_filled = 984544
ic_fluent_edit_person_24_filled = 984545
ic_fluent_highway_20_filled = 984546
ic_fluent_highway_24_filled = 984547
ic_fluent_laptop_person_20_filled = 984548
ic_fluent_laptop_person_24_filled = 984549
ic_fluent_laptop_person_48_filled = 984550
ic_fluent_location_ripple_16_filled = 984551
ic_fluent_location_ripple_20_filled = 984552
ic_fluent_location_ripple_24_filled = 984553
ic_fluent_mail_arrow_double_back_32_filled = 984554
ic_fluent_mail_briefcase_48_filled = 984555
ic_fluent_options_28_filled = 984556
ic_fluent_options_32_filled = 984557
ic_fluent_people_add_32_filled = 984558
ic_fluent_person_alert_32_filled = 984559
ic_fluent_road_20_filled = 984560
ic_fluent_road_24_filled = 984561
ic_fluent_save_32_filled = 984562
ic_fluent_tab_desktop_multiple_24_filled = 984563
ic_fluent_tab_desktop_multiple_sparkle_16_filled = 984564
ic_fluent_tab_desktop_multiple_sparkle_20_filled = 984565
ic_fluent_tab_desktop_multiple_sparkle_24_filled = 984566
ic_fluent_vehicle_tractor_20_filled = 984567
ic_fluent_vehicle_tractor_24_filled = 984568
ic_fluent_classification_32_filled = 984569
ic_fluent_document_target_20_filled = 984570
ic_fluent_document_target_24_filled = 984571
ic_fluent_document_target_32_filled = 984572
ic_fluent_emoji_meme_16_filled = 984573
ic_fluent_emoji_meme_20_filled = 984574
ic_fluent_emoji_meme_24_filled = 984575
ic_fluent_hand_point_16_filled = 984576
ic_fluent_hand_point_20_filled = 984577
ic_fluent_hand_point_24_filled = 984578
ic_fluent_hand_point_28_filled = 984579
ic_fluent_hand_point_32_filled = 984580
ic_fluent_hand_point_48_filled = 984581
ic_fluent_mail_read_briefcase_48_filled = 984582
ic_fluent_people_subtract_20_filled = 984583
ic_fluent_people_subtract_24_filled = 984584
ic_fluent_people_subtract_32_filled = 984585
ic_fluent_person_alert_off_16_filled = 984586
ic_fluent_person_alert_off_20_filled = 984587
ic_fluent_person_alert_off_24_filled = 984588
ic_fluent_person_alert_off_32_filled = 984589
ic_fluent_shopping_bag_add_16_filled = 984590
ic_fluent_spatula_spoon_16_filled = 984591
ic_fluent_spatula_spoon_20_filled = 984592
ic_fluent_spatula_spoon_24_filled = 984593
ic_fluent_spatula_spoon_28_filled = 984594
ic_fluent_spatula_spoon_32_filled = 984595
ic_fluent_spatula_spoon_48_filled = 984596
ic_fluent_apps_settings_16_filled = 984597
ic_fluent_apps_settings_20_filled = 984598
ic_fluent_apps_shield_16_filled = 984599
ic_fluent_apps_shield_20_filled = 984600
ic_fluent_arrow_upload_32_filled = 984601
ic_fluent_calendar_edit_32_filled = 984602
ic_fluent_data_bar_vertical_arrow_down_16_filled = 984603
ic_fluent_data_bar_vertical_arrow_down_20_filled = 984604
ic_fluent_data_bar_vertical_arrow_down_24_filled = 984605
ic_fluent_haptic_strong_16_filled = 984606
ic_fluent_haptic_strong_20_filled = 984607
ic_fluent_haptic_strong_24_filled = 984608
ic_fluent_haptic_weak_16_filled = 984609
ic_fluent_haptic_weak_20_filled = 984610
ic_fluent_haptic_weak_24_filled = 984611
ic_fluent_hexagon_sparkle_20_filled = 984612
ic_fluent_hexagon_sparkle_24_filled = 984613
ic_fluent_mail_edit_32_filled = 984614
ic_fluent_password_32_filled = 984615
ic_fluent_password_48_filled = 984616
ic_fluent_password_clock_48_filled = 984617
ic_fluent_password_reset_48_filled = 984618
ic_fluent_people_eye_16_filled = 984619
ic_fluent_people_eye_20_filled = 984620
ic_fluent_pin_globe_16_filled = 984621
ic_fluent_pin_globe_20_filled = 984622
ic_fluent_run_28_filled = 984623
ic_fluent_run_32_filled = 984624
ic_fluent_run_48_filled = 984625
ic_fluent_tab_group_16_filled = 984626
ic_fluent_tab_group_20_filled = 984627
ic_fluent_tab_group_24_filled = 984628
ic_fluent_book_28_filled = 984629
ic_fluent_book_48_filled = 984630
ic_fluent_camera_arrow_up_16_filled = 984631
ic_fluent_camera_arrow_up_20_filled = 984632
ic_fluent_camera_arrow_up_24_filled = 984633
ic_fluent_chat_settings_16_filled = 984634
ic_fluent_circle_highlight_20_filled = 984635
ic_fluent_circle_highlight_24_filled = 984636
ic_fluent_circle_hint_24_filled = 984637
ic_fluent_circle_shadow_20_filled = 984638
ic_fluent_circle_shadow_24_filled = 984639
ic_fluent_content_view_16_filled = 984640
ic_fluent_double_tap_swipe_down_16_filled = 984641
ic_fluent_double_tap_swipe_up_16_filled = 984642
ic_fluent_flash_sparkle_16_filled = 984643
ic_fluent_location_ripple_12_filled = 984644
ic_fluent_search_square_16_filled = 984645
ic_fluent_settings_chat_16_filled = 984646
ic_fluent_share_multiple_16_filled = 984647
ic_fluent_share_multiple_20_filled = 984648
ic_fluent_share_multiple_24_filled = 984649
ic_fluent_slide_play_20_filled = 984650
ic_fluent_slide_play_24_filled = 984651
ic_fluent_arrow_turn_right_16_filled = 984652
ic_fluent_chart_multiple_16_filled = 984653
ic_fluent_column_24_filled = 984654
ic_fluent_data_pie_16_filled = 984655
ic_fluent_layout_column_two_32_filled = 984656
ic_fluent_layout_column_two_focus_left_32_filled = 984657
ic_fluent_layout_column_two_focus_right_32_filled = 984658
ic_fluent_layout_row_two_32_filled = 984659
ic_fluent_layout_row_two_focus_top_32_filled = 984660
ic_fluent_mail_copy_32_filled = 984661
ic_fluent_paint_brush_sparkle_20_filled = 984662
ic_fluent_paint_brush_sparkle_24_filled = 984663
ic_fluent_people_community_12_filled = 984664
ic_fluent_person_board_12_filled = 984665
ic_fluent_person_tentative_16_filled = 984666
ic_fluent_person_tentative_20_filled = 984667
ic_fluent_person_tentative_24_filled = 984668
ic_fluent_tab_desktop_search_16_filled = 984669
ic_fluent_tab_desktop_search_20_filled = 984670
ic_fluent_tab_desktop_search_24_filled = 984671
ic_fluent_table_sparkle_20_filled = 984672
ic_fluent_table_sparkle_24_filled = 984673
ic_fluent_comment_32_filled = 984674
ic_fluent_comment_add_32_filled = 984675
ic_fluent_crop_arrow_rotate_16_filled = 984676
ic_fluent_crop_arrow_rotate_20_filled = 984677
ic_fluent_crop_arrow_rotate_24_filled = 984678
ic_fluent_desktop_off_20_filled = 984679
ic_fluent_desktop_off_24_filled = 984680
ic_fluent_food_28_filled = 984681
ic_fluent_food_32_filled = 984682
ic_fluent_food_48_filled = 984683
ic_fluent_layer_diagonal_add_24_filled = 984684
ic_fluent_mail_alert_32_filled = 984685
ic_fluent_mail_arrow_clockwise_32_filled = 984686
ic_fluent_person_support_32_filled = 984687
ic_fluent_tag_off_16_filled = 984688
ic_fluent_text_column_one_wide_lightning_16_filled = 984689
ic_fluent_wallet_credit_card_28_filled = 984690
ic_fluent_wallet_credit_card_48_filled = 984691
ic_fluent_breakout_room_32_filled = 984692
ic_fluent_card_ui_portrait_flip_16_filled = 984693
ic_fluent_card_ui_portrait_flip_20_filled = 984694
ic_fluent_card_ui_portrait_flip_24_filled = 984695
ic_fluent_cursor_28_filled = 984696
ic_fluent_cursor_32_filled = 984697
ic_fluent_layout_row_two_28_filled = 984698
ic_fluent_layout_row_two_48_filled = 984699
ic_fluent_notepad_sparkle_16_filled = 984700
ic_fluent_notepad_sparkle_20_filled = 984701
ic_fluent_notepad_sparkle_24_filled = 984702
ic_fluent_notepad_sparkle_28_filled = 984703
ic_fluent_notepad_sparkle_32_filled = 984704
ic_fluent_paint_brush_28_filled = 984705
ic_fluent_paint_brush_subtract_16_filled = 984706
ic_fluent_paint_brush_subtract_20_filled = 984707
ic_fluent_paint_brush_subtract_24_filled = 984708
ic_fluent_paint_brush_subtract_28_filled = 984709
ic_fluent_paint_brush_subtract_32_filled = 984710
ic_fluent_play_circle_sparkle_16_filled = 984711
ic_fluent_play_circle_sparkle_20_filled = 984712
ic_fluent_play_circle_sparkle_24_filled = 984713
ic_fluent_replay_16_filled = 984714
ic_fluent_replay_24_filled = 984715
ic_fluent_replay_28_filled = 984716
ic_fluent_replay_32_filled = 984717
ic_fluent_send_person_16_filled = 984718
ic_fluent_send_person_20_filled = 984719
ic_fluent_send_person_24_filled = 984720
ic_fluent_square_dovetail_joint_12_filled = 984721
ic_fluent_square_dovetail_joint_16_filled = 984722
ic_fluent_square_dovetail_joint_20_filled = 984723
ic_fluent_square_dovetail_joint_24_filled = 984724
ic_fluent_square_dovetail_joint_28_filled = 984725
ic_fluent_square_dovetail_joint_32_filled = 984726
ic_fluent_square_dovetail_joint_48_filled = 984727
ic_fluent_table_cursor_16_filled = 984728
ic_fluent_table_cursor_20_filled = 984729
ic_fluent_table_cursor_24_filled = 984730
ic_fluent_transparency_square_20_filled = 984731
ic_fluent_transparency_square_24_filled = 984732
ic_fluent_arrow_collapse_all_16_filled = 984733
ic_fluent_arrow_expand_all_16_filled = 984734
ic_fluent_arrow_expand_all_20_filled = 984735
ic_fluent_arrow_expand_all_24_filled = 984736
ic_fluent_chat_arrow_back_down_16_filled = 984737
ic_fluent_chat_arrow_back_down_20_filled = 984738
ic_fluent_chat_arrow_back_down_24_filled = 984739
ic_fluent_chat_arrow_back_down_28_filled = 984740
ic_fluent_chat_arrow_back_down_32_filled = 984741
ic_fluent_chat_arrow_back_down_48_filled = 984742
ic_fluent_desktop_arrow_down_32_filled = 984743
ic_fluent_edit_line_horizontal_3_20_filled = 984744
ic_fluent_edit_line_horizontal_3_24_filled = 984745
ic_fluent_gift_open_32_filled = 984746
ic_fluent_prompt_16_filled = 984747
ic_fluent_prompt_20_filled = 984748
ic_fluent_prompt_24_filled = 984749
ic_fluent_prompt_28_filled = 984750
ic_fluent_prompt_32_filled = 984751
ic_fluent_prompt_48_filled = 984752
ic_fluent_search_sparkle_16_filled = 984753
ic_fluent_search_sparkle_20_filled = 984754
ic_fluent_search_sparkle_24_filled = 984755
ic_fluent_search_sparkle_28_filled = 984756
ic_fluent_search_sparkle_32_filled = 984757
ic_fluent_search_sparkle_48_filled = 984758
ic_fluent_slide_text_call_16_filled = 984759
ic_fluent_slide_text_call_20_filled = 984760
ic_fluent_slide_text_call_24_filled = 984761
ic_fluent_slide_text_call_28_filled = 984762
ic_fluent_slide_text_call_48_filled = 984763
ic_fluent_slide_text_cursor_20_filled = 984764
ic_fluent_slide_text_cursor_24_filled = 984765
ic_fluent_vehicle_motorcycle_16_filled = 984766
ic_fluent_vehicle_motorcycle_20_filled = 984767
ic_fluent_vehicle_motorcycle_24_filled = 984768
ic_fluent_vehicle_motorcycle_28_filled = 984769
ic_fluent_vehicle_motorcycle_32_filled = 984770
ic_fluent_vehicle_motorcycle_48_filled = 984771
ic_fluent_accessibility_more_16_filled = 984772
ic_fluent_accessibility_more_20_filled = 984773
ic_fluent_accessibility_more_24_filled = 984774
ic_fluent_battery_0_28_filled = 984775
ic_fluent_battery_0_32_filled = 984776
ic_fluent_battery_1_28_filled = 984777
ic_fluent_battery_1_32_filled = 984778
ic_fluent_battery_10_28_filled = 984779
ic_fluent_battery_10_32_filled = 984780
ic_fluent_battery_2_28_filled = 984781
ic_fluent_battery_2_32_filled = 984782
ic_fluent_battery_3_28_filled = 984783
ic_fluent_battery_3_32_filled = 984784
ic_fluent_battery_4_28_filled = 984785
ic_fluent_battery_4_32_filled = 984786
ic_fluent_battery_5_28_filled = 984787
ic_fluent_battery_5_32_filled = 984788
ic_fluent_battery_6_28_filled = 984789
ic_fluent_battery_6_32_filled = 984790
ic_fluent_battery_7_28_filled = 984791
ic_fluent_battery_7_32_filled = 984792
ic_fluent_battery_8_28_filled = 984793
ic_fluent_battery_8_32_filled = 984794
ic_fluent_battery_9_28_filled = 984795
ic_fluent_battery_9_32_filled = 984796
ic_fluent_battery_charge_28_filled = 984797
ic_fluent_battery_charge_32_filled = 984798
ic_fluent_coin_stack_16_filled = 984799
ic_fluent_coin_stack_20_filled = 984800
ic_fluent_coin_stack_24_filled = 984801
ic_fluent_database_arrow_up_16_filled = 984802
ic_fluent_layout_row_two_focus_top_28_filled = 984803
ic_fluent_layout_row_two_focus_top_settings_20_filled = 984804
ic_fluent_layout_row_two_focus_top_settings_28_filled = 984805
ic_fluent_layout_row_two_focus_top_settings_32_filled = 984806
ic_fluent_paint_brush_12_filled = 984807
ic_fluent_panel_right_12_filled = 984808
ic_fluent_people_edit_32_filled = 984809
ic_fluent_person_mail_32_filled = 984810
ic_fluent_puzzle_piece_12_filled = 984811
ic_fluent_game_chat_20_filled = 984812
ic_fluent_person_home_16_filled = 984813
ic_fluent_person_home_20_filled = 984814
ic_fluent_person_home_24_filled = 984815
ic_fluent_person_home_28_filled = 984816
ic_fluent_person_home_32_filled = 984817
ic_fluent_person_home_48_filled = 984818
ic_fluent_teaching_20_filled = 984819
ic_fluent_edit_lock_16_filled = 984820
ic_fluent_edit_lock_20_filled = 984821
ic_fluent_edit_lock_24_filled = 984822
ic_fluent_layout_row_two_settings_20_filled = 984823
ic_fluent_layout_row_two_settings_24_filled = 984824
ic_fluent_layout_row_two_settings_28_filled = 984825
ic_fluent_layout_row_two_settings_32_filled = 984826
ic_fluent_shield_add_28_filled = 984827
ic_fluent_shield_add_32_filled = 984828
ic_fluent_shield_add_48_filled = 984829
ic_fluent_shield_checkmark_32_filled = 984830
ic_fluent_shield_task_32_filled = 984831
ic_fluent_toolbox_32_filled = 984832
ic_fluent_warning_lock_open_16_filled = 984833
ic_fluent_warning_lock_open_20_filled = 984834
ic_fluent_warning_lock_open_24_filled = 984835
ic_fluent_person_board_add_20_filled = 984836
ic_fluent_person_square_add_16_filled = 984837
ic_fluent_person_square_add_20_filled = 984838
ic_fluent_person_square_add_24_filled = 984839
ic_fluent_airplane_16_filled = 984840
ic_fluent_airplane_28_filled = 984841
ic_fluent_airplane_32_filled = 984842
ic_fluent_airplane_48_filled = 984843
ic_fluent_globe_off_12_filled = 984844
ic_fluent_globe_off_16_filled = 984845
ic_fluent_globe_off_20_filled = 984846
ic_fluent_globe_off_24_filled = 984847
ic_fluent_globe_off_28_filled = 984848
ic_fluent_globe_off_32_filled = 984849
ic_fluent_globe_off_48_filled = 984850
ic_fluent_hat_graduation_32_filled = 984851
ic_fluent_hat_graduation_48_filled = 984852
ic_fluent_person_board_add_16_filled = 984853
ic_fluent_person_board_add_24_filled = 984854
ic_fluent_person_board_add_28_filled = 984855
ic_fluent_person_board_add_32_filled = 984856
ic_fluent_shopping_bag_28_filled = 984857
ic_fluent_shopping_bag_32_filled = 984858
ic_fluent_shopping_bag_48_filled = 984859
ic_fluent_shopping_bag_tag_16_filled = 984860
ic_fluent_shopping_bag_tag_28_filled = 984861
ic_fluent_shopping_bag_tag_32_filled = 984862
ic_fluent_shopping_bag_tag_48_filled = 984863
ic_fluent_teaching_16_filled = 984864
ic_fluent_teaching_24_filled = 984865
ic_fluent_teaching_28_filled = 984866
ic_fluent_teaching_32_filled = 984867
ic_fluent_teaching_48_filled = 984868
ic_fluent_window_brush_20_filled = 984869
ic_fluent_window_brush_24_filled = 984870
ic_fluent_window_column_one_fourth_left_20_filled = 984871
ic_fluent_window_column_one_fourth_left_focus_left_20_filled = 984872
ic_fluent_window_column_one_fourth_left_focus_top_20_filled = 984873
ic_fluent_arrow_sync_circle_28_filled = 984874
ic_fluent_arrow_sync_circle_32_filled = 984875
ic_fluent_arrow_sync_circle_48_filled = 984876
ic_fluent_calendar_arrow_repeat_all_16_filled = 984877
ic_fluent_calendar_arrow_repeat_all_20_filled = 984878
ic_fluent_calendar_arrow_repeat_all_24_filled = 984879
ic_fluent_calendar_arrow_repeat_all_28_filled = 984880
ic_fluent_calendar_arrow_repeat_all_32_filled = 984881
ic_fluent_calendar_arrow_repeat_all_48_filled = 984882
ic_fluent_coin_multiple_28_filled = 984883
ic_fluent_coin_multiple_32_filled = 984884
ic_fluent_coin_multiple_48_filled = 984885
ic_fluent_bin_full_48_filled = 984886
ic_fluent_clock_toolbox_32_filled = 984887
ic_fluent_database_search_32_filled = 984888
ic_fluent_document_globe_20_filled = 984889
ic_fluent_document_globe_24_filled = 984890
ic_fluent_form_sparkle_20_filled = 984891
ic_fluent_line_style_sketch_16_filled = 984892
ic_fluent_line_style_sketch_20_filled = 984893
ic_fluent_line_style_sketch_24_filled = 984894
ic_fluent_line_style_sketch_28_filled = 984895
ic_fluent_line_style_sketch_32_filled = 984896
ic_fluent_microscope_32_filled = 984897
ic_fluent_puzzle_piece_28_filled = 984898
ic_fluent_puzzle_piece_32_filled = 984899
ic_fluent_puzzle_piece_48_filled = 984900
ic_fluent_reward_32_filled = 984901
ic_fluent_tab_add_32_filled = 984902
ic_fluent_add_circle_48_filled = 984903
ic_fluent_approvals_app_48_filled = 984904
ic_fluent_clipboard_text_edit_48_filled = 984905
ic_fluent_design_ideas_28_filled = 984906
ic_fluent_design_ideas_32_filled = 984907
ic_fluent_design_ideas_48_filled = 984908
ic_fluent_document_folder_28_filled = 984909
ic_fluent_document_folder_32_filled = 984910
ic_fluent_document_folder_48_filled = 984911
ic_fluent_eye_off_32_filled = 984912
ic_fluent_learning_app_16_filled = 984913
ic_fluent_receipt_48_filled = 984914
ic_fluent_video_bluetooth_16_filled = 984915
ic_fluent_video_bluetooth_20_filled = 984916
ic_fluent_video_bluetooth_24_filled = 984917
ic_fluent_video_bluetooth_28_filled = 984918
ic_fluent_video_bluetooth_32_filled = 984919
ic_fluent_video_bluetooth_48_filled = 984920
ic_fluent_video_usb_16_filled = 984921
ic_fluent_video_usb_20_filled = 984922
ic_fluent_video_usb_24_filled = 984923
ic_fluent_video_usb_28_filled = 984924
ic_fluent_video_usb_32_filled = 984925
ic_fluent_video_usb_48_filled = 984926
ic_fluent_arrow_circle_up_left_16_filled = 984927
ic_fluent_arrow_circle_up_right_16_filled = 984928
ic_fluent_building_checkmark_16_filled = 984929
ic_fluent_building_checkmark_20_filled = 984930
ic_fluent_clock_alarm_48_filled = 984931
ic_fluent_clothes_hanger_12_filled = 984932
ic_fluent_clothes_hanger_16_filled = 984933
ic_fluent_clothes_hanger_20_filled = 984934
ic_fluent_clothes_hanger_24_filled = 984935
ic_fluent_comment_quote_16_filled = 984936
ic_fluent_comment_quote_20_filled = 984937
ic_fluent_comment_quote_24_filled = 984938
ic_fluent_comment_quote_28_filled = 984939
ic_fluent_comment_text_16_filled = 984940
ic_fluent_comment_text_20_filled = 984941
ic_fluent_comment_text_24_filled = 984942
ic_fluent_comment_text_28_filled = 984943
ic_fluent_comment_text_32_filled = 984944
ic_fluent_comment_text_48_filled = 984945
ic_fluent_glance_16_filled = 984946
ic_fluent_glance_28_filled = 984947
ic_fluent_glance_32_filled = 984948
ic_fluent_glance_48_filled = 984949
ic_fluent_glance_horizontal_28_filled = 984950
ic_fluent_glance_horizontal_48_filled = 984951
ic_fluent_megaphone_12_filled = 984952
ic_fluent_mic_link_16_filled = 984953
ic_fluent_mic_link_20_filled = 984954
ic_fluent_mic_link_24_filled = 984955
ic_fluent_mic_link_28_filled = 984956
ic_fluent_mic_link_32_filled = 984957
ic_fluent_mic_link_48_filled = 984958
ic_fluent_pen_sync_16_filled = 984959
ic_fluent_pen_sync_20_filled = 984960
ic_fluent_pen_sync_24_filled = 984961
ic_fluent_pen_sync_28_filled = 984962
ic_fluent_pen_sync_32_filled = 984963
ic_fluent_pen_sync_48_filled = 984964
ic_fluent_people_link_16_filled = 984965
ic_fluent_people_link_20_filled = 984966
ic_fluent_people_link_24_filled = 984967
ic_fluent_people_link_28_filled = 984968
ic_fluent_people_link_32_filled = 984969
ic_fluent_people_link_48_filled = 984970
ic_fluent_people_queue_28_filled = 984971
ic_fluent_people_queue_32_filled = 984972
ic_fluent_people_queue_48_filled = 984973
ic_fluent_person_head_hint_16_filled = 984974
ic_fluent_person_head_hint_20_filled = 984975
ic_fluent_person_head_hint_24_filled = 984976
ic_fluent_person_sound_spatial_16_filled = 984977
ic_fluent_person_sound_spatial_20_filled = 984978
ic_fluent_person_sound_spatial_24_filled = 984979
ic_fluent_person_sound_spatial_28_filled = 984980
ic_fluent_person_sound_spatial_32_filled = 984981
ic_fluent_person_sound_spatial_48_filled = 984982
ic_fluent_sound_wave_circle_16_filled = 984983
ic_fluent_sound_wave_circle_28_filled = 984984
ic_fluent_sound_wave_circle_32_filled = 984985
ic_fluent_sound_wave_circle_48_filled = 984986
ic_fluent_sound_wave_circle_sparkle_16_filled = 984987
ic_fluent_sound_wave_circle_sparkle_20_filled = 984988
ic_fluent_sound_wave_circle_sparkle_24_filled = 984989
ic_fluent_sound_wave_circle_sparkle_28_filled = 984990
ic_fluent_sound_wave_circle_sparkle_32_filled = 984991
ic_fluent_sound_wave_circle_sparkle_48_filled = 984992
ic_fluent_arrow_down_right_16_filled = 984993
ic_fluent_arrow_down_right_20_filled = 984994
ic_fluent_arrow_down_right_24_filled = 984995
ic_fluent_arrow_down_right_32_filled = 984996
ic_fluent_arrow_down_right_48_filled = 984997
ic_fluent_arrow_repeat_all_28_filled = 984998
ic_fluent_arrow_repeat_all_48_filled = 984999
ic_fluent_attach_28_filled = 985000
ic_fluent_attach_48_filled = 985001
ic_fluent_calendar_mention_16_filled = 985002
ic_fluent_calendar_person_32_filled = 985003
ic_fluent_comment_multiple_mention_16_filled = 985004
ic_fluent_comment_multiple_mention_20_filled = 985005
ic_fluent_document_text_28_filled = 985006
ic_fluent_document_text_32_filled = 985007
ic_fluent_document_text_48_filled = 985008
ic_fluent_equal_circle_16_filled = 985009
ic_fluent_folder_document_16_filled = 985010
ic_fluent_folder_document_20_filled = 985011
ic_fluent_folder_document_24_filled = 985012
ic_fluent_folder_document_28_filled = 985013
ic_fluent_mail_inbox_32_filled = 985014
ic_fluent_mail_inbox_person_16_filled = 985015
ic_fluent_mail_inbox_person_20_filled = 985016
ic_fluent_mail_inbox_person_32_filled = 985017
ic_fluent_plug_connected_28_filled = 985018
ic_fluent_plug_connected_32_filled = 985019
ic_fluent_plug_connected_48_filled = 985020
ic_fluent_arrow_bounce_12_filled = 985021
ic_fluent_arrow_bounce_28_filled = 985022
ic_fluent_arrow_bounce_48_filled = 985023
ic_fluent_arrow_down_left_12_filled = 985024
ic_fluent_arrow_down_left_28_filled = 985025
ic_fluent_arrow_flow_diagonal_up_right_12_filled = 985026
ic_fluent_arrow_flow_diagonal_up_right_28_filled = 985027
ic_fluent_arrow_flow_diagonal_up_right_48_filled = 985028
ic_fluent_arrow_up_right_12_filled = 985029
ic_fluent_arrow_up_right_28_filled = 985030
ic_fluent_arrow_up_right_dashes_12_filled = 985031
ic_fluent_arrow_up_right_dashes_20_filled = 985032
ic_fluent_arrow_up_right_dashes_24_filled = 985033
ic_fluent_arrow_up_right_dashes_28_filled = 985034
ic_fluent_arrow_up_right_dashes_32_filled = 985035
ic_fluent_arrow_up_right_dashes_48_filled = 985036
ic_fluent_arrow_wrap_32_filled = 985037
ic_fluent_arrow_wrap_up_to_down_20_filled = 985038
ic_fluent_arrow_wrap_up_to_down_32_filled = 985039
ic_fluent_coin_multiple_16_filled = 985040
ic_fluent_coin_multiple_20_filled = 985041
ic_fluent_coin_multiple_24_filled = 985042
ic_fluent_comment_badge_16_filled = 985043
ic_fluent_comment_badge_20_filled = 985044
ic_fluent_comment_badge_24_filled = 985045
ic_fluent_data_usage_28_filled = 985046
ic_fluent_data_usage_32_filled = 985047
ic_fluent_data_usage_48_filled = 985048
ic_fluent_data_usage_checkmark_16_filled = 985049
ic_fluent_data_usage_checkmark_20_filled = 985050
ic_fluent_data_usage_checkmark_24_filled = 985051
ic_fluent_data_usage_checkmark_28_filled = 985052
ic_fluent_data_usage_checkmark_32_filled = 985053
ic_fluent_data_usage_checkmark_48_filled = 985054
ic_fluent_line_horizontal_1_dash_dot_dash_20_filled = 985055
ic_fluent_line_horizontal_1_dot_20_filled = 985056
ic_fluent_line_horizontal_3_16_filled = 985057
ic_fluent_line_horizontal_3_24_filled = 985058
ic_fluent_line_horizontal_3_28_filled = 985059
ic_fluent_line_horizontal_3_32_filled = 985060
ic_fluent_line_horizontal_3_48_filled = 985061
ic_fluent_navigation_28_filled = 985062
ic_fluent_navigation_32_filled = 985063
ic_fluent_navigation_48_filled = 985064
ic_fluent_pause_circle_16_filled = 985065
ic_fluent_stack_28_filled = 985066
ic_fluent_stack_48_filled = 985067
ic_fluent_stack_off_16_filled = 985068
ic_fluent_stack_off_20_filled = 985069
ic_fluent_stack_off_24_filled = 985070
ic_fluent_stack_off_28_filled = 985071
ic_fluent_stack_off_32_filled = 985072
ic_fluent_stack_off_48_filled = 985073
ic_fluent_text_bullet_list_square_28_filled = 985074
ic_fluent_textbox_28_filled = 985075
ic_fluent_textbox_32_filled = 985076
ic_fluent_textbox_48_filled = 985077
ic_fluent_textbox_checkmark_16_filled = 985078
ic_fluent_textbox_checkmark_20_filled = 985079
ic_fluent_textbox_checkmark_24_filled = 985080
ic_fluent_textbox_checkmark_28_filled = 985081
ic_fluent_textbox_checkmark_32_filled = 985082
ic_fluent_textbox_checkmark_48_filled = 985083
ic_fluent_document_one_page_multiple_sparkle_16_filled = 985084
ic_fluent_document_one_page_multiple_sparkle_20_filled = 985085
ic_fluent_document_one_page_multiple_sparkle_24_filled = 985086
ic_fluent_animal_paw_print_16_filled = 985087
ic_fluent_animal_paw_print_20_filled = 985088
ic_fluent_animal_paw_print_24_filled = 985089
ic_fluent_animal_paw_print_28_filled = 985090
ic_fluent_animal_paw_print_32_filled = 985091
ic_fluent_animal_paw_print_48_filled = 985092
ic_fluent_arrow_clockwise_dashes_28_filled = 985093
ic_fluent_arrow_clockwise_dashes_48_filled = 985094
ic_fluent_arrow_clockwise_dashes_settings_16_filled = 985095
ic_fluent_arrow_clockwise_dashes_settings_20_filled = 985096
ic_fluent_arrow_clockwise_dashes_settings_24_filled = 985097
ic_fluent_arrow_clockwise_dashes_settings_28_filled = 985098
ic_fluent_arrow_clockwise_dashes_settings_32_filled = 985099
ic_fluent_arrow_clockwise_dashes_settings_48_filled = 985100
ic_fluent_chat_off_16_filled = 985101
ic_fluent_connected_24_filled = 985102
ic_fluent_connected_32_filled = 985103
ic_fluent_square_text_arrow_repeat_all_16_filled = 985104
ic_fluent_square_text_arrow_repeat_all_20_filled = 985105
ic_fluent_square_text_arrow_repeat_all_24_filled = 985106
ic_fluent_translate_32_filled = 985107
ic_fluent_brain_20_filled = 985108
ic_fluent_brain_24_filled = 985109
ic_fluent_brain_sparkle_20_filled = 985110
ic_fluent_circle_hint_28_filled = 985111
ic_fluent_circle_hint_32_filled = 985112
ic_fluent_circle_hint_48_filled = 985113
ic_fluent_circle_hint_cursor_16_filled = 985114
ic_fluent_circle_hint_cursor_20_filled = 985115
ic_fluent_circle_hint_cursor_24_filled = 985116
ic_fluent_circle_hint_dismiss_16_filled = 985117
ic_fluent_circle_hint_dismiss_20_filled = 985118
ic_fluent_circle_hint_dismiss_24_filled = 985119
ic_fluent_circle_multiple_concentric_16_filled = 985120
ic_fluent_circle_multiple_concentric_20_filled = 985121
ic_fluent_circle_multiple_concentric_24_filled = 985122
ic_fluent_database_checkmark_16_filled = 985123
ic_fluent_database_checkmark_20_filled = 985124
ic_fluent_database_checkmark_24_filled = 985125
ic_fluent_directions_28_filled = 985126
ic_fluent_directions_32_filled = 985127
ic_fluent_directions_48_filled = 985128
ic_fluent_folder_open_28_filled = 985129
ic_fluent_folder_open_down_16_filled = 985130
ic_fluent_folder_open_down_20_filled = 985131
ic_fluent_folder_open_down_24_filled = 985132
ic_fluent_folder_open_down_28_filled = 985133
ic_fluent_hd_off_16_filled = 985134
ic_fluent_hd_off_20_filled = 985135
ic_fluent_hd_off_24_filled = 985136
ic_fluent_mail_inbox_48_filled = 985137
ic_fluent_mail_inbox_person_48_filled = 985138
ic_fluent_mail_read_briefcase_20_filled = 985139
ic_fluent_mail_read_briefcase_24_filled = 985140
ic_fluent_row_child_16_filled = 985141
ic_fluent_row_child_20_filled = 985142
ic_fluent_row_child_24_filled = 985143
ic_fluent_row_child_28_filled = 985144
ic_fluent_row_child_32_filled = 985145
ic_fluent_bot_16_filled = 985146
ic_fluent_bot_28_filled = 985147
ic_fluent_bot_32_filled = 985148
ic_fluent_bot_48_filled = 985149
ic_fluent_bot_add_16_filled = 985150
ic_fluent_bot_add_28_filled = 985151
ic_fluent_bot_add_32_filled = 985152
ic_fluent_bot_add_48_filled = 985153
ic_fluent_bot_sparkle_16_filled = 985154
ic_fluent_bot_sparkle_28_filled = 985155
ic_fluent_bot_sparkle_32_filled = 985156
ic_fluent_bot_sparkle_48_filled = 985157
ic_fluent_chat_history_20_filled = 985158
ic_fluent_chat_history_24_filled = 985159
ic_fluent_chat_history_28_filled = 985160
ic_fluent_circle_multiple_hint_checkmark_20_filled = 985161
ic_fluent_circle_multiple_hint_checkmark_24_filled = 985162
ic_fluent_circle_multiple_hint_checkmark_28_filled = 985163
ic_fluent_circle_sparkle_16_filled = 985164
ic_fluent_circle_sparkle_20_filled = 985165
ic_fluent_circle_sparkle_24_filled = 985166
ic_fluent_circle_sparkle_28_filled = 985167
ic_fluent_circle_sparkle_32_filled = 985168
ic_fluent_circle_sparkle_48_filled = 985169
ic_fluent_copy_28_filled = 985170
ic_fluent_document_sparkle_16_filled = 985171
ic_fluent_document_sparkle_20_filled = 985172
ic_fluent_document_sparkle_24_filled = 985173
ic_fluent_document_sparkle_28_filled = 985174
ic_fluent_document_sparkle_32_filled = 985175
ic_fluent_document_sparkle_48_filled = 985176
ic_fluent_home_empty_20_filled = 985177
ic_fluent_home_empty_24_filled = 985178
ic_fluent_home_empty_28_filled = 985179
ic_fluent_paint_bucket_brush_16_filled = 985180
ic_fluent_paint_bucket_brush_20_filled = 985181
ic_fluent_paint_bucket_brush_24_filled = 985182
ic_fluent_paint_bucket_brush_28_filled = 985183
ic_fluent_re_order_vertical_16_filled = 985184
ic_fluent_re_order_vertical_20_filled = 985185
ic_fluent_re_order_vertical_24_filled = 985186
ic_fluent_savings_32_filled = 985187
ic_fluent_share_screen_start_16_filled = 985188
ic_fluent_weather_moon_32_filled = 985189
ic_fluent_location_checkmark_12_filled = 985190
ic_fluent_location_checkmark_16_filled = 985191
ic_fluent_location_checkmark_20_filled = 985192
ic_fluent_location_checkmark_24_filled = 985193
ic_fluent_location_checkmark_48_filled = 985194
ic_fluent_agents_16_filled = 985195
ic_fluent_agents_20_filled = 985196
ic_fluent_agents_24_filled = 985197
ic_fluent_agents_28_filled = 985198
ic_fluent_agents_32_filled = 985199
ic_fluent_agents_48_filled = 985200
ic_fluent_alert_badge_32_filled = 985201
ic_fluent_apps_add_in_32_filled = 985202
ic_fluent_apps_add_in_48_filled = 985203
ic_fluent_apps_add_in_off_16_filled = 985204
ic_fluent_apps_add_in_off_20_filled = 985205
ic_fluent_apps_add_in_off_24_filled = 985206
ic_fluent_apps_add_in_off_28_filled = 985207
ic_fluent_apps_add_in_off_32_filled = 985208
ic_fluent_apps_add_in_off_48_filled = 985209
ic_fluent_apps_list_32_filled = 985210
ic_fluent_apps_list_detail_32_filled = 985211
ic_fluent_arrow_circle_up_sparkle_20_filled = 985212
ic_fluent_arrow_circle_up_sparkle_24_filled = 985213
ic_fluent_arrow_counterclockwise_info_20_filled = 985214
ic_fluent_arrow_counterclockwise_info_24_filled = 985215
ic_fluent_arrow_counterclockwise_info_28_filled = 985216
ic_fluent_arrow_counterclockwise_info_32_filled = 985217
ic_fluent_arrow_counterclockwise_info_48_filled = 985218
ic_fluent_arrow_square_32_filled = 985219
ic_fluent_arrow_square_down_32_filled = 985220
ic_fluent_branch_request_closed_16_filled = 985221
ic_fluent_branch_request_closed_20_filled = 985222
ic_fluent_branch_request_draft_16_filled = 985223
ic_fluent_branch_request_draft_20_filled = 985224
ic_fluent_building_home_32_filled = 985225
ic_fluent_calendar_clock_32_filled = 985226
ic_fluent_call_rectangle_landscape_16_filled = 985227
ic_fluent_call_rectangle_landscape_20_filled = 985228
ic_fluent_call_rectangle_landscape_24_filled = 985229
ic_fluent_call_rectangle_landscape_28_filled = 985230
ic_fluent_call_square_16_filled = 985231
ic_fluent_call_square_20_filled = 985232
ic_fluent_call_square_24_filled = 985233
ic_fluent_call_square_28_filled = 985234
ic_fluent_chart_multiple_32_filled = 985235
ic_fluent_chat_multiple_checkmark_16_filled = 985236
ic_fluent_chat_multiple_checkmark_20_filled = 985237
ic_fluent_chat_multiple_checkmark_24_filled = 985238
ic_fluent_chat_multiple_checkmark_28_filled = 985239
ic_fluent_chat_multiple_minus_16_filled = 985240
ic_fluent_chat_multiple_minus_20_filled = 985241
ic_fluent_chat_multiple_minus_24_filled = 985242
ic_fluent_chat_multiple_minus_28_filled = 985243
ic_fluent_circle_multiple_hint_checkmark_16_filled = 985244
ic_fluent_circle_multiple_hint_checkmark_32_filled = 985245
ic_fluent_clock_sparkle_16_filled = 985246
ic_fluent_clock_sparkle_20_filled = 985247
ic_fluent_clock_sparkle_24_filled = 985248
ic_fluent_clock_sparkle_32_filled = 985249
ic_fluent_code_block_edit_16_filled = 985250
ic_fluent_code_block_edit_20_filled = 985251
ic_fluent_code_block_edit_24_filled = 985252
ic_fluent_collections_empty_16_filled = 985253
ic_fluent_collections_empty_20_filled = 985254
ic_fluent_collections_empty_24_filled = 985255
ic_fluent_crown_subtract_20_filled = 985256
ic_fluent_cube_28_filled = 985257
ic_fluent_cube_checkmark_16_filled = 985258
ic_fluent_cube_checkmark_20_filled = 985259
ic_fluent_cube_checkmark_24_filled = 985260
ic_fluent_cube_checkmark_28_filled = 985261
ic_fluent_cube_checkmark_32_filled = 985262
ic_fluent_cube_checkmark_48_filled = 985263
ic_fluent_data_area_32_filled = 985264
ic_fluent_data_line_32_filled = 985265
ic_fluent_data_pie_32_filled = 985266
ic_fluent_data_scatter_32_filled = 985267
ic_fluent_data_usage_sparkle_20_filled = 985268
ic_fluent_data_usage_sparkle_24_filled = 985269
ic_fluent_database_arrow_right_16_filled = 985270
ic_fluent_database_switch_24_filled = 985271
ic_fluent_desk_multiple_20_filled = 985272
ic_fluent_desk_multiple_24_filled = 985273
ic_fluent_desktop_48_filled = 985274
ic_fluent_desktop_arrow_down_28_filled = 985275
ic_fluent_desktop_arrow_down_48_filled = 985276
ic_fluent_desktop_arrow_down_off_20_filled = 985277
ic_fluent_desktop_arrow_down_off_24_filled = 985278
ic_fluent_desktop_arrow_down_off_28_filled = 985279
ic_fluent_desktop_arrow_down_off_32_filled = 985280
ic_fluent_desktop_arrow_down_off_48_filled = 985281
ic_fluent_diamond_dismiss_16_filled = 985282
ic_fluent_diamond_dismiss_20_filled = 985283
ic_fluent_diamond_dismiss_24_filled = 985284
ic_fluent_diamond_dismiss_28_filled = 985285
ic_fluent_diamond_dismiss_32_filled = 985286
ic_fluent_diamond_dismiss_48_filled = 985287
ic_fluent_document_arrow_right_16_filled = 985288
ic_fluent_edit_person_16_filled = 985289
ic_fluent_flow_sparkle_16_filled = 985290
ic_fluent_flow_sparkle_20_filled = 985291
ic_fluent_hand_multiple_16_filled = 985292
ic_fluent_hand_multiple_20_filled = 985293
ic_fluent_hand_multiple_24_filled = 985294
ic_fluent_hand_multiple_28_filled = 985295
ic_fluent_image_add_28_filled = 985296
ic_fluent_image_add_32_filled = 985297
ic_fluent_image_add_48_filled = 985298
ic_fluent_info_sparkle_16_filled = 985299
ic_fluent_info_sparkle_20_filled = 985300
ic_fluent_info_sparkle_24_filled = 985301
ic_fluent_info_sparkle_28_filled = 985302
ic_fluent_info_sparkle_32_filled = 985303
ic_fluent_info_sparkle_48_filled = 985304
ic_fluent_lightbulb_checkmark_24_filled = 985305
ic_fluent_lightbulb_checkmark_32_filled = 985306
ic_fluent_list_bar_24_filled = 985307
ic_fluent_list_bar_32_filled = 985308
ic_fluent_location_settings_20_filled = 985309
ic_fluent_location_settings_24_filled = 985310
ic_fluent_location_settings_28_filled = 985311
ic_fluent_location_settings_48_filled = 985312
ic_fluent_lock_closed_ribbon_16_filled = 985313
ic_fluent_lock_closed_ribbon_20_filled = 985314
ic_fluent_lock_closed_ribbon_24_filled = 985315
ic_fluent_lock_closed_ribbon_28_filled = 985316
ic_fluent_lock_closed_ribbon_32_filled = 985317
ic_fluent_lock_closed_ribbon_48_filled = 985318
ic_fluent_mail_clock_32_filled = 985319
ic_fluent_mail_data_bar_16_filled = 985320
ic_fluent_mail_data_bar_20_filled = 985321
ic_fluent_mail_data_bar_24_filled = 985322
ic_fluent_mail_fish_hook_16_filled = 985323
ic_fluent_mail_fish_hook_20_filled = 985324
ic_fluent_mail_fish_hook_24_filled = 985325
ic_fluent_mail_fish_hook_28_filled = 985326
ic_fluent_mail_fish_hook_32_filled = 985327
ic_fluent_mail_fish_hook_48_filled = 985328
ic_fluent_mobile_optimized_28_filled = 985329
ic_fluent_mobile_optimized_32_filled = 985330
ic_fluent_mobile_optimized_48_filled = 985331
ic_fluent_navigation_briefcase_20_filled = 985332
ic_fluent_navigation_briefcase_24_filled = 985333
ic_fluent_navigation_briefcase_28_filled = 985334
ic_fluent_navigation_person_20_filled = 985335
ic_fluent_navigation_person_24_filled = 985336
ic_fluent_navigation_person_28_filled = 985337
ic_fluent_number_symbol_square_32_filled = 985338
ic_fluent_people_sync_24_filled = 985339
ic_fluent_people_sync_32_filled = 985340
ic_fluent_person_edit_16_filled = 985341
ic_fluent_person_heart_32_filled = 985342
ic_fluent_person_key_24_filled = 985343
ic_fluent_person_key_32_filled = 985344
ic_fluent_person_starburst_16_filled = 985345
ic_fluent_person_starburst_28_filled = 985346
ic_fluent_person_starburst_32_filled = 985347
ic_fluent_person_starburst_48_filled = 985348
ic_fluent_person_tentative_32_filled = 985349
ic_fluent_play_circle_hint_half_20_filled = 985350
ic_fluent_play_circle_hint_half_24_filled = 985351
ic_fluent_ribbon_star_32_filled = 985352
ic_fluent_send_clock_32_filled = 985353
ic_fluent_shield_arrow_right_16_filled = 985354
ic_fluent_shield_arrow_right_20_filled = 985355
ic_fluent_shield_arrow_right_24_filled = 985356
ic_fluent_shield_arrow_right_28_filled = 985357
ic_fluent_shield_arrow_right_32_filled = 985358
ic_fluent_shield_arrow_right_48_filled = 985359
ic_fluent_shopping_bag_checkmark_16_filled = 985360
ic_fluent_shopping_bag_checkmark_20_filled = 985361
ic_fluent_shopping_bag_checkmark_24_filled = 985362
ic_fluent_shopping_bag_checkmark_28_filled = 985363
ic_fluent_shopping_bag_checkmark_32_filled = 985364
ic_fluent_shopping_bag_checkmark_48_filled = 985365
ic_fluent_skip_back_15_20_filled = 985366
ic_fluent_skip_back_15_24_filled = 985367
ic_fluent_skip_forward_15_20_filled = 985368
ic_fluent_skip_forward_15_24_filled = 985369
ic_fluent_sparkle_info_20_filled = 985370
ic_fluent_sparkle_info_24_filled = 985371
ic_fluent_square_text_arrow_repeat_all_32_filled = 985372
ic_fluent_star_settings_32_filled = 985373
ic_fluent_table_alt_text_20_filled = 985374
ic_fluent_table_alt_text_24_filled = 985375
ic_fluent_table_alt_text_32_filled = 985376
ic_fluent_table_cell_add_16_filled = 985377
ic_fluent_table_cell_add_20_filled = 985378
ic_fluent_table_cell_add_24_filled = 985379
ic_fluent_table_column_top_bottom_16_filled = 985380
ic_fluent_table_column_top_bottom_28_filled = 985381
ic_fluent_table_column_top_bottom_edit_16_filled = 985382
ic_fluent_table_column_top_bottom_edit_20_filled = 985383
ic_fluent_table_column_top_bottom_edit_24_filled = 985384
ic_fluent_table_column_top_bottom_edit_28_filled = 985385
ic_fluent_task_list_square_database_24_filled = 985386
ic_fluent_temperature_degree_celsius_16_filled = 985387
ic_fluent_temperature_degree_celsius_20_filled = 985388
ic_fluent_temperature_degree_celsius_24_filled = 985389
ic_fluent_temperature_degree_celsius_28_filled = 985390
ic_fluent_temperature_degree_celsius_32_filled = 985391
ic_fluent_temperature_degree_celsius_48_filled = 985392
ic_fluent_temperature_degree_fahrenheit_16_filled = 985393
ic_fluent_temperature_degree_fahrenheit_20_filled = 985394
ic_fluent_temperature_degree_fahrenheit_24_filled = 985395
ic_fluent_temperature_degree_fahrenheit_28_filled = 985396
ic_fluent_temperature_degree_fahrenheit_32_filled = 985397
ic_fluent_temperature_degree_fahrenheit_48_filled = 985398
ic_fluent_text_bullet_list_square_sparkle_32_filled = 985399
ic_fluent_text_list_abc_lowercase_ltr_20_filled = 985400
ic_fluent_text_list_abc_lowercase_ltr_24_filled = 985401
ic_fluent_text_list_abc_uppercase_ltr_20_filled = 985402
ic_fluent_text_list_abc_uppercase_ltr_24_filled = 985403
ic_fluent_text_list_roman_numeral_lowercase_20_filled = 985404
ic_fluent_text_list_roman_numeral_lowercase_24_filled = 985405
ic_fluent_text_list_roman_numeral_uppercase_20_filled = 985406
ic_fluent_text_list_roman_numeral_uppercase_24_filled = 985407
ic_fluent_text_paragraph_direction_left_24_filled = 985408
ic_fluent_text_paragraph_direction_right_24_filled = 985409
ic_fluent_vehicle_truck_checkmark_16_filled = 985410
ic_fluent_vehicle_truck_checkmark_20_filled = 985411
ic_fluent_vehicle_truck_checkmark_24_filled = 985412
ic_fluent_vehicle_truck_checkmark_28_filled = 985413
ic_fluent_vehicle_truck_checkmark_32_filled = 985414
ic_fluent_vehicle_truck_checkmark_48_filled = 985415
ic_fluent_vehicle_truck_profile_28_filled = 985416
ic_fluent_vehicle_truck_profile_32_filled = 985417
ic_fluent_vehicle_truck_profile_48_filled = 985418
ic_fluent_video_multiple_16_filled = 985419
ic_fluent_video_multiple_20_filled = 985420
ic_fluent_video_multiple_24_filled = 985421
ic_fluent_video_multiple_28_filled = 985422
ic_fluent_video_multiple_32_filled = 985423
ic_fluent_video_multiple_48_filled = 985424
ic_fluent_video_settings_16_filled = 985425
ic_fluent_video_settings_20_filled = 985426
ic_fluent_video_settings_24_filled = 985427
ic_fluent_video_settings_28_filled = 985428
ic_fluent_video_settings_32_filled = 985429
ic_fluent_video_settings_48_filled = 985430
ic_fluent_vote_16_filled = 985431
ic_fluent_window_text_16_filled = 985432
ic_fluent_window_text_24_filled = 985433
ic_fluent_window_text_28_filled = 985434
ic_fluent_add_starburst_16_filled = 985435
ic_fluent_add_starburst_20_filled = 985436
ic_fluent_add_starburst_24_filled = 985437
ic_fluent_add_starburst_28_filled = 985438
ic_fluent_add_starburst_32_filled = 985439
ic_fluent_add_starburst_48_filled = 985440
ic_fluent_arrow_exit_12_filled = 985441
ic_fluent_arrow_exit_16_filled = 985442
ic_fluent_arrow_exit_24_filled = 985443
ic_fluent_arrow_exit_28_filled = 985444
ic_fluent_arrow_exit_32_filled = 985445
ic_fluent_arrow_exit_48_filled = 985446
ic_fluent_box_28_filled = 985447
ic_fluent_box_32_filled = 985448
ic_fluent_box_48_filled = 985449
ic_fluent_box_checkmark_16_filled = 985450
ic_fluent_box_checkmark_28_filled = 985451
ic_fluent_box_checkmark_32_filled = 985452
ic_fluent_box_checkmark_48_filled = 985453
ic_fluent_data_line_16_filled = 985454
ic_fluent_flash_play_32_filled = 985455
ic_fluent_planet_16_filled = 985457
ic_fluent_planet_20_filled = 985458
ic_fluent_planet_24_filled = 985459
ic_fluent_planet_32_filled = 985460
ic_fluent_rectangle_portrait_12_filled = 985461
ic_fluent_rectangle_portrait_16_filled = 985462
ic_fluent_rectangle_portrait_20_filled = 985463
ic_fluent_rectangle_portrait_24_filled = 985464
ic_fluent_rectangle_portrait_28_filled = 985465
ic_fluent_rectangle_portrait_32_filled = 985466
ic_fluent_rectangle_portrait_48_filled = 985467
ic_fluent_slide_text_title_16_filled = 985468
ic_fluent_slide_text_title_20_filled = 985469
ic_fluent_slide_text_title_24_filled = 985470
ic_fluent_slide_text_title_add_16_filled = 985471
ic_fluent_slide_text_title_add_20_filled = 985472
ic_fluent_slide_text_title_add_24_filled = 985473
ic_fluent_slide_text_title_checkmark_16_filled = 985474
ic_fluent_slide_text_title_checkmark_20_filled = 985475
ic_fluent_slide_text_title_checkmark_24_filled = 985476
ic_fluent_slide_text_title_edit_16_filled = 985477
ic_fluent_slide_text_title_edit_20_filled = 985478
ic_fluent_slide_text_title_edit_24_filled = 985479
ic_fluent_table_arrow_repeat_all_20_filled = 985480
ic_fluent_table_arrow_repeat_all_24_filled = 985481
ic_fluent_table_arrow_repeat_all_28_filled = 985482
ic_fluent_table_cell_center_16_filled = 985483
ic_fluent_table_cell_center_20_filled = 985484
ic_fluent_table_cell_center_24_filled = 985485
ic_fluent_table_cell_center_28_filled = 985486
ic_fluent_table_cell_center_arrow_repeat_all_20_filled = 985487
ic_fluent_table_cell_center_arrow_repeat_all_24_filled = 985488
ic_fluent_table_cell_center_arrow_repeat_all_28_filled = 985489
ic_fluent_table_cell_center_edit_16_filled = 985490
ic_fluent_table_cell_center_edit_20_filled = 985491
ic_fluent_table_cell_center_edit_24_filled = 985492
ic_fluent_table_cell_center_edit_28_filled = 985493
ic_fluent_table_cell_center_link_20_filled = 985494
ic_fluent_table_cell_center_link_24_filled = 985495
ic_fluent_table_cell_center_link_28_filled = 985496
ic_fluent_table_cell_center_search_20_filled = 985497
ic_fluent_table_cell_center_search_24_filled = 985498
ic_fluent_table_cell_center_search_28_filled = 985499
ic_fluent_table_column_top_bottom_arrow_repeat_all_20_filled = 985500
ic_fluent_table_column_top_bottom_arrow_repeat_all_24_filled = 985501
ic_fluent_table_column_top_bottom_arrow_repeat_all_28_filled = 985502
ic_fluent_table_column_top_bottom_link_20_filled = 985503
ic_fluent_table_column_top_bottom_link_24_filled = 985504
ic_fluent_table_column_top_bottom_link_28_filled = 985505
ic_fluent_table_column_top_bottom_search_20_filled = 985506
ic_fluent_table_column_top_bottom_search_24_filled = 985507
ic_fluent_table_column_top_bottom_search_28_filled = 985508
ic_fluent_table_search_24_filled = 985509
ic_fluent_table_search_28_filled = 985510
ic_fluent_tag_48_filled = 985511
ic_fluent_tag_add_16_filled = 985512
ic_fluent_tag_add_20_filled = 985513
ic_fluent_tag_add_24_filled = 985514
ic_fluent_tag_add_28_filled = 985515
ic_fluent_tag_add_32_filled = 985516
ic_fluent_tag_add_48_filled = 985517
ic_fluent_tag_edit_16_filled = 985518
ic_fluent_tag_edit_20_filled = 985519
ic_fluent_tag_edit_24_filled = 985520
ic_fluent_tag_edit_28_filled = 985521
ic_fluent_tag_edit_32_filled = 985522
ic_fluent_tag_edit_48_filled = 985523
ic_fluent_tag_percent_16_filled = 985524
ic_fluent_tag_percent_20_filled = 985525
ic_fluent_tag_percent_24_filled = 985526
ic_fluent_tag_percent_28_filled = 985527
ic_fluent_tag_percent_32_filled = 985528
ic_fluent_tag_percent_48_filled = 985529
ic_fluent_text_percent_16_filled = 985530
ic_fluent_text_percent_20_filled = 985531
ic_fluent_text_percent_24_filled = 985532
ic_fluent_text_percent_28_filled = 985533
ic_fluent_text_percent_32_filled = 985534
ic_fluent_text_percent_48_filled = 985535
ic_fluent_circle_multiple_hint_checkmark_48_filled = 985456
ic_fluent_connected_28_filled = 985536
ic_fluent_connected_48_filled = 985537
ic_fluent_mail_template_28_filled = 985538
ic_fluent_mail_template_32_filled = 985539
ic_fluent_mail_template_48_filled = 985540
ic_fluent_people_chat_28_filled = 985541
ic_fluent_people_chat_32_filled = 985542
ic_fluent_people_chat_48_filled = 985543
ic_fluent_person_account_16_filled = 985544
ic_fluent_person_add_48_filled = 985545
ic_fluent_person_briefcase_16_filled = 985546
ic_fluent_person_briefcase_20_filled = 985547
ic_fluent_person_briefcase_24_filled = 985548
ic_fluent_person_error_16_filled = 985549
ic_fluent_person_error_20_filled = 985550
ic_fluent_person_error_24_filled = 985551
ic_fluent_person_heart_28_filled = 985552
ic_fluent_person_heart_48_filled = 985553
ic_fluent_share_ios_32_filled = 985554
ic_fluent_text_header_4_20_filled = 985555
ic_fluent_text_header_4_24_filled = 985556
ic_fluent_text_header_5_20_filled = 985557
ic_fluent_text_header_5_24_filled = 985558
ic_fluent_text_header_6_20_filled = 985559
ic_fluent_text_header_6_24_filled = 985560
ic_fluent_barcode_scanner_16_filled = 985561
ic_fluent_barcode_scanner_28_filled = 985562
ic_fluent_barcode_scanner_32_filled = 985563
ic_fluent_barcode_scanner_48_filled = 985564
ic_fluent_barcode_scanner_add_16_filled = 985565
ic_fluent_barcode_scanner_add_20_filled = 985566
ic_fluent_barcode_scanner_add_24_filled = 985567
ic_fluent_barcode_scanner_add_28_filled = 985568
ic_fluent_barcode_scanner_add_32_filled = 985569
ic_fluent_barcode_scanner_add_48_filled = 985570
ic_fluent_barcode_scanner_dismiss_16_filled = 985571
ic_fluent_barcode_scanner_dismiss_20_filled = 985572
ic_fluent_barcode_scanner_dismiss_24_filled = 985573
ic_fluent_barcode_scanner_dismiss_28_filled = 985574
ic_fluent_barcode_scanner_dismiss_32_filled = 985575
ic_fluent_barcode_scanner_dismiss_48_filled = 985576
ic_fluent_data_bar_vertical_edit_16_filled = 985577
ic_fluent_data_bar_vertical_edit_20_filled = 985578
ic_fluent_data_bar_vertical_edit_24_filled = 985579
ic_fluent_notepad_48_filled = 985580
ic_fluent_notepad_person_28_filled = 985581
ic_fluent_notepad_person_32_filled = 985582
ic_fluent_notepad_person_48_filled = 985583
ic_fluent_notepad_person_off_16_filled = 985584
ic_fluent_notepad_person_off_20_filled = 985585
ic_fluent_notepad_person_off_24_filled = 985586
ic_fluent_notepad_person_off_28_filled = 985587
ic_fluent_notepad_person_off_32_filled = 985588
ic_fluent_notepad_person_off_48_filled = 985589
ic_fluent_task_list_square_sparkle_16_filled = 985590
ic_fluent_task_list_square_sparkle_20_filled = 985591
ic_fluent_task_list_square_sparkle_24_filled = 985592
ic_fluent_text_proofing_tools_abc_16_filled = 985593
ic_fluent_text_proofing_tools_ga_na_da_16_filled = 985594
ic_fluent_text_proofing_tools_zi_16_filled = 985595
ic_fluent_tooltip_quote_16_filled = 985596
ic_fluent_tooltip_quote_28_filled = 985597
ic_fluent_tooltip_quote_32_filled = 985598
ic_fluent_tooltip_quote_48_filled = 985599
ic_fluent_tooltip_quote_off_16_filled = 985600
ic_fluent_tooltip_quote_off_20_filled = 985601
ic_fluent_tooltip_quote_off_24_filled = 985602
ic_fluent_tooltip_quote_off_28_filled = 985603
ic_fluent_tooltip_quote_off_32_filled = 985604
ic_fluent_tooltip_quote_off_48_filled = 985605
ic_fluent_broom_sparkle_20_filled = 985606
ic_fluent_math_formula_sparkle_20_filled = 985607
ic_fluent_projection_screen_text_sparkle_20_filled = 985608
ic_fluent_sparkle_action_20_filled = 985609
ic_fluent_arrow_circle_down_right_12_filled = 985610
ic_fluent_arrow_clockwise_dashes_12_filled = 985611
ic_fluent_book_open_lightbulb_20_filled = 985612
ic_fluent_book_open_lightbulb_24_filled = 985613
ic_fluent_book_open_lightbulb_32_filled = 985614
ic_fluent_broom_sparkle_16_filled = 985615
ic_fluent_building_multiple_16_filled = 985616
ic_fluent_diamond_dismiss_12_filled = 985617
ic_fluent_flow_sparkle_24_filled = 985618
ic_fluent_incognito_32_filled = 985619
ic_fluent_incognito_48_filled = 985620
ic_fluent_math_formula_sparkle_16_filled = 985621
ic_fluent_pause_circle_12_filled = 985622
ic_fluent_person_edit_32_filled = 985623
ic_fluent_projection_screen_text_16_filled = 985624
ic_fluent_projection_screen_text_sparkle_16_filled = 985625
ic_fluent_shield_settings_16_filled = 985626
ic_fluent_shield_settings_20_filled = 985627
ic_fluent_shield_settings_24_filled = 985628
ic_fluent_shield_settings_28_filled = 985629
ic_fluent_sparkle_action_16_filled = 985630
ic_fluent_text_header_4_lines_caret_16_filled = 985631
ic_fluent_text_header_4_lines_caret_20_filled = 985632
ic_fluent_text_header_4_lines_caret_24_filled = 985633
ic_fluent_arrow_hook_down_left_32_filled = 985634
ic_fluent_arrow_hook_down_right_32_filled = 985635
ic_fluent_arrow_hook_up_left_32_filled = 985636
ic_fluent_arrow_hook_up_right_32_filled = 985637
ic_fluent_auto_fit_height_28_filled = 985638
ic_fluent_auto_fit_height_32_filled = 985639
ic_fluent_auto_fit_width_28_filled = 985640
ic_fluent_auto_fit_width_32_filled = 985641
ic_fluent_book_contacts_16_filled = 985642
ic_fluent_book_contacts_48_filled = 985643
ic_fluent_brain_28_filled = 985644
ic_fluent_brain_32_filled = 985645
ic_fluent_brain_48_filled = 985646
ic_fluent_brain_circuit_28_filled = 985647
ic_fluent_brain_circuit_32_filled = 985648
ic_fluent_brain_circuit_48_filled = 985649
ic_fluent_breakout_room_16_filled = 985650
ic_fluent_cloud_desktop_24_filled = 985651
ic_fluent_cut_28_filled = 985652
ic_fluent_cut_32_filled = 985653
ic_fluent_cut_48_filled = 985654
ic_fluent_door_24_filled = 985655
ic_fluent_door_32_filled = 985656
ic_fluent_door_arrow_right_32_filled = 985657
ic_fluent_immersive_reader_32_filled = 985658
ic_fluent_immersive_reader_48_filled = 985659
ic_fluent_people_settings_32_filled = 985660
ic_fluent_share_32_filled = 985661
ic_fluent_skip_back_15_28_filled = 985662
ic_fluent_skip_back_15_32_filled = 985663
ic_fluent_skip_back_15_48_filled = 985664
ic_fluent_skip_forward_15_28_filled = 985665
ic_fluent_skip_forward_15_32_filled = 985666
ic_fluent_skip_forward_15_48_filled = 985667
ic_fluent_star_add_32_filled = 985668
ic_fluent_hexagon_sparkle_16_filled = 985669
ic_fluent_hexagon_sparkle_28_filled = 985670
ic_fluent_hexagon_sparkle_32_filled = 985671
ic_fluent_hexagon_sparkle_48_filled = 985672
ic_fluent_people_interwoven_16_filled = 985673
ic_fluent_people_interwoven_20_filled = 985674
ic_fluent_people_interwoven_24_filled = 985675
ic_fluent_people_interwoven_28_filled = 985676
ic_fluent_people_interwoven_32_filled = 985677
ic_fluent_people_interwoven_48_filled = 985678
ic_fluent_agents_add_20_filled = 985679
ic_fluent_agents_add_24_filled = 985680
ic_fluent_arrow_expand_28_filled = 985681
ic_fluent_calendar_day_32_filled = 985682
ic_fluent_calendar_work_week_32_filled = 985683
ic_fluent_desk_sparkle_20_filled = 985684
ic_fluent_desk_sparkle_24_filled = 985685
ic_fluent_mail_list_32_filled = 985686
ic_fluent_megaphone_loud_48_filled = 985687
ic_fluent_password_clock_16_filled = 985688
ic_fluent_password_clock_20_filled = 985689
ic_fluent_password_clock_24_filled = 985690
ic_fluent_person_shield_16_filled = 985691
ic_fluent_person_shield_20_filled = 985692
ic_fluent_person_shield_24_filled = 985693
ic_fluent_person_shield_28_filled = 985694
ic_fluent_person_shield_32_filled = 985695
ic_fluent_person_shield_48_filled = 985696
ic_fluent_picture_in_picture_28_filled = 985697
ic_fluent_picture_in_picture_32_filled = 985698
ic_fluent_shield_error_28_filled = 985699
ic_fluent_shield_error_32_filled = 985700
ic_fluent_shield_error_48_filled = 985701
ic_fluent_sticker_16_filled = 985702
ic_fluent_sticker_28_filled = 985703
ic_fluent_sticker_32_filled = 985704
ic_fluent_target_sparkle_16_filled = 985705
ic_fluent_target_sparkle_20_filled = 985706
ic_fluent_target_sparkle_24_filled = 985707
ic_fluent_text_expand_28_filled = 985708
ic_fluent_text_expand_32_filled = 985709
ic_fluent_zoom_in_32_filled = 985710
ic_fluent_zoom_out_32_filled = 985711
